<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Unirest\\' => array($vendorDir . '/mashape/unirest-php/src'),
    'Milon\\Barcode' => array($vendorDir . '/milon/barcode/src'),
    'HTMLPurifier' => array($vendorDir . '/ezyang/htmlpurifier/library'),
);
