<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'AWS\\CRT\\Auth\\AwsCredentials' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/AwsCredentials.php',
    'AWS\\CRT\\Auth\\CredentialsProvider' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/CredentialsProvider.php',
    'AWS\\CRT\\Auth\\Signable' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/Signable.php',
    'AWS\\CRT\\Auth\\SignatureType' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/SignatureType.php',
    'AWS\\CRT\\Auth\\SignedBodyHeaderType' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/SignedBodyHeaderType.php',
    'AWS\\CRT\\Auth\\Signing' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/Signing.php',
    'AWS\\CRT\\Auth\\SigningAlgorithm' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/SigningAlgorithm.php',
    'AWS\\CRT\\Auth\\SigningConfigAWS' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/SigningConfigAWS.php',
    'AWS\\CRT\\Auth\\SigningResult' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/SigningResult.php',
    'AWS\\CRT\\Auth\\StaticCredentialsProvider' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Auth/StaticCredentialsProvider.php',
    'AWS\\CRT\\CRT' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/CRT.php',
    'AWS\\CRT\\HTTP\\Headers' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/HTTP/Headers.php',
    'AWS\\CRT\\HTTP\\Message' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/HTTP/Message.php',
    'AWS\\CRT\\HTTP\\Request' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/HTTP/Request.php',
    'AWS\\CRT\\HTTP\\Response' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/HTTP/Response.php',
    'AWS\\CRT\\IO\\EventLoopGroup' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/IO/EventLoopGroup.php',
    'AWS\\CRT\\IO\\InputStream' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/IO/InputStream.php',
    'AWS\\CRT\\Internal\\Encoding' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Internal/Encoding.php',
    'AWS\\CRT\\Internal\\Extension' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Internal/Extension.php',
    'AWS\\CRT\\Log' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Log.php',
    'AWS\\CRT\\NativeResource' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/NativeResource.php',
    'AWS\\CRT\\OptionValue' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Options.php',
    'AWS\\CRT\\Options' => $vendorDir . '/aws/aws-crt-php/src/AWS/CRT/Options.php',
    'Anand\\LaravelPaytmWallet\\Contracts\\Factory' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Contracts/Factory.php',
    'Anand\\LaravelPaytmWallet\\Contracts\\Provider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Contracts/Provider.php',
    'Anand\\LaravelPaytmWallet\\Facades\\PaytmWallet' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Facades/PaytmWallet.php',
    'Anand\\LaravelPaytmWallet\\PaytmWalletManager' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/PaytmWalletManager.php',
    'Anand\\LaravelPaytmWallet\\PaytmWalletServiceProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/PaytmWalletServiceProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\BalanceCheckProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/BalanceCheckProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\PaytmAppProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/PaytmAppProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\PaytmWalletProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/PaytmWalletProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\ReceivePaymentProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/ReceivePaymentProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\RefundPaymentProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/RefundPaymentProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\RefundStatusCheckProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/RefundStatusCheckProvider.php',
    'Anand\\LaravelPaytmWallet\\Providers\\StatusCheckProvider' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Providers/StatusCheckProvider.php',
    'Anand\\LaravelPaytmWallet\\Traits\\HasTransactionStatus' => $vendorDir . '/anandsiddharth/laravel-paytm-wallet/src/Traits/HasTransactionStatus.php',
    'Anhskohbo\\NoCaptcha\\Facades\\NoCaptcha' => $vendorDir . '/anhskohbo/no-captcha/src/Facades/NoCaptcha.php',
    'Anhskohbo\\NoCaptcha\\NoCaptcha' => $vendorDir . '/anhskohbo/no-captcha/src/NoCaptcha.php',
    'Anhskohbo\\NoCaptcha\\NoCaptchaServiceProvider' => $vendorDir . '/anhskohbo/no-captcha/src/NoCaptchaServiceProvider.php',
    'App\\Coingate\\Coingate' => $baseDir . '/app/Coingate/Coingate.php',
    'App\\Console\\Kernel' => $baseDir . '/app/Console/Kernel.php',
    'App\\Events\\VerifyReCaptchaToken' => $baseDir . '/app/Events/VerifyReCaptchaToken.php',
    'App\\Exceptions\\Handler' => $baseDir . '/app/Exceptions/Handler.php',
    'App\\Exports\\AssetsExport' => $baseDir . '/app/Exports/AssetsExport.php',
    'App\\Exports\\DepositExport' => $baseDir . '/app/Exports/DepositExport.php',
    'App\\Exports\\EmployeesExport' => $baseDir . '/app/Exports/EmployeesExport.php',
    'App\\Exports\\EventExport' => $baseDir . '/app/Exports/EventExport.php',
    'App\\Exports\\ExpenseExport' => $baseDir . '/app/Exports/ExpenseExport.php',
    'App\\Exports\\HolidayExport' => $baseDir . '/app/Exports/HolidayExport.php',
    'App\\Exports\\LeaveExport' => $baseDir . '/app/Exports/LeaveExport.php',
    'App\\Exports\\LeaveReportExport' => $baseDir . '/app/Exports/LeaveReportExport.php',
    'App\\Exports\\PayrollExport' => $baseDir . '/app/Exports/PayrollExport.php',
    'App\\Exports\\PayslipExport' => $baseDir . '/app/Exports/PayslipExport.php',
    'App\\Exports\\TimesheetExport' => $baseDir . '/app/Exports/TimesheetExport.php',
    'App\\Exports\\TimesheetReportExport' => $baseDir . '/app/Exports/TimesheetReportExport.php',
    'App\\Exports\\TrainerExport' => $baseDir . '/app/Exports/TrainerExport.php',
    'App\\Exports\\TrainingExport' => $baseDir . '/app/Exports/TrainingExport.php',
    'App\\Exports\\TransferBalanceExport' => $baseDir . '/app/Exports/TransferBalanceExport.php',
    'App\\Exports\\accountstatementExport' => $baseDir . '/app/Exports/accountstatementExport.php',
    'App\\Http\\Controllers\\AamarpayController' => $baseDir . '/app/Http/Controllers/AamarpayController.php',
    'App\\Http\\Controllers\\AccountListController' => $baseDir . '/app/Http/Controllers/AccountListController.php',
    'App\\Http\\Controllers\\AiTemplateController' => $baseDir . '/app/Http/Controllers/AiTemplateController.php',
    'App\\Http\\Controllers\\AllowanceController' => $baseDir . '/app/Http/Controllers/AllowanceController.php',
    'App\\Http\\Controllers\\AllowanceOptionController' => $baseDir . '/app/Http/Controllers/AllowanceOptionController.php',
    'App\\Http\\Controllers\\AnnouncementController' => $baseDir . '/app/Http/Controllers/AnnouncementController.php',
    'App\\Http\\Controllers\\AppraisalController' => $baseDir . '/app/Http/Controllers/AppraisalController.php',
    'App\\Http\\Controllers\\AssetController' => $baseDir . '/app/Http/Controllers/AssetController.php',
    'App\\Http\\Controllers\\AttendanceEmployeeController' => $baseDir . '/app/Http/Controllers/AttendanceEmployeeController.php',
    'App\\Http\\Controllers\\Auth\\AuthenticatedSessionController' => $baseDir . '/app/Http/Controllers/Auth/AuthenticatedSessionController.php',
    'App\\Http\\Controllers\\Auth\\ConfirmablePasswordController' => $baseDir . '/app/Http/Controllers/Auth/ConfirmablePasswordController.php',
    'App\\Http\\Controllers\\Auth\\EmailVerificationNotificationController' => $baseDir . '/app/Http/Controllers/Auth/EmailVerificationNotificationController.php',
    'App\\Http\\Controllers\\Auth\\EmailVerificationPromptController' => $baseDir . '/app/Http/Controllers/Auth/EmailVerificationPromptController.php',
    'App\\Http\\Controllers\\Auth\\NewPasswordController' => $baseDir . '/app/Http/Controllers/Auth/NewPasswordController.php',
    'App\\Http\\Controllers\\Auth\\PasswordResetLinkController' => $baseDir . '/app/Http/Controllers/Auth/PasswordResetLinkController.php',
    'App\\Http\\Controllers\\Auth\\RegisteredUserController' => $baseDir . '/app/Http/Controllers/Auth/RegisteredUserController.php',
    'App\\Http\\Controllers\\Auth\\VerifyEmailController' => $baseDir . '/app/Http/Controllers/Auth/VerifyEmailController.php',
    'App\\Http\\Controllers\\AuthorizeNetController' => $baseDir . '/app/Http/Controllers/AuthorizeNetController.php',
    'App\\Http\\Controllers\\AwardController' => $baseDir . '/app/Http/Controllers/AwardController.php',
    'App\\Http\\Controllers\\AwardTypeController' => $baseDir . '/app/Http/Controllers/AwardTypeController.php',
    'App\\Http\\Controllers\\BankTransferController' => $baseDir . '/app/Http/Controllers/BankTransferController.php',
    'App\\Http\\Controllers\\BenefitPaymentController' => $baseDir . '/app/Http/Controllers/BenefitPaymentController.php',
    'App\\Http\\Controllers\\BiometricAttendanceController' => $baseDir . '/app/Http/Controllers/BiometricAttendanceController.php',
    'App\\Http\\Controllers\\BranchController' => $baseDir . '/app/Http/Controllers/BranchController.php',
    'App\\Http\\Controllers\\CashfreeController' => $baseDir . '/app/Http/Controllers/CashfreeController.php',
    'App\\Http\\Controllers\\CinetPayController' => $baseDir . '/app/Http/Controllers/CinetPayController.php',
    'App\\Http\\Controllers\\CoingatePaymentController' => $baseDir . '/app/Http/Controllers/CoingatePaymentController.php',
    'App\\Http\\Controllers\\CommissionController' => $baseDir . '/app/Http/Controllers/CommissionController.php',
    'App\\Http\\Controllers\\CompanyPolicyController' => $baseDir . '/app/Http/Controllers/CompanyPolicyController.php',
    'App\\Http\\Controllers\\CompetenciesController' => $baseDir . '/app/Http/Controllers/CompetenciesController.php',
    'App\\Http\\Controllers\\ComplaintController' => $baseDir . '/app/Http/Controllers/ComplaintController.php',
    'App\\Http\\Controllers\\ContractController' => $baseDir . '/app/Http/Controllers/ContractController.php',
    'App\\Http\\Controllers\\ContractTypeController' => $baseDir . '/app/Http/Controllers/ContractTypeController.php',
    'App\\Http\\Controllers\\Controller' => $baseDir . '/app/Http/Controllers/Controller.php',
    'App\\Http\\Controllers\\CouponController' => $baseDir . '/app/Http/Controllers/CouponController.php',
    'App\\Http\\Controllers\\CustomQuestionController' => $baseDir . '/app/Http/Controllers/CustomQuestionController.php',
    'App\\Http\\Controllers\\DeductionOptionController' => $baseDir . '/app/Http/Controllers/DeductionOptionController.php',
    'App\\Http\\Controllers\\DepartmentController' => $baseDir . '/app/Http/Controllers/DepartmentController.php',
    'App\\Http\\Controllers\\DepositController' => $baseDir . '/app/Http/Controllers/DepositController.php',
    'App\\Http\\Controllers\\DesignationController' => $baseDir . '/app/Http/Controllers/DesignationController.php',
    'App\\Http\\Controllers\\DocumentController' => $baseDir . '/app/Http/Controllers/DocumentController.php',
    'App\\Http\\Controllers\\DucumentUploadController' => $baseDir . '/app/Http/Controllers/DucumentUploadController.php',
    'App\\Http\\Controllers\\EmailTemplateController' => $baseDir . '/app/Http/Controllers/EmailTemplateController.php',
    'App\\Http\\Controllers\\EmployeeController' => $baseDir . '/app/Http/Controllers/EmployeeController.php',
    'App\\Http\\Controllers\\EventController' => $baseDir . '/app/Http/Controllers/EventController.php',
    'App\\Http\\Controllers\\ExpenseController' => $baseDir . '/app/Http/Controllers/ExpenseController.php',
    'App\\Http\\Controllers\\ExpenseTypeController' => $baseDir . '/app/Http/Controllers/ExpenseTypeController.php',
    'App\\Http\\Controllers\\FedapayController' => $baseDir . '/app/Http/Controllers/FedapayController.php',
    'App\\Http\\Controllers\\FlutterwavePaymentController' => $baseDir . '/app/Http/Controllers/FlutterwavePaymentController.php',
    'App\\Http\\Controllers\\GoalTrackingController' => $baseDir . '/app/Http/Controllers/GoalTrackingController.php',
    'App\\Http\\Controllers\\GoalTypeController' => $baseDir . '/app/Http/Controllers/GoalTypeController.php',
    'App\\Http\\Controllers\\HolidayController' => $baseDir . '/app/Http/Controllers/HolidayController.php',
    'App\\Http\\Controllers\\HomeController' => $baseDir . '/app/Http/Controllers/HomeController.php',
    'App\\Http\\Controllers\\ImportController' => $baseDir . '/app/Http/Controllers/ImportController.php',
    'App\\Http\\Controllers\\IncomeTypeController' => $baseDir . '/app/Http/Controllers/IncomeTypeController.php',
    'App\\Http\\Controllers\\IndicatorController' => $baseDir . '/app/Http/Controllers/IndicatorController.php',
    'App\\Http\\Controllers\\InterviewScheduleController' => $baseDir . '/app/Http/Controllers/InterviewScheduleController.php',
    'App\\Http\\Controllers\\IyziPayController' => $baseDir . '/app/Http/Controllers/IyziPayController.php',
    'App\\Http\\Controllers\\JobApplicationController' => $baseDir . '/app/Http/Controllers/JobApplicationController.php',
    'App\\Http\\Controllers\\JobCategoryController' => $baseDir . '/app/Http/Controllers/JobCategoryController.php',
    'App\\Http\\Controllers\\JobController' => $baseDir . '/app/Http/Controllers/JobController.php',
    'App\\Http\\Controllers\\JobStageController' => $baseDir . '/app/Http/Controllers/JobStageController.php',
    'App\\Http\\Controllers\\KhaltiPaymentController' => $baseDir . '/app/Http/Controllers/KhaltiPaymentController.php',
    'App\\Http\\Controllers\\LandingPageSectionController' => $baseDir . '/app/Http/Controllers/LandingPageSectionController.php',
    'App\\Http\\Controllers\\LanguageController' => $baseDir . '/app/Http/Controllers/LanguageController.php',
    'App\\Http\\Controllers\\LeaveController' => $baseDir . '/app/Http/Controllers/LeaveController.php',
    'App\\Http\\Controllers\\LeaveTypeController' => $baseDir . '/app/Http/Controllers/LeaveTypeController.php',
    'App\\Http\\Controllers\\LoanController' => $baseDir . '/app/Http/Controllers/LoanController.php',
    'App\\Http\\Controllers\\LoanOptionController' => $baseDir . '/app/Http/Controllers/LoanOptionController.php',
    'App\\Http\\Controllers\\MeetingController' => $baseDir . '/app/Http/Controllers/MeetingController.php',
    'App\\Http\\Controllers\\MercadoPaymentController' => $baseDir . '/app/Http/Controllers/MercadoPaymentController.php',
    'App\\Http\\Controllers\\MidtransController' => $baseDir . '/app/Http/Controllers/MidtransController.php',
    'App\\Http\\Controllers\\MolliePaymentController' => $baseDir . '/app/Http/Controllers/MolliePaymentController.php',
    'App\\Http\\Controllers\\NepalstePaymnetController' => $baseDir . '/app/Http/Controllers/NepalstePaymnetController.php',
    'App\\Http\\Controllers\\NotificationTemplatesController' => $baseDir . '/app/Http/Controllers/NotificationTemplatesController.php',
    'App\\Http\\Controllers\\OtherPaymentController' => $baseDir . '/app/Http/Controllers/OtherPaymentController.php',
    'App\\Http\\Controllers\\OvertimeController' => $baseDir . '/app/Http/Controllers/OvertimeController.php',
    'App\\Http\\Controllers\\OzowController' => $baseDir . '/app/Http/Controllers/OzowController.php',
    'App\\Http\\Controllers\\PaiementProController' => $baseDir . '/app/Http/Controllers/PaiementProController.php',
    'App\\Http\\Controllers\\PayHereController' => $baseDir . '/app/Http/Controllers/PayHereController.php',
    'App\\Http\\Controllers\\PaySlipController' => $baseDir . '/app/Http/Controllers/PaySlipController.php',
    'App\\Http\\Controllers\\PayeesController' => $baseDir . '/app/Http/Controllers/PayeesController.php',
    'App\\Http\\Controllers\\PayerController' => $baseDir . '/app/Http/Controllers/PayerController.php',
    'App\\Http\\Controllers\\PayfastController' => $baseDir . '/app/Http/Controllers/PayfastController.php',
    'App\\Http\\Controllers\\PaymentTypeController' => $baseDir . '/app/Http/Controllers/PaymentTypeController.php',
    'App\\Http\\Controllers\\PaymentWallPaymentController' => $baseDir . '/app/Http/Controllers/PaymentWallPaymentController.php',
    'App\\Http\\Controllers\\PaypalController' => $baseDir . '/app/Http/Controllers/PaypalController.php',
    'App\\Http\\Controllers\\PayslipTypeController' => $baseDir . '/app/Http/Controllers/PayslipTypeController.php',
    'App\\Http\\Controllers\\PaystackPaymentController' => $baseDir . '/app/Http/Controllers/PaystackPaymentController.php',
    'App\\Http\\Controllers\\PaytabController' => $baseDir . '/app/Http/Controllers/PaytabController.php',
    'App\\Http\\Controllers\\PaytmPaymentController' => $baseDir . '/app/Http/Controllers/PaytmPaymentController.php',
    'App\\Http\\Controllers\\PaytrController' => $baseDir . '/app/Http/Controllers/PaytrController.php',
    'App\\Http\\Controllers\\PerformanceTypeController' => $baseDir . '/app/Http/Controllers/PerformanceTypeController.php',
    'App\\Http\\Controllers\\PermissionController' => $baseDir . '/app/Http/Controllers/PermissionController.php',
    'App\\Http\\Controllers\\PlanController' => $baseDir . '/app/Http/Controllers/PlanController.php',
    'App\\Http\\Controllers\\PlanRequestController' => $baseDir . '/app/Http/Controllers/PlanRequestController.php',
    'App\\Http\\Controllers\\PromotionController' => $baseDir . '/app/Http/Controllers/PromotionController.php',
    'App\\Http\\Controllers\\RazorpayPaymentController' => $baseDir . '/app/Http/Controllers/RazorpayPaymentController.php',
    'App\\Http\\Controllers\\ReferralProgramController' => $baseDir . '/app/Http/Controllers/ReferralProgramController.php',
    'App\\Http\\Controllers\\ReportController' => $baseDir . '/app/Http/Controllers/ReportController.php',
    'App\\Http\\Controllers\\ResignationController' => $baseDir . '/app/Http/Controllers/ResignationController.php',
    'App\\Http\\Controllers\\RoleController' => $baseDir . '/app/Http/Controllers/RoleController.php',
    'App\\Http\\Controllers\\SaturationDeductionController' => $baseDir . '/app/Http/Controllers/SaturationDeductionController.php',
    'App\\Http\\Controllers\\SetSalaryController' => $baseDir . '/app/Http/Controllers/SetSalaryController.php',
    'App\\Http\\Controllers\\SettingsController' => $baseDir . '/app/Http/Controllers/SettingsController.php',
    'App\\Http\\Controllers\\SkrillPaymentController' => $baseDir . '/app/Http/Controllers/SkrillPaymentController.php',
    'App\\Http\\Controllers\\SspayController' => $baseDir . '/app/Http/Controllers/SspayController.php',
    'App\\Http\\Controllers\\StripePaymentController' => $baseDir . '/app/Http/Controllers/StripePaymentController.php',
    'App\\Http\\Controllers\\TapPaymentController' => $baseDir . '/app/Http/Controllers/TapPaymentController.php',
    'App\\Http\\Controllers\\TerminationController' => $baseDir . '/app/Http/Controllers/TerminationController.php',
    'App\\Http\\Controllers\\TerminationTypeController' => $baseDir . '/app/Http/Controllers/TerminationTypeController.php',
    'App\\Http\\Controllers\\TicketController' => $baseDir . '/app/Http/Controllers/TicketController.php',
    'App\\Http\\Controllers\\TimeSheetController' => $baseDir . '/app/Http/Controllers/TimeSheetController.php',
    'App\\Http\\Controllers\\ToyyibpayPaymentController' => $baseDir . '/app/Http/Controllers/ToyyibpayPaymentController.php',
    'App\\Http\\Controllers\\TrainerController' => $baseDir . '/app/Http/Controllers/TrainerController.php',
    'App\\Http\\Controllers\\TrainingController' => $baseDir . '/app/Http/Controllers/TrainingController.php',
    'App\\Http\\Controllers\\TrainingTypeController' => $baseDir . '/app/Http/Controllers/TrainingTypeController.php',
    'App\\Http\\Controllers\\TransferBalanceController' => $baseDir . '/app/Http/Controllers/TransferBalanceController.php',
    'App\\Http\\Controllers\\TransferController' => $baseDir . '/app/Http/Controllers/TransferController.php',
    'App\\Http\\Controllers\\TravelController' => $baseDir . '/app/Http/Controllers/TravelController.php',
    'App\\Http\\Controllers\\UserController' => $baseDir . '/app/Http/Controllers/UserController.php',
    'App\\Http\\Controllers\\WarningController' => $baseDir . '/app/Http/Controllers/WarningController.php',
    'App\\Http\\Controllers\\XenditPaymentController' => $baseDir . '/app/Http/Controllers/XenditPaymentController.php',
    'App\\Http\\Controllers\\YooKassaController' => $baseDir . '/app/Http/Controllers/YooKassaController.php',
    'App\\Http\\Controllers\\ZoomMeetingController' => $baseDir . '/app/Http/Controllers/ZoomMeetingController.php',
    'App\\Http\\Controllers\\vendor\\Chatify\\MessagesController' => $baseDir . '/app/Http/Controllers/vendor/Chatify/MessagesController.php',
    'App\\Http\\Middleware\\Authenticate' => $baseDir . '/app/Http/Middleware/Authenticate.php',
    'App\\Http\\Middleware\\CheckForMaintenanceMode' => $baseDir . '/app/Http/Middleware/CheckForMaintenanceMode.php',
    'App\\Http\\Middleware\\EncryptCookies' => $baseDir . '/app/Http/Middleware/EncryptCookies.php',
    'App\\Http\\Middleware\\FilterRequest' => $baseDir . '/app/Http/Middleware/FilterRequest.php',
    'App\\Http\\Middleware\\PreventRequestsDuringMaintenance' => $baseDir . '/app/Http/Middleware/PreventRequestsDuringMaintenance.php',
    'App\\Http\\Middleware\\RedirectIfAuthenticated' => $baseDir . '/app/Http/Middleware/RedirectIfAuthenticated.php',
    'App\\Http\\Middleware\\TrimStrings' => $baseDir . '/app/Http/Middleware/TrimStrings.php',
    'App\\Http\\Middleware\\TrustHosts' => $baseDir . '/app/Http/Middleware/TrustHosts.php',
    'App\\Http\\Middleware\\TrustProxies' => $baseDir . '/app/Http/Middleware/TrustProxies.php',
    'App\\Http\\Middleware\\VerifyCsrfToken' => $baseDir . '/app/Http/Middleware/VerifyCsrfToken.php',
    'App\\Http\\Middleware\\XSS' => $baseDir . '/app/Http/Middleware/XSS.php',
    'App\\Http\\Middleware\\getPusherSettings' => $baseDir . '/app/Http/Middleware/getPusherSettings.php',
    'App\\Http\\Middleware\\testui' => $baseDir . '/app/Http/Middleware/testui.php',
    'App\\Http\\Requests\\Auth\\LoginRequest' => $baseDir . '/app/Http/Requests/Auth/LoginRequest.php',
    'App\\Imports\\AssetsImport' => $baseDir . '/app/Imports/AssetsImport.php',
    'App\\Imports\\AttendanceImport' => $baseDir . '/app/Imports/AttendanceImport.php',
    'App\\Imports\\EmployeesImport' => $baseDir . '/app/Imports/EmployeesImport.php',
    'App\\Imports\\EventImport' => $baseDir . '/app/Imports/EventImport.php',
    'App\\Imports\\HolidayImport' => $baseDir . '/app/Imports/HolidayImport.php',
    'App\\Imports\\TimesheetImport' => $baseDir . '/app/Imports/TimesheetImport.php',
    'App\\Imports\\TrainerImport' => $baseDir . '/app/Imports/TrainerImport.php',
    'App\\Listeners\\VerifyReCaptchaTokenLis' => $baseDir . '/app/Listeners/VerifyReCaptchaTokenLis.php',
    'App\\Mail\\AwardSend' => $baseDir . '/app/Mail/AwardSend.php',
    'App\\Mail\\CommonEmailTemplate' => $baseDir . '/app/Mail/CommonEmailTemplate.php',
    'App\\Mail\\ComplaintsSend' => $baseDir . '/app/Mail/ComplaintsSend.php',
    'App\\Mail\\LeaveActionSend' => $baseDir . '/app/Mail/LeaveActionSend.php',
    'App\\Mail\\PayslipSend' => $baseDir . '/app/Mail/PayslipSend.php',
    'App\\Mail\\PromotionSend' => $baseDir . '/app/Mail/PromotionSend.php',
    'App\\Mail\\ResignationSend' => $baseDir . '/app/Mail/ResignationSend.php',
    'App\\Mail\\TerminationSend' => $baseDir . '/app/Mail/TerminationSend.php',
    'App\\Mail\\TestMail' => $baseDir . '/app/Mail/TestMail.php',
    'App\\Mail\\TicketSend' => $baseDir . '/app/Mail/TicketSend.php',
    'App\\Mail\\TransferSend' => $baseDir . '/app/Mail/TransferSend.php',
    'App\\Mail\\TripSend' => $baseDir . '/app/Mail/TripSend.php',
    'App\\Mail\\UserCreate' => $baseDir . '/app/Mail/UserCreate.php',
    'App\\Mail\\WarningSend' => $baseDir . '/app/Mail/WarningSend.php',
    'App\\Models\\AccountList' => $baseDir . '/app/Models/AccountList.php',
    'App\\Models\\Allowance' => $baseDir . '/app/Models/Allowance.php',
    'App\\Models\\AllowanceOption' => $baseDir . '/app/Models/AllowanceOption.php',
    'App\\Models\\Announcement' => $baseDir . '/app/Models/Announcement.php',
    'App\\Models\\AnnouncementEmployee' => $baseDir . '/app/Models/AnnouncementEmployee.php',
    'App\\Models\\Appraisal' => $baseDir . '/app/Models/Appraisal.php',
    'App\\Models\\Asset' => $baseDir . '/app/Models/Asset.php',
    'App\\Models\\AttendanceEmployee' => $baseDir . '/app/Models/AttendanceEmployee.php',
    'App\\Models\\Award' => $baseDir . '/app/Models/Award.php',
    'App\\Models\\AwardType' => $baseDir . '/app/Models/AwardType.php',
    'App\\Models\\Branch' => $baseDir . '/app/Models/Branch.php',
    'App\\Models\\ChFavorite' => $baseDir . '/app/Models/ChFavorite.php',
    'App\\Models\\ChMessage' => $baseDir . '/app/Models/ChMessage.php',
    'App\\Models\\Commission' => $baseDir . '/app/Models/Commission.php',
    'App\\Models\\CompanyPolicy' => $baseDir . '/app/Models/CompanyPolicy.php',
    'App\\Models\\Competencies' => $baseDir . '/app/Models/Competencies.php',
    'App\\Models\\Complaint' => $baseDir . '/app/Models/Complaint.php',
    'App\\Models\\Contract' => $baseDir . '/app/Models/Contract.php',
    'App\\Models\\ContractAttechment' => $baseDir . '/app/Models/ContractAttechment.php',
    'App\\Models\\ContractComment' => $baseDir . '/app/Models/ContractComment.php',
    'App\\Models\\ContractNote' => $baseDir . '/app/Models/ContractNote.php',
    'App\\Models\\ContractType' => $baseDir . '/app/Models/ContractType.php',
    'App\\Models\\Coupon' => $baseDir . '/app/Models/Coupon.php',
    'App\\Models\\CustomQuestion' => $baseDir . '/app/Models/CustomQuestion.php',
    'App\\Models\\DeductionOption' => $baseDir . '/app/Models/DeductionOption.php',
    'App\\Models\\Department' => $baseDir . '/app/Models/Department.php',
    'App\\Models\\Deposit' => $baseDir . '/app/Models/Deposit.php',
    'App\\Models\\Designation' => $baseDir . '/app/Models/Designation.php',
    'App\\Models\\Document' => $baseDir . '/app/Models/Document.php',
    'App\\Models\\DucumentUpload' => $baseDir . '/app/Models/DucumentUpload.php',
    'App\\Models\\EmailTemplate' => $baseDir . '/app/Models/EmailTemplate.php',
    'App\\Models\\EmailTemplateLang' => $baseDir . '/app/Models/EmailTemplateLang.php',
    'App\\Models\\Employee' => $baseDir . '/app/Models/Employee.php',
    'App\\Models\\EmployeeDocument' => $baseDir . '/app/Models/EmployeeDocument.php',
    'App\\Models\\Event' => $baseDir . '/app/Models/Event.php',
    'App\\Models\\EventEmployee' => $baseDir . '/app/Models/EventEmployee.php',
    'App\\Models\\Expense' => $baseDir . '/app/Models/Expense.php',
    'App\\Models\\ExpenseType' => $baseDir . '/app/Models/ExpenseType.php',
    'App\\Models\\ExperienceCertificate' => $baseDir . '/app/Models/ExperienceCertificate.php',
    'App\\Models\\GenerateOfferLetter' => $baseDir . '/app/Models/GenerateOfferLetter.php',
    'App\\Models\\GoalTracking' => $baseDir . '/app/Models/GoalTracking.php',
    'App\\Models\\GoalType' => $baseDir . '/app/Models/GoalType.php',
    'App\\Models\\Holiday' => $baseDir . '/app/Models/Holiday.php',
    'App\\Models\\IncomeType' => $baseDir . '/app/Models/IncomeType.php',
    'App\\Models\\Indicator' => $baseDir . '/app/Models/Indicator.php',
    'App\\Models\\InterviewSchedule' => $baseDir . '/app/Models/InterviewSchedule.php',
    'App\\Models\\IpRestrict' => $baseDir . '/app/Models/IpRestrict.php',
    'App\\Models\\Job' => $baseDir . '/app/Models/Job.php',
    'App\\Models\\JobApplication' => $baseDir . '/app/Models/JobApplication.php',
    'App\\Models\\JobApplicationNote' => $baseDir . '/app/Models/JobApplicationNote.php',
    'App\\Models\\JobCategory' => $baseDir . '/app/Models/JobCategory.php',
    'App\\Models\\JobOnBoard' => $baseDir . '/app/Models/JobOnBoard.php',
    'App\\Models\\JobStage' => $baseDir . '/app/Models/JobStage.php',
    'App\\Models\\JoiningLetter' => $baseDir . '/app/Models/JoiningLetter.php',
    'App\\Models\\LandingPageSection' => $baseDir . '/app/Models/LandingPageSection.php',
    'App\\Models\\Languages' => $baseDir . '/app/Models/Languages.php',
    'App\\Models\\Leave' => $baseDir . '/app/Models/Leave.php',
    'App\\Models\\LeaveType' => $baseDir . '/app/Models/LeaveType.php',
    'App\\Models\\Loan' => $baseDir . '/app/Models/Loan.php',
    'App\\Models\\LoanOption' => $baseDir . '/app/Models/LoanOption.php',
    'App\\Models\\LoginDetail' => $baseDir . '/app/Models/LoginDetail.php',
    'App\\Models\\Meeting' => $baseDir . '/app/Models/Meeting.php',
    'App\\Models\\MeetingEmployee' => $baseDir . '/app/Models/MeetingEmployee.php',
    'App\\Models\\NOC' => $baseDir . '/app/Models/NOC.php',
    'App\\Models\\NotificationTemplateLangs' => $baseDir . '/app/Models/NotificationTemplateLangs.php',
    'App\\Models\\NotificationTemplates' => $baseDir . '/app/Models/NotificationTemplates.php',
    'App\\Models\\Order' => $baseDir . '/app/Models/Order.php',
    'App\\Models\\OtherPayment' => $baseDir . '/app/Models/OtherPayment.php',
    'App\\Models\\Overtime' => $baseDir . '/app/Models/Overtime.php',
    'App\\Models\\PaySlip' => $baseDir . '/app/Models/PaySlip.php',
    'App\\Models\\Payees' => $baseDir . '/app/Models/Payees.php',
    'App\\Models\\Payer' => $baseDir . '/app/Models/Payer.php',
    'App\\Models\\PaymentType' => $baseDir . '/app/Models/PaymentType.php',
    'App\\Models\\PayslipType' => $baseDir . '/app/Models/PayslipType.php',
    'App\\Models\\Performance_Type' => $baseDir . '/app/Models/Performance_Type.php',
    'App\\Models\\Plan' => $baseDir . '/app/Models/Plan.php',
    'App\\Models\\PlanRequest' => $baseDir . '/app/Models/PlanRequest.php',
    'App\\Models\\Promotion' => $baseDir . '/app/Models/Promotion.php',
    'App\\Models\\ReferralSetting' => $baseDir . '/app/Models/ReferralSetting.php',
    'App\\Models\\ReferralTransaction' => $baseDir . '/app/Models/ReferralTransaction.php',
    'App\\Models\\Resignation' => $baseDir . '/app/Models/Resignation.php',
    'App\\Models\\SaturationDeduction' => $baseDir . '/app/Models/SaturationDeduction.php',
    'App\\Models\\SetSalary' => $baseDir . '/app/Models/SetSalary.php',
    'App\\Models\\Template' => $baseDir . '/app/Models/Template.php',
    'App\\Models\\Termination' => $baseDir . '/app/Models/Termination.php',
    'App\\Models\\TerminationType' => $baseDir . '/app/Models/TerminationType.php',
    'App\\Models\\Ticket' => $baseDir . '/app/Models/Ticket.php',
    'App\\Models\\TicketReply' => $baseDir . '/app/Models/TicketReply.php',
    'App\\Models\\TimeSheet' => $baseDir . '/app/Models/TimeSheet.php',
    'App\\Models\\Trainer' => $baseDir . '/app/Models/Trainer.php',
    'App\\Models\\Training' => $baseDir . '/app/Models/Training.php',
    'App\\Models\\TrainingType' => $baseDir . '/app/Models/TrainingType.php',
    'App\\Models\\TransactionOrder' => $baseDir . '/app/Models/TransactionOrder.php',
    'App\\Models\\Transfer' => $baseDir . '/app/Models/Transfer.php',
    'App\\Models\\TransferBalance' => $baseDir . '/app/Models/TransferBalance.php',
    'App\\Models\\Travel' => $baseDir . '/app/Models/Travel.php',
    'App\\Models\\User' => $baseDir . '/app/Models/User.php',
    'App\\Models\\UserCoupon' => $baseDir . '/app/Models/UserCoupon.php',
    'App\\Models\\UserEmailTemplate' => $baseDir . '/app/Models/UserEmailTemplate.php',
    'App\\Models\\Utility' => $baseDir . '/app/Models/Utility.php',
    'App\\Models\\Warning' => $baseDir . '/app/Models/Warning.php',
    'App\\Models\\Webhook' => $baseDir . '/app/Models/Webhook.php',
    'App\\Models\\ZoomMeeting' => $baseDir . '/app/Models/ZoomMeeting.php',
    'App\\Package\\Payment' => $baseDir . '/app/Package/Payment.php',
    'App\\Package\\Reference' => $baseDir . '/app/Package/Reference.php',
    'App\\Package\\Tap' => $baseDir . '/app/Package/Tap.php',
    'App\\Package\\TapServiceProvider' => $baseDir . '/app/Package/TapServiceProvider.php',
    'App\\PayTab\\paypage' => $baseDir . '/app/PayTab/paypage.php',
    'App\\PayTab\\paytabs_core' => $baseDir . '/app/PayTab/paytabs_core.php',
    'App\\Providers\\AppServiceProvider' => $baseDir . '/app/Providers/AppServiceProvider.php',
    'App\\Providers\\AuthServiceProvider' => $baseDir . '/app/Providers/AuthServiceProvider.php',
    'App\\Providers\\BroadcastServiceProvider' => $baseDir . '/app/Providers/BroadcastServiceProvider.php',
    'App\\Providers\\EventServiceProvider' => $baseDir . '/app/Providers/EventServiceProvider.php',
    'App\\Providers\\RouteServiceProvider' => $baseDir . '/app/Providers/RouteServiceProvider.php',
    'App\\Traits\\ApiResponser' => $baseDir . '/app/Traits/ApiResponser.php',
    'App\\Traits\\ZoomMeetingTrait' => $baseDir . '/app/Traits/ZoomMeetingTrait.php',
    'App\\View\\Components\\AppLayout' => $baseDir . '/app/View/Components/AppLayout.php',
    'App\\View\\Components\\GuestLayout' => $baseDir . '/app/View/Components/GuestLayout.php',
    'App\\View\\Components\\Mobile' => $baseDir . '/app/View/Components/Mobile.php',
    'App\\View\\Components\\required' => $baseDir . '/app/View/Components/required.php',
    'App\\Xendit\\ApiOperations\\Create' => $baseDir . '/app/Xendit/ApiOperations/Create.php',
    'App\\Xendit\\ApiOperations\\Request' => $baseDir . '/app/Xendit/ApiOperations/Request.php',
    'App\\Xendit\\ApiOperations\\Retrieve' => $baseDir . '/app/Xendit/ApiOperations/Retrieve.php',
    'App\\Xendit\\ApiOperations\\RetrieveAll' => $baseDir . '/app/Xendit/ApiOperations/RetrieveAll.php',
    'App\\Xendit\\ApiOperations\\Update' => $baseDir . '/app/Xendit/ApiOperations/Update.php',
    'App\\Xendit\\ApiRequestor' => $baseDir . '/app/Xendit/ApiRequestor.php',
    'App\\Xendit\\Exceptions\\ApiException' => $baseDir . '/app/Xendit/Exceptions/ApiException.php',
    'App\\Xendit\\Exceptions\\ExceptionInterface' => $baseDir . '/app/Xendit/Exceptions/ExceptionInterface.php',
    'App\\Xendit\\Exceptions\\InvalidArgumentException' => $baseDir . '/app/Xendit/Exceptions/InvalidArgumentException.php',
    'App\\Xendit\\HttpClient\\ClientInterface' => $baseDir . '/app/Xendit/HttpClient/ClientInterface.php',
    'App\\Xendit\\HttpClient\\GuzzleClient' => $baseDir . '/app/Xendit/HttpClient/GuzzleClient.php',
    'App\\Xendit\\Invoice' => $baseDir . '/app/Xendit/Invoice.php',
    'App\\Xendit\\Xendit' => $baseDir . '/app/Xendit/Xendit.php',
    'Arkitecht\\Twilio\\Facades\\Twilio' => $vendorDir . '/arkitecht/laravel-twilio/src/Facades/Twilio.php',
    'Arkitecht\\Twilio\\Providers\\TwilioServiceProvider' => $vendorDir . '/arkitecht/laravel-twilio/src/Providers/TwilioServiceProvider.php',
    'Arkitecht\\Twilio\\Twilio' => $vendorDir . '/arkitecht/laravel-twilio/src/Twilio.php',
    'Attribute' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/Attribute.php',
    'Aws\\ACMPCA\\ACMPCAClient' => $vendorDir . '/aws/aws-sdk-php/src/ACMPCA/ACMPCAClient.php',
    'Aws\\ACMPCA\\Exception\\ACMPCAException' => $vendorDir . '/aws/aws-sdk-php/src/ACMPCA/Exception/ACMPCAException.php',
    'Aws\\ARCZonalShift\\ARCZonalShiftClient' => $vendorDir . '/aws/aws-sdk-php/src/ARCZonalShift/ARCZonalShiftClient.php',
    'Aws\\ARCZonalShift\\Exception\\ARCZonalShiftException' => $vendorDir . '/aws/aws-sdk-php/src/ARCZonalShift/Exception/ARCZonalShiftException.php',
    'Aws\\AbstractConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/AbstractConfigurationProvider.php',
    'Aws\\AccessAnalyzer\\AccessAnalyzerClient' => $vendorDir . '/aws/aws-sdk-php/src/AccessAnalyzer/AccessAnalyzerClient.php',
    'Aws\\AccessAnalyzer\\Exception\\AccessAnalyzerException' => $vendorDir . '/aws/aws-sdk-php/src/AccessAnalyzer/Exception/AccessAnalyzerException.php',
    'Aws\\Account\\AccountClient' => $vendorDir . '/aws/aws-sdk-php/src/Account/AccountClient.php',
    'Aws\\Account\\Exception\\AccountException' => $vendorDir . '/aws/aws-sdk-php/src/Account/Exception/AccountException.php',
    'Aws\\Acm\\AcmClient' => $vendorDir . '/aws/aws-sdk-php/src/Acm/AcmClient.php',
    'Aws\\Acm\\Exception\\AcmException' => $vendorDir . '/aws/aws-sdk-php/src/Acm/Exception/AcmException.php',
    'Aws\\AmplifyBackend\\AmplifyBackendClient' => $vendorDir . '/aws/aws-sdk-php/src/AmplifyBackend/AmplifyBackendClient.php',
    'Aws\\AmplifyBackend\\Exception\\AmplifyBackendException' => $vendorDir . '/aws/aws-sdk-php/src/AmplifyBackend/Exception/AmplifyBackendException.php',
    'Aws\\AmplifyUIBuilder\\AmplifyUIBuilderClient' => $vendorDir . '/aws/aws-sdk-php/src/AmplifyUIBuilder/AmplifyUIBuilderClient.php',
    'Aws\\AmplifyUIBuilder\\Exception\\AmplifyUIBuilderException' => $vendorDir . '/aws/aws-sdk-php/src/AmplifyUIBuilder/Exception/AmplifyUIBuilderException.php',
    'Aws\\Amplify\\AmplifyClient' => $vendorDir . '/aws/aws-sdk-php/src/Amplify/AmplifyClient.php',
    'Aws\\Amplify\\Exception\\AmplifyException' => $vendorDir . '/aws/aws-sdk-php/src/Amplify/Exception/AmplifyException.php',
    'Aws\\ApiGatewayManagementApi\\ApiGatewayManagementApiClient' => $vendorDir . '/aws/aws-sdk-php/src/ApiGatewayManagementApi/ApiGatewayManagementApiClient.php',
    'Aws\\ApiGatewayManagementApi\\Exception\\ApiGatewayManagementApiException' => $vendorDir . '/aws/aws-sdk-php/src/ApiGatewayManagementApi/Exception/ApiGatewayManagementApiException.php',
    'Aws\\ApiGatewayV2\\ApiGatewayV2Client' => $vendorDir . '/aws/aws-sdk-php/src/ApiGatewayV2/ApiGatewayV2Client.php',
    'Aws\\ApiGatewayV2\\Exception\\ApiGatewayV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/ApiGatewayV2/Exception/ApiGatewayV2Exception.php',
    'Aws\\ApiGateway\\ApiGatewayClient' => $vendorDir . '/aws/aws-sdk-php/src/ApiGateway/ApiGatewayClient.php',
    'Aws\\ApiGateway\\Exception\\ApiGatewayException' => $vendorDir . '/aws/aws-sdk-php/src/ApiGateway/Exception/ApiGatewayException.php',
    'Aws\\Api\\AbstractModel' => $vendorDir . '/aws/aws-sdk-php/src/Api/AbstractModel.php',
    'Aws\\Api\\ApiProvider' => $vendorDir . '/aws/aws-sdk-php/src/Api/ApiProvider.php',
    'Aws\\Api\\DateTimeResult' => $vendorDir . '/aws/aws-sdk-php/src/Api/DateTimeResult.php',
    'Aws\\Api\\DocModel' => $vendorDir . '/aws/aws-sdk-php/src/Api/DocModel.php',
    'Aws\\Api\\ErrorParser\\AbstractErrorParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/ErrorParser/AbstractErrorParser.php',
    'Aws\\Api\\ErrorParser\\JsonParserTrait' => $vendorDir . '/aws/aws-sdk-php/src/Api/ErrorParser/JsonParserTrait.php',
    'Aws\\Api\\ErrorParser\\JsonRpcErrorParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/ErrorParser/JsonRpcErrorParser.php',
    'Aws\\Api\\ErrorParser\\RestJsonErrorParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/ErrorParser/RestJsonErrorParser.php',
    'Aws\\Api\\ErrorParser\\XmlErrorParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/ErrorParser/XmlErrorParser.php',
    'Aws\\Api\\ListShape' => $vendorDir . '/aws/aws-sdk-php/src/Api/ListShape.php',
    'Aws\\Api\\MapShape' => $vendorDir . '/aws/aws-sdk-php/src/Api/MapShape.php',
    'Aws\\Api\\Operation' => $vendorDir . '/aws/aws-sdk-php/src/Api/Operation.php',
    'Aws\\Api\\Parser\\AbstractParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/AbstractParser.php',
    'Aws\\Api\\Parser\\AbstractRestParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/AbstractRestParser.php',
    'Aws\\Api\\Parser\\Crc32ValidatingParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/Crc32ValidatingParser.php',
    'Aws\\Api\\Parser\\DecodingEventStreamIterator' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/DecodingEventStreamIterator.php',
    'Aws\\Api\\Parser\\EventParsingIterator' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/EventParsingIterator.php',
    'Aws\\Api\\Parser\\Exception\\ParserException' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/Exception/ParserException.php',
    'Aws\\Api\\Parser\\JsonParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/JsonParser.php',
    'Aws\\Api\\Parser\\JsonRpcParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/JsonRpcParser.php',
    'Aws\\Api\\Parser\\MetadataParserTrait' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/MetadataParserTrait.php',
    'Aws\\Api\\Parser\\NonSeekableStreamDecodingEventStreamIterator' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/NonSeekableStreamDecodingEventStreamIterator.php',
    'Aws\\Api\\Parser\\PayloadParserTrait' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/PayloadParserTrait.php',
    'Aws\\Api\\Parser\\QueryParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/QueryParser.php',
    'Aws\\Api\\Parser\\RestJsonParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/RestJsonParser.php',
    'Aws\\Api\\Parser\\RestXmlParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/RestXmlParser.php',
    'Aws\\Api\\Parser\\XmlParser' => $vendorDir . '/aws/aws-sdk-php/src/Api/Parser/XmlParser.php',
    'Aws\\Api\\Serializer\\Ec2ParamBuilder' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/Ec2ParamBuilder.php',
    'Aws\\Api\\Serializer\\JsonBody' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/JsonBody.php',
    'Aws\\Api\\Serializer\\JsonRpcSerializer' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/JsonRpcSerializer.php',
    'Aws\\Api\\Serializer\\QueryParamBuilder' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/QueryParamBuilder.php',
    'Aws\\Api\\Serializer\\QuerySerializer' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/QuerySerializer.php',
    'Aws\\Api\\Serializer\\RestJsonSerializer' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/RestJsonSerializer.php',
    'Aws\\Api\\Serializer\\RestSerializer' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/RestSerializer.php',
    'Aws\\Api\\Serializer\\RestXmlSerializer' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/RestXmlSerializer.php',
    'Aws\\Api\\Serializer\\XmlBody' => $vendorDir . '/aws/aws-sdk-php/src/Api/Serializer/XmlBody.php',
    'Aws\\Api\\Service' => $vendorDir . '/aws/aws-sdk-php/src/Api/Service.php',
    'Aws\\Api\\Shape' => $vendorDir . '/aws/aws-sdk-php/src/Api/Shape.php',
    'Aws\\Api\\ShapeMap' => $vendorDir . '/aws/aws-sdk-php/src/Api/ShapeMap.php',
    'Aws\\Api\\StructureShape' => $vendorDir . '/aws/aws-sdk-php/src/Api/StructureShape.php',
    'Aws\\Api\\TimestampShape' => $vendorDir . '/aws/aws-sdk-php/src/Api/TimestampShape.php',
    'Aws\\Api\\Validator' => $vendorDir . '/aws/aws-sdk-php/src/Api/Validator.php',
    'Aws\\AppConfigData\\AppConfigDataClient' => $vendorDir . '/aws/aws-sdk-php/src/AppConfigData/AppConfigDataClient.php',
    'Aws\\AppConfigData\\Exception\\AppConfigDataException' => $vendorDir . '/aws/aws-sdk-php/src/AppConfigData/Exception/AppConfigDataException.php',
    'Aws\\AppConfig\\AppConfigClient' => $vendorDir . '/aws/aws-sdk-php/src/AppConfig/AppConfigClient.php',
    'Aws\\AppConfig\\Exception\\AppConfigException' => $vendorDir . '/aws/aws-sdk-php/src/AppConfig/Exception/AppConfigException.php',
    'Aws\\AppFabric\\AppFabricClient' => $vendorDir . '/aws/aws-sdk-php/src/AppFabric/AppFabricClient.php',
    'Aws\\AppFabric\\Exception\\AppFabricException' => $vendorDir . '/aws/aws-sdk-php/src/AppFabric/Exception/AppFabricException.php',
    'Aws\\AppIntegrationsService\\AppIntegrationsServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/AppIntegrationsService/AppIntegrationsServiceClient.php',
    'Aws\\AppIntegrationsService\\Exception\\AppIntegrationsServiceException' => $vendorDir . '/aws/aws-sdk-php/src/AppIntegrationsService/Exception/AppIntegrationsServiceException.php',
    'Aws\\AppMesh\\AppMeshClient' => $vendorDir . '/aws/aws-sdk-php/src/AppMesh/AppMeshClient.php',
    'Aws\\AppMesh\\Exception\\AppMeshException' => $vendorDir . '/aws/aws-sdk-php/src/AppMesh/Exception/AppMeshException.php',
    'Aws\\AppRegistry\\AppRegistryClient' => $vendorDir . '/aws/aws-sdk-php/src/AppRegistry/AppRegistryClient.php',
    'Aws\\AppRegistry\\Exception\\AppRegistryException' => $vendorDir . '/aws/aws-sdk-php/src/AppRegistry/Exception/AppRegistryException.php',
    'Aws\\AppRunner\\AppRunnerClient' => $vendorDir . '/aws/aws-sdk-php/src/AppRunner/AppRunnerClient.php',
    'Aws\\AppRunner\\Exception\\AppRunnerException' => $vendorDir . '/aws/aws-sdk-php/src/AppRunner/Exception/AppRunnerException.php',
    'Aws\\AppSync\\AppSyncClient' => $vendorDir . '/aws/aws-sdk-php/src/AppSync/AppSyncClient.php',
    'Aws\\AppSync\\Exception\\AppSyncException' => $vendorDir . '/aws/aws-sdk-php/src/AppSync/Exception/AppSyncException.php',
    'Aws\\AppTest\\AppTestClient' => $vendorDir . '/aws/aws-sdk-php/src/AppTest/AppTestClient.php',
    'Aws\\AppTest\\Exception\\AppTestException' => $vendorDir . '/aws/aws-sdk-php/src/AppTest/Exception/AppTestException.php',
    'Aws\\Appflow\\AppflowClient' => $vendorDir . '/aws/aws-sdk-php/src/Appflow/AppflowClient.php',
    'Aws\\Appflow\\Exception\\AppflowException' => $vendorDir . '/aws/aws-sdk-php/src/Appflow/Exception/AppflowException.php',
    'Aws\\ApplicationAutoScaling\\ApplicationAutoScalingClient' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationAutoScaling/ApplicationAutoScalingClient.php',
    'Aws\\ApplicationAutoScaling\\Exception\\ApplicationAutoScalingException' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationAutoScaling/Exception/ApplicationAutoScalingException.php',
    'Aws\\ApplicationCostProfiler\\ApplicationCostProfilerClient' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationCostProfiler/ApplicationCostProfilerClient.php',
    'Aws\\ApplicationCostProfiler\\Exception\\ApplicationCostProfilerException' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationCostProfiler/Exception/ApplicationCostProfilerException.php',
    'Aws\\ApplicationDiscoveryService\\ApplicationDiscoveryServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationDiscoveryService/ApplicationDiscoveryServiceClient.php',
    'Aws\\ApplicationDiscoveryService\\Exception\\ApplicationDiscoveryServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationDiscoveryService/Exception/ApplicationDiscoveryServiceException.php',
    'Aws\\ApplicationInsights\\ApplicationInsightsClient' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationInsights/ApplicationInsightsClient.php',
    'Aws\\ApplicationInsights\\Exception\\ApplicationInsightsException' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationInsights/Exception/ApplicationInsightsException.php',
    'Aws\\ApplicationSignals\\ApplicationSignalsClient' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationSignals/ApplicationSignalsClient.php',
    'Aws\\ApplicationSignals\\Exception\\ApplicationSignalsException' => $vendorDir . '/aws/aws-sdk-php/src/ApplicationSignals/Exception/ApplicationSignalsException.php',
    'Aws\\Appstream\\AppstreamClient' => $vendorDir . '/aws/aws-sdk-php/src/Appstream/AppstreamClient.php',
    'Aws\\Appstream\\Exception\\AppstreamException' => $vendorDir . '/aws/aws-sdk-php/src/Appstream/Exception/AppstreamException.php',
    'Aws\\Arn\\AccessPointArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/AccessPointArn.php',
    'Aws\\Arn\\AccessPointArnInterface' => $vendorDir . '/aws/aws-sdk-php/src/Arn/AccessPointArnInterface.php',
    'Aws\\Arn\\Arn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/Arn.php',
    'Aws\\Arn\\ArnInterface' => $vendorDir . '/aws/aws-sdk-php/src/Arn/ArnInterface.php',
    'Aws\\Arn\\ArnParser' => $vendorDir . '/aws/aws-sdk-php/src/Arn/ArnParser.php',
    'Aws\\Arn\\Exception\\InvalidArnException' => $vendorDir . '/aws/aws-sdk-php/src/Arn/Exception/InvalidArnException.php',
    'Aws\\Arn\\ObjectLambdaAccessPointArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/ObjectLambdaAccessPointArn.php',
    'Aws\\Arn\\ResourceTypeAndIdTrait' => $vendorDir . '/aws/aws-sdk-php/src/Arn/ResourceTypeAndIdTrait.php',
    'Aws\\Arn\\S3\\AccessPointArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/AccessPointArn.php',
    'Aws\\Arn\\S3\\BucketArnInterface' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/BucketArnInterface.php',
    'Aws\\Arn\\S3\\MultiRegionAccessPointArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/MultiRegionAccessPointArn.php',
    'Aws\\Arn\\S3\\OutpostsAccessPointArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/OutpostsAccessPointArn.php',
    'Aws\\Arn\\S3\\OutpostsArnInterface' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/OutpostsArnInterface.php',
    'Aws\\Arn\\S3\\OutpostsBucketArn' => $vendorDir . '/aws/aws-sdk-php/src/Arn/S3/OutpostsBucketArn.php',
    'Aws\\Artifact\\ArtifactClient' => $vendorDir . '/aws/aws-sdk-php/src/Artifact/ArtifactClient.php',
    'Aws\\Artifact\\Exception\\ArtifactException' => $vendorDir . '/aws/aws-sdk-php/src/Artifact/Exception/ArtifactException.php',
    'Aws\\Athena\\AthenaClient' => $vendorDir . '/aws/aws-sdk-php/src/Athena/AthenaClient.php',
    'Aws\\Athena\\Exception\\AthenaException' => $vendorDir . '/aws/aws-sdk-php/src/Athena/Exception/AthenaException.php',
    'Aws\\AuditManager\\AuditManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/AuditManager/AuditManagerClient.php',
    'Aws\\AuditManager\\Exception\\AuditManagerException' => $vendorDir . '/aws/aws-sdk-php/src/AuditManager/Exception/AuditManagerException.php',
    'Aws\\AugmentedAIRuntime\\AugmentedAIRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/AugmentedAIRuntime/AugmentedAIRuntimeClient.php',
    'Aws\\AugmentedAIRuntime\\Exception\\AugmentedAIRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/AugmentedAIRuntime/Exception/AugmentedAIRuntimeException.php',
    'Aws\\Auth\\AuthSchemeResolver' => $vendorDir . '/aws/aws-sdk-php/src/Auth/AuthSchemeResolver.php',
    'Aws\\Auth\\AuthSchemeResolverInterface' => $vendorDir . '/aws/aws-sdk-php/src/Auth/AuthSchemeResolverInterface.php',
    'Aws\\Auth\\AuthSelectionMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/Auth/AuthSelectionMiddleware.php',
    'Aws\\Auth\\Exception\\UnresolvedAuthSchemeException' => $vendorDir . '/aws/aws-sdk-php/src/Auth/Exception/UnresolvedAuthSchemeException.php',
    'Aws\\AutoScalingPlans\\AutoScalingPlansClient' => $vendorDir . '/aws/aws-sdk-php/src/AutoScalingPlans/AutoScalingPlansClient.php',
    'Aws\\AutoScalingPlans\\Exception\\AutoScalingPlansException' => $vendorDir . '/aws/aws-sdk-php/src/AutoScalingPlans/Exception/AutoScalingPlansException.php',
    'Aws\\AutoScaling\\AutoScalingClient' => $vendorDir . '/aws/aws-sdk-php/src/AutoScaling/AutoScalingClient.php',
    'Aws\\AutoScaling\\Exception\\AutoScalingException' => $vendorDir . '/aws/aws-sdk-php/src/AutoScaling/Exception/AutoScalingException.php',
    'Aws\\AwsClient' => $vendorDir . '/aws/aws-sdk-php/src/AwsClient.php',
    'Aws\\AwsClientInterface' => $vendorDir . '/aws/aws-sdk-php/src/AwsClientInterface.php',
    'Aws\\AwsClientTrait' => $vendorDir . '/aws/aws-sdk-php/src/AwsClientTrait.php',
    'Aws\\B2bi\\B2biClient' => $vendorDir . '/aws/aws-sdk-php/src/B2bi/B2biClient.php',
    'Aws\\B2bi\\Exception\\B2biException' => $vendorDir . '/aws/aws-sdk-php/src/B2bi/Exception/B2biException.php',
    'Aws\\BCMDataExports\\BCMDataExportsClient' => $vendorDir . '/aws/aws-sdk-php/src/BCMDataExports/BCMDataExportsClient.php',
    'Aws\\BCMDataExports\\Exception\\BCMDataExportsException' => $vendorDir . '/aws/aws-sdk-php/src/BCMDataExports/Exception/BCMDataExportsException.php',
    'Aws\\BackupGateway\\BackupGatewayClient' => $vendorDir . '/aws/aws-sdk-php/src/BackupGateway/BackupGatewayClient.php',
    'Aws\\BackupGateway\\Exception\\BackupGatewayException' => $vendorDir . '/aws/aws-sdk-php/src/BackupGateway/Exception/BackupGatewayException.php',
    'Aws\\Backup\\BackupClient' => $vendorDir . '/aws/aws-sdk-php/src/Backup/BackupClient.php',
    'Aws\\Backup\\Exception\\BackupException' => $vendorDir . '/aws/aws-sdk-php/src/Backup/Exception/BackupException.php',
    'Aws\\Batch\\BatchClient' => $vendorDir . '/aws/aws-sdk-php/src/Batch/BatchClient.php',
    'Aws\\Batch\\Exception\\BatchException' => $vendorDir . '/aws/aws-sdk-php/src/Batch/Exception/BatchException.php',
    'Aws\\BedrockAgentRuntime\\BedrockAgentRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/BedrockAgentRuntime/BedrockAgentRuntimeClient.php',
    'Aws\\BedrockAgentRuntime\\Exception\\BedrockAgentRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/BedrockAgentRuntime/Exception/BedrockAgentRuntimeException.php',
    'Aws\\BedrockAgent\\BedrockAgentClient' => $vendorDir . '/aws/aws-sdk-php/src/BedrockAgent/BedrockAgentClient.php',
    'Aws\\BedrockAgent\\Exception\\BedrockAgentException' => $vendorDir . '/aws/aws-sdk-php/src/BedrockAgent/Exception/BedrockAgentException.php',
    'Aws\\BedrockRuntime\\BedrockRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/BedrockRuntime/BedrockRuntimeClient.php',
    'Aws\\BedrockRuntime\\Exception\\BedrockRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/BedrockRuntime/Exception/BedrockRuntimeException.php',
    'Aws\\Bedrock\\BedrockClient' => $vendorDir . '/aws/aws-sdk-php/src/Bedrock/BedrockClient.php',
    'Aws\\Bedrock\\Exception\\BedrockException' => $vendorDir . '/aws/aws-sdk-php/src/Bedrock/Exception/BedrockException.php',
    'Aws\\BillingConductor\\BillingConductorClient' => $vendorDir . '/aws/aws-sdk-php/src/BillingConductor/BillingConductorClient.php',
    'Aws\\BillingConductor\\Exception\\BillingConductorException' => $vendorDir . '/aws/aws-sdk-php/src/BillingConductor/Exception/BillingConductorException.php',
    'Aws\\Braket\\BraketClient' => $vendorDir . '/aws/aws-sdk-php/src/Braket/BraketClient.php',
    'Aws\\Braket\\Exception\\BraketException' => $vendorDir . '/aws/aws-sdk-php/src/Braket/Exception/BraketException.php',
    'Aws\\Budgets\\BudgetsClient' => $vendorDir . '/aws/aws-sdk-php/src/Budgets/BudgetsClient.php',
    'Aws\\Budgets\\Exception\\BudgetsException' => $vendorDir . '/aws/aws-sdk-php/src/Budgets/Exception/BudgetsException.php',
    'Aws\\CacheInterface' => $vendorDir . '/aws/aws-sdk-php/src/CacheInterface.php',
    'Aws\\Chatbot\\ChatbotClient' => $vendorDir . '/aws/aws-sdk-php/src/Chatbot/ChatbotClient.php',
    'Aws\\Chatbot\\Exception\\ChatbotException' => $vendorDir . '/aws/aws-sdk-php/src/Chatbot/Exception/ChatbotException.php',
    'Aws\\ChimeSDKIdentity\\ChimeSDKIdentityClient' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKIdentity/ChimeSDKIdentityClient.php',
    'Aws\\ChimeSDKIdentity\\Exception\\ChimeSDKIdentityException' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKIdentity/Exception/ChimeSDKIdentityException.php',
    'Aws\\ChimeSDKMediaPipelines\\ChimeSDKMediaPipelinesClient' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMediaPipelines/ChimeSDKMediaPipelinesClient.php',
    'Aws\\ChimeSDKMediaPipelines\\Exception\\ChimeSDKMediaPipelinesException' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMediaPipelines/Exception/ChimeSDKMediaPipelinesException.php',
    'Aws\\ChimeSDKMeetings\\ChimeSDKMeetingsClient' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMeetings/ChimeSDKMeetingsClient.php',
    'Aws\\ChimeSDKMeetings\\Exception\\ChimeSDKMeetingsException' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMeetings/Exception/ChimeSDKMeetingsException.php',
    'Aws\\ChimeSDKMessaging\\ChimeSDKMessagingClient' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMessaging/ChimeSDKMessagingClient.php',
    'Aws\\ChimeSDKMessaging\\Exception\\ChimeSDKMessagingException' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKMessaging/Exception/ChimeSDKMessagingException.php',
    'Aws\\ChimeSDKVoice\\ChimeSDKVoiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKVoice/ChimeSDKVoiceClient.php',
    'Aws\\ChimeSDKVoice\\Exception\\ChimeSDKVoiceException' => $vendorDir . '/aws/aws-sdk-php/src/ChimeSDKVoice/Exception/ChimeSDKVoiceException.php',
    'Aws\\Chime\\ChimeClient' => $vendorDir . '/aws/aws-sdk-php/src/Chime/ChimeClient.php',
    'Aws\\Chime\\Exception\\ChimeException' => $vendorDir . '/aws/aws-sdk-php/src/Chime/Exception/ChimeException.php',
    'Aws\\CleanRoomsML\\CleanRoomsMLClient' => $vendorDir . '/aws/aws-sdk-php/src/CleanRoomsML/CleanRoomsMLClient.php',
    'Aws\\CleanRoomsML\\Exception\\CleanRoomsMLException' => $vendorDir . '/aws/aws-sdk-php/src/CleanRoomsML/Exception/CleanRoomsMLException.php',
    'Aws\\CleanRooms\\CleanRoomsClient' => $vendorDir . '/aws/aws-sdk-php/src/CleanRooms/CleanRoomsClient.php',
    'Aws\\CleanRooms\\Exception\\CleanRoomsException' => $vendorDir . '/aws/aws-sdk-php/src/CleanRooms/Exception/CleanRoomsException.php',
    'Aws\\ClientResolver' => $vendorDir . '/aws/aws-sdk-php/src/ClientResolver.php',
    'Aws\\ClientSideMonitoring\\AbstractMonitoringMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/AbstractMonitoringMiddleware.php',
    'Aws\\ClientSideMonitoring\\ApiCallAttemptMonitoringMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/ApiCallAttemptMonitoringMiddleware.php',
    'Aws\\ClientSideMonitoring\\ApiCallMonitoringMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/ApiCallMonitoringMiddleware.php',
    'Aws\\ClientSideMonitoring\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/Configuration.php',
    'Aws\\ClientSideMonitoring\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/ConfigurationInterface.php',
    'Aws\\ClientSideMonitoring\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/ConfigurationProvider.php',
    'Aws\\ClientSideMonitoring\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/Exception/ConfigurationException.php',
    'Aws\\ClientSideMonitoring\\MonitoringMiddlewareInterface' => $vendorDir . '/aws/aws-sdk-php/src/ClientSideMonitoring/MonitoringMiddlewareInterface.php',
    'Aws\\Cloud9\\Cloud9Client' => $vendorDir . '/aws/aws-sdk-php/src/Cloud9/Cloud9Client.php',
    'Aws\\Cloud9\\Exception\\Cloud9Exception' => $vendorDir . '/aws/aws-sdk-php/src/Cloud9/Exception/Cloud9Exception.php',
    'Aws\\CloudControlApi\\CloudControlApiClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudControlApi/CloudControlApiClient.php',
    'Aws\\CloudControlApi\\Exception\\CloudControlApiException' => $vendorDir . '/aws/aws-sdk-php/src/CloudControlApi/Exception/CloudControlApiException.php',
    'Aws\\CloudDirectory\\CloudDirectoryClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudDirectory/CloudDirectoryClient.php',
    'Aws\\CloudDirectory\\Exception\\CloudDirectoryException' => $vendorDir . '/aws/aws-sdk-php/src/CloudDirectory/Exception/CloudDirectoryException.php',
    'Aws\\CloudFormation\\CloudFormationClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudFormation/CloudFormationClient.php',
    'Aws\\CloudFormation\\Exception\\CloudFormationException' => $vendorDir . '/aws/aws-sdk-php/src/CloudFormation/Exception/CloudFormationException.php',
    'Aws\\CloudFrontKeyValueStore\\CloudFrontKeyValueStoreClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudFrontKeyValueStore/CloudFrontKeyValueStoreClient.php',
    'Aws\\CloudFrontKeyValueStore\\Exception\\CloudFrontKeyValueStoreException' => $vendorDir . '/aws/aws-sdk-php/src/CloudFrontKeyValueStore/Exception/CloudFrontKeyValueStoreException.php',
    'Aws\\CloudFront\\CloudFrontClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudFront/CloudFrontClient.php',
    'Aws\\CloudFront\\CookieSigner' => $vendorDir . '/aws/aws-sdk-php/src/CloudFront/CookieSigner.php',
    'Aws\\CloudFront\\Exception\\CloudFrontException' => $vendorDir . '/aws/aws-sdk-php/src/CloudFront/Exception/CloudFrontException.php',
    'Aws\\CloudFront\\Signer' => $vendorDir . '/aws/aws-sdk-php/src/CloudFront/Signer.php',
    'Aws\\CloudFront\\UrlSigner' => $vendorDir . '/aws/aws-sdk-php/src/CloudFront/UrlSigner.php',
    'Aws\\CloudHSMV2\\CloudHSMV2Client' => $vendorDir . '/aws/aws-sdk-php/src/CloudHSMV2/CloudHSMV2Client.php',
    'Aws\\CloudHSMV2\\Exception\\CloudHSMV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/CloudHSMV2/Exception/CloudHSMV2Exception.php',
    'Aws\\CloudHsm\\CloudHsmClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudHsm/CloudHsmClient.php',
    'Aws\\CloudHsm\\Exception\\CloudHsmException' => $vendorDir . '/aws/aws-sdk-php/src/CloudHsm/Exception/CloudHsmException.php',
    'Aws\\CloudSearchDomain\\CloudSearchDomainClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudSearchDomain/CloudSearchDomainClient.php',
    'Aws\\CloudSearchDomain\\Exception\\CloudSearchDomainException' => $vendorDir . '/aws/aws-sdk-php/src/CloudSearchDomain/Exception/CloudSearchDomainException.php',
    'Aws\\CloudSearch\\CloudSearchClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudSearch/CloudSearchClient.php',
    'Aws\\CloudSearch\\Exception\\CloudSearchException' => $vendorDir . '/aws/aws-sdk-php/src/CloudSearch/Exception/CloudSearchException.php',
    'Aws\\CloudTrailData\\CloudTrailDataClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrailData/CloudTrailDataClient.php',
    'Aws\\CloudTrailData\\Exception\\CloudTrailDataException' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrailData/Exception/CloudTrailDataException.php',
    'Aws\\CloudTrail\\CloudTrailClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrail/CloudTrailClient.php',
    'Aws\\CloudTrail\\Exception\\CloudTrailException' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrail/Exception/CloudTrailException.php',
    'Aws\\CloudTrail\\LogFileIterator' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrail/LogFileIterator.php',
    'Aws\\CloudTrail\\LogFileReader' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrail/LogFileReader.php',
    'Aws\\CloudTrail\\LogRecordIterator' => $vendorDir . '/aws/aws-sdk-php/src/CloudTrail/LogRecordIterator.php',
    'Aws\\CloudWatchEvents\\CloudWatchEventsClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchEvents/CloudWatchEventsClient.php',
    'Aws\\CloudWatchEvents\\Exception\\CloudWatchEventsException' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchEvents/Exception/CloudWatchEventsException.php',
    'Aws\\CloudWatchEvidently\\CloudWatchEvidentlyClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchEvidently/CloudWatchEvidentlyClient.php',
    'Aws\\CloudWatchEvidently\\Exception\\CloudWatchEvidentlyException' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchEvidently/Exception/CloudWatchEvidentlyException.php',
    'Aws\\CloudWatchLogs\\CloudWatchLogsClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchLogs/CloudWatchLogsClient.php',
    'Aws\\CloudWatchLogs\\Exception\\CloudWatchLogsException' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchLogs/Exception/CloudWatchLogsException.php',
    'Aws\\CloudWatchRUM\\CloudWatchRUMClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchRUM/CloudWatchRUMClient.php',
    'Aws\\CloudWatchRUM\\Exception\\CloudWatchRUMException' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatchRUM/Exception/CloudWatchRUMException.php',
    'Aws\\CloudWatch\\CloudWatchClient' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatch/CloudWatchClient.php',
    'Aws\\CloudWatch\\Exception\\CloudWatchException' => $vendorDir . '/aws/aws-sdk-php/src/CloudWatch/Exception/CloudWatchException.php',
    'Aws\\CodeArtifact\\CodeArtifactClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeArtifact/CodeArtifactClient.php',
    'Aws\\CodeArtifact\\Exception\\CodeArtifactException' => $vendorDir . '/aws/aws-sdk-php/src/CodeArtifact/Exception/CodeArtifactException.php',
    'Aws\\CodeBuild\\CodeBuildClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeBuild/CodeBuildClient.php',
    'Aws\\CodeBuild\\Exception\\CodeBuildException' => $vendorDir . '/aws/aws-sdk-php/src/CodeBuild/Exception/CodeBuildException.php',
    'Aws\\CodeCatalyst\\CodeCatalystClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeCatalyst/CodeCatalystClient.php',
    'Aws\\CodeCatalyst\\Exception\\CodeCatalystException' => $vendorDir . '/aws/aws-sdk-php/src/CodeCatalyst/Exception/CodeCatalystException.php',
    'Aws\\CodeCommit\\CodeCommitClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeCommit/CodeCommitClient.php',
    'Aws\\CodeCommit\\Exception\\CodeCommitException' => $vendorDir . '/aws/aws-sdk-php/src/CodeCommit/Exception/CodeCommitException.php',
    'Aws\\CodeConnections\\CodeConnectionsClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeConnections/CodeConnectionsClient.php',
    'Aws\\CodeConnections\\Exception\\CodeConnectionsException' => $vendorDir . '/aws/aws-sdk-php/src/CodeConnections/Exception/CodeConnectionsException.php',
    'Aws\\CodeDeploy\\CodeDeployClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeDeploy/CodeDeployClient.php',
    'Aws\\CodeDeploy\\Exception\\CodeDeployException' => $vendorDir . '/aws/aws-sdk-php/src/CodeDeploy/Exception/CodeDeployException.php',
    'Aws\\CodeGuruProfiler\\CodeGuruProfilerClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruProfiler/CodeGuruProfilerClient.php',
    'Aws\\CodeGuruProfiler\\Exception\\CodeGuruProfilerException' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruProfiler/Exception/CodeGuruProfilerException.php',
    'Aws\\CodeGuruReviewer\\CodeGuruReviewerClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruReviewer/CodeGuruReviewerClient.php',
    'Aws\\CodeGuruReviewer\\Exception\\CodeGuruReviewerException' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruReviewer/Exception/CodeGuruReviewerException.php',
    'Aws\\CodeGuruSecurity\\CodeGuruSecurityClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruSecurity/CodeGuruSecurityClient.php',
    'Aws\\CodeGuruSecurity\\Exception\\CodeGuruSecurityException' => $vendorDir . '/aws/aws-sdk-php/src/CodeGuruSecurity/Exception/CodeGuruSecurityException.php',
    'Aws\\CodePipeline\\CodePipelineClient' => $vendorDir . '/aws/aws-sdk-php/src/CodePipeline/CodePipelineClient.php',
    'Aws\\CodePipeline\\Exception\\CodePipelineException' => $vendorDir . '/aws/aws-sdk-php/src/CodePipeline/Exception/CodePipelineException.php',
    'Aws\\CodeStarNotifications\\CodeStarNotificationsClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeStarNotifications/CodeStarNotificationsClient.php',
    'Aws\\CodeStarNotifications\\Exception\\CodeStarNotificationsException' => $vendorDir . '/aws/aws-sdk-php/src/CodeStarNotifications/Exception/CodeStarNotificationsException.php',
    'Aws\\CodeStarconnections\\CodeStarconnectionsClient' => $vendorDir . '/aws/aws-sdk-php/src/CodeStarconnections/CodeStarconnectionsClient.php',
    'Aws\\CodeStarconnections\\Exception\\CodeStarconnectionsException' => $vendorDir . '/aws/aws-sdk-php/src/CodeStarconnections/Exception/CodeStarconnectionsException.php',
    'Aws\\CognitoIdentityProvider\\CognitoIdentityProviderClient' => $vendorDir . '/aws/aws-sdk-php/src/CognitoIdentityProvider/CognitoIdentityProviderClient.php',
    'Aws\\CognitoIdentityProvider\\Exception\\CognitoIdentityProviderException' => $vendorDir . '/aws/aws-sdk-php/src/CognitoIdentityProvider/Exception/CognitoIdentityProviderException.php',
    'Aws\\CognitoIdentity\\CognitoIdentityClient' => $vendorDir . '/aws/aws-sdk-php/src/CognitoIdentity/CognitoIdentityClient.php',
    'Aws\\CognitoIdentity\\CognitoIdentityProvider' => $vendorDir . '/aws/aws-sdk-php/src/CognitoIdentity/CognitoIdentityProvider.php',
    'Aws\\CognitoIdentity\\Exception\\CognitoIdentityException' => $vendorDir . '/aws/aws-sdk-php/src/CognitoIdentity/Exception/CognitoIdentityException.php',
    'Aws\\CognitoSync\\CognitoSyncClient' => $vendorDir . '/aws/aws-sdk-php/src/CognitoSync/CognitoSyncClient.php',
    'Aws\\CognitoSync\\Exception\\CognitoSyncException' => $vendorDir . '/aws/aws-sdk-php/src/CognitoSync/Exception/CognitoSyncException.php',
    'Aws\\Command' => $vendorDir . '/aws/aws-sdk-php/src/Command.php',
    'Aws\\CommandInterface' => $vendorDir . '/aws/aws-sdk-php/src/CommandInterface.php',
    'Aws\\CommandPool' => $vendorDir . '/aws/aws-sdk-php/src/CommandPool.php',
    'Aws\\ComprehendMedical\\ComprehendMedicalClient' => $vendorDir . '/aws/aws-sdk-php/src/ComprehendMedical/ComprehendMedicalClient.php',
    'Aws\\ComprehendMedical\\Exception\\ComprehendMedicalException' => $vendorDir . '/aws/aws-sdk-php/src/ComprehendMedical/Exception/ComprehendMedicalException.php',
    'Aws\\Comprehend\\ComprehendClient' => $vendorDir . '/aws/aws-sdk-php/src/Comprehend/ComprehendClient.php',
    'Aws\\Comprehend\\Exception\\ComprehendException' => $vendorDir . '/aws/aws-sdk-php/src/Comprehend/Exception/ComprehendException.php',
    'Aws\\ComputeOptimizer\\ComputeOptimizerClient' => $vendorDir . '/aws/aws-sdk-php/src/ComputeOptimizer/ComputeOptimizerClient.php',
    'Aws\\ComputeOptimizer\\Exception\\ComputeOptimizerException' => $vendorDir . '/aws/aws-sdk-php/src/ComputeOptimizer/Exception/ComputeOptimizerException.php',
    'Aws\\ConfigService\\ConfigServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ConfigService/ConfigServiceClient.php',
    'Aws\\ConfigService\\Exception\\ConfigServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ConfigService/Exception/ConfigServiceException.php',
    'Aws\\ConfigurationProviderInterface' => $vendorDir . '/aws/aws-sdk-php/src/ConfigurationProviderInterface.php',
    'Aws\\Configuration\\ConfigurationResolver' => $vendorDir . '/aws/aws-sdk-php/src/Configuration/ConfigurationResolver.php',
    'Aws\\ConnectCampaignService\\ConnectCampaignServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ConnectCampaignService/ConnectCampaignServiceClient.php',
    'Aws\\ConnectCampaignService\\Exception\\ConnectCampaignServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ConnectCampaignService/Exception/ConnectCampaignServiceException.php',
    'Aws\\ConnectCases\\ConnectCasesClient' => $vendorDir . '/aws/aws-sdk-php/src/ConnectCases/ConnectCasesClient.php',
    'Aws\\ConnectCases\\Exception\\ConnectCasesException' => $vendorDir . '/aws/aws-sdk-php/src/ConnectCases/Exception/ConnectCasesException.php',
    'Aws\\ConnectContactLens\\ConnectContactLensClient' => $vendorDir . '/aws/aws-sdk-php/src/ConnectContactLens/ConnectContactLensClient.php',
    'Aws\\ConnectContactLens\\Exception\\ConnectContactLensException' => $vendorDir . '/aws/aws-sdk-php/src/ConnectContactLens/Exception/ConnectContactLensException.php',
    'Aws\\ConnectParticipant\\ConnectParticipantClient' => $vendorDir . '/aws/aws-sdk-php/src/ConnectParticipant/ConnectParticipantClient.php',
    'Aws\\ConnectParticipant\\Exception\\ConnectParticipantException' => $vendorDir . '/aws/aws-sdk-php/src/ConnectParticipant/Exception/ConnectParticipantException.php',
    'Aws\\ConnectWisdomService\\ConnectWisdomServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ConnectWisdomService/ConnectWisdomServiceClient.php',
    'Aws\\ConnectWisdomService\\Exception\\ConnectWisdomServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ConnectWisdomService/Exception/ConnectWisdomServiceException.php',
    'Aws\\Connect\\ConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/Connect/ConnectClient.php',
    'Aws\\Connect\\Exception\\ConnectException' => $vendorDir . '/aws/aws-sdk-php/src/Connect/Exception/ConnectException.php',
    'Aws\\ControlCatalog\\ControlCatalogClient' => $vendorDir . '/aws/aws-sdk-php/src/ControlCatalog/ControlCatalogClient.php',
    'Aws\\ControlCatalog\\Exception\\ControlCatalogException' => $vendorDir . '/aws/aws-sdk-php/src/ControlCatalog/Exception/ControlCatalogException.php',
    'Aws\\ControlTower\\ControlTowerClient' => $vendorDir . '/aws/aws-sdk-php/src/ControlTower/ControlTowerClient.php',
    'Aws\\ControlTower\\Exception\\ControlTowerException' => $vendorDir . '/aws/aws-sdk-php/src/ControlTower/Exception/ControlTowerException.php',
    'Aws\\CostExplorer\\CostExplorerClient' => $vendorDir . '/aws/aws-sdk-php/src/CostExplorer/CostExplorerClient.php',
    'Aws\\CostExplorer\\Exception\\CostExplorerException' => $vendorDir . '/aws/aws-sdk-php/src/CostExplorer/Exception/CostExplorerException.php',
    'Aws\\CostOptimizationHub\\CostOptimizationHubClient' => $vendorDir . '/aws/aws-sdk-php/src/CostOptimizationHub/CostOptimizationHubClient.php',
    'Aws\\CostOptimizationHub\\Exception\\CostOptimizationHubException' => $vendorDir . '/aws/aws-sdk-php/src/CostOptimizationHub/Exception/CostOptimizationHubException.php',
    'Aws\\CostandUsageReportService\\CostandUsageReportServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/CostandUsageReportService/CostandUsageReportServiceClient.php',
    'Aws\\CostandUsageReportService\\Exception\\CostandUsageReportServiceException' => $vendorDir . '/aws/aws-sdk-php/src/CostandUsageReportService/Exception/CostandUsageReportServiceException.php',
    'Aws\\Credentials\\AssumeRoleCredentialProvider' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/AssumeRoleCredentialProvider.php',
    'Aws\\Credentials\\AssumeRoleWithWebIdentityCredentialProvider' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/AssumeRoleWithWebIdentityCredentialProvider.php',
    'Aws\\Credentials\\CredentialProvider' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/CredentialProvider.php',
    'Aws\\Credentials\\Credentials' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/Credentials.php',
    'Aws\\Credentials\\CredentialsInterface' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/CredentialsInterface.php',
    'Aws\\Credentials\\CredentialsUtils' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/CredentialsUtils.php',
    'Aws\\Credentials\\EcsCredentialProvider' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/EcsCredentialProvider.php',
    'Aws\\Credentials\\InstanceProfileProvider' => $vendorDir . '/aws/aws-sdk-php/src/Credentials/InstanceProfileProvider.php',
    'Aws\\Crypto\\AbstractCryptoClient' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AbstractCryptoClient.php',
    'Aws\\Crypto\\AbstractCryptoClientV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AbstractCryptoClientV2.php',
    'Aws\\Crypto\\AesDecryptingStream' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesDecryptingStream.php',
    'Aws\\Crypto\\AesEncryptingStream' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesEncryptingStream.php',
    'Aws\\Crypto\\AesGcmDecryptingStream' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesGcmDecryptingStream.php',
    'Aws\\Crypto\\AesGcmEncryptingStream' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesGcmEncryptingStream.php',
    'Aws\\Crypto\\AesStreamInterface' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesStreamInterface.php',
    'Aws\\Crypto\\AesStreamInterfaceV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/AesStreamInterfaceV2.php',
    'Aws\\Crypto\\Cipher\\Cbc' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Cipher/Cbc.php',
    'Aws\\Crypto\\Cipher\\CipherBuilderTrait' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Cipher/CipherBuilderTrait.php',
    'Aws\\Crypto\\Cipher\\CipherMethod' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Cipher/CipherMethod.php',
    'Aws\\Crypto\\DecryptionTrait' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/DecryptionTrait.php',
    'Aws\\Crypto\\DecryptionTraitV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/DecryptionTraitV2.php',
    'Aws\\Crypto\\EncryptionTrait' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/EncryptionTrait.php',
    'Aws\\Crypto\\EncryptionTraitV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/EncryptionTraitV2.php',
    'Aws\\Crypto\\KmsMaterialsProvider' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/KmsMaterialsProvider.php',
    'Aws\\Crypto\\KmsMaterialsProviderV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/KmsMaterialsProviderV2.php',
    'Aws\\Crypto\\MaterialsProvider' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MaterialsProvider.php',
    'Aws\\Crypto\\MaterialsProviderInterface' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MaterialsProviderInterface.php',
    'Aws\\Crypto\\MaterialsProviderInterfaceV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MaterialsProviderInterfaceV2.php',
    'Aws\\Crypto\\MaterialsProviderV2' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MaterialsProviderV2.php',
    'Aws\\Crypto\\MetadataEnvelope' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MetadataEnvelope.php',
    'Aws\\Crypto\\MetadataStrategyInterface' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/MetadataStrategyInterface.php',
    'Aws\\Crypto\\Polyfill\\AesGcm' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Polyfill/AesGcm.php',
    'Aws\\Crypto\\Polyfill\\ByteArray' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Polyfill/ByteArray.php',
    'Aws\\Crypto\\Polyfill\\Gmac' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Polyfill/Gmac.php',
    'Aws\\Crypto\\Polyfill\\Key' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Polyfill/Key.php',
    'Aws\\Crypto\\Polyfill\\NeedsTrait' => $vendorDir . '/aws/aws-sdk-php/src/Crypto/Polyfill/NeedsTrait.php',
    'Aws\\CustomerProfiles\\CustomerProfilesClient' => $vendorDir . '/aws/aws-sdk-php/src/CustomerProfiles/CustomerProfilesClient.php',
    'Aws\\CustomerProfiles\\Exception\\CustomerProfilesException' => $vendorDir . '/aws/aws-sdk-php/src/CustomerProfiles/Exception/CustomerProfilesException.php',
    'Aws\\DAX\\DAXClient' => $vendorDir . '/aws/aws-sdk-php/src/DAX/DAXClient.php',
    'Aws\\DAX\\Exception\\DAXException' => $vendorDir . '/aws/aws-sdk-php/src/DAX/Exception/DAXException.php',
    'Aws\\DLM\\DLMClient' => $vendorDir . '/aws/aws-sdk-php/src/DLM/DLMClient.php',
    'Aws\\DLM\\Exception\\DLMException' => $vendorDir . '/aws/aws-sdk-php/src/DLM/Exception/DLMException.php',
    'Aws\\DataExchange\\DataExchangeClient' => $vendorDir . '/aws/aws-sdk-php/src/DataExchange/DataExchangeClient.php',
    'Aws\\DataExchange\\Exception\\DataExchangeException' => $vendorDir . '/aws/aws-sdk-php/src/DataExchange/Exception/DataExchangeException.php',
    'Aws\\DataPipeline\\DataPipelineClient' => $vendorDir . '/aws/aws-sdk-php/src/DataPipeline/DataPipelineClient.php',
    'Aws\\DataPipeline\\Exception\\DataPipelineException' => $vendorDir . '/aws/aws-sdk-php/src/DataPipeline/Exception/DataPipelineException.php',
    'Aws\\DataSync\\DataSyncClient' => $vendorDir . '/aws/aws-sdk-php/src/DataSync/DataSyncClient.php',
    'Aws\\DataSync\\Exception\\DataSyncException' => $vendorDir . '/aws/aws-sdk-php/src/DataSync/Exception/DataSyncException.php',
    'Aws\\DataZone\\DataZoneClient' => $vendorDir . '/aws/aws-sdk-php/src/DataZone/DataZoneClient.php',
    'Aws\\DataZone\\Exception\\DataZoneException' => $vendorDir . '/aws/aws-sdk-php/src/DataZone/Exception/DataZoneException.php',
    'Aws\\DatabaseMigrationService\\DatabaseMigrationServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/DatabaseMigrationService/DatabaseMigrationServiceClient.php',
    'Aws\\DatabaseMigrationService\\Exception\\DatabaseMigrationServiceException' => $vendorDir . '/aws/aws-sdk-php/src/DatabaseMigrationService/Exception/DatabaseMigrationServiceException.php',
    'Aws\\Deadline\\DeadlineClient' => $vendorDir . '/aws/aws-sdk-php/src/Deadline/DeadlineClient.php',
    'Aws\\Deadline\\Exception\\DeadlineException' => $vendorDir . '/aws/aws-sdk-php/src/Deadline/Exception/DeadlineException.php',
    'Aws\\DefaultsMode\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/DefaultsMode/Configuration.php',
    'Aws\\DefaultsMode\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/DefaultsMode/ConfigurationInterface.php',
    'Aws\\DefaultsMode\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/DefaultsMode/ConfigurationProvider.php',
    'Aws\\DefaultsMode\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/DefaultsMode/Exception/ConfigurationException.php',
    'Aws\\Detective\\DetectiveClient' => $vendorDir . '/aws/aws-sdk-php/src/Detective/DetectiveClient.php',
    'Aws\\Detective\\Exception\\DetectiveException' => $vendorDir . '/aws/aws-sdk-php/src/Detective/Exception/DetectiveException.php',
    'Aws\\DevOpsGuru\\DevOpsGuruClient' => $vendorDir . '/aws/aws-sdk-php/src/DevOpsGuru/DevOpsGuruClient.php',
    'Aws\\DevOpsGuru\\Exception\\DevOpsGuruException' => $vendorDir . '/aws/aws-sdk-php/src/DevOpsGuru/Exception/DevOpsGuruException.php',
    'Aws\\DeviceFarm\\DeviceFarmClient' => $vendorDir . '/aws/aws-sdk-php/src/DeviceFarm/DeviceFarmClient.php',
    'Aws\\DeviceFarm\\Exception\\DeviceFarmException' => $vendorDir . '/aws/aws-sdk-php/src/DeviceFarm/Exception/DeviceFarmException.php',
    'Aws\\DirectConnect\\DirectConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/DirectConnect/DirectConnectClient.php',
    'Aws\\DirectConnect\\Exception\\DirectConnectException' => $vendorDir . '/aws/aws-sdk-php/src/DirectConnect/Exception/DirectConnectException.php',
    'Aws\\DirectoryService\\DirectoryServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/DirectoryService/DirectoryServiceClient.php',
    'Aws\\DirectoryService\\Exception\\DirectoryServiceException' => $vendorDir . '/aws/aws-sdk-php/src/DirectoryService/Exception/DirectoryServiceException.php',
    'Aws\\DocDBElastic\\DocDBElasticClient' => $vendorDir . '/aws/aws-sdk-php/src/DocDBElastic/DocDBElasticClient.php',
    'Aws\\DocDBElastic\\Exception\\DocDBElasticException' => $vendorDir . '/aws/aws-sdk-php/src/DocDBElastic/Exception/DocDBElasticException.php',
    'Aws\\DocDB\\DocDBClient' => $vendorDir . '/aws/aws-sdk-php/src/DocDB/DocDBClient.php',
    'Aws\\DocDB\\Exception\\DocDBException' => $vendorDir . '/aws/aws-sdk-php/src/DocDB/Exception/DocDBException.php',
    'Aws\\DoctrineCacheAdapter' => $vendorDir . '/aws/aws-sdk-php/src/DoctrineCacheAdapter.php',
    'Aws\\DynamoDbStreams\\DynamoDbStreamsClient' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDbStreams/DynamoDbStreamsClient.php',
    'Aws\\DynamoDbStreams\\Exception\\DynamoDbStreamsException' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDbStreams/Exception/DynamoDbStreamsException.php',
    'Aws\\DynamoDb\\BinaryValue' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/BinaryValue.php',
    'Aws\\DynamoDb\\DynamoDbClient' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/DynamoDbClient.php',
    'Aws\\DynamoDb\\Exception\\DynamoDbException' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/Exception/DynamoDbException.php',
    'Aws\\DynamoDb\\LockingSessionConnection' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/LockingSessionConnection.php',
    'Aws\\DynamoDb\\Marshaler' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/Marshaler.php',
    'Aws\\DynamoDb\\NumberValue' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/NumberValue.php',
    'Aws\\DynamoDb\\SessionConnectionConfigTrait' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/SessionConnectionConfigTrait.php',
    'Aws\\DynamoDb\\SessionConnectionInterface' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/SessionConnectionInterface.php',
    'Aws\\DynamoDb\\SessionHandler' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/SessionHandler.php',
    'Aws\\DynamoDb\\SetValue' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/SetValue.php',
    'Aws\\DynamoDb\\StandardSessionConnection' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/StandardSessionConnection.php',
    'Aws\\DynamoDb\\WriteRequestBatch' => $vendorDir . '/aws/aws-sdk-php/src/DynamoDb/WriteRequestBatch.php',
    'Aws\\EBS\\EBSClient' => $vendorDir . '/aws/aws-sdk-php/src/EBS/EBSClient.php',
    'Aws\\EBS\\Exception\\EBSException' => $vendorDir . '/aws/aws-sdk-php/src/EBS/Exception/EBSException.php',
    'Aws\\EC2InstanceConnect\\EC2InstanceConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/EC2InstanceConnect/EC2InstanceConnectClient.php',
    'Aws\\EC2InstanceConnect\\Exception\\EC2InstanceConnectException' => $vendorDir . '/aws/aws-sdk-php/src/EC2InstanceConnect/Exception/EC2InstanceConnectException.php',
    'Aws\\ECRPublic\\ECRPublicClient' => $vendorDir . '/aws/aws-sdk-php/src/ECRPublic/ECRPublicClient.php',
    'Aws\\ECRPublic\\Exception\\ECRPublicException' => $vendorDir . '/aws/aws-sdk-php/src/ECRPublic/Exception/ECRPublicException.php',
    'Aws\\EKSAuth\\EKSAuthClient' => $vendorDir . '/aws/aws-sdk-php/src/EKSAuth/EKSAuthClient.php',
    'Aws\\EKSAuth\\Exception\\EKSAuthException' => $vendorDir . '/aws/aws-sdk-php/src/EKSAuth/Exception/EKSAuthException.php',
    'Aws\\EKS\\EKSClient' => $vendorDir . '/aws/aws-sdk-php/src/EKS/EKSClient.php',
    'Aws\\EKS\\Exception\\EKSException' => $vendorDir . '/aws/aws-sdk-php/src/EKS/Exception/EKSException.php',
    'Aws\\EMRContainers\\EMRContainersClient' => $vendorDir . '/aws/aws-sdk-php/src/EMRContainers/EMRContainersClient.php',
    'Aws\\EMRContainers\\Exception\\EMRContainersException' => $vendorDir . '/aws/aws-sdk-php/src/EMRContainers/Exception/EMRContainersException.php',
    'Aws\\EMRServerless\\EMRServerlessClient' => $vendorDir . '/aws/aws-sdk-php/src/EMRServerless/EMRServerlessClient.php',
    'Aws\\EMRServerless\\Exception\\EMRServerlessException' => $vendorDir . '/aws/aws-sdk-php/src/EMRServerless/Exception/EMRServerlessException.php',
    'Aws\\Ec2\\Ec2Client' => $vendorDir . '/aws/aws-sdk-php/src/Ec2/Ec2Client.php',
    'Aws\\Ec2\\Exception\\Ec2Exception' => $vendorDir . '/aws/aws-sdk-php/src/Ec2/Exception/Ec2Exception.php',
    'Aws\\Ecr\\EcrClient' => $vendorDir . '/aws/aws-sdk-php/src/Ecr/EcrClient.php',
    'Aws\\Ecr\\Exception\\EcrException' => $vendorDir . '/aws/aws-sdk-php/src/Ecr/Exception/EcrException.php',
    'Aws\\Ecs\\EcsClient' => $vendorDir . '/aws/aws-sdk-php/src/Ecs/EcsClient.php',
    'Aws\\Ecs\\Exception\\EcsException' => $vendorDir . '/aws/aws-sdk-php/src/Ecs/Exception/EcsException.php',
    'Aws\\Efs\\EfsClient' => $vendorDir . '/aws/aws-sdk-php/src/Efs/EfsClient.php',
    'Aws\\Efs\\Exception\\EfsException' => $vendorDir . '/aws/aws-sdk-php/src/Efs/Exception/EfsException.php',
    'Aws\\ElastiCache\\ElastiCacheClient' => $vendorDir . '/aws/aws-sdk-php/src/ElastiCache/ElastiCacheClient.php',
    'Aws\\ElastiCache\\Exception\\ElastiCacheException' => $vendorDir . '/aws/aws-sdk-php/src/ElastiCache/Exception/ElastiCacheException.php',
    'Aws\\ElasticBeanstalk\\ElasticBeanstalkClient' => $vendorDir . '/aws/aws-sdk-php/src/ElasticBeanstalk/ElasticBeanstalkClient.php',
    'Aws\\ElasticBeanstalk\\Exception\\ElasticBeanstalkException' => $vendorDir . '/aws/aws-sdk-php/src/ElasticBeanstalk/Exception/ElasticBeanstalkException.php',
    'Aws\\ElasticInference\\ElasticInferenceClient' => $vendorDir . '/aws/aws-sdk-php/src/ElasticInference/ElasticInferenceClient.php',
    'Aws\\ElasticInference\\Exception\\ElasticInferenceException' => $vendorDir . '/aws/aws-sdk-php/src/ElasticInference/Exception/ElasticInferenceException.php',
    'Aws\\ElasticLoadBalancingV2\\ElasticLoadBalancingV2Client' => $vendorDir . '/aws/aws-sdk-php/src/ElasticLoadBalancingV2/ElasticLoadBalancingV2Client.php',
    'Aws\\ElasticLoadBalancingV2\\Exception\\ElasticLoadBalancingV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/ElasticLoadBalancingV2/Exception/ElasticLoadBalancingV2Exception.php',
    'Aws\\ElasticLoadBalancing\\ElasticLoadBalancingClient' => $vendorDir . '/aws/aws-sdk-php/src/ElasticLoadBalancing/ElasticLoadBalancingClient.php',
    'Aws\\ElasticLoadBalancing\\Exception\\ElasticLoadBalancingException' => $vendorDir . '/aws/aws-sdk-php/src/ElasticLoadBalancing/Exception/ElasticLoadBalancingException.php',
    'Aws\\ElasticTranscoder\\ElasticTranscoderClient' => $vendorDir . '/aws/aws-sdk-php/src/ElasticTranscoder/ElasticTranscoderClient.php',
    'Aws\\ElasticTranscoder\\Exception\\ElasticTranscoderException' => $vendorDir . '/aws/aws-sdk-php/src/ElasticTranscoder/Exception/ElasticTranscoderException.php',
    'Aws\\ElasticsearchService\\ElasticsearchServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ElasticsearchService/ElasticsearchServiceClient.php',
    'Aws\\ElasticsearchService\\Exception\\ElasticsearchServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ElasticsearchService/Exception/ElasticsearchServiceException.php',
    'Aws\\Emr\\EmrClient' => $vendorDir . '/aws/aws-sdk-php/src/Emr/EmrClient.php',
    'Aws\\Emr\\Exception\\EmrException' => $vendorDir . '/aws/aws-sdk-php/src/Emr/Exception/EmrException.php',
    'Aws\\EndpointDiscovery\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/Configuration.php',
    'Aws\\EndpointDiscovery\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/ConfigurationInterface.php',
    'Aws\\EndpointDiscovery\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/ConfigurationProvider.php',
    'Aws\\EndpointDiscovery\\EndpointDiscoveryMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/EndpointDiscoveryMiddleware.php',
    'Aws\\EndpointDiscovery\\EndpointList' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/EndpointList.php',
    'Aws\\EndpointDiscovery\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/EndpointDiscovery/Exception/ConfigurationException.php',
    'Aws\\EndpointParameterMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/EndpointParameterMiddleware.php',
    'Aws\\EndpointV2\\EndpointDefinitionProvider' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/EndpointDefinitionProvider.php',
    'Aws\\EndpointV2\\EndpointProviderV2' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/EndpointProviderV2.php',
    'Aws\\EndpointV2\\EndpointV2Middleware' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/EndpointV2Middleware.php',
    'Aws\\EndpointV2\\EndpointV2SerializerTrait' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/EndpointV2SerializerTrait.php',
    'Aws\\EndpointV2\\Rule\\AbstractRule' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Rule/AbstractRule.php',
    'Aws\\EndpointV2\\Rule\\EndpointRule' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Rule/EndpointRule.php',
    'Aws\\EndpointV2\\Rule\\ErrorRule' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Rule/ErrorRule.php',
    'Aws\\EndpointV2\\Rule\\RuleCreator' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Rule/RuleCreator.php',
    'Aws\\EndpointV2\\Rule\\TreeRule' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Rule/TreeRule.php',
    'Aws\\EndpointV2\\Ruleset\\Ruleset' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Ruleset/Ruleset.php',
    'Aws\\EndpointV2\\Ruleset\\RulesetEndpoint' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Ruleset/RulesetEndpoint.php',
    'Aws\\EndpointV2\\Ruleset\\RulesetParameter' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Ruleset/RulesetParameter.php',
    'Aws\\EndpointV2\\Ruleset\\RulesetStandardLibrary' => $vendorDir . '/aws/aws-sdk-php/src/EndpointV2/Ruleset/RulesetStandardLibrary.php',
    'Aws\\Endpoint\\EndpointProvider' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/EndpointProvider.php',
    'Aws\\Endpoint\\Partition' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/Partition.php',
    'Aws\\Endpoint\\PartitionEndpointProvider' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/PartitionEndpointProvider.php',
    'Aws\\Endpoint\\PartitionInterface' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/PartitionInterface.php',
    'Aws\\Endpoint\\PatternEndpointProvider' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/PatternEndpointProvider.php',
    'Aws\\Endpoint\\UseDualstackEndpoint\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseDualstackEndpoint/Configuration.php',
    'Aws\\Endpoint\\UseDualstackEndpoint\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseDualstackEndpoint/ConfigurationInterface.php',
    'Aws\\Endpoint\\UseDualstackEndpoint\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseDualstackEndpoint/ConfigurationProvider.php',
    'Aws\\Endpoint\\UseDualstackEndpoint\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseDualstackEndpoint/Exception/ConfigurationException.php',
    'Aws\\Endpoint\\UseFipsEndpoint\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseFipsEndpoint/Configuration.php',
    'Aws\\Endpoint\\UseFipsEndpoint\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseFipsEndpoint/ConfigurationInterface.php',
    'Aws\\Endpoint\\UseFipsEndpoint\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseFipsEndpoint/ConfigurationProvider.php',
    'Aws\\Endpoint\\UseFipsEndpoint\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/Endpoint/UseFipsEndpoint/Exception/ConfigurationException.php',
    'Aws\\EntityResolution\\EntityResolutionClient' => $vendorDir . '/aws/aws-sdk-php/src/EntityResolution/EntityResolutionClient.php',
    'Aws\\EntityResolution\\Exception\\EntityResolutionException' => $vendorDir . '/aws/aws-sdk-php/src/EntityResolution/Exception/EntityResolutionException.php',
    'Aws\\EventBridge\\EventBridgeClient' => $vendorDir . '/aws/aws-sdk-php/src/EventBridge/EventBridgeClient.php',
    'Aws\\EventBridge\\EventBridgeEndpointMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/EventBridge/EventBridgeEndpointMiddleware.php',
    'Aws\\EventBridge\\Exception\\EventBridgeException' => $vendorDir . '/aws/aws-sdk-php/src/EventBridge/Exception/EventBridgeException.php',
    'Aws\\Exception\\AwsException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/AwsException.php',
    'Aws\\Exception\\CommonRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/CommonRuntimeException.php',
    'Aws\\Exception\\CouldNotCreateChecksumException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/CouldNotCreateChecksumException.php',
    'Aws\\Exception\\CredentialsException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/CredentialsException.php',
    'Aws\\Exception\\CryptoException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/CryptoException.php',
    'Aws\\Exception\\CryptoPolyfillException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/CryptoPolyfillException.php',
    'Aws\\Exception\\EventStreamDataException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/EventStreamDataException.php',
    'Aws\\Exception\\IncalculablePayloadException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/IncalculablePayloadException.php',
    'Aws\\Exception\\InvalidJsonException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/InvalidJsonException.php',
    'Aws\\Exception\\InvalidRegionException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/InvalidRegionException.php',
    'Aws\\Exception\\MultipartUploadException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/MultipartUploadException.php',
    'Aws\\Exception\\TokenException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/TokenException.php',
    'Aws\\Exception\\UnresolvedApiException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/UnresolvedApiException.php',
    'Aws\\Exception\\UnresolvedEndpointException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/UnresolvedEndpointException.php',
    'Aws\\Exception\\UnresolvedSignatureException' => $vendorDir . '/aws/aws-sdk-php/src/Exception/UnresolvedSignatureException.php',
    'Aws\\FIS\\Exception\\FISException' => $vendorDir . '/aws/aws-sdk-php/src/FIS/Exception/FISException.php',
    'Aws\\FIS\\FISClient' => $vendorDir . '/aws/aws-sdk-php/src/FIS/FISClient.php',
    'Aws\\FMS\\Exception\\FMSException' => $vendorDir . '/aws/aws-sdk-php/src/FMS/Exception/FMSException.php',
    'Aws\\FMS\\FMSClient' => $vendorDir . '/aws/aws-sdk-php/src/FMS/FMSClient.php',
    'Aws\\FSx\\Exception\\FSxException' => $vendorDir . '/aws/aws-sdk-php/src/FSx/Exception/FSxException.php',
    'Aws\\FSx\\FSxClient' => $vendorDir . '/aws/aws-sdk-php/src/FSx/FSxClient.php',
    'Aws\\FinSpaceData\\Exception\\FinSpaceDataException' => $vendorDir . '/aws/aws-sdk-php/src/FinSpaceData/Exception/FinSpaceDataException.php',
    'Aws\\FinSpaceData\\FinSpaceDataClient' => $vendorDir . '/aws/aws-sdk-php/src/FinSpaceData/FinSpaceDataClient.php',
    'Aws\\Firehose\\Exception\\FirehoseException' => $vendorDir . '/aws/aws-sdk-php/src/Firehose/Exception/FirehoseException.php',
    'Aws\\Firehose\\FirehoseClient' => $vendorDir . '/aws/aws-sdk-php/src/Firehose/FirehoseClient.php',
    'Aws\\ForecastQueryService\\Exception\\ForecastQueryServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ForecastQueryService/Exception/ForecastQueryServiceException.php',
    'Aws\\ForecastQueryService\\ForecastQueryServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ForecastQueryService/ForecastQueryServiceClient.php',
    'Aws\\ForecastService\\Exception\\ForecastServiceException' => $vendorDir . '/aws/aws-sdk-php/src/ForecastService/Exception/ForecastServiceException.php',
    'Aws\\ForecastService\\ForecastServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/ForecastService/ForecastServiceClient.php',
    'Aws\\FraudDetector\\Exception\\FraudDetectorException' => $vendorDir . '/aws/aws-sdk-php/src/FraudDetector/Exception/FraudDetectorException.php',
    'Aws\\FraudDetector\\FraudDetectorClient' => $vendorDir . '/aws/aws-sdk-php/src/FraudDetector/FraudDetectorClient.php',
    'Aws\\FreeTier\\Exception\\FreeTierException' => $vendorDir . '/aws/aws-sdk-php/src/FreeTier/Exception/FreeTierException.php',
    'Aws\\FreeTier\\FreeTierClient' => $vendorDir . '/aws/aws-sdk-php/src/FreeTier/FreeTierClient.php',
    'Aws\\GameLift\\Exception\\GameLiftException' => $vendorDir . '/aws/aws-sdk-php/src/GameLift/Exception/GameLiftException.php',
    'Aws\\GameLift\\GameLiftClient' => $vendorDir . '/aws/aws-sdk-php/src/GameLift/GameLiftClient.php',
    'Aws\\Glacier\\Exception\\GlacierException' => $vendorDir . '/aws/aws-sdk-php/src/Glacier/Exception/GlacierException.php',
    'Aws\\Glacier\\GlacierClient' => $vendorDir . '/aws/aws-sdk-php/src/Glacier/GlacierClient.php',
    'Aws\\Glacier\\MultipartUploader' => $vendorDir . '/aws/aws-sdk-php/src/Glacier/MultipartUploader.php',
    'Aws\\Glacier\\TreeHash' => $vendorDir . '/aws/aws-sdk-php/src/Glacier/TreeHash.php',
    'Aws\\GlobalAccelerator\\Exception\\GlobalAcceleratorException' => $vendorDir . '/aws/aws-sdk-php/src/GlobalAccelerator/Exception/GlobalAcceleratorException.php',
    'Aws\\GlobalAccelerator\\GlobalAcceleratorClient' => $vendorDir . '/aws/aws-sdk-php/src/GlobalAccelerator/GlobalAcceleratorClient.php',
    'Aws\\GlueDataBrew\\Exception\\GlueDataBrewException' => $vendorDir . '/aws/aws-sdk-php/src/GlueDataBrew/Exception/GlueDataBrewException.php',
    'Aws\\GlueDataBrew\\GlueDataBrewClient' => $vendorDir . '/aws/aws-sdk-php/src/GlueDataBrew/GlueDataBrewClient.php',
    'Aws\\Glue\\Exception\\GlueException' => $vendorDir . '/aws/aws-sdk-php/src/Glue/Exception/GlueException.php',
    'Aws\\Glue\\GlueClient' => $vendorDir . '/aws/aws-sdk-php/src/Glue/GlueClient.php',
    'Aws\\GreengrassV2\\Exception\\GreengrassV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/GreengrassV2/Exception/GreengrassV2Exception.php',
    'Aws\\GreengrassV2\\GreengrassV2Client' => $vendorDir . '/aws/aws-sdk-php/src/GreengrassV2/GreengrassV2Client.php',
    'Aws\\Greengrass\\Exception\\GreengrassException' => $vendorDir . '/aws/aws-sdk-php/src/Greengrass/Exception/GreengrassException.php',
    'Aws\\Greengrass\\GreengrassClient' => $vendorDir . '/aws/aws-sdk-php/src/Greengrass/GreengrassClient.php',
    'Aws\\GroundStation\\Exception\\GroundStationException' => $vendorDir . '/aws/aws-sdk-php/src/GroundStation/Exception/GroundStationException.php',
    'Aws\\GroundStation\\GroundStationClient' => $vendorDir . '/aws/aws-sdk-php/src/GroundStation/GroundStationClient.php',
    'Aws\\GuardDuty\\Exception\\GuardDutyException' => $vendorDir . '/aws/aws-sdk-php/src/GuardDuty/Exception/GuardDutyException.php',
    'Aws\\GuardDuty\\GuardDutyClient' => $vendorDir . '/aws/aws-sdk-php/src/GuardDuty/GuardDutyClient.php',
    'Aws\\HandlerList' => $vendorDir . '/aws/aws-sdk-php/src/HandlerList.php',
    'Aws\\Handler\\GuzzleV5\\GuzzleHandler' => $vendorDir . '/aws/aws-sdk-php/src/Handler/GuzzleV5/GuzzleHandler.php',
    'Aws\\Handler\\GuzzleV5\\GuzzleStream' => $vendorDir . '/aws/aws-sdk-php/src/Handler/GuzzleV5/GuzzleStream.php',
    'Aws\\Handler\\GuzzleV5\\PsrStream' => $vendorDir . '/aws/aws-sdk-php/src/Handler/GuzzleV5/PsrStream.php',
    'Aws\\Handler\\GuzzleV6\\GuzzleHandler' => $vendorDir . '/aws/aws-sdk-php/src/Handler/GuzzleV6/GuzzleHandler.php',
    'Aws\\HasDataTrait' => $vendorDir . '/aws/aws-sdk-php/src/HasDataTrait.php',
    'Aws\\HasMonitoringEventsTrait' => $vendorDir . '/aws/aws-sdk-php/src/HasMonitoringEventsTrait.php',
    'Aws\\HashInterface' => $vendorDir . '/aws/aws-sdk-php/src/HashInterface.php',
    'Aws\\HashingStream' => $vendorDir . '/aws/aws-sdk-php/src/HashingStream.php',
    'Aws\\HealthLake\\Exception\\HealthLakeException' => $vendorDir . '/aws/aws-sdk-php/src/HealthLake/Exception/HealthLakeException.php',
    'Aws\\HealthLake\\HealthLakeClient' => $vendorDir . '/aws/aws-sdk-php/src/HealthLake/HealthLakeClient.php',
    'Aws\\Health\\Exception\\HealthException' => $vendorDir . '/aws/aws-sdk-php/src/Health/Exception/HealthException.php',
    'Aws\\Health\\HealthClient' => $vendorDir . '/aws/aws-sdk-php/src/Health/HealthClient.php',
    'Aws\\History' => $vendorDir . '/aws/aws-sdk-php/src/History.php',
    'Aws\\IVSRealTime\\Exception\\IVSRealTimeException' => $vendorDir . '/aws/aws-sdk-php/src/IVSRealTime/Exception/IVSRealTimeException.php',
    'Aws\\IVSRealTime\\IVSRealTimeClient' => $vendorDir . '/aws/aws-sdk-php/src/IVSRealTime/IVSRealTimeClient.php',
    'Aws\\IVS\\Exception\\IVSException' => $vendorDir . '/aws/aws-sdk-php/src/IVS/Exception/IVSException.php',
    'Aws\\IVS\\IVSClient' => $vendorDir . '/aws/aws-sdk-php/src/IVS/IVSClient.php',
    'Aws\\Iam\\Exception\\IamException' => $vendorDir . '/aws/aws-sdk-php/src/Iam/Exception/IamException.php',
    'Aws\\Iam\\IamClient' => $vendorDir . '/aws/aws-sdk-php/src/Iam/IamClient.php',
    'Aws\\IdempotencyTokenMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/IdempotencyTokenMiddleware.php',
    'Aws\\IdentityStore\\Exception\\IdentityStoreException' => $vendorDir . '/aws/aws-sdk-php/src/IdentityStore/Exception/IdentityStoreException.php',
    'Aws\\IdentityStore\\IdentityStoreClient' => $vendorDir . '/aws/aws-sdk-php/src/IdentityStore/IdentityStoreClient.php',
    'Aws\\Identity\\AwsCredentialIdentity' => $vendorDir . '/aws/aws-sdk-php/src/Identity/AwsCredentialIdentity.php',
    'Aws\\Identity\\BearerTokenIdentity' => $vendorDir . '/aws/aws-sdk-php/src/Identity/BearerTokenIdentity.php',
    'Aws\\Identity\\IdentityInterface' => $vendorDir . '/aws/aws-sdk-php/src/Identity/IdentityInterface.php',
    'Aws\\Identity\\S3\\S3ExpressIdentity' => $vendorDir . '/aws/aws-sdk-php/src/Identity/S3/S3ExpressIdentity.php',
    'Aws\\Identity\\S3\\S3ExpressIdentityProvider' => $vendorDir . '/aws/aws-sdk-php/src/Identity/S3/S3ExpressIdentityProvider.php',
    'Aws\\ImportExport\\Exception\\ImportExportException' => $vendorDir . '/aws/aws-sdk-php/src/ImportExport/Exception/ImportExportException.php',
    'Aws\\ImportExport\\ImportExportClient' => $vendorDir . '/aws/aws-sdk-php/src/ImportExport/ImportExportClient.php',
    'Aws\\InputValidationMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/InputValidationMiddleware.php',
    'Aws\\Inspector2\\Exception\\Inspector2Exception' => $vendorDir . '/aws/aws-sdk-php/src/Inspector2/Exception/Inspector2Exception.php',
    'Aws\\Inspector2\\Inspector2Client' => $vendorDir . '/aws/aws-sdk-php/src/Inspector2/Inspector2Client.php',
    'Aws\\InspectorScan\\Exception\\InspectorScanException' => $vendorDir . '/aws/aws-sdk-php/src/InspectorScan/Exception/InspectorScanException.php',
    'Aws\\InspectorScan\\InspectorScanClient' => $vendorDir . '/aws/aws-sdk-php/src/InspectorScan/InspectorScanClient.php',
    'Aws\\Inspector\\Exception\\InspectorException' => $vendorDir . '/aws/aws-sdk-php/src/Inspector/Exception/InspectorException.php',
    'Aws\\Inspector\\InspectorClient' => $vendorDir . '/aws/aws-sdk-php/src/Inspector/InspectorClient.php',
    'Aws\\InternetMonitor\\Exception\\InternetMonitorException' => $vendorDir . '/aws/aws-sdk-php/src/InternetMonitor/Exception/InternetMonitorException.php',
    'Aws\\InternetMonitor\\InternetMonitorClient' => $vendorDir . '/aws/aws-sdk-php/src/InternetMonitor/InternetMonitorClient.php',
    'Aws\\IoT1ClickDevicesService\\Exception\\IoT1ClickDevicesServiceException' => $vendorDir . '/aws/aws-sdk-php/src/IoT1ClickDevicesService/Exception/IoT1ClickDevicesServiceException.php',
    'Aws\\IoT1ClickDevicesService\\IoT1ClickDevicesServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/IoT1ClickDevicesService/IoT1ClickDevicesServiceClient.php',
    'Aws\\IoT1ClickProjects\\Exception\\IoT1ClickProjectsException' => $vendorDir . '/aws/aws-sdk-php/src/IoT1ClickProjects/Exception/IoT1ClickProjectsException.php',
    'Aws\\IoT1ClickProjects\\IoT1ClickProjectsClient' => $vendorDir . '/aws/aws-sdk-php/src/IoT1ClickProjects/IoT1ClickProjectsClient.php',
    'Aws\\IoTAnalytics\\Exception\\IoTAnalyticsException' => $vendorDir . '/aws/aws-sdk-php/src/IoTAnalytics/Exception/IoTAnalyticsException.php',
    'Aws\\IoTAnalytics\\IoTAnalyticsClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTAnalytics/IoTAnalyticsClient.php',
    'Aws\\IoTDeviceAdvisor\\Exception\\IoTDeviceAdvisorException' => $vendorDir . '/aws/aws-sdk-php/src/IoTDeviceAdvisor/Exception/IoTDeviceAdvisorException.php',
    'Aws\\IoTDeviceAdvisor\\IoTDeviceAdvisorClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTDeviceAdvisor/IoTDeviceAdvisorClient.php',
    'Aws\\IoTEventsData\\Exception\\IoTEventsDataException' => $vendorDir . '/aws/aws-sdk-php/src/IoTEventsData/Exception/IoTEventsDataException.php',
    'Aws\\IoTEventsData\\IoTEventsDataClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTEventsData/IoTEventsDataClient.php',
    'Aws\\IoTEvents\\Exception\\IoTEventsException' => $vendorDir . '/aws/aws-sdk-php/src/IoTEvents/Exception/IoTEventsException.php',
    'Aws\\IoTEvents\\IoTEventsClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTEvents/IoTEventsClient.php',
    'Aws\\IoTFleetHub\\Exception\\IoTFleetHubException' => $vendorDir . '/aws/aws-sdk-php/src/IoTFleetHub/Exception/IoTFleetHubException.php',
    'Aws\\IoTFleetHub\\IoTFleetHubClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTFleetHub/IoTFleetHubClient.php',
    'Aws\\IoTFleetWise\\Exception\\IoTFleetWiseException' => $vendorDir . '/aws/aws-sdk-php/src/IoTFleetWise/Exception/IoTFleetWiseException.php',
    'Aws\\IoTFleetWise\\IoTFleetWiseClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTFleetWise/IoTFleetWiseClient.php',
    'Aws\\IoTJobsDataPlane\\Exception\\IoTJobsDataPlaneException' => $vendorDir . '/aws/aws-sdk-php/src/IoTJobsDataPlane/Exception/IoTJobsDataPlaneException.php',
    'Aws\\IoTJobsDataPlane\\IoTJobsDataPlaneClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTJobsDataPlane/IoTJobsDataPlaneClient.php',
    'Aws\\IoTSecureTunneling\\Exception\\IoTSecureTunnelingException' => $vendorDir . '/aws/aws-sdk-php/src/IoTSecureTunneling/Exception/IoTSecureTunnelingException.php',
    'Aws\\IoTSecureTunneling\\IoTSecureTunnelingClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTSecureTunneling/IoTSecureTunnelingClient.php',
    'Aws\\IoTSiteWise\\Exception\\IoTSiteWiseException' => $vendorDir . '/aws/aws-sdk-php/src/IoTSiteWise/Exception/IoTSiteWiseException.php',
    'Aws\\IoTSiteWise\\IoTSiteWiseClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTSiteWise/IoTSiteWiseClient.php',
    'Aws\\IoTThingsGraph\\Exception\\IoTThingsGraphException' => $vendorDir . '/aws/aws-sdk-php/src/IoTThingsGraph/Exception/IoTThingsGraphException.php',
    'Aws\\IoTThingsGraph\\IoTThingsGraphClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTThingsGraph/IoTThingsGraphClient.php',
    'Aws\\IoTTwinMaker\\Exception\\IoTTwinMakerException' => $vendorDir . '/aws/aws-sdk-php/src/IoTTwinMaker/Exception/IoTTwinMakerException.php',
    'Aws\\IoTTwinMaker\\IoTTwinMakerClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTTwinMaker/IoTTwinMakerClient.php',
    'Aws\\IoTWireless\\Exception\\IoTWirelessException' => $vendorDir . '/aws/aws-sdk-php/src/IoTWireless/Exception/IoTWirelessException.php',
    'Aws\\IoTWireless\\IoTWirelessClient' => $vendorDir . '/aws/aws-sdk-php/src/IoTWireless/IoTWirelessClient.php',
    'Aws\\IotDataPlane\\Exception\\IotDataPlaneException' => $vendorDir . '/aws/aws-sdk-php/src/IotDataPlane/Exception/IotDataPlaneException.php',
    'Aws\\IotDataPlane\\IotDataPlaneClient' => $vendorDir . '/aws/aws-sdk-php/src/IotDataPlane/IotDataPlaneClient.php',
    'Aws\\Iot\\Exception\\IotException' => $vendorDir . '/aws/aws-sdk-php/src/Iot/Exception/IotException.php',
    'Aws\\Iot\\IotClient' => $vendorDir . '/aws/aws-sdk-php/src/Iot/IotClient.php',
    'Aws\\JsonCompiler' => $vendorDir . '/aws/aws-sdk-php/src/JsonCompiler.php',
    'Aws\\KafkaConnect\\Exception\\KafkaConnectException' => $vendorDir . '/aws/aws-sdk-php/src/KafkaConnect/Exception/KafkaConnectException.php',
    'Aws\\KafkaConnect\\KafkaConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/KafkaConnect/KafkaConnectClient.php',
    'Aws\\Kafka\\Exception\\KafkaException' => $vendorDir . '/aws/aws-sdk-php/src/Kafka/Exception/KafkaException.php',
    'Aws\\Kafka\\KafkaClient' => $vendorDir . '/aws/aws-sdk-php/src/Kafka/KafkaClient.php',
    'Aws\\KendraRanking\\Exception\\KendraRankingException' => $vendorDir . '/aws/aws-sdk-php/src/KendraRanking/Exception/KendraRankingException.php',
    'Aws\\KendraRanking\\KendraRankingClient' => $vendorDir . '/aws/aws-sdk-php/src/KendraRanking/KendraRankingClient.php',
    'Aws\\Keyspaces\\Exception\\KeyspacesException' => $vendorDir . '/aws/aws-sdk-php/src/Keyspaces/Exception/KeyspacesException.php',
    'Aws\\Keyspaces\\KeyspacesClient' => $vendorDir . '/aws/aws-sdk-php/src/Keyspaces/KeyspacesClient.php',
    'Aws\\KinesisAnalyticsV2\\Exception\\KinesisAnalyticsV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/KinesisAnalyticsV2/Exception/KinesisAnalyticsV2Exception.php',
    'Aws\\KinesisAnalyticsV2\\KinesisAnalyticsV2Client' => $vendorDir . '/aws/aws-sdk-php/src/KinesisAnalyticsV2/KinesisAnalyticsV2Client.php',
    'Aws\\KinesisAnalytics\\Exception\\KinesisAnalyticsException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisAnalytics/Exception/KinesisAnalyticsException.php',
    'Aws\\KinesisAnalytics\\KinesisAnalyticsClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisAnalytics/KinesisAnalyticsClient.php',
    'Aws\\KinesisVideoArchivedMedia\\Exception\\KinesisVideoArchivedMediaException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoArchivedMedia/Exception/KinesisVideoArchivedMediaException.php',
    'Aws\\KinesisVideoArchivedMedia\\KinesisVideoArchivedMediaClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoArchivedMedia/KinesisVideoArchivedMediaClient.php',
    'Aws\\KinesisVideoMedia\\Exception\\KinesisVideoMediaException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoMedia/Exception/KinesisVideoMediaException.php',
    'Aws\\KinesisVideoMedia\\KinesisVideoMediaClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoMedia/KinesisVideoMediaClient.php',
    'Aws\\KinesisVideoSignalingChannels\\Exception\\KinesisVideoSignalingChannelsException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoSignalingChannels/Exception/KinesisVideoSignalingChannelsException.php',
    'Aws\\KinesisVideoSignalingChannels\\KinesisVideoSignalingChannelsClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoSignalingChannels/KinesisVideoSignalingChannelsClient.php',
    'Aws\\KinesisVideoWebRTCStorage\\Exception\\KinesisVideoWebRTCStorageException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoWebRTCStorage/Exception/KinesisVideoWebRTCStorageException.php',
    'Aws\\KinesisVideoWebRTCStorage\\KinesisVideoWebRTCStorageClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideoWebRTCStorage/KinesisVideoWebRTCStorageClient.php',
    'Aws\\KinesisVideo\\Exception\\KinesisVideoException' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideo/Exception/KinesisVideoException.php',
    'Aws\\KinesisVideo\\KinesisVideoClient' => $vendorDir . '/aws/aws-sdk-php/src/KinesisVideo/KinesisVideoClient.php',
    'Aws\\Kinesis\\Exception\\KinesisException' => $vendorDir . '/aws/aws-sdk-php/src/Kinesis/Exception/KinesisException.php',
    'Aws\\Kinesis\\KinesisClient' => $vendorDir . '/aws/aws-sdk-php/src/Kinesis/KinesisClient.php',
    'Aws\\Kms\\Exception\\KmsException' => $vendorDir . '/aws/aws-sdk-php/src/Kms/Exception/KmsException.php',
    'Aws\\Kms\\KmsClient' => $vendorDir . '/aws/aws-sdk-php/src/Kms/KmsClient.php',
    'Aws\\LakeFormation\\Exception\\LakeFormationException' => $vendorDir . '/aws/aws-sdk-php/src/LakeFormation/Exception/LakeFormationException.php',
    'Aws\\LakeFormation\\LakeFormationClient' => $vendorDir . '/aws/aws-sdk-php/src/LakeFormation/LakeFormationClient.php',
    'Aws\\Lambda\\Exception\\LambdaException' => $vendorDir . '/aws/aws-sdk-php/src/Lambda/Exception/LambdaException.php',
    'Aws\\Lambda\\LambdaClient' => $vendorDir . '/aws/aws-sdk-php/src/Lambda/LambdaClient.php',
    'Aws\\LaunchWizard\\Exception\\LaunchWizardException' => $vendorDir . '/aws/aws-sdk-php/src/LaunchWizard/Exception/LaunchWizardException.php',
    'Aws\\LaunchWizard\\LaunchWizardClient' => $vendorDir . '/aws/aws-sdk-php/src/LaunchWizard/LaunchWizardClient.php',
    'Aws\\LexModelBuildingService\\Exception\\LexModelBuildingServiceException' => $vendorDir . '/aws/aws-sdk-php/src/LexModelBuildingService/Exception/LexModelBuildingServiceException.php',
    'Aws\\LexModelBuildingService\\LexModelBuildingServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/LexModelBuildingService/LexModelBuildingServiceClient.php',
    'Aws\\LexModelsV2\\Exception\\LexModelsV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/LexModelsV2/Exception/LexModelsV2Exception.php',
    'Aws\\LexModelsV2\\LexModelsV2Client' => $vendorDir . '/aws/aws-sdk-php/src/LexModelsV2/LexModelsV2Client.php',
    'Aws\\LexRuntimeService\\Exception\\LexRuntimeServiceException' => $vendorDir . '/aws/aws-sdk-php/src/LexRuntimeService/Exception/LexRuntimeServiceException.php',
    'Aws\\LexRuntimeService\\LexRuntimeServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/LexRuntimeService/LexRuntimeServiceClient.php',
    'Aws\\LexRuntimeV2\\Exception\\LexRuntimeV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/LexRuntimeV2/Exception/LexRuntimeV2Exception.php',
    'Aws\\LexRuntimeV2\\LexRuntimeV2Client' => $vendorDir . '/aws/aws-sdk-php/src/LexRuntimeV2/LexRuntimeV2Client.php',
    'Aws\\LicenseManagerLinuxSubscriptions\\Exception\\LicenseManagerLinuxSubscriptionsException' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManagerLinuxSubscriptions/Exception/LicenseManagerLinuxSubscriptionsException.php',
    'Aws\\LicenseManagerLinuxSubscriptions\\LicenseManagerLinuxSubscriptionsClient' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManagerLinuxSubscriptions/LicenseManagerLinuxSubscriptionsClient.php',
    'Aws\\LicenseManagerUserSubscriptions\\Exception\\LicenseManagerUserSubscriptionsException' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManagerUserSubscriptions/Exception/LicenseManagerUserSubscriptionsException.php',
    'Aws\\LicenseManagerUserSubscriptions\\LicenseManagerUserSubscriptionsClient' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManagerUserSubscriptions/LicenseManagerUserSubscriptionsClient.php',
    'Aws\\LicenseManager\\Exception\\LicenseManagerException' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManager/Exception/LicenseManagerException.php',
    'Aws\\LicenseManager\\LicenseManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/LicenseManager/LicenseManagerClient.php',
    'Aws\\Lightsail\\Exception\\LightsailException' => $vendorDir . '/aws/aws-sdk-php/src/Lightsail/Exception/LightsailException.php',
    'Aws\\Lightsail\\LightsailClient' => $vendorDir . '/aws/aws-sdk-php/src/Lightsail/LightsailClient.php',
    'Aws\\LocationService\\Exception\\LocationServiceException' => $vendorDir . '/aws/aws-sdk-php/src/LocationService/Exception/LocationServiceException.php',
    'Aws\\LocationService\\LocationServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/LocationService/LocationServiceClient.php',
    'Aws\\LookoutEquipment\\Exception\\LookoutEquipmentException' => $vendorDir . '/aws/aws-sdk-php/src/LookoutEquipment/Exception/LookoutEquipmentException.php',
    'Aws\\LookoutEquipment\\LookoutEquipmentClient' => $vendorDir . '/aws/aws-sdk-php/src/LookoutEquipment/LookoutEquipmentClient.php',
    'Aws\\LookoutMetrics\\Exception\\LookoutMetricsException' => $vendorDir . '/aws/aws-sdk-php/src/LookoutMetrics/Exception/LookoutMetricsException.php',
    'Aws\\LookoutMetrics\\LookoutMetricsClient' => $vendorDir . '/aws/aws-sdk-php/src/LookoutMetrics/LookoutMetricsClient.php',
    'Aws\\LookoutforVision\\Exception\\LookoutforVisionException' => $vendorDir . '/aws/aws-sdk-php/src/LookoutforVision/Exception/LookoutforVisionException.php',
    'Aws\\LookoutforVision\\LookoutforVisionClient' => $vendorDir . '/aws/aws-sdk-php/src/LookoutforVision/LookoutforVisionClient.php',
    'Aws\\LruArrayCache' => $vendorDir . '/aws/aws-sdk-php/src/LruArrayCache.php',
    'Aws\\MQ\\Exception\\MQException' => $vendorDir . '/aws/aws-sdk-php/src/MQ/Exception/MQException.php',
    'Aws\\MQ\\MQClient' => $vendorDir . '/aws/aws-sdk-php/src/MQ/MQClient.php',
    'Aws\\MTurk\\Exception\\MTurkException' => $vendorDir . '/aws/aws-sdk-php/src/MTurk/Exception/MTurkException.php',
    'Aws\\MTurk\\MTurkClient' => $vendorDir . '/aws/aws-sdk-php/src/MTurk/MTurkClient.php',
    'Aws\\MWAA\\Exception\\MWAAException' => $vendorDir . '/aws/aws-sdk-php/src/MWAA/Exception/MWAAException.php',
    'Aws\\MWAA\\MWAAClient' => $vendorDir . '/aws/aws-sdk-php/src/MWAA/MWAAClient.php',
    'Aws\\MachineLearning\\Exception\\MachineLearningException' => $vendorDir . '/aws/aws-sdk-php/src/MachineLearning/Exception/MachineLearningException.php',
    'Aws\\MachineLearning\\MachineLearningClient' => $vendorDir . '/aws/aws-sdk-php/src/MachineLearning/MachineLearningClient.php',
    'Aws\\Macie2\\Exception\\Macie2Exception' => $vendorDir . '/aws/aws-sdk-php/src/Macie2/Exception/Macie2Exception.php',
    'Aws\\Macie2\\Macie2Client' => $vendorDir . '/aws/aws-sdk-php/src/Macie2/Macie2Client.php',
    'Aws\\MailManager\\Exception\\MailManagerException' => $vendorDir . '/aws/aws-sdk-php/src/MailManager/Exception/MailManagerException.php',
    'Aws\\MailManager\\MailManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/MailManager/MailManagerClient.php',
    'Aws\\MainframeModernization\\Exception\\MainframeModernizationException' => $vendorDir . '/aws/aws-sdk-php/src/MainframeModernization/Exception/MainframeModernizationException.php',
    'Aws\\MainframeModernization\\MainframeModernizationClient' => $vendorDir . '/aws/aws-sdk-php/src/MainframeModernization/MainframeModernizationClient.php',
    'Aws\\ManagedBlockchainQuery\\Exception\\ManagedBlockchainQueryException' => $vendorDir . '/aws/aws-sdk-php/src/ManagedBlockchainQuery/Exception/ManagedBlockchainQueryException.php',
    'Aws\\ManagedBlockchainQuery\\ManagedBlockchainQueryClient' => $vendorDir . '/aws/aws-sdk-php/src/ManagedBlockchainQuery/ManagedBlockchainQueryClient.php',
    'Aws\\ManagedBlockchain\\Exception\\ManagedBlockchainException' => $vendorDir . '/aws/aws-sdk-php/src/ManagedBlockchain/Exception/ManagedBlockchainException.php',
    'Aws\\ManagedBlockchain\\ManagedBlockchainClient' => $vendorDir . '/aws/aws-sdk-php/src/ManagedBlockchain/ManagedBlockchainClient.php',
    'Aws\\ManagedGrafana\\Exception\\ManagedGrafanaException' => $vendorDir . '/aws/aws-sdk-php/src/ManagedGrafana/Exception/ManagedGrafanaException.php',
    'Aws\\ManagedGrafana\\ManagedGrafanaClient' => $vendorDir . '/aws/aws-sdk-php/src/ManagedGrafana/ManagedGrafanaClient.php',
    'Aws\\MarketplaceAgreement\\Exception\\MarketplaceAgreementException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceAgreement/Exception/MarketplaceAgreementException.php',
    'Aws\\MarketplaceAgreement\\MarketplaceAgreementClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceAgreement/MarketplaceAgreementClient.php',
    'Aws\\MarketplaceCatalog\\Exception\\MarketplaceCatalogException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceCatalog/Exception/MarketplaceCatalogException.php',
    'Aws\\MarketplaceCatalog\\MarketplaceCatalogClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceCatalog/MarketplaceCatalogClient.php',
    'Aws\\MarketplaceCommerceAnalytics\\Exception\\MarketplaceCommerceAnalyticsException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceCommerceAnalytics/Exception/MarketplaceCommerceAnalyticsException.php',
    'Aws\\MarketplaceCommerceAnalytics\\MarketplaceCommerceAnalyticsClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceCommerceAnalytics/MarketplaceCommerceAnalyticsClient.php',
    'Aws\\MarketplaceDeployment\\Exception\\MarketplaceDeploymentException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceDeployment/Exception/MarketplaceDeploymentException.php',
    'Aws\\MarketplaceDeployment\\MarketplaceDeploymentClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceDeployment/MarketplaceDeploymentClient.php',
    'Aws\\MarketplaceEntitlementService\\Exception\\MarketplaceEntitlementServiceException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceEntitlementService/Exception/MarketplaceEntitlementServiceException.php',
    'Aws\\MarketplaceEntitlementService\\MarketplaceEntitlementServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceEntitlementService/MarketplaceEntitlementServiceClient.php',
    'Aws\\MarketplaceMetering\\Exception\\MarketplaceMeteringException' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceMetering/Exception/MarketplaceMeteringException.php',
    'Aws\\MarketplaceMetering\\MarketplaceMeteringClient' => $vendorDir . '/aws/aws-sdk-php/src/MarketplaceMetering/MarketplaceMeteringClient.php',
    'Aws\\MediaConnect\\Exception\\MediaConnectException' => $vendorDir . '/aws/aws-sdk-php/src/MediaConnect/Exception/MediaConnectException.php',
    'Aws\\MediaConnect\\MediaConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaConnect/MediaConnectClient.php',
    'Aws\\MediaConvert\\Exception\\MediaConvertException' => $vendorDir . '/aws/aws-sdk-php/src/MediaConvert/Exception/MediaConvertException.php',
    'Aws\\MediaConvert\\MediaConvertClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaConvert/MediaConvertClient.php',
    'Aws\\MediaLive\\Exception\\MediaLiveException' => $vendorDir . '/aws/aws-sdk-php/src/MediaLive/Exception/MediaLiveException.php',
    'Aws\\MediaLive\\MediaLiveClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaLive/MediaLiveClient.php',
    'Aws\\MediaPackageV2\\Exception\\MediaPackageV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackageV2/Exception/MediaPackageV2Exception.php',
    'Aws\\MediaPackageV2\\MediaPackageV2Client' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackageV2/MediaPackageV2Client.php',
    'Aws\\MediaPackageVod\\Exception\\MediaPackageVodException' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackageVod/Exception/MediaPackageVodException.php',
    'Aws\\MediaPackageVod\\MediaPackageVodClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackageVod/MediaPackageVodClient.php',
    'Aws\\MediaPackage\\Exception\\MediaPackageException' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackage/Exception/MediaPackageException.php',
    'Aws\\MediaPackage\\MediaPackageClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaPackage/MediaPackageClient.php',
    'Aws\\MediaStoreData\\Exception\\MediaStoreDataException' => $vendorDir . '/aws/aws-sdk-php/src/MediaStoreData/Exception/MediaStoreDataException.php',
    'Aws\\MediaStoreData\\MediaStoreDataClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaStoreData/MediaStoreDataClient.php',
    'Aws\\MediaStore\\Exception\\MediaStoreException' => $vendorDir . '/aws/aws-sdk-php/src/MediaStore/Exception/MediaStoreException.php',
    'Aws\\MediaStore\\MediaStoreClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaStore/MediaStoreClient.php',
    'Aws\\MediaTailor\\Exception\\MediaTailorException' => $vendorDir . '/aws/aws-sdk-php/src/MediaTailor/Exception/MediaTailorException.php',
    'Aws\\MediaTailor\\MediaTailorClient' => $vendorDir . '/aws/aws-sdk-php/src/MediaTailor/MediaTailorClient.php',
    'Aws\\MedicalImaging\\Exception\\MedicalImagingException' => $vendorDir . '/aws/aws-sdk-php/src/MedicalImaging/Exception/MedicalImagingException.php',
    'Aws\\MedicalImaging\\MedicalImagingClient' => $vendorDir . '/aws/aws-sdk-php/src/MedicalImaging/MedicalImagingClient.php',
    'Aws\\MemoryDB\\Exception\\MemoryDBException' => $vendorDir . '/aws/aws-sdk-php/src/MemoryDB/Exception/MemoryDBException.php',
    'Aws\\MemoryDB\\MemoryDBClient' => $vendorDir . '/aws/aws-sdk-php/src/MemoryDB/MemoryDBClient.php',
    'Aws\\Middleware' => $vendorDir . '/aws/aws-sdk-php/src/Middleware.php',
    'Aws\\MigrationHubConfig\\Exception\\MigrationHubConfigException' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubConfig/Exception/MigrationHubConfigException.php',
    'Aws\\MigrationHubConfig\\MigrationHubConfigClient' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubConfig/MigrationHubConfigClient.php',
    'Aws\\MigrationHubOrchestrator\\Exception\\MigrationHubOrchestratorException' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubOrchestrator/Exception/MigrationHubOrchestratorException.php',
    'Aws\\MigrationHubOrchestrator\\MigrationHubOrchestratorClient' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubOrchestrator/MigrationHubOrchestratorClient.php',
    'Aws\\MigrationHubRefactorSpaces\\Exception\\MigrationHubRefactorSpacesException' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubRefactorSpaces/Exception/MigrationHubRefactorSpacesException.php',
    'Aws\\MigrationHubRefactorSpaces\\MigrationHubRefactorSpacesClient' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubRefactorSpaces/MigrationHubRefactorSpacesClient.php',
    'Aws\\MigrationHubStrategyRecommendations\\Exception\\MigrationHubStrategyRecommendationsException' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubStrategyRecommendations/Exception/MigrationHubStrategyRecommendationsException.php',
    'Aws\\MigrationHubStrategyRecommendations\\MigrationHubStrategyRecommendationsClient' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHubStrategyRecommendations/MigrationHubStrategyRecommendationsClient.php',
    'Aws\\MigrationHub\\Exception\\MigrationHubException' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHub/Exception/MigrationHubException.php',
    'Aws\\MigrationHub\\MigrationHubClient' => $vendorDir . '/aws/aws-sdk-php/src/MigrationHub/MigrationHubClient.php',
    'Aws\\MockHandler' => $vendorDir . '/aws/aws-sdk-php/src/MockHandler.php',
    'Aws\\MonitoringEventsInterface' => $vendorDir . '/aws/aws-sdk-php/src/MonitoringEventsInterface.php',
    'Aws\\MultiRegionClient' => $vendorDir . '/aws/aws-sdk-php/src/MultiRegionClient.php',
    'Aws\\Multipart\\AbstractUploadManager' => $vendorDir . '/aws/aws-sdk-php/src/Multipart/AbstractUploadManager.php',
    'Aws\\Multipart\\AbstractUploader' => $vendorDir . '/aws/aws-sdk-php/src/Multipart/AbstractUploader.php',
    'Aws\\Multipart\\UploadState' => $vendorDir . '/aws/aws-sdk-php/src/Multipart/UploadState.php',
    'Aws\\NeptuneGraph\\Exception\\NeptuneGraphException' => $vendorDir . '/aws/aws-sdk-php/src/NeptuneGraph/Exception/NeptuneGraphException.php',
    'Aws\\NeptuneGraph\\NeptuneGraphClient' => $vendorDir . '/aws/aws-sdk-php/src/NeptuneGraph/NeptuneGraphClient.php',
    'Aws\\Neptune\\Exception\\NeptuneException' => $vendorDir . '/aws/aws-sdk-php/src/Neptune/Exception/NeptuneException.php',
    'Aws\\Neptune\\NeptuneClient' => $vendorDir . '/aws/aws-sdk-php/src/Neptune/NeptuneClient.php',
    'Aws\\Neptunedata\\Exception\\NeptunedataException' => $vendorDir . '/aws/aws-sdk-php/src/Neptunedata/Exception/NeptunedataException.php',
    'Aws\\Neptunedata\\NeptunedataClient' => $vendorDir . '/aws/aws-sdk-php/src/Neptunedata/NeptunedataClient.php',
    'Aws\\NetworkFirewall\\Exception\\NetworkFirewallException' => $vendorDir . '/aws/aws-sdk-php/src/NetworkFirewall/Exception/NetworkFirewallException.php',
    'Aws\\NetworkFirewall\\NetworkFirewallClient' => $vendorDir . '/aws/aws-sdk-php/src/NetworkFirewall/NetworkFirewallClient.php',
    'Aws\\NetworkManager\\Exception\\NetworkManagerException' => $vendorDir . '/aws/aws-sdk-php/src/NetworkManager/Exception/NetworkManagerException.php',
    'Aws\\NetworkManager\\NetworkManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/NetworkManager/NetworkManagerClient.php',
    'Aws\\NetworkMonitor\\Exception\\NetworkMonitorException' => $vendorDir . '/aws/aws-sdk-php/src/NetworkMonitor/Exception/NetworkMonitorException.php',
    'Aws\\NetworkMonitor\\NetworkMonitorClient' => $vendorDir . '/aws/aws-sdk-php/src/NetworkMonitor/NetworkMonitorClient.php',
    'Aws\\NimbleStudio\\Exception\\NimbleStudioException' => $vendorDir . '/aws/aws-sdk-php/src/NimbleStudio/Exception/NimbleStudioException.php',
    'Aws\\NimbleStudio\\NimbleStudioClient' => $vendorDir . '/aws/aws-sdk-php/src/NimbleStudio/NimbleStudioClient.php',
    'Aws\\OAM\\Exception\\OAMException' => $vendorDir . '/aws/aws-sdk-php/src/OAM/Exception/OAMException.php',
    'Aws\\OAM\\OAMClient' => $vendorDir . '/aws/aws-sdk-php/src/OAM/OAMClient.php',
    'Aws\\OSIS\\Exception\\OSISException' => $vendorDir . '/aws/aws-sdk-php/src/OSIS/Exception/OSISException.php',
    'Aws\\OSIS\\OSISClient' => $vendorDir . '/aws/aws-sdk-php/src/OSIS/OSISClient.php',
    'Aws\\Omics\\Exception\\OmicsException' => $vendorDir . '/aws/aws-sdk-php/src/Omics/Exception/OmicsException.php',
    'Aws\\Omics\\OmicsClient' => $vendorDir . '/aws/aws-sdk-php/src/Omics/OmicsClient.php',
    'Aws\\OpenSearchServerless\\Exception\\OpenSearchServerlessException' => $vendorDir . '/aws/aws-sdk-php/src/OpenSearchServerless/Exception/OpenSearchServerlessException.php',
    'Aws\\OpenSearchServerless\\OpenSearchServerlessClient' => $vendorDir . '/aws/aws-sdk-php/src/OpenSearchServerless/OpenSearchServerlessClient.php',
    'Aws\\OpenSearchService\\Exception\\OpenSearchServiceException' => $vendorDir . '/aws/aws-sdk-php/src/OpenSearchService/Exception/OpenSearchServiceException.php',
    'Aws\\OpenSearchService\\OpenSearchServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/OpenSearchService/OpenSearchServiceClient.php',
    'Aws\\OpsWorksCM\\Exception\\OpsWorksCMException' => $vendorDir . '/aws/aws-sdk-php/src/OpsWorksCM/Exception/OpsWorksCMException.php',
    'Aws\\OpsWorksCM\\OpsWorksCMClient' => $vendorDir . '/aws/aws-sdk-php/src/OpsWorksCM/OpsWorksCMClient.php',
    'Aws\\OpsWorks\\Exception\\OpsWorksException' => $vendorDir . '/aws/aws-sdk-php/src/OpsWorks/Exception/OpsWorksException.php',
    'Aws\\OpsWorks\\OpsWorksClient' => $vendorDir . '/aws/aws-sdk-php/src/OpsWorks/OpsWorksClient.php',
    'Aws\\Organizations\\Exception\\OrganizationsException' => $vendorDir . '/aws/aws-sdk-php/src/Organizations/Exception/OrganizationsException.php',
    'Aws\\Organizations\\OrganizationsClient' => $vendorDir . '/aws/aws-sdk-php/src/Organizations/OrganizationsClient.php',
    'Aws\\Outposts\\Exception\\OutpostsException' => $vendorDir . '/aws/aws-sdk-php/src/Outposts/Exception/OutpostsException.php',
    'Aws\\Outposts\\OutpostsClient' => $vendorDir . '/aws/aws-sdk-php/src/Outposts/OutpostsClient.php',
    'Aws\\PCS\\Exception\\PCSException' => $vendorDir . '/aws/aws-sdk-php/src/PCS/Exception/PCSException.php',
    'Aws\\PCS\\PCSClient' => $vendorDir . '/aws/aws-sdk-php/src/PCS/PCSClient.php',
    'Aws\\PI\\Exception\\PIException' => $vendorDir . '/aws/aws-sdk-php/src/PI/Exception/PIException.php',
    'Aws\\PI\\PIClient' => $vendorDir . '/aws/aws-sdk-php/src/PI/PIClient.php',
    'Aws\\Panorama\\Exception\\PanoramaException' => $vendorDir . '/aws/aws-sdk-php/src/Panorama/Exception/PanoramaException.php',
    'Aws\\Panorama\\PanoramaClient' => $vendorDir . '/aws/aws-sdk-php/src/Panorama/PanoramaClient.php',
    'Aws\\PaymentCryptographyData\\Exception\\PaymentCryptographyDataException' => $vendorDir . '/aws/aws-sdk-php/src/PaymentCryptographyData/Exception/PaymentCryptographyDataException.php',
    'Aws\\PaymentCryptographyData\\PaymentCryptographyDataClient' => $vendorDir . '/aws/aws-sdk-php/src/PaymentCryptographyData/PaymentCryptographyDataClient.php',
    'Aws\\PaymentCryptography\\Exception\\PaymentCryptographyException' => $vendorDir . '/aws/aws-sdk-php/src/PaymentCryptography/Exception/PaymentCryptographyException.php',
    'Aws\\PaymentCryptography\\PaymentCryptographyClient' => $vendorDir . '/aws/aws-sdk-php/src/PaymentCryptography/PaymentCryptographyClient.php',
    'Aws\\PcaConnectorAd\\Exception\\PcaConnectorAdException' => $vendorDir . '/aws/aws-sdk-php/src/PcaConnectorAd/Exception/PcaConnectorAdException.php',
    'Aws\\PcaConnectorAd\\PcaConnectorAdClient' => $vendorDir . '/aws/aws-sdk-php/src/PcaConnectorAd/PcaConnectorAdClient.php',
    'Aws\\PcaConnectorScep\\Exception\\PcaConnectorScepException' => $vendorDir . '/aws/aws-sdk-php/src/PcaConnectorScep/Exception/PcaConnectorScepException.php',
    'Aws\\PcaConnectorScep\\PcaConnectorScepClient' => $vendorDir . '/aws/aws-sdk-php/src/PcaConnectorScep/PcaConnectorScepClient.php',
    'Aws\\PersonalizeEvents\\Exception\\PersonalizeEventsException' => $vendorDir . '/aws/aws-sdk-php/src/PersonalizeEvents/Exception/PersonalizeEventsException.php',
    'Aws\\PersonalizeEvents\\PersonalizeEventsClient' => $vendorDir . '/aws/aws-sdk-php/src/PersonalizeEvents/PersonalizeEventsClient.php',
    'Aws\\PersonalizeRuntime\\Exception\\PersonalizeRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/PersonalizeRuntime/Exception/PersonalizeRuntimeException.php',
    'Aws\\PersonalizeRuntime\\PersonalizeRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/PersonalizeRuntime/PersonalizeRuntimeClient.php',
    'Aws\\Personalize\\Exception\\PersonalizeException' => $vendorDir . '/aws/aws-sdk-php/src/Personalize/Exception/PersonalizeException.php',
    'Aws\\Personalize\\PersonalizeClient' => $vendorDir . '/aws/aws-sdk-php/src/Personalize/PersonalizeClient.php',
    'Aws\\PhpHash' => $vendorDir . '/aws/aws-sdk-php/src/PhpHash.php',
    'Aws\\PinpointEmail\\Exception\\PinpointEmailException' => $vendorDir . '/aws/aws-sdk-php/src/PinpointEmail/Exception/PinpointEmailException.php',
    'Aws\\PinpointEmail\\PinpointEmailClient' => $vendorDir . '/aws/aws-sdk-php/src/PinpointEmail/PinpointEmailClient.php',
    'Aws\\PinpointSMSVoiceV2\\Exception\\PinpointSMSVoiceV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/PinpointSMSVoiceV2/Exception/PinpointSMSVoiceV2Exception.php',
    'Aws\\PinpointSMSVoiceV2\\PinpointSMSVoiceV2Client' => $vendorDir . '/aws/aws-sdk-php/src/PinpointSMSVoiceV2/PinpointSMSVoiceV2Client.php',
    'Aws\\PinpointSMSVoice\\Exception\\PinpointSMSVoiceException' => $vendorDir . '/aws/aws-sdk-php/src/PinpointSMSVoice/Exception/PinpointSMSVoiceException.php',
    'Aws\\PinpointSMSVoice\\PinpointSMSVoiceClient' => $vendorDir . '/aws/aws-sdk-php/src/PinpointSMSVoice/PinpointSMSVoiceClient.php',
    'Aws\\Pinpoint\\Exception\\PinpointException' => $vendorDir . '/aws/aws-sdk-php/src/Pinpoint/Exception/PinpointException.php',
    'Aws\\Pinpoint\\PinpointClient' => $vendorDir . '/aws/aws-sdk-php/src/Pinpoint/PinpointClient.php',
    'Aws\\Pipes\\Exception\\PipesException' => $vendorDir . '/aws/aws-sdk-php/src/Pipes/Exception/PipesException.php',
    'Aws\\Pipes\\PipesClient' => $vendorDir . '/aws/aws-sdk-php/src/Pipes/PipesClient.php',
    'Aws\\Polly\\Exception\\PollyException' => $vendorDir . '/aws/aws-sdk-php/src/Polly/Exception/PollyException.php',
    'Aws\\Polly\\PollyClient' => $vendorDir . '/aws/aws-sdk-php/src/Polly/PollyClient.php',
    'Aws\\PresignUrlMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/PresignUrlMiddleware.php',
    'Aws\\Pricing\\Exception\\PricingException' => $vendorDir . '/aws/aws-sdk-php/src/Pricing/Exception/PricingException.php',
    'Aws\\Pricing\\PricingClient' => $vendorDir . '/aws/aws-sdk-php/src/Pricing/PricingClient.php',
    'Aws\\PrivateNetworks\\Exception\\PrivateNetworksException' => $vendorDir . '/aws/aws-sdk-php/src/PrivateNetworks/Exception/PrivateNetworksException.php',
    'Aws\\PrivateNetworks\\PrivateNetworksClient' => $vendorDir . '/aws/aws-sdk-php/src/PrivateNetworks/PrivateNetworksClient.php',
    'Aws\\PrometheusService\\Exception\\PrometheusServiceException' => $vendorDir . '/aws/aws-sdk-php/src/PrometheusService/Exception/PrometheusServiceException.php',
    'Aws\\PrometheusService\\PrometheusServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/PrometheusService/PrometheusServiceClient.php',
    'Aws\\Proton\\Exception\\ProtonException' => $vendorDir . '/aws/aws-sdk-php/src/Proton/Exception/ProtonException.php',
    'Aws\\Proton\\ProtonClient' => $vendorDir . '/aws/aws-sdk-php/src/Proton/ProtonClient.php',
    'Aws\\Psr16CacheAdapter' => $vendorDir . '/aws/aws-sdk-php/src/Psr16CacheAdapter.php',
    'Aws\\PsrCacheAdapter' => $vendorDir . '/aws/aws-sdk-php/src/PsrCacheAdapter.php',
    'Aws\\QApps\\Exception\\QAppsException' => $vendorDir . '/aws/aws-sdk-php/src/QApps/Exception/QAppsException.php',
    'Aws\\QApps\\QAppsClient' => $vendorDir . '/aws/aws-sdk-php/src/QApps/QAppsClient.php',
    'Aws\\QBusiness\\Exception\\QBusinessException' => $vendorDir . '/aws/aws-sdk-php/src/QBusiness/Exception/QBusinessException.php',
    'Aws\\QBusiness\\QBusinessClient' => $vendorDir . '/aws/aws-sdk-php/src/QBusiness/QBusinessClient.php',
    'Aws\\QConnect\\Exception\\QConnectException' => $vendorDir . '/aws/aws-sdk-php/src/QConnect/Exception/QConnectException.php',
    'Aws\\QConnect\\QConnectClient' => $vendorDir . '/aws/aws-sdk-php/src/QConnect/QConnectClient.php',
    'Aws\\QLDBSession\\Exception\\QLDBSessionException' => $vendorDir . '/aws/aws-sdk-php/src/QLDBSession/Exception/QLDBSessionException.php',
    'Aws\\QLDBSession\\QLDBSessionClient' => $vendorDir . '/aws/aws-sdk-php/src/QLDBSession/QLDBSessionClient.php',
    'Aws\\QLDB\\Exception\\QLDBException' => $vendorDir . '/aws/aws-sdk-php/src/QLDB/Exception/QLDBException.php',
    'Aws\\QLDB\\QLDBClient' => $vendorDir . '/aws/aws-sdk-php/src/QLDB/QLDBClient.php',
    'Aws\\QueryCompatibleInputMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/QueryCompatibleInputMiddleware.php',
    'Aws\\QuickSight\\Exception\\QuickSightException' => $vendorDir . '/aws/aws-sdk-php/src/QuickSight/Exception/QuickSightException.php',
    'Aws\\QuickSight\\QuickSightClient' => $vendorDir . '/aws/aws-sdk-php/src/QuickSight/QuickSightClient.php',
    'Aws\\RAM\\Exception\\RAMException' => $vendorDir . '/aws/aws-sdk-php/src/RAM/Exception/RAMException.php',
    'Aws\\RAM\\RAMClient' => $vendorDir . '/aws/aws-sdk-php/src/RAM/RAMClient.php',
    'Aws\\RDSDataService\\Exception\\RDSDataServiceException' => $vendorDir . '/aws/aws-sdk-php/src/RDSDataService/Exception/RDSDataServiceException.php',
    'Aws\\RDSDataService\\RDSDataServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/RDSDataService/RDSDataServiceClient.php',
    'Aws\\Rds\\AuthTokenGenerator' => $vendorDir . '/aws/aws-sdk-php/src/Rds/AuthTokenGenerator.php',
    'Aws\\Rds\\Exception\\RdsException' => $vendorDir . '/aws/aws-sdk-php/src/Rds/Exception/RdsException.php',
    'Aws\\Rds\\RdsClient' => $vendorDir . '/aws/aws-sdk-php/src/Rds/RdsClient.php',
    'Aws\\RecycleBin\\Exception\\RecycleBinException' => $vendorDir . '/aws/aws-sdk-php/src/RecycleBin/Exception/RecycleBinException.php',
    'Aws\\RecycleBin\\RecycleBinClient' => $vendorDir . '/aws/aws-sdk-php/src/RecycleBin/RecycleBinClient.php',
    'Aws\\RedshiftDataAPIService\\Exception\\RedshiftDataAPIServiceException' => $vendorDir . '/aws/aws-sdk-php/src/RedshiftDataAPIService/Exception/RedshiftDataAPIServiceException.php',
    'Aws\\RedshiftDataAPIService\\RedshiftDataAPIServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/RedshiftDataAPIService/RedshiftDataAPIServiceClient.php',
    'Aws\\RedshiftServerless\\Exception\\RedshiftServerlessException' => $vendorDir . '/aws/aws-sdk-php/src/RedshiftServerless/Exception/RedshiftServerlessException.php',
    'Aws\\RedshiftServerless\\RedshiftServerlessClient' => $vendorDir . '/aws/aws-sdk-php/src/RedshiftServerless/RedshiftServerlessClient.php',
    'Aws\\Redshift\\Exception\\RedshiftException' => $vendorDir . '/aws/aws-sdk-php/src/Redshift/Exception/RedshiftException.php',
    'Aws\\Redshift\\RedshiftClient' => $vendorDir . '/aws/aws-sdk-php/src/Redshift/RedshiftClient.php',
    'Aws\\Rekognition\\Exception\\RekognitionException' => $vendorDir . '/aws/aws-sdk-php/src/Rekognition/Exception/RekognitionException.php',
    'Aws\\Rekognition\\RekognitionClient' => $vendorDir . '/aws/aws-sdk-php/src/Rekognition/RekognitionClient.php',
    'Aws\\Repostspace\\Exception\\RepostspaceException' => $vendorDir . '/aws/aws-sdk-php/src/Repostspace/Exception/RepostspaceException.php',
    'Aws\\Repostspace\\RepostspaceClient' => $vendorDir . '/aws/aws-sdk-php/src/Repostspace/RepostspaceClient.php',
    'Aws\\RequestCompressionMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/RequestCompressionMiddleware.php',
    'Aws\\ResilienceHub\\Exception\\ResilienceHubException' => $vendorDir . '/aws/aws-sdk-php/src/ResilienceHub/Exception/ResilienceHubException.php',
    'Aws\\ResilienceHub\\ResilienceHubClient' => $vendorDir . '/aws/aws-sdk-php/src/ResilienceHub/ResilienceHubClient.php',
    'Aws\\ResourceExplorer2\\Exception\\ResourceExplorer2Exception' => $vendorDir . '/aws/aws-sdk-php/src/ResourceExplorer2/Exception/ResourceExplorer2Exception.php',
    'Aws\\ResourceExplorer2\\ResourceExplorer2Client' => $vendorDir . '/aws/aws-sdk-php/src/ResourceExplorer2/ResourceExplorer2Client.php',
    'Aws\\ResourceGroupsTaggingAPI\\Exception\\ResourceGroupsTaggingAPIException' => $vendorDir . '/aws/aws-sdk-php/src/ResourceGroupsTaggingAPI/Exception/ResourceGroupsTaggingAPIException.php',
    'Aws\\ResourceGroupsTaggingAPI\\ResourceGroupsTaggingAPIClient' => $vendorDir . '/aws/aws-sdk-php/src/ResourceGroupsTaggingAPI/ResourceGroupsTaggingAPIClient.php',
    'Aws\\ResourceGroups\\Exception\\ResourceGroupsException' => $vendorDir . '/aws/aws-sdk-php/src/ResourceGroups/Exception/ResourceGroupsException.php',
    'Aws\\ResourceGroups\\ResourceGroupsClient' => $vendorDir . '/aws/aws-sdk-php/src/ResourceGroups/ResourceGroupsClient.php',
    'Aws\\ResponseContainerInterface' => $vendorDir . '/aws/aws-sdk-php/src/ResponseContainerInterface.php',
    'Aws\\Result' => $vendorDir . '/aws/aws-sdk-php/src/Result.php',
    'Aws\\ResultInterface' => $vendorDir . '/aws/aws-sdk-php/src/ResultInterface.php',
    'Aws\\ResultPaginator' => $vendorDir . '/aws/aws-sdk-php/src/ResultPaginator.php',
    'Aws\\RetryMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/RetryMiddleware.php',
    'Aws\\RetryMiddlewareV2' => $vendorDir . '/aws/aws-sdk-php/src/RetryMiddlewareV2.php',
    'Aws\\Retry\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/Retry/Configuration.php',
    'Aws\\Retry\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/Retry/ConfigurationInterface.php',
    'Aws\\Retry\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/Retry/ConfigurationProvider.php',
    'Aws\\Retry\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/Retry/Exception/ConfigurationException.php',
    'Aws\\Retry\\QuotaManager' => $vendorDir . '/aws/aws-sdk-php/src/Retry/QuotaManager.php',
    'Aws\\Retry\\RateLimiter' => $vendorDir . '/aws/aws-sdk-php/src/Retry/RateLimiter.php',
    'Aws\\Retry\\RetryHelperTrait' => $vendorDir . '/aws/aws-sdk-php/src/Retry/RetryHelperTrait.php',
    'Aws\\RoboMaker\\Exception\\RoboMakerException' => $vendorDir . '/aws/aws-sdk-php/src/RoboMaker/Exception/RoboMakerException.php',
    'Aws\\RoboMaker\\RoboMakerClient' => $vendorDir . '/aws/aws-sdk-php/src/RoboMaker/RoboMakerClient.php',
    'Aws\\RolesAnywhere\\Exception\\RolesAnywhereException' => $vendorDir . '/aws/aws-sdk-php/src/RolesAnywhere/Exception/RolesAnywhereException.php',
    'Aws\\RolesAnywhere\\RolesAnywhereClient' => $vendorDir . '/aws/aws-sdk-php/src/RolesAnywhere/RolesAnywhereClient.php',
    'Aws\\Route53Domains\\Exception\\Route53DomainsException' => $vendorDir . '/aws/aws-sdk-php/src/Route53Domains/Exception/Route53DomainsException.php',
    'Aws\\Route53Domains\\Route53DomainsClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53Domains/Route53DomainsClient.php',
    'Aws\\Route53Profiles\\Exception\\Route53ProfilesException' => $vendorDir . '/aws/aws-sdk-php/src/Route53Profiles/Exception/Route53ProfilesException.php',
    'Aws\\Route53Profiles\\Route53ProfilesClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53Profiles/Route53ProfilesClient.php',
    'Aws\\Route53RecoveryCluster\\Exception\\Route53RecoveryClusterException' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryCluster/Exception/Route53RecoveryClusterException.php',
    'Aws\\Route53RecoveryCluster\\Route53RecoveryClusterClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryCluster/Route53RecoveryClusterClient.php',
    'Aws\\Route53RecoveryControlConfig\\Exception\\Route53RecoveryControlConfigException' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryControlConfig/Exception/Route53RecoveryControlConfigException.php',
    'Aws\\Route53RecoveryControlConfig\\Route53RecoveryControlConfigClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryControlConfig/Route53RecoveryControlConfigClient.php',
    'Aws\\Route53RecoveryReadiness\\Exception\\Route53RecoveryReadinessException' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryReadiness/Exception/Route53RecoveryReadinessException.php',
    'Aws\\Route53RecoveryReadiness\\Route53RecoveryReadinessClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53RecoveryReadiness/Route53RecoveryReadinessClient.php',
    'Aws\\Route53Resolver\\Exception\\Route53ResolverException' => $vendorDir . '/aws/aws-sdk-php/src/Route53Resolver/Exception/Route53ResolverException.php',
    'Aws\\Route53Resolver\\Route53ResolverClient' => $vendorDir . '/aws/aws-sdk-php/src/Route53Resolver/Route53ResolverClient.php',
    'Aws\\Route53\\Exception\\Route53Exception' => $vendorDir . '/aws/aws-sdk-php/src/Route53/Exception/Route53Exception.php',
    'Aws\\Route53\\Route53Client' => $vendorDir . '/aws/aws-sdk-php/src/Route53/Route53Client.php',
    'Aws\\S3Control\\EndpointArnMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3Control/EndpointArnMiddleware.php',
    'Aws\\S3Control\\Exception\\S3ControlException' => $vendorDir . '/aws/aws-sdk-php/src/S3Control/Exception/S3ControlException.php',
    'Aws\\S3Control\\S3ControlClient' => $vendorDir . '/aws/aws-sdk-php/src/S3Control/S3ControlClient.php',
    'Aws\\S3Outposts\\Exception\\S3OutpostsException' => $vendorDir . '/aws/aws-sdk-php/src/S3Outposts/Exception/S3OutpostsException.php',
    'Aws\\S3Outposts\\S3OutpostsClient' => $vendorDir . '/aws/aws-sdk-php/src/S3Outposts/S3OutpostsClient.php',
    'Aws\\S3\\AmbiguousSuccessParser' => $vendorDir . '/aws/aws-sdk-php/src/S3/AmbiguousSuccessParser.php',
    'Aws\\S3\\ApplyChecksumMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/ApplyChecksumMiddleware.php',
    'Aws\\S3\\BatchDelete' => $vendorDir . '/aws/aws-sdk-php/src/S3/BatchDelete.php',
    'Aws\\S3\\BucketEndpointArnMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/BucketEndpointArnMiddleware.php',
    'Aws\\S3\\BucketEndpointMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/BucketEndpointMiddleware.php',
    'Aws\\S3\\CalculatesChecksumTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/CalculatesChecksumTrait.php',
    'Aws\\S3\\Crypto\\CryptoParamsTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/CryptoParamsTrait.php',
    'Aws\\S3\\Crypto\\CryptoParamsTraitV2' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/CryptoParamsTraitV2.php',
    'Aws\\S3\\Crypto\\HeadersMetadataStrategy' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/HeadersMetadataStrategy.php',
    'Aws\\S3\\Crypto\\InstructionFileMetadataStrategy' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/InstructionFileMetadataStrategy.php',
    'Aws\\S3\\Crypto\\S3EncryptionClient' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/S3EncryptionClient.php',
    'Aws\\S3\\Crypto\\S3EncryptionClientV2' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/S3EncryptionClientV2.php',
    'Aws\\S3\\Crypto\\S3EncryptionMultipartUploader' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/S3EncryptionMultipartUploader.php',
    'Aws\\S3\\Crypto\\S3EncryptionMultipartUploaderV2' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/S3EncryptionMultipartUploaderV2.php',
    'Aws\\S3\\Crypto\\UserAgentTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/Crypto/UserAgentTrait.php',
    'Aws\\S3\\EndpointRegionHelperTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/EndpointRegionHelperTrait.php',
    'Aws\\S3\\Exception\\DeleteMultipleObjectsException' => $vendorDir . '/aws/aws-sdk-php/src/S3/Exception/DeleteMultipleObjectsException.php',
    'Aws\\S3\\Exception\\PermanentRedirectException' => $vendorDir . '/aws/aws-sdk-php/src/S3/Exception/PermanentRedirectException.php',
    'Aws\\S3\\Exception\\S3Exception' => $vendorDir . '/aws/aws-sdk-php/src/S3/Exception/S3Exception.php',
    'Aws\\S3\\Exception\\S3MultipartUploadException' => $vendorDir . '/aws/aws-sdk-php/src/S3/Exception/S3MultipartUploadException.php',
    'Aws\\S3\\ExpiresParsingMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/ExpiresParsingMiddleware.php',
    'Aws\\S3\\GetBucketLocationParser' => $vendorDir . '/aws/aws-sdk-php/src/S3/GetBucketLocationParser.php',
    'Aws\\S3\\MultipartCopy' => $vendorDir . '/aws/aws-sdk-php/src/S3/MultipartCopy.php',
    'Aws\\S3\\MultipartUploader' => $vendorDir . '/aws/aws-sdk-php/src/S3/MultipartUploader.php',
    'Aws\\S3\\MultipartUploadingTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/MultipartUploadingTrait.php',
    'Aws\\S3\\ObjectCopier' => $vendorDir . '/aws/aws-sdk-php/src/S3/ObjectCopier.php',
    'Aws\\S3\\ObjectUploader' => $vendorDir . '/aws/aws-sdk-php/src/S3/ObjectUploader.php',
    'Aws\\S3\\Parser\\GetBucketLocationResultMutator' => $vendorDir . '/aws/aws-sdk-php/src/S3/Parser/GetBucketLocationResultMutator.php',
    'Aws\\S3\\Parser\\S3Parser' => $vendorDir . '/aws/aws-sdk-php/src/S3/Parser/S3Parser.php',
    'Aws\\S3\\Parser\\S3ResultMutator' => $vendorDir . '/aws/aws-sdk-php/src/S3/Parser/S3ResultMutator.php',
    'Aws\\S3\\Parser\\ValidateResponseChecksumResultMutator' => $vendorDir . '/aws/aws-sdk-php/src/S3/Parser/ValidateResponseChecksumResultMutator.php',
    'Aws\\S3\\PermanentRedirectMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/PermanentRedirectMiddleware.php',
    'Aws\\S3\\PostObject' => $vendorDir . '/aws/aws-sdk-php/src/S3/PostObject.php',
    'Aws\\S3\\PostObjectV4' => $vendorDir . '/aws/aws-sdk-php/src/S3/PostObjectV4.php',
    'Aws\\S3\\PutObjectUrlMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/PutObjectUrlMiddleware.php',
    'Aws\\S3\\RegionalEndpoint\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/S3/RegionalEndpoint/Configuration.php',
    'Aws\\S3\\RegionalEndpoint\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/S3/RegionalEndpoint/ConfigurationInterface.php',
    'Aws\\S3\\RegionalEndpoint\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/S3/RegionalEndpoint/ConfigurationProvider.php',
    'Aws\\S3\\RegionalEndpoint\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/S3/RegionalEndpoint/Exception/ConfigurationException.php',
    'Aws\\S3\\RetryableMalformedResponseParser' => $vendorDir . '/aws/aws-sdk-php/src/S3/RetryableMalformedResponseParser.php',
    'Aws\\S3\\S3Client' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3Client.php',
    'Aws\\S3\\S3ClientInterface' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3ClientInterface.php',
    'Aws\\S3\\S3ClientTrait' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3ClientTrait.php',
    'Aws\\S3\\S3EndpointMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3EndpointMiddleware.php',
    'Aws\\S3\\S3MultiRegionClient' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3MultiRegionClient.php',
    'Aws\\S3\\S3UriParser' => $vendorDir . '/aws/aws-sdk-php/src/S3/S3UriParser.php',
    'Aws\\S3\\SSECMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/S3/SSECMiddleware.php',
    'Aws\\S3\\StreamWrapper' => $vendorDir . '/aws/aws-sdk-php/src/S3/StreamWrapper.php',
    'Aws\\S3\\Transfer' => $vendorDir . '/aws/aws-sdk-php/src/S3/Transfer.php',
    'Aws\\S3\\UseArnRegion\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/S3/UseArnRegion/Configuration.php',
    'Aws\\S3\\UseArnRegion\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/S3/UseArnRegion/ConfigurationInterface.php',
    'Aws\\S3\\UseArnRegion\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/S3/UseArnRegion/ConfigurationProvider.php',
    'Aws\\S3\\UseArnRegion\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/S3/UseArnRegion/Exception/ConfigurationException.php',
    'Aws\\S3\\ValidateResponseChecksumParser' => $vendorDir . '/aws/aws-sdk-php/src/S3/ValidateResponseChecksumParser.php',
    'Aws\\SSMContacts\\Exception\\SSMContactsException' => $vendorDir . '/aws/aws-sdk-php/src/SSMContacts/Exception/SSMContactsException.php',
    'Aws\\SSMContacts\\SSMContactsClient' => $vendorDir . '/aws/aws-sdk-php/src/SSMContacts/SSMContactsClient.php',
    'Aws\\SSMIncidents\\Exception\\SSMIncidentsException' => $vendorDir . '/aws/aws-sdk-php/src/SSMIncidents/Exception/SSMIncidentsException.php',
    'Aws\\SSMIncidents\\SSMIncidentsClient' => $vendorDir . '/aws/aws-sdk-php/src/SSMIncidents/SSMIncidentsClient.php',
    'Aws\\SSMQuickSetup\\Exception\\SSMQuickSetupException' => $vendorDir . '/aws/aws-sdk-php/src/SSMQuickSetup/Exception/SSMQuickSetupException.php',
    'Aws\\SSMQuickSetup\\SSMQuickSetupClient' => $vendorDir . '/aws/aws-sdk-php/src/SSMQuickSetup/SSMQuickSetupClient.php',
    'Aws\\SSOAdmin\\Exception\\SSOAdminException' => $vendorDir . '/aws/aws-sdk-php/src/SSOAdmin/Exception/SSOAdminException.php',
    'Aws\\SSOAdmin\\SSOAdminClient' => $vendorDir . '/aws/aws-sdk-php/src/SSOAdmin/SSOAdminClient.php',
    'Aws\\SSOOIDC\\Exception\\SSOOIDCException' => $vendorDir . '/aws/aws-sdk-php/src/SSOOIDC/Exception/SSOOIDCException.php',
    'Aws\\SSOOIDC\\SSOOIDCClient' => $vendorDir . '/aws/aws-sdk-php/src/SSOOIDC/SSOOIDCClient.php',
    'Aws\\SSO\\Exception\\SSOException' => $vendorDir . '/aws/aws-sdk-php/src/SSO/Exception/SSOException.php',
    'Aws\\SSO\\SSOClient' => $vendorDir . '/aws/aws-sdk-php/src/SSO/SSOClient.php',
    'Aws\\SageMakerFeatureStoreRuntime\\Exception\\SageMakerFeatureStoreRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerFeatureStoreRuntime/Exception/SageMakerFeatureStoreRuntimeException.php',
    'Aws\\SageMakerFeatureStoreRuntime\\SageMakerFeatureStoreRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerFeatureStoreRuntime/SageMakerFeatureStoreRuntimeClient.php',
    'Aws\\SageMakerGeospatial\\Exception\\SageMakerGeospatialException' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerGeospatial/Exception/SageMakerGeospatialException.php',
    'Aws\\SageMakerGeospatial\\SageMakerGeospatialClient' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerGeospatial/SageMakerGeospatialClient.php',
    'Aws\\SageMakerMetrics\\Exception\\SageMakerMetricsException' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerMetrics/Exception/SageMakerMetricsException.php',
    'Aws\\SageMakerMetrics\\SageMakerMetricsClient' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerMetrics/SageMakerMetricsClient.php',
    'Aws\\SageMakerRuntime\\Exception\\SageMakerRuntimeException' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerRuntime/Exception/SageMakerRuntimeException.php',
    'Aws\\SageMakerRuntime\\SageMakerRuntimeClient' => $vendorDir . '/aws/aws-sdk-php/src/SageMakerRuntime/SageMakerRuntimeClient.php',
    'Aws\\SageMaker\\Exception\\SageMakerException' => $vendorDir . '/aws/aws-sdk-php/src/SageMaker/Exception/SageMakerException.php',
    'Aws\\SageMaker\\SageMakerClient' => $vendorDir . '/aws/aws-sdk-php/src/SageMaker/SageMakerClient.php',
    'Aws\\SagemakerEdgeManager\\Exception\\SagemakerEdgeManagerException' => $vendorDir . '/aws/aws-sdk-php/src/SagemakerEdgeManager/Exception/SagemakerEdgeManagerException.php',
    'Aws\\SagemakerEdgeManager\\SagemakerEdgeManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/SagemakerEdgeManager/SagemakerEdgeManagerClient.php',
    'Aws\\SavingsPlans\\Exception\\SavingsPlansException' => $vendorDir . '/aws/aws-sdk-php/src/SavingsPlans/Exception/SavingsPlansException.php',
    'Aws\\SavingsPlans\\SavingsPlansClient' => $vendorDir . '/aws/aws-sdk-php/src/SavingsPlans/SavingsPlansClient.php',
    'Aws\\Scheduler\\Exception\\SchedulerException' => $vendorDir . '/aws/aws-sdk-php/src/Scheduler/Exception/SchedulerException.php',
    'Aws\\Scheduler\\SchedulerClient' => $vendorDir . '/aws/aws-sdk-php/src/Scheduler/SchedulerClient.php',
    'Aws\\Schemas\\Exception\\SchemasException' => $vendorDir . '/aws/aws-sdk-php/src/Schemas/Exception/SchemasException.php',
    'Aws\\Schemas\\SchemasClient' => $vendorDir . '/aws/aws-sdk-php/src/Schemas/SchemasClient.php',
    'Aws\\Script\\Composer\\Composer' => $vendorDir . '/aws/aws-sdk-php/src/Script/Composer/Composer.php',
    'Aws\\Sdk' => $vendorDir . '/aws/aws-sdk-php/src/Sdk.php',
    'Aws\\SecretsManager\\Exception\\SecretsManagerException' => $vendorDir . '/aws/aws-sdk-php/src/SecretsManager/Exception/SecretsManagerException.php',
    'Aws\\SecretsManager\\SecretsManagerClient' => $vendorDir . '/aws/aws-sdk-php/src/SecretsManager/SecretsManagerClient.php',
    'Aws\\SecurityHub\\Exception\\SecurityHubException' => $vendorDir . '/aws/aws-sdk-php/src/SecurityHub/Exception/SecurityHubException.php',
    'Aws\\SecurityHub\\SecurityHubClient' => $vendorDir . '/aws/aws-sdk-php/src/SecurityHub/SecurityHubClient.php',
    'Aws\\SecurityLake\\Exception\\SecurityLakeException' => $vendorDir . '/aws/aws-sdk-php/src/SecurityLake/Exception/SecurityLakeException.php',
    'Aws\\SecurityLake\\SecurityLakeClient' => $vendorDir . '/aws/aws-sdk-php/src/SecurityLake/SecurityLakeClient.php',
    'Aws\\ServerlessApplicationRepository\\Exception\\ServerlessApplicationRepositoryException' => $vendorDir . '/aws/aws-sdk-php/src/ServerlessApplicationRepository/Exception/ServerlessApplicationRepositoryException.php',
    'Aws\\ServerlessApplicationRepository\\ServerlessApplicationRepositoryClient' => $vendorDir . '/aws/aws-sdk-php/src/ServerlessApplicationRepository/ServerlessApplicationRepositoryClient.php',
    'Aws\\ServiceCatalog\\Exception\\ServiceCatalogException' => $vendorDir . '/aws/aws-sdk-php/src/ServiceCatalog/Exception/ServiceCatalogException.php',
    'Aws\\ServiceCatalog\\ServiceCatalogClient' => $vendorDir . '/aws/aws-sdk-php/src/ServiceCatalog/ServiceCatalogClient.php',
    'Aws\\ServiceDiscovery\\Exception\\ServiceDiscoveryException' => $vendorDir . '/aws/aws-sdk-php/src/ServiceDiscovery/Exception/ServiceDiscoveryException.php',
    'Aws\\ServiceDiscovery\\ServiceDiscoveryClient' => $vendorDir . '/aws/aws-sdk-php/src/ServiceDiscovery/ServiceDiscoveryClient.php',
    'Aws\\ServiceQuotas\\Exception\\ServiceQuotasException' => $vendorDir . '/aws/aws-sdk-php/src/ServiceQuotas/Exception/ServiceQuotasException.php',
    'Aws\\ServiceQuotas\\ServiceQuotasClient' => $vendorDir . '/aws/aws-sdk-php/src/ServiceQuotas/ServiceQuotasClient.php',
    'Aws\\SesV2\\Exception\\SesV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/SesV2/Exception/SesV2Exception.php',
    'Aws\\SesV2\\SesV2Client' => $vendorDir . '/aws/aws-sdk-php/src/SesV2/SesV2Client.php',
    'Aws\\Ses\\Exception\\SesException' => $vendorDir . '/aws/aws-sdk-php/src/Ses/Exception/SesException.php',
    'Aws\\Ses\\SesClient' => $vendorDir . '/aws/aws-sdk-php/src/Ses/SesClient.php',
    'Aws\\Sfn\\Exception\\SfnException' => $vendorDir . '/aws/aws-sdk-php/src/Sfn/Exception/SfnException.php',
    'Aws\\Sfn\\SfnClient' => $vendorDir . '/aws/aws-sdk-php/src/Sfn/SfnClient.php',
    'Aws\\Shield\\Exception\\ShieldException' => $vendorDir . '/aws/aws-sdk-php/src/Shield/Exception/ShieldException.php',
    'Aws\\Shield\\ShieldClient' => $vendorDir . '/aws/aws-sdk-php/src/Shield/ShieldClient.php',
    'Aws\\Signature\\AnonymousSignature' => $vendorDir . '/aws/aws-sdk-php/src/Signature/AnonymousSignature.php',
    'Aws\\Signature\\S3ExpressSignature' => $vendorDir . '/aws/aws-sdk-php/src/Signature/S3ExpressSignature.php',
    'Aws\\Signature\\S3SignatureV4' => $vendorDir . '/aws/aws-sdk-php/src/Signature/S3SignatureV4.php',
    'Aws\\Signature\\SignatureInterface' => $vendorDir . '/aws/aws-sdk-php/src/Signature/SignatureInterface.php',
    'Aws\\Signature\\SignatureProvider' => $vendorDir . '/aws/aws-sdk-php/src/Signature/SignatureProvider.php',
    'Aws\\Signature\\SignatureTrait' => $vendorDir . '/aws/aws-sdk-php/src/Signature/SignatureTrait.php',
    'Aws\\Signature\\SignatureV4' => $vendorDir . '/aws/aws-sdk-php/src/Signature/SignatureV4.php',
    'Aws\\SimSpaceWeaver\\Exception\\SimSpaceWeaverException' => $vendorDir . '/aws/aws-sdk-php/src/SimSpaceWeaver/Exception/SimSpaceWeaverException.php',
    'Aws\\SimSpaceWeaver\\SimSpaceWeaverClient' => $vendorDir . '/aws/aws-sdk-php/src/SimSpaceWeaver/SimSpaceWeaverClient.php',
    'Aws\\Sms\\Exception\\SmsException' => $vendorDir . '/aws/aws-sdk-php/src/Sms/Exception/SmsException.php',
    'Aws\\Sms\\SmsClient' => $vendorDir . '/aws/aws-sdk-php/src/Sms/SmsClient.php',
    'Aws\\SnowBall\\Exception\\SnowBallException' => $vendorDir . '/aws/aws-sdk-php/src/SnowBall/Exception/SnowBallException.php',
    'Aws\\SnowBall\\SnowBallClient' => $vendorDir . '/aws/aws-sdk-php/src/SnowBall/SnowBallClient.php',
    'Aws\\SnowDeviceManagement\\Exception\\SnowDeviceManagementException' => $vendorDir . '/aws/aws-sdk-php/src/SnowDeviceManagement/Exception/SnowDeviceManagementException.php',
    'Aws\\SnowDeviceManagement\\SnowDeviceManagementClient' => $vendorDir . '/aws/aws-sdk-php/src/SnowDeviceManagement/SnowDeviceManagementClient.php',
    'Aws\\Sns\\Exception\\SnsException' => $vendorDir . '/aws/aws-sdk-php/src/Sns/Exception/SnsException.php',
    'Aws\\Sns\\SnsClient' => $vendorDir . '/aws/aws-sdk-php/src/Sns/SnsClient.php',
    'Aws\\Sqs\\Exception\\SqsException' => $vendorDir . '/aws/aws-sdk-php/src/Sqs/Exception/SqsException.php',
    'Aws\\Sqs\\SqsClient' => $vendorDir . '/aws/aws-sdk-php/src/Sqs/SqsClient.php',
    'Aws\\SsmSap\\Exception\\SsmSapException' => $vendorDir . '/aws/aws-sdk-php/src/SsmSap/Exception/SsmSapException.php',
    'Aws\\SsmSap\\SsmSapClient' => $vendorDir . '/aws/aws-sdk-php/src/SsmSap/SsmSapClient.php',
    'Aws\\Ssm\\Exception\\SsmException' => $vendorDir . '/aws/aws-sdk-php/src/Ssm/Exception/SsmException.php',
    'Aws\\Ssm\\SsmClient' => $vendorDir . '/aws/aws-sdk-php/src/Ssm/SsmClient.php',
    'Aws\\StorageGateway\\Exception\\StorageGatewayException' => $vendorDir . '/aws/aws-sdk-php/src/StorageGateway/Exception/StorageGatewayException.php',
    'Aws\\StorageGateway\\StorageGatewayClient' => $vendorDir . '/aws/aws-sdk-php/src/StorageGateway/StorageGatewayClient.php',
    'Aws\\StreamRequestPayloadMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/StreamRequestPayloadMiddleware.php',
    'Aws\\Sts\\Exception\\StsException' => $vendorDir . '/aws/aws-sdk-php/src/Sts/Exception/StsException.php',
    'Aws\\Sts\\RegionalEndpoints\\Configuration' => $vendorDir . '/aws/aws-sdk-php/src/Sts/RegionalEndpoints/Configuration.php',
    'Aws\\Sts\\RegionalEndpoints\\ConfigurationInterface' => $vendorDir . '/aws/aws-sdk-php/src/Sts/RegionalEndpoints/ConfigurationInterface.php',
    'Aws\\Sts\\RegionalEndpoints\\ConfigurationProvider' => $vendorDir . '/aws/aws-sdk-php/src/Sts/RegionalEndpoints/ConfigurationProvider.php',
    'Aws\\Sts\\RegionalEndpoints\\Exception\\ConfigurationException' => $vendorDir . '/aws/aws-sdk-php/src/Sts/RegionalEndpoints/Exception/ConfigurationException.php',
    'Aws\\Sts\\StsClient' => $vendorDir . '/aws/aws-sdk-php/src/Sts/StsClient.php',
    'Aws\\SupplyChain\\Exception\\SupplyChainException' => $vendorDir . '/aws/aws-sdk-php/src/SupplyChain/Exception/SupplyChainException.php',
    'Aws\\SupplyChain\\SupplyChainClient' => $vendorDir . '/aws/aws-sdk-php/src/SupplyChain/SupplyChainClient.php',
    'Aws\\SupportApp\\Exception\\SupportAppException' => $vendorDir . '/aws/aws-sdk-php/src/SupportApp/Exception/SupportAppException.php',
    'Aws\\SupportApp\\SupportAppClient' => $vendorDir . '/aws/aws-sdk-php/src/SupportApp/SupportAppClient.php',
    'Aws\\Support\\Exception\\SupportException' => $vendorDir . '/aws/aws-sdk-php/src/Support/Exception/SupportException.php',
    'Aws\\Support\\SupportClient' => $vendorDir . '/aws/aws-sdk-php/src/Support/SupportClient.php',
    'Aws\\Swf\\Exception\\SwfException' => $vendorDir . '/aws/aws-sdk-php/src/Swf/Exception/SwfException.php',
    'Aws\\Swf\\SwfClient' => $vendorDir . '/aws/aws-sdk-php/src/Swf/SwfClient.php',
    'Aws\\Synthetics\\Exception\\SyntheticsException' => $vendorDir . '/aws/aws-sdk-php/src/Synthetics/Exception/SyntheticsException.php',
    'Aws\\Synthetics\\SyntheticsClient' => $vendorDir . '/aws/aws-sdk-php/src/Synthetics/SyntheticsClient.php',
    'Aws\\TaxSettings\\Exception\\TaxSettingsException' => $vendorDir . '/aws/aws-sdk-php/src/TaxSettings/Exception/TaxSettingsException.php',
    'Aws\\TaxSettings\\TaxSettingsClient' => $vendorDir . '/aws/aws-sdk-php/src/TaxSettings/TaxSettingsClient.php',
    'Aws\\Textract\\Exception\\TextractException' => $vendorDir . '/aws/aws-sdk-php/src/Textract/Exception/TextractException.php',
    'Aws\\Textract\\TextractClient' => $vendorDir . '/aws/aws-sdk-php/src/Textract/TextractClient.php',
    'Aws\\TimestreamInfluxDB\\Exception\\TimestreamInfluxDBException' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamInfluxDB/Exception/TimestreamInfluxDBException.php',
    'Aws\\TimestreamInfluxDB\\TimestreamInfluxDBClient' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamInfluxDB/TimestreamInfluxDBClient.php',
    'Aws\\TimestreamQuery\\Exception\\TimestreamQueryException' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamQuery/Exception/TimestreamQueryException.php',
    'Aws\\TimestreamQuery\\TimestreamQueryClient' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamQuery/TimestreamQueryClient.php',
    'Aws\\TimestreamWrite\\Exception\\TimestreamWriteException' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamWrite/Exception/TimestreamWriteException.php',
    'Aws\\TimestreamWrite\\TimestreamWriteClient' => $vendorDir . '/aws/aws-sdk-php/src/TimestreamWrite/TimestreamWriteClient.php',
    'Aws\\Tnb\\Exception\\TnbException' => $vendorDir . '/aws/aws-sdk-php/src/Tnb/Exception/TnbException.php',
    'Aws\\Tnb\\TnbClient' => $vendorDir . '/aws/aws-sdk-php/src/Tnb/TnbClient.php',
    'Aws\\Token\\BearerTokenAuthorization' => $vendorDir . '/aws/aws-sdk-php/src/Token/BearerTokenAuthorization.php',
    'Aws\\Token\\ParsesIniTrait' => $vendorDir . '/aws/aws-sdk-php/src/Token/ParsesIniTrait.php',
    'Aws\\Token\\RefreshableTokenProviderInterface' => $vendorDir . '/aws/aws-sdk-php/src/Token/RefreshableTokenProviderInterface.php',
    'Aws\\Token\\SsoToken' => $vendorDir . '/aws/aws-sdk-php/src/Token/SsoToken.php',
    'Aws\\Token\\SsoTokenProvider' => $vendorDir . '/aws/aws-sdk-php/src/Token/SsoTokenProvider.php',
    'Aws\\Token\\Token' => $vendorDir . '/aws/aws-sdk-php/src/Token/Token.php',
    'Aws\\Token\\TokenAuthorization' => $vendorDir . '/aws/aws-sdk-php/src/Token/TokenAuthorization.php',
    'Aws\\Token\\TokenInterface' => $vendorDir . '/aws/aws-sdk-php/src/Token/TokenInterface.php',
    'Aws\\Token\\TokenProvider' => $vendorDir . '/aws/aws-sdk-php/src/Token/TokenProvider.php',
    'Aws\\TraceMiddleware' => $vendorDir . '/aws/aws-sdk-php/src/TraceMiddleware.php',
    'Aws\\TranscribeService\\Exception\\TranscribeServiceException' => $vendorDir . '/aws/aws-sdk-php/src/TranscribeService/Exception/TranscribeServiceException.php',
    'Aws\\TranscribeService\\TranscribeServiceClient' => $vendorDir . '/aws/aws-sdk-php/src/TranscribeService/TranscribeServiceClient.php',
    'Aws\\Transfer\\Exception\\TransferException' => $vendorDir . '/aws/aws-sdk-php/src/Transfer/Exception/TransferException.php',
    'Aws\\Transfer\\TransferClient' => $vendorDir . '/aws/aws-sdk-php/src/Transfer/TransferClient.php',
    'Aws\\Translate\\Exception\\TranslateException' => $vendorDir . '/aws/aws-sdk-php/src/Translate/Exception/TranslateException.php',
    'Aws\\Translate\\TranslateClient' => $vendorDir . '/aws/aws-sdk-php/src/Translate/TranslateClient.php',
    'Aws\\TrustedAdvisor\\Exception\\TrustedAdvisorException' => $vendorDir . '/aws/aws-sdk-php/src/TrustedAdvisor/Exception/TrustedAdvisorException.php',
    'Aws\\TrustedAdvisor\\TrustedAdvisorClient' => $vendorDir . '/aws/aws-sdk-php/src/TrustedAdvisor/TrustedAdvisorClient.php',
    'Aws\\VPCLattice\\Exception\\VPCLatticeException' => $vendorDir . '/aws/aws-sdk-php/src/VPCLattice/Exception/VPCLatticeException.php',
    'Aws\\VPCLattice\\VPCLatticeClient' => $vendorDir . '/aws/aws-sdk-php/src/VPCLattice/VPCLatticeClient.php',
    'Aws\\VerifiedPermissions\\Exception\\VerifiedPermissionsException' => $vendorDir . '/aws/aws-sdk-php/src/VerifiedPermissions/Exception/VerifiedPermissionsException.php',
    'Aws\\VerifiedPermissions\\VerifiedPermissionsClient' => $vendorDir . '/aws/aws-sdk-php/src/VerifiedPermissions/VerifiedPermissionsClient.php',
    'Aws\\VoiceID\\Exception\\VoiceIDException' => $vendorDir . '/aws/aws-sdk-php/src/VoiceID/Exception/VoiceIDException.php',
    'Aws\\VoiceID\\VoiceIDClient' => $vendorDir . '/aws/aws-sdk-php/src/VoiceID/VoiceIDClient.php',
    'Aws\\WAFV2\\Exception\\WAFV2Exception' => $vendorDir . '/aws/aws-sdk-php/src/WAFV2/Exception/WAFV2Exception.php',
    'Aws\\WAFV2\\WAFV2Client' => $vendorDir . '/aws/aws-sdk-php/src/WAFV2/WAFV2Client.php',
    'Aws\\WafRegional\\Exception\\WafRegionalException' => $vendorDir . '/aws/aws-sdk-php/src/WafRegional/Exception/WafRegionalException.php',
    'Aws\\WafRegional\\WafRegionalClient' => $vendorDir . '/aws/aws-sdk-php/src/WafRegional/WafRegionalClient.php',
    'Aws\\Waf\\Exception\\WafException' => $vendorDir . '/aws/aws-sdk-php/src/Waf/Exception/WafException.php',
    'Aws\\Waf\\WafClient' => $vendorDir . '/aws/aws-sdk-php/src/Waf/WafClient.php',
    'Aws\\Waiter' => $vendorDir . '/aws/aws-sdk-php/src/Waiter.php',
    'Aws\\WellArchitected\\Exception\\WellArchitectedException' => $vendorDir . '/aws/aws-sdk-php/src/WellArchitected/Exception/WellArchitectedException.php',
    'Aws\\WellArchitected\\WellArchitectedClient' => $vendorDir . '/aws/aws-sdk-php/src/WellArchitected/WellArchitectedClient.php',
    'Aws\\WorkDocs\\Exception\\WorkDocsException' => $vendorDir . '/aws/aws-sdk-php/src/WorkDocs/Exception/WorkDocsException.php',
    'Aws\\WorkDocs\\WorkDocsClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkDocs/WorkDocsClient.php',
    'Aws\\WorkLink\\Exception\\WorkLinkException' => $vendorDir . '/aws/aws-sdk-php/src/WorkLink/Exception/WorkLinkException.php',
    'Aws\\WorkLink\\WorkLinkClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkLink/WorkLinkClient.php',
    'Aws\\WorkMailMessageFlow\\Exception\\WorkMailMessageFlowException' => $vendorDir . '/aws/aws-sdk-php/src/WorkMailMessageFlow/Exception/WorkMailMessageFlowException.php',
    'Aws\\WorkMailMessageFlow\\WorkMailMessageFlowClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkMailMessageFlow/WorkMailMessageFlowClient.php',
    'Aws\\WorkMail\\Exception\\WorkMailException' => $vendorDir . '/aws/aws-sdk-php/src/WorkMail/Exception/WorkMailException.php',
    'Aws\\WorkMail\\WorkMailClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkMail/WorkMailClient.php',
    'Aws\\WorkSpacesThinClient\\Exception\\WorkSpacesThinClientException' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpacesThinClient/Exception/WorkSpacesThinClientException.php',
    'Aws\\WorkSpacesThinClient\\WorkSpacesThinClientClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpacesThinClient/WorkSpacesThinClientClient.php',
    'Aws\\WorkSpacesWeb\\Exception\\WorkSpacesWebException' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpacesWeb/Exception/WorkSpacesWebException.php',
    'Aws\\WorkSpacesWeb\\WorkSpacesWebClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpacesWeb/WorkSpacesWebClient.php',
    'Aws\\WorkSpaces\\Exception\\WorkSpacesException' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpaces/Exception/WorkSpacesException.php',
    'Aws\\WorkSpaces\\WorkSpacesClient' => $vendorDir . '/aws/aws-sdk-php/src/WorkSpaces/WorkSpacesClient.php',
    'Aws\\WrappedHttpHandler' => $vendorDir . '/aws/aws-sdk-php/src/WrappedHttpHandler.php',
    'Aws\\XRay\\Exception\\XRayException' => $vendorDir . '/aws/aws-sdk-php/src/XRay/Exception/XRayException.php',
    'Aws\\XRay\\XRayClient' => $vendorDir . '/aws/aws-sdk-php/src/XRay/XRayClient.php',
    'Aws\\drs\\Exception\\drsException' => $vendorDir . '/aws/aws-sdk-php/src/drs/Exception/drsException.php',
    'Aws\\drs\\drsClient' => $vendorDir . '/aws/aws-sdk-php/src/drs/drsClient.php',
    'Aws\\finspace\\Exception\\finspaceException' => $vendorDir . '/aws/aws-sdk-php/src/finspace/Exception/finspaceException.php',
    'Aws\\finspace\\finspaceClient' => $vendorDir . '/aws/aws-sdk-php/src/finspace/finspaceClient.php',
    'Aws\\imagebuilder\\Exception\\imagebuilderException' => $vendorDir . '/aws/aws-sdk-php/src/imagebuilder/Exception/imagebuilderException.php',
    'Aws\\imagebuilder\\imagebuilderClient' => $vendorDir . '/aws/aws-sdk-php/src/imagebuilder/imagebuilderClient.php',
    'Aws\\ivschat\\Exception\\ivschatException' => $vendorDir . '/aws/aws-sdk-php/src/ivschat/Exception/ivschatException.php',
    'Aws\\ivschat\\ivschatClient' => $vendorDir . '/aws/aws-sdk-php/src/ivschat/ivschatClient.php',
    'Aws\\kendra\\Exception\\kendraException' => $vendorDir . '/aws/aws-sdk-php/src/kendra/Exception/kendraException.php',
    'Aws\\kendra\\kendraClient' => $vendorDir . '/aws/aws-sdk-php/src/kendra/kendraClient.php',
    'Aws\\mgn\\Exception\\mgnException' => $vendorDir . '/aws/aws-sdk-php/src/mgn/Exception/mgnException.php',
    'Aws\\mgn\\mgnClient' => $vendorDir . '/aws/aws-sdk-php/src/mgn/mgnClient.php',
    'Aws\\signer\\Exception\\signerException' => $vendorDir . '/aws/aws-sdk-php/src/signer/Exception/signerException.php',
    'Aws\\signer\\signerClient' => $vendorDir . '/aws/aws-sdk-php/src/signer/signerClient.php',
    'Barryvdh\\Debugbar\\Console\\ClearCommand' => $vendorDir . '/barryvdh/laravel-debugbar/src/Console/ClearCommand.php',
    'Barryvdh\\Debugbar\\Controllers\\AssetController' => $vendorDir . '/barryvdh/laravel-debugbar/src/Controllers/AssetController.php',
    'Barryvdh\\Debugbar\\Controllers\\BaseController' => $vendorDir . '/barryvdh/laravel-debugbar/src/Controllers/BaseController.php',
    'Barryvdh\\Debugbar\\Controllers\\CacheController' => $vendorDir . '/barryvdh/laravel-debugbar/src/Controllers/CacheController.php',
    'Barryvdh\\Debugbar\\Controllers\\OpenHandlerController' => $vendorDir . '/barryvdh/laravel-debugbar/src/Controllers/OpenHandlerController.php',
    'Barryvdh\\Debugbar\\Controllers\\TelescopeController' => $vendorDir . '/barryvdh/laravel-debugbar/src/Controllers/TelescopeController.php',
    'Barryvdh\\Debugbar\\DataCollector\\CacheCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/CacheCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\EventCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/EventCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\FilesCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/FilesCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\GateCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/GateCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\JobsCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/JobsCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\LaravelCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/LaravelCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\LivewireCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/LivewireCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\LogsCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/LogsCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\ModelsCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/ModelsCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\MultiAuthCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/MultiAuthCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\QueryCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/QueryCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\RequestCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/RequestCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\RouteCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/RouteCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\SessionCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/SessionCollector.php',
    'Barryvdh\\Debugbar\\DataCollector\\ViewCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataCollector/ViewCollector.php',
    'Barryvdh\\Debugbar\\DataFormatter\\QueryFormatter' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataFormatter/QueryFormatter.php',
    'Barryvdh\\Debugbar\\DataFormatter\\SimpleFormatter' => $vendorDir . '/barryvdh/laravel-debugbar/src/DataFormatter/SimpleFormatter.php',
    'Barryvdh\\Debugbar\\DebugbarViewEngine' => $vendorDir . '/barryvdh/laravel-debugbar/src/DebugbarViewEngine.php',
    'Barryvdh\\Debugbar\\Facade' => $vendorDir . '/barryvdh/laravel-debugbar/src/Facade.php',
    'Barryvdh\\Debugbar\\Facades\\Debugbar' => $vendorDir . '/barryvdh/laravel-debugbar/src/Facades/Debugbar.php',
    'Barryvdh\\Debugbar\\JavascriptRenderer' => $vendorDir . '/barryvdh/laravel-debugbar/src/JavascriptRenderer.php',
    'Barryvdh\\Debugbar\\LaravelDebugbar' => $vendorDir . '/barryvdh/laravel-debugbar/src/LaravelDebugbar.php',
    'Barryvdh\\Debugbar\\LumenServiceProvider' => $vendorDir . '/barryvdh/laravel-debugbar/src/LumenServiceProvider.php',
    'Barryvdh\\Debugbar\\Middleware\\DebugbarEnabled' => $vendorDir . '/barryvdh/laravel-debugbar/src/Middleware/DebugbarEnabled.php',
    'Barryvdh\\Debugbar\\Middleware\\InjectDebugbar' => $vendorDir . '/barryvdh/laravel-debugbar/src/Middleware/InjectDebugbar.php',
    'Barryvdh\\Debugbar\\ServiceProvider' => $vendorDir . '/barryvdh/laravel-debugbar/src/ServiceProvider.php',
    'Barryvdh\\Debugbar\\Storage\\FilesystemStorage' => $vendorDir . '/barryvdh/laravel-debugbar/src/Storage/FilesystemStorage.php',
    'Barryvdh\\Debugbar\\Storage\\SocketStorage' => $vendorDir . '/barryvdh/laravel-debugbar/src/Storage/SocketStorage.php',
    'Barryvdh\\Debugbar\\Support\\Clockwork\\ClockworkCollector' => $vendorDir . '/barryvdh/laravel-debugbar/src/Support/Clockwork/ClockworkCollector.php',
    'Barryvdh\\Debugbar\\Support\\Clockwork\\Converter' => $vendorDir . '/barryvdh/laravel-debugbar/src/Support/Clockwork/Converter.php',
    'Barryvdh\\Debugbar\\SymfonyHttpDriver' => $vendorDir . '/barryvdh/laravel-debugbar/src/SymfonyHttpDriver.php',
    'Barryvdh\\Debugbar\\Twig\\Extension\\Debug' => $vendorDir . '/barryvdh/laravel-debugbar/src/Twig/Extension/Debug.php',
    'Barryvdh\\Debugbar\\Twig\\Extension\\Dump' => $vendorDir . '/barryvdh/laravel-debugbar/src/Twig/Extension/Dump.php',
    'Barryvdh\\Debugbar\\Twig\\Extension\\Stopwatch' => $vendorDir . '/barryvdh/laravel-debugbar/src/Twig/Extension/Stopwatch.php',
    'Brick\\Math\\BigDecimal' => $vendorDir . '/brick/math/src/BigDecimal.php',
    'Brick\\Math\\BigInteger' => $vendorDir . '/brick/math/src/BigInteger.php',
    'Brick\\Math\\BigNumber' => $vendorDir . '/brick/math/src/BigNumber.php',
    'Brick\\Math\\BigRational' => $vendorDir . '/brick/math/src/BigRational.php',
    'Brick\\Math\\Exception\\DivisionByZeroException' => $vendorDir . '/brick/math/src/Exception/DivisionByZeroException.php',
    'Brick\\Math\\Exception\\IntegerOverflowException' => $vendorDir . '/brick/math/src/Exception/IntegerOverflowException.php',
    'Brick\\Math\\Exception\\MathException' => $vendorDir . '/brick/math/src/Exception/MathException.php',
    'Brick\\Math\\Exception\\NegativeNumberException' => $vendorDir . '/brick/math/src/Exception/NegativeNumberException.php',
    'Brick\\Math\\Exception\\NumberFormatException' => $vendorDir . '/brick/math/src/Exception/NumberFormatException.php',
    'Brick\\Math\\Exception\\RoundingNecessaryException' => $vendorDir . '/brick/math/src/Exception/RoundingNecessaryException.php',
    'Brick\\Math\\Internal\\Calculator' => $vendorDir . '/brick/math/src/Internal/Calculator.php',
    'Brick\\Math\\Internal\\Calculator\\BcMathCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/BcMathCalculator.php',
    'Brick\\Math\\Internal\\Calculator\\GmpCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/GmpCalculator.php',
    'Brick\\Math\\Internal\\Calculator\\NativeCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/NativeCalculator.php',
    'Brick\\Math\\RoundingMode' => $vendorDir . '/brick/math/src/RoundingMode.php',
    'Carbon\\AbstractTranslator' => $vendorDir . '/nesbot/carbon/src/Carbon/AbstractTranslator.php',
    'Carbon\\Callback' => $vendorDir . '/nesbot/carbon/src/Carbon/Callback.php',
    'Carbon\\Carbon' => $vendorDir . '/nesbot/carbon/src/Carbon/Carbon.php',
    'Carbon\\CarbonConverterInterface' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonConverterInterface.php',
    'Carbon\\CarbonImmutable' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonImmutable.php',
    'Carbon\\CarbonInterface' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonInterface.php',
    'Carbon\\CarbonInterval' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonInterval.php',
    'Carbon\\CarbonPeriod' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonPeriod.php',
    'Carbon\\CarbonPeriodImmutable' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonPeriodImmutable.php',
    'Carbon\\CarbonTimeZone' => $vendorDir . '/nesbot/carbon/src/Carbon/CarbonTimeZone.php',
    'Carbon\\Cli\\Invoker' => $vendorDir . '/nesbot/carbon/src/Carbon/Cli/Invoker.php',
    'Carbon\\Doctrine\\CarbonDoctrineType' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/CarbonDoctrineType.php',
    'Carbon\\Doctrine\\CarbonImmutableType' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/CarbonImmutableType.php',
    'Carbon\\Doctrine\\CarbonType' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/CarbonType.php',
    'Carbon\\Doctrine\\CarbonTypeConverter' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/CarbonTypeConverter.php',
    'Carbon\\Doctrine\\DateTimeDefaultPrecision' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/DateTimeDefaultPrecision.php',
    'Carbon\\Doctrine\\DateTimeImmutableType' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/DateTimeImmutableType.php',
    'Carbon\\Doctrine\\DateTimeType' => $vendorDir . '/carbonphp/carbon-doctrine-types/src/Carbon/Doctrine/DateTimeType.php',
    'Carbon\\Exceptions\\BadComparisonUnitException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/BadComparisonUnitException.php',
    'Carbon\\Exceptions\\BadFluentConstructorException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/BadFluentConstructorException.php',
    'Carbon\\Exceptions\\BadFluentSetterException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/BadFluentSetterException.php',
    'Carbon\\Exceptions\\BadMethodCallException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/BadMethodCallException.php',
    'Carbon\\Exceptions\\EndLessPeriodException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/EndLessPeriodException.php',
    'Carbon\\Exceptions\\Exception' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/Exception.php',
    'Carbon\\Exceptions\\ImmutableException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/ImmutableException.php',
    'Carbon\\Exceptions\\InvalidArgumentException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidArgumentException.php',
    'Carbon\\Exceptions\\InvalidCastException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidCastException.php',
    'Carbon\\Exceptions\\InvalidDateException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidDateException.php',
    'Carbon\\Exceptions\\InvalidFormatException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidFormatException.php',
    'Carbon\\Exceptions\\InvalidIntervalException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidIntervalException.php',
    'Carbon\\Exceptions\\InvalidPeriodDateException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidPeriodDateException.php',
    'Carbon\\Exceptions\\InvalidPeriodParameterException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidPeriodParameterException.php',
    'Carbon\\Exceptions\\InvalidTimeZoneException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidTimeZoneException.php',
    'Carbon\\Exceptions\\InvalidTypeException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/InvalidTypeException.php',
    'Carbon\\Exceptions\\NotACarbonClassException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/NotACarbonClassException.php',
    'Carbon\\Exceptions\\NotAPeriodException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/NotAPeriodException.php',
    'Carbon\\Exceptions\\NotLocaleAwareException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/NotLocaleAwareException.php',
    'Carbon\\Exceptions\\OutOfRangeException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/OutOfRangeException.php',
    'Carbon\\Exceptions\\ParseErrorException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/ParseErrorException.php',
    'Carbon\\Exceptions\\RuntimeException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/RuntimeException.php',
    'Carbon\\Exceptions\\UnitException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnitException.php',
    'Carbon\\Exceptions\\UnitNotConfiguredException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnitNotConfiguredException.php',
    'Carbon\\Exceptions\\UnknownGetterException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnknownGetterException.php',
    'Carbon\\Exceptions\\UnknownMethodException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnknownMethodException.php',
    'Carbon\\Exceptions\\UnknownSetterException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnknownSetterException.php',
    'Carbon\\Exceptions\\UnknownUnitException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnknownUnitException.php',
    'Carbon\\Exceptions\\UnreachableException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnreachableException.php',
    'Carbon\\Exceptions\\UnsupportedUnitException' => $vendorDir . '/nesbot/carbon/src/Carbon/Exceptions/UnsupportedUnitException.php',
    'Carbon\\Factory' => $vendorDir . '/nesbot/carbon/src/Carbon/Factory.php',
    'Carbon\\FactoryImmutable' => $vendorDir . '/nesbot/carbon/src/Carbon/FactoryImmutable.php',
    'Carbon\\Language' => $vendorDir . '/nesbot/carbon/src/Carbon/Language.php',
    'Carbon\\Laravel\\ServiceProvider' => $vendorDir . '/nesbot/carbon/src/Carbon/Laravel/ServiceProvider.php',
    'Carbon\\MessageFormatter\\MessageFormatterMapper' => $vendorDir . '/nesbot/carbon/src/Carbon/MessageFormatter/MessageFormatterMapper.php',
    'Carbon\\Month' => $vendorDir . '/nesbot/carbon/src/Carbon/Month.php',
    'Carbon\\PHPStan\\MacroExtension' => $vendorDir . '/nesbot/carbon/src/Carbon/PHPStan/MacroExtension.php',
    'Carbon\\PHPStan\\MacroMethodReflection' => $vendorDir . '/nesbot/carbon/src/Carbon/PHPStan/MacroMethodReflection.php',
    'Carbon\\Traits\\Boundaries' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Boundaries.php',
    'Carbon\\Traits\\Cast' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Cast.php',
    'Carbon\\Traits\\Comparison' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Comparison.php',
    'Carbon\\Traits\\Converter' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Converter.php',
    'Carbon\\Traits\\Creator' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Creator.php',
    'Carbon\\Traits\\Date' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Date.php',
    'Carbon\\Traits\\DeprecatedPeriodProperties' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/DeprecatedPeriodProperties.php',
    'Carbon\\Traits\\Difference' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Difference.php',
    'Carbon\\Traits\\IntervalRounding' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/IntervalRounding.php',
    'Carbon\\Traits\\IntervalStep' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/IntervalStep.php',
    'Carbon\\Traits\\LocalFactory' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/LocalFactory.php',
    'Carbon\\Traits\\Localization' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Localization.php',
    'Carbon\\Traits\\Macro' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Macro.php',
    'Carbon\\Traits\\MagicParameter' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/MagicParameter.php',
    'Carbon\\Traits\\Mixin' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Mixin.php',
    'Carbon\\Traits\\Modifiers' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Modifiers.php',
    'Carbon\\Traits\\Mutability' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Mutability.php',
    'Carbon\\Traits\\ObjectInitialisation' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/ObjectInitialisation.php',
    'Carbon\\Traits\\Options' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Options.php',
    'Carbon\\Traits\\Rounding' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Rounding.php',
    'Carbon\\Traits\\Serialization' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Serialization.php',
    'Carbon\\Traits\\StaticLocalization' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/StaticLocalization.php',
    'Carbon\\Traits\\StaticOptions' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/StaticOptions.php',
    'Carbon\\Traits\\Test' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Test.php',
    'Carbon\\Traits\\Timestamp' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Timestamp.php',
    'Carbon\\Traits\\ToStringFormat' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/ToStringFormat.php',
    'Carbon\\Traits\\Units' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Units.php',
    'Carbon\\Traits\\Week' => $vendorDir . '/nesbot/carbon/src/Carbon/Traits/Week.php',
    'Carbon\\Translator' => $vendorDir . '/nesbot/carbon/src/Carbon/Translator.php',
    'Carbon\\TranslatorImmutable' => $vendorDir . '/nesbot/carbon/src/Carbon/TranslatorImmutable.php',
    'Carbon\\TranslatorStrongTypeInterface' => $vendorDir . '/nesbot/carbon/src/Carbon/TranslatorStrongTypeInterface.php',
    'Carbon\\Unit' => $vendorDir . '/nesbot/carbon/src/Carbon/Unit.php',
    'Carbon\\WeekDay' => $vendorDir . '/nesbot/carbon/src/Carbon/WeekDay.php',
    'Carbon\\WrapperClock' => $vendorDir . '/nesbot/carbon/src/Carbon/WrapperClock.php',
    'Chatify\\ChatifyMessenger' => $vendorDir . '/munafio/chatify/src/ChatifyMessenger.php',
    'Chatify\\ChatifyServiceProvider' => $vendorDir . '/munafio/chatify/src/ChatifyServiceProvider.php',
    'Chatify\\Console\\InstallCommand' => $vendorDir . '/munafio/chatify/src/Console/InstallCommand.php',
    'Chatify\\Console\\PublishCommand' => $vendorDir . '/munafio/chatify/src/Console/PublishCommand.php',
    'Chatify\\Facades\\ChatifyMessenger' => $vendorDir . '/munafio/chatify/src/Facades/ChatifyMessenger.php',
    'Chatify\\Http\\Controllers\\Api\\MessagesController' => $vendorDir . '/munafio/chatify/src/Http/Controllers/Api/MessagesController.php',
    'Chatify\\Http\\Controllers\\MessagesController' => $vendorDir . '/munafio/chatify/src/Http/Controllers/MessagesController.php',
    'Chatify\\Traits\\UUID' => $vendorDir . '/munafio/chatify/src/Traits/UUID.php',
    'Collective\\Html\\Componentable' => $vendorDir . '/konekt/html/src/Componentable.php',
    'Collective\\Html\\Eloquent\\FormAccessible' => $vendorDir . '/konekt/html/src/Eloquent/FormAccessible.php',
    'Collective\\Html\\FormBuilder' => $vendorDir . '/konekt/html/src/FormBuilder.php',
    'Collective\\Html\\FormFacade' => $vendorDir . '/konekt/html/src/FormFacade.php',
    'Collective\\Html\\HtmlBuilder' => $vendorDir . '/konekt/html/src/HtmlBuilder.php',
    'Collective\\Html\\HtmlFacade' => $vendorDir . '/konekt/html/src/HtmlFacade.php',
    'Collective\\Html\\HtmlServiceProvider' => $vendorDir . '/konekt/html/src/HtmlServiceProvider.php',
    'Complex\\Complex' => $vendorDir . '/markbaker/complex/classes/src/Complex.php',
    'Complex\\Exception' => $vendorDir . '/markbaker/complex/classes/src/Exception.php',
    'Complex\\Functions' => $vendorDir . '/markbaker/complex/classes/src/Functions.php',
    'Complex\\Operations' => $vendorDir . '/markbaker/complex/classes/src/Operations.php',
    'Composer\\CaBundle\\CaBundle' => $vendorDir . '/composer/ca-bundle/src/CaBundle.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Composer\\Semver\\Comparator' => $vendorDir . '/composer/semver/src/Comparator.php',
    'Composer\\Semver\\CompilingMatcher' => $vendorDir . '/composer/semver/src/CompilingMatcher.php',
    'Composer\\Semver\\Constraint\\Bound' => $vendorDir . '/composer/semver/src/Constraint/Bound.php',
    'Composer\\Semver\\Constraint\\Constraint' => $vendorDir . '/composer/semver/src/Constraint/Constraint.php',
    'Composer\\Semver\\Constraint\\ConstraintInterface' => $vendorDir . '/composer/semver/src/Constraint/ConstraintInterface.php',
    'Composer\\Semver\\Constraint\\MatchAllConstraint' => $vendorDir . '/composer/semver/src/Constraint/MatchAllConstraint.php',
    'Composer\\Semver\\Constraint\\MatchNoneConstraint' => $vendorDir . '/composer/semver/src/Constraint/MatchNoneConstraint.php',
    'Composer\\Semver\\Constraint\\MultiConstraint' => $vendorDir . '/composer/semver/src/Constraint/MultiConstraint.php',
    'Composer\\Semver\\Interval' => $vendorDir . '/composer/semver/src/Interval.php',
    'Composer\\Semver\\Intervals' => $vendorDir . '/composer/semver/src/Intervals.php',
    'Composer\\Semver\\Semver' => $vendorDir . '/composer/semver/src/Semver.php',
    'Composer\\Semver\\VersionParser' => $vendorDir . '/composer/semver/src/VersionParser.php',
    'Cron\\AbstractField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/AbstractField.php',
    'Cron\\CronExpression' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/CronExpression.php',
    'Cron\\DayOfMonthField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/DayOfMonthField.php',
    'Cron\\DayOfWeekField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/DayOfWeekField.php',
    'Cron\\FieldFactory' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/FieldFactory.php',
    'Cron\\FieldFactoryInterface' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/FieldFactoryInterface.php',
    'Cron\\FieldInterface' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/FieldInterface.php',
    'Cron\\HoursField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/HoursField.php',
    'Cron\\MinutesField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/MinutesField.php',
    'Cron\\MonthField' => $vendorDir . '/dragonmantank/cron-expression/src/Cron/MonthField.php',
    'Database\\Factories\\UserFactory' => $baseDir . '/database/factories/UserFactory.php',
    'Database\\Seeders\\AiTemplateSeeder' => $baseDir . '/database/seeders/AiTemplateSeeder.php',
    'Database\\Seeders\\DatabaseSeeder' => $baseDir . '/database/seeders/DatabaseSeeder.php',
    'Database\\Seeders\\NotificationSeeder' => $baseDir . '/database/seeders/NotificationSeeder.php',
    'Database\\Seeders\\PlansTableSeeder' => $baseDir . '/database/seeders/PlansTableSeeder.php',
    'Database\\Seeders\\UsersTableSeeder' => $baseDir . '/database/seeders/UsersTableSeeder.php',
    'DateError' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateError.php',
    'DateException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateException.php',
    'DateInvalidOperationException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateInvalidOperationException.php',
    'DateInvalidTimeZoneException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateInvalidTimeZoneException.php',
    'DateMalformedIntervalStringException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateMalformedIntervalStringException.php',
    'DateMalformedPeriodStringException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateMalformedPeriodStringException.php',
    'DateMalformedStringException' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateMalformedStringException.php',
    'DateObjectError' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateObjectError.php',
    'DateRangeError' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/DateRangeError.php',
    'DebugBar\\Bridge\\CacheCacheCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/CacheCacheCollector.php',
    'DebugBar\\Bridge\\DoctrineCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/DoctrineCollector.php',
    'DebugBar\\Bridge\\MonologCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/MonologCollector.php',
    'DebugBar\\Bridge\\NamespacedTwigProfileCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/NamespacedTwigProfileCollector.php',
    'DebugBar\\Bridge\\Propel2Collector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Propel2Collector.php',
    'DebugBar\\Bridge\\PropelCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/PropelCollector.php',
    'DebugBar\\Bridge\\SlimCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/SlimCollector.php',
    'DebugBar\\Bridge\\SwiftMailer\\SwiftLogCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/SwiftMailer/SwiftLogCollector.php',
    'DebugBar\\Bridge\\SwiftMailer\\SwiftMailCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/SwiftMailer/SwiftMailCollector.php',
    'DebugBar\\Bridge\\Symfony\\SymfonyMailCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Symfony/SymfonyMailCollector.php',
    'DebugBar\\Bridge\\TwigProfileCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/TwigProfileCollector.php',
    'DebugBar\\Bridge\\Twig\\DebugTwigExtension' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/DebugTwigExtension.php',
    'DebugBar\\Bridge\\Twig\\DumpTwigExtension' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/DumpTwigExtension.php',
    'DebugBar\\Bridge\\Twig\\MeasureTwigExtension' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/MeasureTwigExtension.php',
    'DebugBar\\Bridge\\Twig\\MeasureTwigNode' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/MeasureTwigNode.php',
    'DebugBar\\Bridge\\Twig\\MeasureTwigTokenParser' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/MeasureTwigTokenParser.php',
    'DebugBar\\Bridge\\Twig\\TimeableTwigExtensionProfiler' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/TimeableTwigExtensionProfiler.php',
    'DebugBar\\Bridge\\Twig\\TraceableTwigEnvironment' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/TraceableTwigEnvironment.php',
    'DebugBar\\Bridge\\Twig\\TraceableTwigTemplate' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/TraceableTwigTemplate.php',
    'DebugBar\\Bridge\\Twig\\TwigCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Bridge/Twig/TwigCollector.php',
    'DebugBar\\DataCollector\\AggregatedCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/AggregatedCollector.php',
    'DebugBar\\DataCollector\\AssetProvider' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/AssetProvider.php',
    'DebugBar\\DataCollector\\ConfigCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/ConfigCollector.php',
    'DebugBar\\DataCollector\\DataCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/DataCollector.php',
    'DebugBar\\DataCollector\\DataCollectorInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/DataCollectorInterface.php',
    'DebugBar\\DataCollector\\ExceptionsCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/ExceptionsCollector.php',
    'DebugBar\\DataCollector\\LocalizationCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/LocalizationCollector.php',
    'DebugBar\\DataCollector\\MemoryCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/MemoryCollector.php',
    'DebugBar\\DataCollector\\MessagesAggregateInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/MessagesAggregateInterface.php',
    'DebugBar\\DataCollector\\MessagesCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/MessagesCollector.php',
    'DebugBar\\DataCollector\\ObjectCountCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/ObjectCountCollector.php',
    'DebugBar\\DataCollector\\PDO\\PDOCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/PDO/PDOCollector.php',
    'DebugBar\\DataCollector\\PDO\\TraceablePDO' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/PDO/TraceablePDO.php',
    'DebugBar\\DataCollector\\PDO\\TraceablePDOStatement' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/PDO/TraceablePDOStatement.php',
    'DebugBar\\DataCollector\\PDO\\TracedStatement' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/PDO/TracedStatement.php',
    'DebugBar\\DataCollector\\PhpInfoCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/PhpInfoCollector.php',
    'DebugBar\\DataCollector\\Renderable' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/Renderable.php',
    'DebugBar\\DataCollector\\RequestDataCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/RequestDataCollector.php',
    'DebugBar\\DataCollector\\TimeDataCollector' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataCollector/TimeDataCollector.php',
    'DebugBar\\DataFormatter\\DataFormatter' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/DataFormatter.php',
    'DebugBar\\DataFormatter\\DataFormatterInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/DataFormatterInterface.php',
    'DebugBar\\DataFormatter\\DebugBarVarDumper' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/DebugBarVarDumper.php',
    'DebugBar\\DataFormatter\\HasDataFormatter' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/HasDataFormatter.php',
    'DebugBar\\DataFormatter\\HasXdebugLinks' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/HasXdebugLinks.php',
    'DebugBar\\DataFormatter\\VarDumper\\DebugBarHtmlDumper' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DataFormatter/VarDumper/DebugBarHtmlDumper.php',
    'DebugBar\\DebugBar' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DebugBar.php',
    'DebugBar\\DebugBarException' => $vendorDir . '/maximebf/debugbar/src/DebugBar/DebugBarException.php',
    'DebugBar\\HttpDriverInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/HttpDriverInterface.php',
    'DebugBar\\JavascriptRenderer' => $vendorDir . '/maximebf/debugbar/src/DebugBar/JavascriptRenderer.php',
    'DebugBar\\OpenHandler' => $vendorDir . '/maximebf/debugbar/src/DebugBar/OpenHandler.php',
    'DebugBar\\PhpHttpDriver' => $vendorDir . '/maximebf/debugbar/src/DebugBar/PhpHttpDriver.php',
    'DebugBar\\RequestIdGenerator' => $vendorDir . '/maximebf/debugbar/src/DebugBar/RequestIdGenerator.php',
    'DebugBar\\RequestIdGeneratorInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/RequestIdGeneratorInterface.php',
    'DebugBar\\StandardDebugBar' => $vendorDir . '/maximebf/debugbar/src/DebugBar/StandardDebugBar.php',
    'DebugBar\\Storage\\FileStorage' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Storage/FileStorage.php',
    'DebugBar\\Storage\\MemcachedStorage' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Storage/MemcachedStorage.php',
    'DebugBar\\Storage\\PdoStorage' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Storage/PdoStorage.php',
    'DebugBar\\Storage\\RedisStorage' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Storage/RedisStorage.php',
    'DebugBar\\Storage\\StorageInterface' => $vendorDir . '/maximebf/debugbar/src/DebugBar/Storage/StorageInterface.php',
    'DeepCopy\\DeepCopy' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/DeepCopy.php',
    'DeepCopy\\Exception\\CloneException' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Exception/CloneException.php',
    'DeepCopy\\Exception\\PropertyException' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Exception/PropertyException.php',
    'DeepCopy\\Filter\\ChainableFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/ChainableFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineCollectionFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineCollectionFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineEmptyCollectionFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineEmptyCollectionFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineProxyFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineProxyFilter.php',
    'DeepCopy\\Filter\\Filter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Filter.php',
    'DeepCopy\\Filter\\KeepFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/KeepFilter.php',
    'DeepCopy\\Filter\\ReplaceFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/ReplaceFilter.php',
    'DeepCopy\\Filter\\SetNullFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/SetNullFilter.php',
    'DeepCopy\\Matcher\\Doctrine\\DoctrineProxyMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/Doctrine/DoctrineProxyMatcher.php',
    'DeepCopy\\Matcher\\Matcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/Matcher.php',
    'DeepCopy\\Matcher\\PropertyMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyMatcher.php',
    'DeepCopy\\Matcher\\PropertyNameMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyNameMatcher.php',
    'DeepCopy\\Matcher\\PropertyTypeMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyTypeMatcher.php',
    'DeepCopy\\Reflection\\ReflectionHelper' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Reflection/ReflectionHelper.php',
    'DeepCopy\\TypeFilter\\Date\\DateIntervalFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Date/DateIntervalFilter.php',
    'DeepCopy\\TypeFilter\\ReplaceFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/ReplaceFilter.php',
    'DeepCopy\\TypeFilter\\ShallowCopyFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/ShallowCopyFilter.php',
    'DeepCopy\\TypeFilter\\Spl\\ArrayObjectFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/ArrayObjectFilter.php',
    'DeepCopy\\TypeFilter\\Spl\\SplDoublyLinkedList' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/SplDoublyLinkedList.php',
    'DeepCopy\\TypeFilter\\Spl\\SplDoublyLinkedListFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/SplDoublyLinkedListFilter.php',
    'DeepCopy\\TypeFilter\\TypeFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/TypeFilter.php',
    'DeepCopy\\TypeMatcher\\TypeMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeMatcher/TypeMatcher.php',
    'Dflydev\\DotAccessData\\Data' => $vendorDir . '/dflydev/dot-access-data/src/Data.php',
    'Dflydev\\DotAccessData\\DataInterface' => $vendorDir . '/dflydev/dot-access-data/src/DataInterface.php',
    'Dflydev\\DotAccessData\\Exception\\DataException' => $vendorDir . '/dflydev/dot-access-data/src/Exception/DataException.php',
    'Dflydev\\DotAccessData\\Exception\\InvalidPathException' => $vendorDir . '/dflydev/dot-access-data/src/Exception/InvalidPathException.php',
    'Dflydev\\DotAccessData\\Exception\\MissingPathException' => $vendorDir . '/dflydev/dot-access-data/src/Exception/MissingPathException.php',
    'Dflydev\\DotAccessData\\Util' => $vendorDir . '/dflydev/dot-access-data/src/Util.php',
    'Doctrine\\Common\\Annotations\\Annotation' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation.php',
    'Doctrine\\Common\\Annotations\\AnnotationException' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/AnnotationException.php',
    'Doctrine\\Common\\Annotations\\AnnotationReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/AnnotationReader.php',
    'Doctrine\\Common\\Annotations\\AnnotationRegistry' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/AnnotationRegistry.php',
    'Doctrine\\Common\\Annotations\\Annotation\\Attribute' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/Attribute.php',
    'Doctrine\\Common\\Annotations\\Annotation\\Attributes' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/Attributes.php',
    'Doctrine\\Common\\Annotations\\Annotation\\Enum' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/Enum.php',
    'Doctrine\\Common\\Annotations\\Annotation\\IgnoreAnnotation' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/IgnoreAnnotation.php',
    'Doctrine\\Common\\Annotations\\Annotation\\NamedArgumentConstructor' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/NamedArgumentConstructor.php',
    'Doctrine\\Common\\Annotations\\Annotation\\Required' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/Required.php',
    'Doctrine\\Common\\Annotations\\Annotation\\Target' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Annotation/Target.php',
    'Doctrine\\Common\\Annotations\\CachedReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/CachedReader.php',
    'Doctrine\\Common\\Annotations\\DocLexer' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/DocLexer.php',
    'Doctrine\\Common\\Annotations\\DocParser' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/DocParser.php',
    'Doctrine\\Common\\Annotations\\FileCacheReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/FileCacheReader.php',
    'Doctrine\\Common\\Annotations\\ImplicitlyIgnoredAnnotationNames' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/ImplicitlyIgnoredAnnotationNames.php',
    'Doctrine\\Common\\Annotations\\IndexedReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/IndexedReader.php',
    'Doctrine\\Common\\Annotations\\NamedArgumentConstructorAnnotation' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/NamedArgumentConstructorAnnotation.php',
    'Doctrine\\Common\\Annotations\\PhpParser' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/PhpParser.php',
    'Doctrine\\Common\\Annotations\\PsrCachedReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/PsrCachedReader.php',
    'Doctrine\\Common\\Annotations\\Reader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/Reader.php',
    'Doctrine\\Common\\Annotations\\SimpleAnnotationReader' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/SimpleAnnotationReader.php',
    'Doctrine\\Common\\Annotations\\TokenParser' => $vendorDir . '/doctrine/annotations/lib/Doctrine/Common/Annotations/TokenParser.php',
    'Doctrine\\Common\\ClassLoader' => $vendorDir . '/doctrine/common/src/ClassLoader.php',
    'Doctrine\\Common\\CommonException' => $vendorDir . '/doctrine/common/src/CommonException.php',
    'Doctrine\\Common\\Comparable' => $vendorDir . '/doctrine/common/src/Comparable.php',
    'Doctrine\\Common\\EventArgs' => $vendorDir . '/doctrine/event-manager/src/EventArgs.php',
    'Doctrine\\Common\\EventManager' => $vendorDir . '/doctrine/event-manager/src/EventManager.php',
    'Doctrine\\Common\\EventSubscriber' => $vendorDir . '/doctrine/event-manager/src/EventSubscriber.php',
    'Doctrine\\Common\\Lexer\\AbstractLexer' => $vendorDir . '/doctrine/lexer/src/AbstractLexer.php',
    'Doctrine\\Common\\Lexer\\Token' => $vendorDir . '/doctrine/lexer/src/Token.php',
    'Doctrine\\Common\\Proxy\\AbstractProxyFactory' => $vendorDir . '/doctrine/common/src/Proxy/AbstractProxyFactory.php',
    'Doctrine\\Common\\Proxy\\Autoloader' => $vendorDir . '/doctrine/common/src/Proxy/Autoloader.php',
    'Doctrine\\Common\\Proxy\\Exception\\InvalidArgumentException' => $vendorDir . '/doctrine/common/src/Proxy/Exception/InvalidArgumentException.php',
    'Doctrine\\Common\\Proxy\\Exception\\OutOfBoundsException' => $vendorDir . '/doctrine/common/src/Proxy/Exception/OutOfBoundsException.php',
    'Doctrine\\Common\\Proxy\\Exception\\ProxyException' => $vendorDir . '/doctrine/common/src/Proxy/Exception/ProxyException.php',
    'Doctrine\\Common\\Proxy\\Exception\\UnexpectedValueException' => $vendorDir . '/doctrine/common/src/Proxy/Exception/UnexpectedValueException.php',
    'Doctrine\\Common\\Proxy\\Proxy' => $vendorDir . '/doctrine/common/src/Proxy/Proxy.php',
    'Doctrine\\Common\\Proxy\\ProxyDefinition' => $vendorDir . '/doctrine/common/src/Proxy/ProxyDefinition.php',
    'Doctrine\\Common\\Proxy\\ProxyGenerator' => $vendorDir . '/doctrine/common/src/Proxy/ProxyGenerator.php',
    'Doctrine\\Common\\Util\\ClassUtils' => $vendorDir . '/doctrine/common/src/Util/ClassUtils.php',
    'Doctrine\\Common\\Util\\Debug' => $vendorDir . '/doctrine/common/src/Util/Debug.php',
    'Doctrine\\DBAL\\ArrayParameterType' => $vendorDir . '/doctrine/dbal/src/ArrayParameterType.php',
    'Doctrine\\DBAL\\ArrayParameters\\Exception' => $vendorDir . '/doctrine/dbal/src/ArrayParameters/Exception.php',
    'Doctrine\\DBAL\\ArrayParameters\\Exception\\MissingNamedParameter' => $vendorDir . '/doctrine/dbal/src/ArrayParameters/Exception/MissingNamedParameter.php',
    'Doctrine\\DBAL\\ArrayParameters\\Exception\\MissingPositionalParameter' => $vendorDir . '/doctrine/dbal/src/ArrayParameters/Exception/MissingPositionalParameter.php',
    'Doctrine\\DBAL\\Cache\\ArrayResult' => $vendorDir . '/doctrine/dbal/src/Cache/ArrayResult.php',
    'Doctrine\\DBAL\\Cache\\CacheException' => $vendorDir . '/doctrine/dbal/src/Cache/CacheException.php',
    'Doctrine\\DBAL\\Cache\\Exception\\NoCacheKey' => $vendorDir . '/doctrine/dbal/src/Cache/Exception/NoCacheKey.php',
    'Doctrine\\DBAL\\Cache\\Exception\\NoResultDriverConfigured' => $vendorDir . '/doctrine/dbal/src/Cache/Exception/NoResultDriverConfigured.php',
    'Doctrine\\DBAL\\Cache\\QueryCacheProfile' => $vendorDir . '/doctrine/dbal/src/Cache/QueryCacheProfile.php',
    'Doctrine\\DBAL\\ColumnCase' => $vendorDir . '/doctrine/dbal/src/ColumnCase.php',
    'Doctrine\\DBAL\\Configuration' => $vendorDir . '/doctrine/dbal/src/Configuration.php',
    'Doctrine\\DBAL\\Connection' => $vendorDir . '/doctrine/dbal/src/Connection.php',
    'Doctrine\\DBAL\\ConnectionException' => $vendorDir . '/doctrine/dbal/src/ConnectionException.php',
    'Doctrine\\DBAL\\Connection\\StaticServerVersionProvider' => $vendorDir . '/doctrine/dbal/src/Connection/StaticServerVersionProvider.php',
    'Doctrine\\DBAL\\Connections\\PrimaryReadReplicaConnection' => $vendorDir . '/doctrine/dbal/src/Connections/PrimaryReadReplicaConnection.php',
    'Doctrine\\DBAL\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver.php',
    'Doctrine\\DBAL\\DriverManager' => $vendorDir . '/doctrine/dbal/src/DriverManager.php',
    'Doctrine\\DBAL\\Driver\\API\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\IBMDB2\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/IBMDB2/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\MySQL\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/MySQL/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\OCI\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/OCI/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\PostgreSQL\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/PostgreSQL/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\SQLSrv\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/SQLSrv/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\API\\SQLite\\ExceptionConverter' => $vendorDir . '/doctrine/dbal/src/Driver/API/SQLite/ExceptionConverter.php',
    'Doctrine\\DBAL\\Driver\\AbstractDB2Driver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractDB2Driver.php',
    'Doctrine\\DBAL\\Driver\\AbstractException' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractException.php',
    'Doctrine\\DBAL\\Driver\\AbstractMySQLDriver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractMySQLDriver.php',
    'Doctrine\\DBAL\\Driver\\AbstractOracleDriver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractOracleDriver.php',
    'Doctrine\\DBAL\\Driver\\AbstractOracleDriver\\EasyConnectString' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractOracleDriver/EasyConnectString.php',
    'Doctrine\\DBAL\\Driver\\AbstractPostgreSQLDriver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractPostgreSQLDriver.php',
    'Doctrine\\DBAL\\Driver\\AbstractSQLServerDriver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractSQLServerDriver.php',
    'Doctrine\\DBAL\\Driver\\AbstractSQLServerDriver\\Exception\\PortWithoutHost' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractSQLServerDriver/Exception/PortWithoutHost.php',
    'Doctrine\\DBAL\\Driver\\AbstractSQLiteDriver' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractSQLiteDriver.php',
    'Doctrine\\DBAL\\Driver\\AbstractSQLiteDriver\\Middleware\\EnableForeignKeys' => $vendorDir . '/doctrine/dbal/src/Driver/AbstractSQLiteDriver/Middleware/EnableForeignKeys.php',
    'Doctrine\\DBAL\\Driver\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/Connection.php',
    'Doctrine\\DBAL\\Driver\\Exception' => $vendorDir . '/doctrine/dbal/src/Driver/Exception.php',
    'Doctrine\\DBAL\\Driver\\Exception\\IdentityColumnsNotSupported' => $vendorDir . '/doctrine/dbal/src/Driver/Exception/IdentityColumnsNotSupported.php',
    'Doctrine\\DBAL\\Driver\\Exception\\NoIdentityValue' => $vendorDir . '/doctrine/dbal/src/Driver/Exception/NoIdentityValue.php',
    'Doctrine\\DBAL\\Driver\\FetchUtils' => $vendorDir . '/doctrine/dbal/src/Driver/FetchUtils.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Connection.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\DataSourceName' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/DataSourceName.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Driver.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\CannotCopyStreamToStream' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/CannotCopyStreamToStream.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\CannotCreateTemporaryFile' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/CannotCreateTemporaryFile.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\ConnectionError' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/ConnectionError.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\ConnectionFailed' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/ConnectionFailed.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\Factory' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/Factory.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\PrepareFailed' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/PrepareFailed.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Exception\\StatementError' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Exception/StatementError.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Result.php',
    'Doctrine\\DBAL\\Driver\\IBMDB2\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/IBMDB2/Statement.php',
    'Doctrine\\DBAL\\Driver\\Middleware' => $vendorDir . '/doctrine/dbal/src/Driver/Middleware.php',
    'Doctrine\\DBAL\\Driver\\Middleware\\AbstractConnectionMiddleware' => $vendorDir . '/doctrine/dbal/src/Driver/Middleware/AbstractConnectionMiddleware.php',
    'Doctrine\\DBAL\\Driver\\Middleware\\AbstractDriverMiddleware' => $vendorDir . '/doctrine/dbal/src/Driver/Middleware/AbstractDriverMiddleware.php',
    'Doctrine\\DBAL\\Driver\\Middleware\\AbstractResultMiddleware' => $vendorDir . '/doctrine/dbal/src/Driver/Middleware/AbstractResultMiddleware.php',
    'Doctrine\\DBAL\\Driver\\Middleware\\AbstractStatementMiddleware' => $vendorDir . '/doctrine/dbal/src/Driver/Middleware/AbstractStatementMiddleware.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Connection.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Driver.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\ConnectionError' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/ConnectionError.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\ConnectionFailed' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/ConnectionFailed.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\FailedReadingStreamOffset' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/FailedReadingStreamOffset.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\HostRequired' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/HostRequired.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\InvalidCharset' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/InvalidCharset.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\InvalidOption' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/InvalidOption.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\NonStreamResourceUsedAsLargeObject' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/NonStreamResourceUsedAsLargeObject.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Exception\\StatementError' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Exception/StatementError.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Initializer' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Initializer.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Initializer\\Charset' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Initializer/Charset.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Initializer\\Options' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Initializer/Options.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Initializer\\Secure' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Initializer/Secure.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Result.php',
    'Doctrine\\DBAL\\Driver\\Mysqli\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/Mysqli/Statement.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Connection.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\ConvertPositionalToNamedPlaceholders' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/ConvertPositionalToNamedPlaceholders.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Driver.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Exception\\ConnectionFailed' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Exception/ConnectionFailed.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Exception\\Error' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Exception/Error.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Exception\\InvalidConfiguration' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Exception/InvalidConfiguration.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Exception\\NonTerminatedStringLiteral' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Exception/NonTerminatedStringLiteral.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Exception\\UnknownParameterIndex' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Exception/UnknownParameterIndex.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\ExecutionMode' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/ExecutionMode.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Middleware\\InitializeSession' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Middleware/InitializeSession.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Result.php',
    'Doctrine\\DBAL\\Driver\\OCI8\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/OCI8/Statement.php',
    'Doctrine\\DBAL\\Driver\\PDO\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/Connection.php',
    'Doctrine\\DBAL\\Driver\\PDO\\Exception' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/Exception.php',
    'Doctrine\\DBAL\\Driver\\PDO\\Exception\\InvalidConfiguration' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/Exception/InvalidConfiguration.php',
    'Doctrine\\DBAL\\Driver\\PDO\\MySQL\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/MySQL/Driver.php',
    'Doctrine\\DBAL\\Driver\\PDO\\OCI\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/OCI/Driver.php',
    'Doctrine\\DBAL\\Driver\\PDO\\PgSQL\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/PgSQL/Driver.php',
    'Doctrine\\DBAL\\Driver\\PDO\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/Result.php',
    'Doctrine\\DBAL\\Driver\\PDO\\SQLSrv\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/SQLSrv/Connection.php',
    'Doctrine\\DBAL\\Driver\\PDO\\SQLSrv\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/SQLSrv/Driver.php',
    'Doctrine\\DBAL\\Driver\\PDO\\SQLSrv\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/SQLSrv/Statement.php',
    'Doctrine\\DBAL\\Driver\\PDO\\SQLite\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/SQLite/Driver.php',
    'Doctrine\\DBAL\\Driver\\PDO\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/PDO/Statement.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Connection.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\ConvertParameters' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/ConvertParameters.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Driver.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Exception' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Exception.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Exception\\UnexpectedValue' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Exception/UnexpectedValue.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Exception\\UnknownParameter' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Exception/UnknownParameter.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Result.php',
    'Doctrine\\DBAL\\Driver\\PgSQL\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/PgSQL/Statement.php',
    'Doctrine\\DBAL\\Driver\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/Result.php',
    'Doctrine\\DBAL\\Driver\\SQLSrv\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/SQLSrv/Connection.php',
    'Doctrine\\DBAL\\Driver\\SQLSrv\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/SQLSrv/Driver.php',
    'Doctrine\\DBAL\\Driver\\SQLSrv\\Exception\\Error' => $vendorDir . '/doctrine/dbal/src/Driver/SQLSrv/Exception/Error.php',
    'Doctrine\\DBAL\\Driver\\SQLSrv\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/SQLSrv/Result.php',
    'Doctrine\\DBAL\\Driver\\SQLSrv\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/SQLSrv/Statement.php',
    'Doctrine\\DBAL\\Driver\\SQLite3\\Connection' => $vendorDir . '/doctrine/dbal/src/Driver/SQLite3/Connection.php',
    'Doctrine\\DBAL\\Driver\\SQLite3\\Driver' => $vendorDir . '/doctrine/dbal/src/Driver/SQLite3/Driver.php',
    'Doctrine\\DBAL\\Driver\\SQLite3\\Exception' => $vendorDir . '/doctrine/dbal/src/Driver/SQLite3/Exception.php',
    'Doctrine\\DBAL\\Driver\\SQLite3\\Result' => $vendorDir . '/doctrine/dbal/src/Driver/SQLite3/Result.php',
    'Doctrine\\DBAL\\Driver\\SQLite3\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/SQLite3/Statement.php',
    'Doctrine\\DBAL\\Driver\\Statement' => $vendorDir . '/doctrine/dbal/src/Driver/Statement.php',
    'Doctrine\\DBAL\\Exception' => $vendorDir . '/doctrine/dbal/src/Exception.php',
    'Doctrine\\DBAL\\Exception\\CommitFailedRollbackOnly' => $vendorDir . '/doctrine/dbal/src/Exception/CommitFailedRollbackOnly.php',
    'Doctrine\\DBAL\\Exception\\ConnectionException' => $vendorDir . '/doctrine/dbal/src/Exception/ConnectionException.php',
    'Doctrine\\DBAL\\Exception\\ConnectionLost' => $vendorDir . '/doctrine/dbal/src/Exception/ConnectionLost.php',
    'Doctrine\\DBAL\\Exception\\ConstraintViolationException' => $vendorDir . '/doctrine/dbal/src/Exception/ConstraintViolationException.php',
    'Doctrine\\DBAL\\Exception\\DatabaseDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Exception/DatabaseDoesNotExist.php',
    'Doctrine\\DBAL\\Exception\\DatabaseObjectExistsException' => $vendorDir . '/doctrine/dbal/src/Exception/DatabaseObjectExistsException.php',
    'Doctrine\\DBAL\\Exception\\DatabaseObjectNotFoundException' => $vendorDir . '/doctrine/dbal/src/Exception/DatabaseObjectNotFoundException.php',
    'Doctrine\\DBAL\\Exception\\DatabaseRequired' => $vendorDir . '/doctrine/dbal/src/Exception/DatabaseRequired.php',
    'Doctrine\\DBAL\\Exception\\DeadlockException' => $vendorDir . '/doctrine/dbal/src/Exception/DeadlockException.php',
    'Doctrine\\DBAL\\Exception\\DriverException' => $vendorDir . '/doctrine/dbal/src/Exception/DriverException.php',
    'Doctrine\\DBAL\\Exception\\DriverRequired' => $vendorDir . '/doctrine/dbal/src/Exception/DriverRequired.php',
    'Doctrine\\DBAL\\Exception\\ForeignKeyConstraintViolationException' => $vendorDir . '/doctrine/dbal/src/Exception/ForeignKeyConstraintViolationException.php',
    'Doctrine\\DBAL\\Exception\\InvalidArgumentException' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidArgumentException.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnDeclaration' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnDeclaration.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnIndex' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnIndex.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnType' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnType.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnType\\ColumnLengthRequired' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnType/ColumnLengthRequired.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnType\\ColumnPrecisionRequired' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnType/ColumnPrecisionRequired.php',
    'Doctrine\\DBAL\\Exception\\InvalidColumnType\\ColumnScaleRequired' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidColumnType/ColumnScaleRequired.php',
    'Doctrine\\DBAL\\Exception\\InvalidDriverClass' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidDriverClass.php',
    'Doctrine\\DBAL\\Exception\\InvalidFieldNameException' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidFieldNameException.php',
    'Doctrine\\DBAL\\Exception\\InvalidWrapperClass' => $vendorDir . '/doctrine/dbal/src/Exception/InvalidWrapperClass.php',
    'Doctrine\\DBAL\\Exception\\LockWaitTimeoutException' => $vendorDir . '/doctrine/dbal/src/Exception/LockWaitTimeoutException.php',
    'Doctrine\\DBAL\\Exception\\MalformedDsnException' => $vendorDir . '/doctrine/dbal/src/Exception/MalformedDsnException.php',
    'Doctrine\\DBAL\\Exception\\NoActiveTransaction' => $vendorDir . '/doctrine/dbal/src/Exception/NoActiveTransaction.php',
    'Doctrine\\DBAL\\Exception\\NoKeyValue' => $vendorDir . '/doctrine/dbal/src/Exception/NoKeyValue.php',
    'Doctrine\\DBAL\\Exception\\NonUniqueFieldNameException' => $vendorDir . '/doctrine/dbal/src/Exception/NonUniqueFieldNameException.php',
    'Doctrine\\DBAL\\Exception\\NotNullConstraintViolationException' => $vendorDir . '/doctrine/dbal/src/Exception/NotNullConstraintViolationException.php',
    'Doctrine\\DBAL\\Exception\\ReadOnlyException' => $vendorDir . '/doctrine/dbal/src/Exception/ReadOnlyException.php',
    'Doctrine\\DBAL\\Exception\\RetryableException' => $vendorDir . '/doctrine/dbal/src/Exception/RetryableException.php',
    'Doctrine\\DBAL\\Exception\\SavepointsNotSupported' => $vendorDir . '/doctrine/dbal/src/Exception/SavepointsNotSupported.php',
    'Doctrine\\DBAL\\Exception\\SchemaDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Exception/SchemaDoesNotExist.php',
    'Doctrine\\DBAL\\Exception\\ServerException' => $vendorDir . '/doctrine/dbal/src/Exception/ServerException.php',
    'Doctrine\\DBAL\\Exception\\SyntaxErrorException' => $vendorDir . '/doctrine/dbal/src/Exception/SyntaxErrorException.php',
    'Doctrine\\DBAL\\Exception\\TableExistsException' => $vendorDir . '/doctrine/dbal/src/Exception/TableExistsException.php',
    'Doctrine\\DBAL\\Exception\\TableNotFoundException' => $vendorDir . '/doctrine/dbal/src/Exception/TableNotFoundException.php',
    'Doctrine\\DBAL\\Exception\\UniqueConstraintViolationException' => $vendorDir . '/doctrine/dbal/src/Exception/UniqueConstraintViolationException.php',
    'Doctrine\\DBAL\\Exception\\UnknownDriver' => $vendorDir . '/doctrine/dbal/src/Exception/UnknownDriver.php',
    'Doctrine\\DBAL\\ExpandArrayParameters' => $vendorDir . '/doctrine/dbal/src/ExpandArrayParameters.php',
    'Doctrine\\DBAL\\LockMode' => $vendorDir . '/doctrine/dbal/src/LockMode.php',
    'Doctrine\\DBAL\\Logging\\Connection' => $vendorDir . '/doctrine/dbal/src/Logging/Connection.php',
    'Doctrine\\DBAL\\Logging\\Driver' => $vendorDir . '/doctrine/dbal/src/Logging/Driver.php',
    'Doctrine\\DBAL\\Logging\\Middleware' => $vendorDir . '/doctrine/dbal/src/Logging/Middleware.php',
    'Doctrine\\DBAL\\Logging\\Statement' => $vendorDir . '/doctrine/dbal/src/Logging/Statement.php',
    'Doctrine\\DBAL\\ParameterType' => $vendorDir . '/doctrine/dbal/src/ParameterType.php',
    'Doctrine\\DBAL\\Platforms\\AbstractMySQLPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/AbstractMySQLPlatform.php',
    'Doctrine\\DBAL\\Platforms\\AbstractPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/AbstractPlatform.php',
    'Doctrine\\DBAL\\Platforms\\DB2Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/DB2Platform.php',
    'Doctrine\\DBAL\\Platforms\\DateIntervalUnit' => $vendorDir . '/doctrine/dbal/src/Platforms/DateIntervalUnit.php',
    'Doctrine\\DBAL\\Platforms\\Exception\\InvalidPlatformVersion' => $vendorDir . '/doctrine/dbal/src/Platforms/Exception/InvalidPlatformVersion.php',
    'Doctrine\\DBAL\\Platforms\\Exception\\NoColumnsSpecifiedForTable' => $vendorDir . '/doctrine/dbal/src/Platforms/Exception/NoColumnsSpecifiedForTable.php',
    'Doctrine\\DBAL\\Platforms\\Exception\\NotSupported' => $vendorDir . '/doctrine/dbal/src/Platforms/Exception/NotSupported.php',
    'Doctrine\\DBAL\\Platforms\\Exception\\PlatformException' => $vendorDir . '/doctrine/dbal/src/Platforms/Exception/PlatformException.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\DB2Keywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/DB2Keywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\KeywordList' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/KeywordList.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\MariaDBKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/MariaDBKeywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\MySQL80Keywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/MySQL80Keywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\MySQL84Keywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/MySQL84Keywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\MySQLKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/MySQLKeywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\OracleKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/OracleKeywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\PostgreSQLKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/PostgreSQLKeywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\SQLServerKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/SQLServerKeywords.php',
    'Doctrine\\DBAL\\Platforms\\Keywords\\SQLiteKeywords' => $vendorDir . '/doctrine/dbal/src/Platforms/Keywords/SQLiteKeywords.php',
    'Doctrine\\DBAL\\Platforms\\MariaDB1010Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/MariaDB1010Platform.php',
    'Doctrine\\DBAL\\Platforms\\MariaDB1052Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/MariaDB1052Platform.php',
    'Doctrine\\DBAL\\Platforms\\MariaDB1060Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/MariaDB1060Platform.php',
    'Doctrine\\DBAL\\Platforms\\MariaDBPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/MariaDBPlatform.php',
    'Doctrine\\DBAL\\Platforms\\MySQL80Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL80Platform.php',
    'Doctrine\\DBAL\\Platforms\\MySQL84Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL84Platform.php',
    'Doctrine\\DBAL\\Platforms\\MySQLPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQLPlatform.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CharsetMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CharsetMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CharsetMetadataProvider\\CachingCharsetMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CharsetMetadataProvider/CachingCharsetMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CharsetMetadataProvider\\ConnectionCharsetMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CharsetMetadataProvider/ConnectionCharsetMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CollationMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CollationMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CollationMetadataProvider\\CachingCollationMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CollationMetadataProvider/CachingCollationMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\CollationMetadataProvider\\ConnectionCollationMetadataProvider' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/CollationMetadataProvider/ConnectionCollationMetadataProvider.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\Comparator' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/Comparator.php',
    'Doctrine\\DBAL\\Platforms\\MySQL\\DefaultTableOptions' => $vendorDir . '/doctrine/dbal/src/Platforms/MySQL/DefaultTableOptions.php',
    'Doctrine\\DBAL\\Platforms\\OraclePlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/OraclePlatform.php',
    'Doctrine\\DBAL\\Platforms\\PostgreSQL120Platform' => $vendorDir . '/doctrine/dbal/src/Platforms/PostgreSQL120Platform.php',
    'Doctrine\\DBAL\\Platforms\\PostgreSQLPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/PostgreSQLPlatform.php',
    'Doctrine\\DBAL\\Platforms\\SQLServerPlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/SQLServerPlatform.php',
    'Doctrine\\DBAL\\Platforms\\SQLServer\\Comparator' => $vendorDir . '/doctrine/dbal/src/Platforms/SQLServer/Comparator.php',
    'Doctrine\\DBAL\\Platforms\\SQLServer\\SQL\\Builder\\SQLServerSelectSQLBuilder' => $vendorDir . '/doctrine/dbal/src/Platforms/SQLServer/SQL/Builder/SQLServerSelectSQLBuilder.php',
    'Doctrine\\DBAL\\Platforms\\SQLitePlatform' => $vendorDir . '/doctrine/dbal/src/Platforms/SQLitePlatform.php',
    'Doctrine\\DBAL\\Platforms\\SQLite\\Comparator' => $vendorDir . '/doctrine/dbal/src/Platforms/SQLite/Comparator.php',
    'Doctrine\\DBAL\\Platforms\\TrimMode' => $vendorDir . '/doctrine/dbal/src/Platforms/TrimMode.php',
    'Doctrine\\DBAL\\Portability\\Connection' => $vendorDir . '/doctrine/dbal/src/Portability/Connection.php',
    'Doctrine\\DBAL\\Portability\\Converter' => $vendorDir . '/doctrine/dbal/src/Portability/Converter.php',
    'Doctrine\\DBAL\\Portability\\Driver' => $vendorDir . '/doctrine/dbal/src/Portability/Driver.php',
    'Doctrine\\DBAL\\Portability\\Middleware' => $vendorDir . '/doctrine/dbal/src/Portability/Middleware.php',
    'Doctrine\\DBAL\\Portability\\OptimizeFlags' => $vendorDir . '/doctrine/dbal/src/Portability/OptimizeFlags.php',
    'Doctrine\\DBAL\\Portability\\Result' => $vendorDir . '/doctrine/dbal/src/Portability/Result.php',
    'Doctrine\\DBAL\\Portability\\Statement' => $vendorDir . '/doctrine/dbal/src/Portability/Statement.php',
    'Doctrine\\DBAL\\Query' => $vendorDir . '/doctrine/dbal/src/Query.php',
    'Doctrine\\DBAL\\Query\\Exception\\NonUniqueAlias' => $vendorDir . '/doctrine/dbal/src/Query/Exception/NonUniqueAlias.php',
    'Doctrine\\DBAL\\Query\\Exception\\UnknownAlias' => $vendorDir . '/doctrine/dbal/src/Query/Exception/UnknownAlias.php',
    'Doctrine\\DBAL\\Query\\Expression\\CompositeExpression' => $vendorDir . '/doctrine/dbal/src/Query/Expression/CompositeExpression.php',
    'Doctrine\\DBAL\\Query\\Expression\\ExpressionBuilder' => $vendorDir . '/doctrine/dbal/src/Query/Expression/ExpressionBuilder.php',
    'Doctrine\\DBAL\\Query\\ForUpdate' => $vendorDir . '/doctrine/dbal/src/Query/ForUpdate.php',
    'Doctrine\\DBAL\\Query\\ForUpdate\\ConflictResolutionMode' => $vendorDir . '/doctrine/dbal/src/Query/ForUpdate/ConflictResolutionMode.php',
    'Doctrine\\DBAL\\Query\\From' => $vendorDir . '/doctrine/dbal/src/Query/From.php',
    'Doctrine\\DBAL\\Query\\Join' => $vendorDir . '/doctrine/dbal/src/Query/Join.php',
    'Doctrine\\DBAL\\Query\\Limit' => $vendorDir . '/doctrine/dbal/src/Query/Limit.php',
    'Doctrine\\DBAL\\Query\\QueryBuilder' => $vendorDir . '/doctrine/dbal/src/Query/QueryBuilder.php',
    'Doctrine\\DBAL\\Query\\QueryException' => $vendorDir . '/doctrine/dbal/src/Query/QueryException.php',
    'Doctrine\\DBAL\\Query\\QueryType' => $vendorDir . '/doctrine/dbal/src/Query/QueryType.php',
    'Doctrine\\DBAL\\Query\\SelectQuery' => $vendorDir . '/doctrine/dbal/src/Query/SelectQuery.php',
    'Doctrine\\DBAL\\Query\\Union' => $vendorDir . '/doctrine/dbal/src/Query/Union.php',
    'Doctrine\\DBAL\\Query\\UnionQuery' => $vendorDir . '/doctrine/dbal/src/Query/UnionQuery.php',
    'Doctrine\\DBAL\\Query\\UnionType' => $vendorDir . '/doctrine/dbal/src/Query/UnionType.php',
    'Doctrine\\DBAL\\Result' => $vendorDir . '/doctrine/dbal/src/Result.php',
    'Doctrine\\DBAL\\SQL\\Builder\\CreateSchemaObjectsSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/CreateSchemaObjectsSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Builder\\DefaultSelectSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/DefaultSelectSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Builder\\DefaultUnionSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/DefaultUnionSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Builder\\DropSchemaObjectsSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/DropSchemaObjectsSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Builder\\SelectSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/SelectSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Builder\\UnionSQLBuilder' => $vendorDir . '/doctrine/dbal/src/SQL/Builder/UnionSQLBuilder.php',
    'Doctrine\\DBAL\\SQL\\Parser' => $vendorDir . '/doctrine/dbal/src/SQL/Parser.php',
    'Doctrine\\DBAL\\SQL\\Parser\\Exception' => $vendorDir . '/doctrine/dbal/src/SQL/Parser/Exception.php',
    'Doctrine\\DBAL\\SQL\\Parser\\Exception\\RegularExpressionError' => $vendorDir . '/doctrine/dbal/src/SQL/Parser/Exception/RegularExpressionError.php',
    'Doctrine\\DBAL\\SQL\\Parser\\Visitor' => $vendorDir . '/doctrine/dbal/src/SQL/Parser/Visitor.php',
    'Doctrine\\DBAL\\Schema\\AbstractAsset' => $vendorDir . '/doctrine/dbal/src/Schema/AbstractAsset.php',
    'Doctrine\\DBAL\\Schema\\AbstractSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/AbstractSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\Column' => $vendorDir . '/doctrine/dbal/src/Schema/Column.php',
    'Doctrine\\DBAL\\Schema\\ColumnDiff' => $vendorDir . '/doctrine/dbal/src/Schema/ColumnDiff.php',
    'Doctrine\\DBAL\\Schema\\Comparator' => $vendorDir . '/doctrine/dbal/src/Schema/Comparator.php',
    'Doctrine\\DBAL\\Schema\\DB2SchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/DB2SchemaManager.php',
    'Doctrine\\DBAL\\Schema\\DefaultSchemaManagerFactory' => $vendorDir . '/doctrine/dbal/src/Schema/DefaultSchemaManagerFactory.php',
    'Doctrine\\DBAL\\Schema\\Exception\\ColumnAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/ColumnAlreadyExists.php',
    'Doctrine\\DBAL\\Schema\\Exception\\ColumnDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/ColumnDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\ForeignKeyDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/ForeignKeyDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\IndexAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/IndexAlreadyExists.php',
    'Doctrine\\DBAL\\Schema\\Exception\\IndexDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/IndexDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\IndexNameInvalid' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/IndexNameInvalid.php',
    'Doctrine\\DBAL\\Schema\\Exception\\InvalidTableName' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/InvalidTableName.php',
    'Doctrine\\DBAL\\Schema\\Exception\\NamespaceAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/NamespaceAlreadyExists.php',
    'Doctrine\\DBAL\\Schema\\Exception\\SequenceAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/SequenceAlreadyExists.php',
    'Doctrine\\DBAL\\Schema\\Exception\\SequenceDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/SequenceDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\TableAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/TableAlreadyExists.php',
    'Doctrine\\DBAL\\Schema\\Exception\\TableDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/TableDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\UniqueConstraintDoesNotExist' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/UniqueConstraintDoesNotExist.php',
    'Doctrine\\DBAL\\Schema\\Exception\\UnknownColumnOption' => $vendorDir . '/doctrine/dbal/src/Schema/Exception/UnknownColumnOption.php',
    'Doctrine\\DBAL\\Schema\\ForeignKeyConstraint' => $vendorDir . '/doctrine/dbal/src/Schema/ForeignKeyConstraint.php',
    'Doctrine\\DBAL\\Schema\\Identifier' => $vendorDir . '/doctrine/dbal/src/Schema/Identifier.php',
    'Doctrine\\DBAL\\Schema\\Index' => $vendorDir . '/doctrine/dbal/src/Schema/Index.php',
    'Doctrine\\DBAL\\Schema\\MySQLSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/MySQLSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\OracleSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/OracleSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\PostgreSQLSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/PostgreSQLSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\SQLServerSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/SQLServerSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\SQLiteSchemaManager' => $vendorDir . '/doctrine/dbal/src/Schema/SQLiteSchemaManager.php',
    'Doctrine\\DBAL\\Schema\\Schema' => $vendorDir . '/doctrine/dbal/src/Schema/Schema.php',
    'Doctrine\\DBAL\\Schema\\SchemaConfig' => $vendorDir . '/doctrine/dbal/src/Schema/SchemaConfig.php',
    'Doctrine\\DBAL\\Schema\\SchemaDiff' => $vendorDir . '/doctrine/dbal/src/Schema/SchemaDiff.php',
    'Doctrine\\DBAL\\Schema\\SchemaException' => $vendorDir . '/doctrine/dbal/src/Schema/SchemaException.php',
    'Doctrine\\DBAL\\Schema\\SchemaManagerFactory' => $vendorDir . '/doctrine/dbal/src/Schema/SchemaManagerFactory.php',
    'Doctrine\\DBAL\\Schema\\Sequence' => $vendorDir . '/doctrine/dbal/src/Schema/Sequence.php',
    'Doctrine\\DBAL\\Schema\\Table' => $vendorDir . '/doctrine/dbal/src/Schema/Table.php',
    'Doctrine\\DBAL\\Schema\\TableDiff' => $vendorDir . '/doctrine/dbal/src/Schema/TableDiff.php',
    'Doctrine\\DBAL\\Schema\\UniqueConstraint' => $vendorDir . '/doctrine/dbal/src/Schema/UniqueConstraint.php',
    'Doctrine\\DBAL\\Schema\\View' => $vendorDir . '/doctrine/dbal/src/Schema/View.php',
    'Doctrine\\DBAL\\ServerVersionProvider' => $vendorDir . '/doctrine/dbal/src/ServerVersionProvider.php',
    'Doctrine\\DBAL\\Statement' => $vendorDir . '/doctrine/dbal/src/Statement.php',
    'Doctrine\\DBAL\\Tools\\Console\\Command\\RunSqlCommand' => $vendorDir . '/doctrine/dbal/src/Tools/Console/Command/RunSqlCommand.php',
    'Doctrine\\DBAL\\Tools\\Console\\ConnectionNotFound' => $vendorDir . '/doctrine/dbal/src/Tools/Console/ConnectionNotFound.php',
    'Doctrine\\DBAL\\Tools\\Console\\ConnectionProvider' => $vendorDir . '/doctrine/dbal/src/Tools/Console/ConnectionProvider.php',
    'Doctrine\\DBAL\\Tools\\Console\\ConnectionProvider\\SingleConnectionProvider' => $vendorDir . '/doctrine/dbal/src/Tools/Console/ConnectionProvider/SingleConnectionProvider.php',
    'Doctrine\\DBAL\\Tools\\DsnParser' => $vendorDir . '/doctrine/dbal/src/Tools/DsnParser.php',
    'Doctrine\\DBAL\\TransactionIsolationLevel' => $vendorDir . '/doctrine/dbal/src/TransactionIsolationLevel.php',
    'Doctrine\\DBAL\\Types\\AsciiStringType' => $vendorDir . '/doctrine/dbal/src/Types/AsciiStringType.php',
    'Doctrine\\DBAL\\Types\\BigIntType' => $vendorDir . '/doctrine/dbal/src/Types/BigIntType.php',
    'Doctrine\\DBAL\\Types\\BinaryType' => $vendorDir . '/doctrine/dbal/src/Types/BinaryType.php',
    'Doctrine\\DBAL\\Types\\BlobType' => $vendorDir . '/doctrine/dbal/src/Types/BlobType.php',
    'Doctrine\\DBAL\\Types\\BooleanType' => $vendorDir . '/doctrine/dbal/src/Types/BooleanType.php',
    'Doctrine\\DBAL\\Types\\ConversionException' => $vendorDir . '/doctrine/dbal/src/Types/ConversionException.php',
    'Doctrine\\DBAL\\Types\\DateImmutableType' => $vendorDir . '/doctrine/dbal/src/Types/DateImmutableType.php',
    'Doctrine\\DBAL\\Types\\DateIntervalType' => $vendorDir . '/doctrine/dbal/src/Types/DateIntervalType.php',
    'Doctrine\\DBAL\\Types\\DateTimeImmutableType' => $vendorDir . '/doctrine/dbal/src/Types/DateTimeImmutableType.php',
    'Doctrine\\DBAL\\Types\\DateTimeType' => $vendorDir . '/doctrine/dbal/src/Types/DateTimeType.php',
    'Doctrine\\DBAL\\Types\\DateTimeTzImmutableType' => $vendorDir . '/doctrine/dbal/src/Types/DateTimeTzImmutableType.php',
    'Doctrine\\DBAL\\Types\\DateTimeTzType' => $vendorDir . '/doctrine/dbal/src/Types/DateTimeTzType.php',
    'Doctrine\\DBAL\\Types\\DateType' => $vendorDir . '/doctrine/dbal/src/Types/DateType.php',
    'Doctrine\\DBAL\\Types\\DecimalType' => $vendorDir . '/doctrine/dbal/src/Types/DecimalType.php',
    'Doctrine\\DBAL\\Types\\Exception\\InvalidFormat' => $vendorDir . '/doctrine/dbal/src/Types/Exception/InvalidFormat.php',
    'Doctrine\\DBAL\\Types\\Exception\\InvalidType' => $vendorDir . '/doctrine/dbal/src/Types/Exception/InvalidType.php',
    'Doctrine\\DBAL\\Types\\Exception\\SerializationFailed' => $vendorDir . '/doctrine/dbal/src/Types/Exception/SerializationFailed.php',
    'Doctrine\\DBAL\\Types\\Exception\\TypeAlreadyRegistered' => $vendorDir . '/doctrine/dbal/src/Types/Exception/TypeAlreadyRegistered.php',
    'Doctrine\\DBAL\\Types\\Exception\\TypeNotFound' => $vendorDir . '/doctrine/dbal/src/Types/Exception/TypeNotFound.php',
    'Doctrine\\DBAL\\Types\\Exception\\TypeNotRegistered' => $vendorDir . '/doctrine/dbal/src/Types/Exception/TypeNotRegistered.php',
    'Doctrine\\DBAL\\Types\\Exception\\TypesAlreadyExists' => $vendorDir . '/doctrine/dbal/src/Types/Exception/TypesAlreadyExists.php',
    'Doctrine\\DBAL\\Types\\Exception\\TypesException' => $vendorDir . '/doctrine/dbal/src/Types/Exception/TypesException.php',
    'Doctrine\\DBAL\\Types\\Exception\\UnknownColumnType' => $vendorDir . '/doctrine/dbal/src/Types/Exception/UnknownColumnType.php',
    'Doctrine\\DBAL\\Types\\Exception\\ValueNotConvertible' => $vendorDir . '/doctrine/dbal/src/Types/Exception/ValueNotConvertible.php',
    'Doctrine\\DBAL\\Types\\FloatType' => $vendorDir . '/doctrine/dbal/src/Types/FloatType.php',
    'Doctrine\\DBAL\\Types\\GuidType' => $vendorDir . '/doctrine/dbal/src/Types/GuidType.php',
    'Doctrine\\DBAL\\Types\\IntegerType' => $vendorDir . '/doctrine/dbal/src/Types/IntegerType.php',
    'Doctrine\\DBAL\\Types\\JsonType' => $vendorDir . '/doctrine/dbal/src/Types/JsonType.php',
    'Doctrine\\DBAL\\Types\\PhpDateMappingType' => $vendorDir . '/doctrine/dbal/src/Types/PhpDateMappingType.php',
    'Doctrine\\DBAL\\Types\\PhpDateTimeMappingType' => $vendorDir . '/doctrine/dbal/src/Types/PhpDateTimeMappingType.php',
    'Doctrine\\DBAL\\Types\\PhpIntegerMappingType' => $vendorDir . '/doctrine/dbal/src/Types/PhpIntegerMappingType.php',
    'Doctrine\\DBAL\\Types\\PhpTimeMappingType' => $vendorDir . '/doctrine/dbal/src/Types/PhpTimeMappingType.php',
    'Doctrine\\DBAL\\Types\\SimpleArrayType' => $vendorDir . '/doctrine/dbal/src/Types/SimpleArrayType.php',
    'Doctrine\\DBAL\\Types\\SmallFloatType' => $vendorDir . '/doctrine/dbal/src/Types/SmallFloatType.php',
    'Doctrine\\DBAL\\Types\\SmallIntType' => $vendorDir . '/doctrine/dbal/src/Types/SmallIntType.php',
    'Doctrine\\DBAL\\Types\\StringType' => $vendorDir . '/doctrine/dbal/src/Types/StringType.php',
    'Doctrine\\DBAL\\Types\\TextType' => $vendorDir . '/doctrine/dbal/src/Types/TextType.php',
    'Doctrine\\DBAL\\Types\\TimeImmutableType' => $vendorDir . '/doctrine/dbal/src/Types/TimeImmutableType.php',
    'Doctrine\\DBAL\\Types\\TimeType' => $vendorDir . '/doctrine/dbal/src/Types/TimeType.php',
    'Doctrine\\DBAL\\Types\\Type' => $vendorDir . '/doctrine/dbal/src/Types/Type.php',
    'Doctrine\\DBAL\\Types\\TypeRegistry' => $vendorDir . '/doctrine/dbal/src/Types/TypeRegistry.php',
    'Doctrine\\DBAL\\Types\\Types' => $vendorDir . '/doctrine/dbal/src/Types/Types.php',
    'Doctrine\\DBAL\\Types\\VarDateTimeImmutableType' => $vendorDir . '/doctrine/dbal/src/Types/VarDateTimeImmutableType.php',
    'Doctrine\\DBAL\\Types\\VarDateTimeType' => $vendorDir . '/doctrine/dbal/src/Types/VarDateTimeType.php',
    'Doctrine\\Deprecations\\Deprecation' => $vendorDir . '/doctrine/deprecations/lib/Doctrine/Deprecations/Deprecation.php',
    'Doctrine\\Deprecations\\PHPUnit\\VerifyDeprecations' => $vendorDir . '/doctrine/deprecations/lib/Doctrine/Deprecations/PHPUnit/VerifyDeprecations.php',
    'Doctrine\\Inflector\\CachedWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/CachedWordInflector.php',
    'Doctrine\\Inflector\\GenericLanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/GenericLanguageInflectorFactory.php',
    'Doctrine\\Inflector\\Inflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Inflector.php',
    'Doctrine\\Inflector\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/InflectorFactory.php',
    'Doctrine\\Inflector\\Language' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Language.php',
    'Doctrine\\Inflector\\LanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/LanguageInflectorFactory.php',
    'Doctrine\\Inflector\\NoopWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/NoopWordInflector.php',
    'Doctrine\\Inflector\\Rules\\English\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\English\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\English\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Rules.php',
    'Doctrine\\Inflector\\Rules\\English\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\French\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\French\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\French\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Rules.php',
    'Doctrine\\Inflector\\Rules\\French\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Rules.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Pattern' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Pattern.php',
    'Doctrine\\Inflector\\Rules\\Patterns' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Patterns.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Rules.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Ruleset' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Ruleset.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Substitution' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitution.php',
    'Doctrine\\Inflector\\Rules\\Substitutions' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitutions.php',
    'Doctrine\\Inflector\\Rules\\Transformation' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformation.php',
    'Doctrine\\Inflector\\Rules\\Transformations' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformations.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Word' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Word.php',
    'Doctrine\\Inflector\\RulesetInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/RulesetInflector.php',
    'Doctrine\\Inflector\\WordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/WordInflector.php',
    'Doctrine\\Persistence\\AbstractManagerRegistry' => $vendorDir . '/doctrine/persistence/src/Persistence/AbstractManagerRegistry.php',
    'Doctrine\\Persistence\\ConnectionRegistry' => $vendorDir . '/doctrine/persistence/src/Persistence/ConnectionRegistry.php',
    'Doctrine\\Persistence\\Event\\LifecycleEventArgs' => $vendorDir . '/doctrine/persistence/src/Persistence/Event/LifecycleEventArgs.php',
    'Doctrine\\Persistence\\Event\\LoadClassMetadataEventArgs' => $vendorDir . '/doctrine/persistence/src/Persistence/Event/LoadClassMetadataEventArgs.php',
    'Doctrine\\Persistence\\Event\\ManagerEventArgs' => $vendorDir . '/doctrine/persistence/src/Persistence/Event/ManagerEventArgs.php',
    'Doctrine\\Persistence\\Event\\OnClearEventArgs' => $vendorDir . '/doctrine/persistence/src/Persistence/Event/OnClearEventArgs.php',
    'Doctrine\\Persistence\\Event\\PreUpdateEventArgs' => $vendorDir . '/doctrine/persistence/src/Persistence/Event/PreUpdateEventArgs.php',
    'Doctrine\\Persistence\\ManagerRegistry' => $vendorDir . '/doctrine/persistence/src/Persistence/ManagerRegistry.php',
    'Doctrine\\Persistence\\Mapping\\AbstractClassMetadataFactory' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/AbstractClassMetadataFactory.php',
    'Doctrine\\Persistence\\Mapping\\ClassMetadata' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/ClassMetadata.php',
    'Doctrine\\Persistence\\Mapping\\ClassMetadataFactory' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/ClassMetadataFactory.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\ColocatedMappingDriver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/ColocatedMappingDriver.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\DefaultFileLocator' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/DefaultFileLocator.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\FileDriver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/FileDriver.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\FileLocator' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/FileLocator.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\MappingDriver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/MappingDriver.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\MappingDriverChain' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/MappingDriverChain.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\PHPDriver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/PHPDriver.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\StaticPHPDriver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/StaticPHPDriver.php',
    'Doctrine\\Persistence\\Mapping\\Driver\\SymfonyFileLocator' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/Driver/SymfonyFileLocator.php',
    'Doctrine\\Persistence\\Mapping\\MappingException' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/MappingException.php',
    'Doctrine\\Persistence\\Mapping\\ProxyClassNameResolver' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/ProxyClassNameResolver.php',
    'Doctrine\\Persistence\\Mapping\\ReflectionService' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/ReflectionService.php',
    'Doctrine\\Persistence\\Mapping\\RuntimeReflectionService' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/RuntimeReflectionService.php',
    'Doctrine\\Persistence\\Mapping\\StaticReflectionService' => $vendorDir . '/doctrine/persistence/src/Persistence/Mapping/StaticReflectionService.php',
    'Doctrine\\Persistence\\NotifyPropertyChanged' => $vendorDir . '/doctrine/persistence/src/Persistence/NotifyPropertyChanged.php',
    'Doctrine\\Persistence\\ObjectManager' => $vendorDir . '/doctrine/persistence/src/Persistence/ObjectManager.php',
    'Doctrine\\Persistence\\ObjectManagerDecorator' => $vendorDir . '/doctrine/persistence/src/Persistence/ObjectManagerDecorator.php',
    'Doctrine\\Persistence\\ObjectRepository' => $vendorDir . '/doctrine/persistence/src/Persistence/ObjectRepository.php',
    'Doctrine\\Persistence\\PropertyChangedListener' => $vendorDir . '/doctrine/persistence/src/Persistence/PropertyChangedListener.php',
    'Doctrine\\Persistence\\Proxy' => $vendorDir . '/doctrine/persistence/src/Persistence/Proxy.php',
    'Doctrine\\Persistence\\Reflection\\EnumReflectionProperty' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/EnumReflectionProperty.php',
    'Doctrine\\Persistence\\Reflection\\RuntimePublicReflectionProperty' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/RuntimePublicReflectionProperty.php',
    'Doctrine\\Persistence\\Reflection\\RuntimeReflectionProperty' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/RuntimeReflectionProperty.php',
    'Doctrine\\Persistence\\Reflection\\TypedNoDefaultReflectionProperty' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/TypedNoDefaultReflectionProperty.php',
    'Doctrine\\Persistence\\Reflection\\TypedNoDefaultReflectionPropertyBase' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/TypedNoDefaultReflectionPropertyBase.php',
    'Doctrine\\Persistence\\Reflection\\TypedNoDefaultRuntimePublicReflectionProperty' => $vendorDir . '/doctrine/persistence/src/Persistence/Reflection/TypedNoDefaultRuntimePublicReflectionProperty.php',
    'Dotenv\\Dotenv' => $vendorDir . '/vlucas/phpdotenv/src/Dotenv.php',
    'Dotenv\\Exception\\ExceptionInterface' => $vendorDir . '/vlucas/phpdotenv/src/Exception/ExceptionInterface.php',
    'Dotenv\\Exception\\InvalidEncodingException' => $vendorDir . '/vlucas/phpdotenv/src/Exception/InvalidEncodingException.php',
    'Dotenv\\Exception\\InvalidFileException' => $vendorDir . '/vlucas/phpdotenv/src/Exception/InvalidFileException.php',
    'Dotenv\\Exception\\InvalidPathException' => $vendorDir . '/vlucas/phpdotenv/src/Exception/InvalidPathException.php',
    'Dotenv\\Exception\\ValidationException' => $vendorDir . '/vlucas/phpdotenv/src/Exception/ValidationException.php',
    'Dotenv\\Loader\\Loader' => $vendorDir . '/vlucas/phpdotenv/src/Loader/Loader.php',
    'Dotenv\\Loader\\LoaderInterface' => $vendorDir . '/vlucas/phpdotenv/src/Loader/LoaderInterface.php',
    'Dotenv\\Loader\\Resolver' => $vendorDir . '/vlucas/phpdotenv/src/Loader/Resolver.php',
    'Dotenv\\Parser\\Entry' => $vendorDir . '/vlucas/phpdotenv/src/Parser/Entry.php',
    'Dotenv\\Parser\\EntryParser' => $vendorDir . '/vlucas/phpdotenv/src/Parser/EntryParser.php',
    'Dotenv\\Parser\\Lexer' => $vendorDir . '/vlucas/phpdotenv/src/Parser/Lexer.php',
    'Dotenv\\Parser\\Lines' => $vendorDir . '/vlucas/phpdotenv/src/Parser/Lines.php',
    'Dotenv\\Parser\\Parser' => $vendorDir . '/vlucas/phpdotenv/src/Parser/Parser.php',
    'Dotenv\\Parser\\ParserInterface' => $vendorDir . '/vlucas/phpdotenv/src/Parser/ParserInterface.php',
    'Dotenv\\Parser\\Value' => $vendorDir . '/vlucas/phpdotenv/src/Parser/Value.php',
    'Dotenv\\Repository\\AdapterRepository' => $vendorDir . '/vlucas/phpdotenv/src/Repository/AdapterRepository.php',
    'Dotenv\\Repository\\Adapter\\AdapterInterface' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/AdapterInterface.php',
    'Dotenv\\Repository\\Adapter\\ApacheAdapter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ApacheAdapter.php',
    'Dotenv\\Repository\\Adapter\\ArrayAdapter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ArrayAdapter.php',
    'Dotenv\\Repository\\Adapter\\EnvConstAdapter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/EnvConstAdapter.php',
    'Dotenv\\Repository\\Adapter\\GuardedWriter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/GuardedWriter.php',
    'Dotenv\\Repository\\Adapter\\ImmutableWriter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ImmutableWriter.php',
    'Dotenv\\Repository\\Adapter\\MultiReader' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/MultiReader.php',
    'Dotenv\\Repository\\Adapter\\MultiWriter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/MultiWriter.php',
    'Dotenv\\Repository\\Adapter\\PutenvAdapter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/PutenvAdapter.php',
    'Dotenv\\Repository\\Adapter\\ReaderInterface' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ReaderInterface.php',
    'Dotenv\\Repository\\Adapter\\ReplacingWriter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ReplacingWriter.php',
    'Dotenv\\Repository\\Adapter\\ServerConstAdapter' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/ServerConstAdapter.php',
    'Dotenv\\Repository\\Adapter\\WriterInterface' => $vendorDir . '/vlucas/phpdotenv/src/Repository/Adapter/WriterInterface.php',
    'Dotenv\\Repository\\RepositoryBuilder' => $vendorDir . '/vlucas/phpdotenv/src/Repository/RepositoryBuilder.php',
    'Dotenv\\Repository\\RepositoryInterface' => $vendorDir . '/vlucas/phpdotenv/src/Repository/RepositoryInterface.php',
    'Dotenv\\Store\\FileStore' => $vendorDir . '/vlucas/phpdotenv/src/Store/FileStore.php',
    'Dotenv\\Store\\File\\Paths' => $vendorDir . '/vlucas/phpdotenv/src/Store/File/Paths.php',
    'Dotenv\\Store\\File\\Reader' => $vendorDir . '/vlucas/phpdotenv/src/Store/File/Reader.php',
    'Dotenv\\Store\\StoreBuilder' => $vendorDir . '/vlucas/phpdotenv/src/Store/StoreBuilder.php',
    'Dotenv\\Store\\StoreInterface' => $vendorDir . '/vlucas/phpdotenv/src/Store/StoreInterface.php',
    'Dotenv\\Store\\StringStore' => $vendorDir . '/vlucas/phpdotenv/src/Store/StringStore.php',
    'Dotenv\\Util\\Regex' => $vendorDir . '/vlucas/phpdotenv/src/Util/Regex.php',
    'Dotenv\\Util\\Str' => $vendorDir . '/vlucas/phpdotenv/src/Util/Str.php',
    'Dotenv\\Validator' => $vendorDir . '/vlucas/phpdotenv/src/Validator.php',
    'Ds\\Collection' => $vendorDir . '/php-ds/php-ds/src/Collection.php',
    'Ds\\Deque' => $vendorDir . '/php-ds/php-ds/src/Deque.php',
    'Ds\\Hashable' => $vendorDir . '/php-ds/php-ds/src/Hashable.php',
    'Ds\\Map' => $vendorDir . '/php-ds/php-ds/src/Map.php',
    'Ds\\Pair' => $vendorDir . '/php-ds/php-ds/src/Pair.php',
    'Ds\\PriorityQueue' => $vendorDir . '/php-ds/php-ds/src/PriorityQueue.php',
    'Ds\\Queue' => $vendorDir . '/php-ds/php-ds/src/Queue.php',
    'Ds\\Sequence' => $vendorDir . '/php-ds/php-ds/src/Sequence.php',
    'Ds\\Set' => $vendorDir . '/php-ds/php-ds/src/Set.php',
    'Ds\\Stack' => $vendorDir . '/php-ds/php-ds/src/Stack.php',
    'Ds\\Traits\\Capacity' => $vendorDir . '/php-ds/php-ds/src/Traits/Capacity.php',
    'Ds\\Traits\\GenericCollection' => $vendorDir . '/php-ds/php-ds/src/Traits/GenericCollection.php',
    'Ds\\Traits\\GenericSequence' => $vendorDir . '/php-ds/php-ds/src/Traits/GenericSequence.php',
    'Ds\\Traits\\SquaredCapacity' => $vendorDir . '/php-ds/php-ds/src/Traits/SquaredCapacity.php',
    'Ds\\Vector' => $vendorDir . '/php-ds/php-ds/src/Vector.php',
    'Egulias\\EmailValidator\\EmailLexer' => $vendorDir . '/egulias/email-validator/src/EmailLexer.php',
    'Egulias\\EmailValidator\\EmailParser' => $vendorDir . '/egulias/email-validator/src/EmailParser.php',
    'Egulias\\EmailValidator\\EmailValidator' => $vendorDir . '/egulias/email-validator/src/EmailValidator.php',
    'Egulias\\EmailValidator\\MessageIDParser' => $vendorDir . '/egulias/email-validator/src/MessageIDParser.php',
    'Egulias\\EmailValidator\\Parser' => $vendorDir . '/egulias/email-validator/src/Parser.php',
    'Egulias\\EmailValidator\\Parser\\Comment' => $vendorDir . '/egulias/email-validator/src/Parser/Comment.php',
    'Egulias\\EmailValidator\\Parser\\CommentStrategy\\CommentStrategy' => $vendorDir . '/egulias/email-validator/src/Parser/CommentStrategy/CommentStrategy.php',
    'Egulias\\EmailValidator\\Parser\\CommentStrategy\\DomainComment' => $vendorDir . '/egulias/email-validator/src/Parser/CommentStrategy/DomainComment.php',
    'Egulias\\EmailValidator\\Parser\\CommentStrategy\\LocalComment' => $vendorDir . '/egulias/email-validator/src/Parser/CommentStrategy/LocalComment.php',
    'Egulias\\EmailValidator\\Parser\\DomainLiteral' => $vendorDir . '/egulias/email-validator/src/Parser/DomainLiteral.php',
    'Egulias\\EmailValidator\\Parser\\DomainPart' => $vendorDir . '/egulias/email-validator/src/Parser/DomainPart.php',
    'Egulias\\EmailValidator\\Parser\\DoubleQuote' => $vendorDir . '/egulias/email-validator/src/Parser/DoubleQuote.php',
    'Egulias\\EmailValidator\\Parser\\FoldingWhiteSpace' => $vendorDir . '/egulias/email-validator/src/Parser/FoldingWhiteSpace.php',
    'Egulias\\EmailValidator\\Parser\\IDLeftPart' => $vendorDir . '/egulias/email-validator/src/Parser/IDLeftPart.php',
    'Egulias\\EmailValidator\\Parser\\IDRightPart' => $vendorDir . '/egulias/email-validator/src/Parser/IDRightPart.php',
    'Egulias\\EmailValidator\\Parser\\LocalPart' => $vendorDir . '/egulias/email-validator/src/Parser/LocalPart.php',
    'Egulias\\EmailValidator\\Parser\\PartParser' => $vendorDir . '/egulias/email-validator/src/Parser/PartParser.php',
    'Egulias\\EmailValidator\\Result\\InvalidEmail' => $vendorDir . '/egulias/email-validator/src/Result/InvalidEmail.php',
    'Egulias\\EmailValidator\\Result\\MultipleErrors' => $vendorDir . '/egulias/email-validator/src/Result/MultipleErrors.php',
    'Egulias\\EmailValidator\\Result\\Reason\\AtextAfterCFWS' => $vendorDir . '/egulias/email-validator/src/Result/Reason/AtextAfterCFWS.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CRLFAtTheEnd' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CRLFAtTheEnd.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CRLFX2' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CRLFX2.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CRNoLF' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CRNoLF.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CharNotAllowed' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CharNotAllowed.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CommaInDomain' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CommaInDomain.php',
    'Egulias\\EmailValidator\\Result\\Reason\\CommentsInIDRight' => $vendorDir . '/egulias/email-validator/src/Result/Reason/CommentsInIDRight.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ConsecutiveAt' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ConsecutiveAt.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ConsecutiveDot' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ConsecutiveDot.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DetailedReason' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DetailedReason.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DomainAcceptsNoMail' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DomainAcceptsNoMail.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DomainHyphened' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DomainHyphened.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DomainTooLong' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DomainTooLong.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DotAtEnd' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DotAtEnd.php',
    'Egulias\\EmailValidator\\Result\\Reason\\DotAtStart' => $vendorDir . '/egulias/email-validator/src/Result/Reason/DotAtStart.php',
    'Egulias\\EmailValidator\\Result\\Reason\\EmptyReason' => $vendorDir . '/egulias/email-validator/src/Result/Reason/EmptyReason.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ExceptionFound' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ExceptionFound.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ExpectingATEXT' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ExpectingATEXT.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ExpectingCTEXT' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ExpectingCTEXT.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ExpectingDTEXT' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ExpectingDTEXT.php',
    'Egulias\\EmailValidator\\Result\\Reason\\ExpectingDomainLiteralClose' => $vendorDir . '/egulias/email-validator/src/Result/Reason/ExpectingDomainLiteralClose.php',
    'Egulias\\EmailValidator\\Result\\Reason\\LabelTooLong' => $vendorDir . '/egulias/email-validator/src/Result/Reason/LabelTooLong.php',
    'Egulias\\EmailValidator\\Result\\Reason\\LocalOrReservedDomain' => $vendorDir . '/egulias/email-validator/src/Result/Reason/LocalOrReservedDomain.php',
    'Egulias\\EmailValidator\\Result\\Reason\\NoDNSRecord' => $vendorDir . '/egulias/email-validator/src/Result/Reason/NoDNSRecord.php',
    'Egulias\\EmailValidator\\Result\\Reason\\NoDomainPart' => $vendorDir . '/egulias/email-validator/src/Result/Reason/NoDomainPart.php',
    'Egulias\\EmailValidator\\Result\\Reason\\NoLocalPart' => $vendorDir . '/egulias/email-validator/src/Result/Reason/NoLocalPart.php',
    'Egulias\\EmailValidator\\Result\\Reason\\RFCWarnings' => $vendorDir . '/egulias/email-validator/src/Result/Reason/RFCWarnings.php',
    'Egulias\\EmailValidator\\Result\\Reason\\Reason' => $vendorDir . '/egulias/email-validator/src/Result/Reason/Reason.php',
    'Egulias\\EmailValidator\\Result\\Reason\\SpoofEmail' => $vendorDir . '/egulias/email-validator/src/Result/Reason/SpoofEmail.php',
    'Egulias\\EmailValidator\\Result\\Reason\\UnOpenedComment' => $vendorDir . '/egulias/email-validator/src/Result/Reason/UnOpenedComment.php',
    'Egulias\\EmailValidator\\Result\\Reason\\UnableToGetDNSRecord' => $vendorDir . '/egulias/email-validator/src/Result/Reason/UnableToGetDNSRecord.php',
    'Egulias\\EmailValidator\\Result\\Reason\\UnclosedComment' => $vendorDir . '/egulias/email-validator/src/Result/Reason/UnclosedComment.php',
    'Egulias\\EmailValidator\\Result\\Reason\\UnclosedQuotedString' => $vendorDir . '/egulias/email-validator/src/Result/Reason/UnclosedQuotedString.php',
    'Egulias\\EmailValidator\\Result\\Reason\\UnusualElements' => $vendorDir . '/egulias/email-validator/src/Result/Reason/UnusualElements.php',
    'Egulias\\EmailValidator\\Result\\Result' => $vendorDir . '/egulias/email-validator/src/Result/Result.php',
    'Egulias\\EmailValidator\\Result\\SpoofEmail' => $vendorDir . '/egulias/email-validator/src/Result/SpoofEmail.php',
    'Egulias\\EmailValidator\\Result\\ValidEmail' => $vendorDir . '/egulias/email-validator/src/Result/ValidEmail.php',
    'Egulias\\EmailValidator\\Validation\\DNSCheckValidation' => $vendorDir . '/egulias/email-validator/src/Validation/DNSCheckValidation.php',
    'Egulias\\EmailValidator\\Validation\\DNSGetRecordWrapper' => $vendorDir . '/egulias/email-validator/src/Validation/DNSGetRecordWrapper.php',
    'Egulias\\EmailValidator\\Validation\\DNSRecords' => $vendorDir . '/egulias/email-validator/src/Validation/DNSRecords.php',
    'Egulias\\EmailValidator\\Validation\\EmailValidation' => $vendorDir . '/egulias/email-validator/src/Validation/EmailValidation.php',
    'Egulias\\EmailValidator\\Validation\\Exception\\EmptyValidationList' => $vendorDir . '/egulias/email-validator/src/Validation/Exception/EmptyValidationList.php',
    'Egulias\\EmailValidator\\Validation\\Extra\\SpoofCheckValidation' => $vendorDir . '/egulias/email-validator/src/Validation/Extra/SpoofCheckValidation.php',
    'Egulias\\EmailValidator\\Validation\\MessageIDValidation' => $vendorDir . '/egulias/email-validator/src/Validation/MessageIDValidation.php',
    'Egulias\\EmailValidator\\Validation\\MultipleValidationWithAnd' => $vendorDir . '/egulias/email-validator/src/Validation/MultipleValidationWithAnd.php',
    'Egulias\\EmailValidator\\Validation\\NoRFCWarningsValidation' => $vendorDir . '/egulias/email-validator/src/Validation/NoRFCWarningsValidation.php',
    'Egulias\\EmailValidator\\Validation\\RFCValidation' => $vendorDir . '/egulias/email-validator/src/Validation/RFCValidation.php',
    'Egulias\\EmailValidator\\Warning\\AddressLiteral' => $vendorDir . '/egulias/email-validator/src/Warning/AddressLiteral.php',
    'Egulias\\EmailValidator\\Warning\\CFWSNearAt' => $vendorDir . '/egulias/email-validator/src/Warning/CFWSNearAt.php',
    'Egulias\\EmailValidator\\Warning\\CFWSWithFWS' => $vendorDir . '/egulias/email-validator/src/Warning/CFWSWithFWS.php',
    'Egulias\\EmailValidator\\Warning\\Comment' => $vendorDir . '/egulias/email-validator/src/Warning/Comment.php',
    'Egulias\\EmailValidator\\Warning\\DeprecatedComment' => $vendorDir . '/egulias/email-validator/src/Warning/DeprecatedComment.php',
    'Egulias\\EmailValidator\\Warning\\DomainLiteral' => $vendorDir . '/egulias/email-validator/src/Warning/DomainLiteral.php',
    'Egulias\\EmailValidator\\Warning\\EmailTooLong' => $vendorDir . '/egulias/email-validator/src/Warning/EmailTooLong.php',
    'Egulias\\EmailValidator\\Warning\\IPV6BadChar' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6BadChar.php',
    'Egulias\\EmailValidator\\Warning\\IPV6ColonEnd' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6ColonEnd.php',
    'Egulias\\EmailValidator\\Warning\\IPV6ColonStart' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6ColonStart.php',
    'Egulias\\EmailValidator\\Warning\\IPV6Deprecated' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6Deprecated.php',
    'Egulias\\EmailValidator\\Warning\\IPV6DoubleColon' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6DoubleColon.php',
    'Egulias\\EmailValidator\\Warning\\IPV6GroupCount' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6GroupCount.php',
    'Egulias\\EmailValidator\\Warning\\IPV6MaxGroups' => $vendorDir . '/egulias/email-validator/src/Warning/IPV6MaxGroups.php',
    'Egulias\\EmailValidator\\Warning\\LocalTooLong' => $vendorDir . '/egulias/email-validator/src/Warning/LocalTooLong.php',
    'Egulias\\EmailValidator\\Warning\\NoDNSMXRecord' => $vendorDir . '/egulias/email-validator/src/Warning/NoDNSMXRecord.php',
    'Egulias\\EmailValidator\\Warning\\ObsoleteDTEXT' => $vendorDir . '/egulias/email-validator/src/Warning/ObsoleteDTEXT.php',
    'Egulias\\EmailValidator\\Warning\\QuotedPart' => $vendorDir . '/egulias/email-validator/src/Warning/QuotedPart.php',
    'Egulias\\EmailValidator\\Warning\\QuotedString' => $vendorDir . '/egulias/email-validator/src/Warning/QuotedString.php',
    'Egulias\\EmailValidator\\Warning\\TLD' => $vendorDir . '/egulias/email-validator/src/Warning/TLD.php',
    'Egulias\\EmailValidator\\Warning\\Warning' => $vendorDir . '/egulias/email-validator/src/Warning/Warning.php',
    'Faker\\Calculator\\Ean' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/Ean.php',
    'Faker\\Calculator\\Iban' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/Iban.php',
    'Faker\\Calculator\\Inn' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/Inn.php',
    'Faker\\Calculator\\Isbn' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/Isbn.php',
    'Faker\\Calculator\\Luhn' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/Luhn.php',
    'Faker\\Calculator\\TCNo' => $vendorDir . '/fakerphp/faker/src/Faker/Calculator/TCNo.php',
    'Faker\\ChanceGenerator' => $vendorDir . '/fakerphp/faker/src/Faker/ChanceGenerator.php',
    'Faker\\Container\\Container' => $vendorDir . '/fakerphp/faker/src/Faker/Container/Container.php',
    'Faker\\Container\\ContainerBuilder' => $vendorDir . '/fakerphp/faker/src/Faker/Container/ContainerBuilder.php',
    'Faker\\Container\\ContainerException' => $vendorDir . '/fakerphp/faker/src/Faker/Container/ContainerException.php',
    'Faker\\Container\\ContainerInterface' => $vendorDir . '/fakerphp/faker/src/Faker/Container/ContainerInterface.php',
    'Faker\\Container\\NotInContainerException' => $vendorDir . '/fakerphp/faker/src/Faker/Container/NotInContainerException.php',
    'Faker\\Core\\Barcode' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Barcode.php',
    'Faker\\Core\\Blood' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Blood.php',
    'Faker\\Core\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Color.php',
    'Faker\\Core\\Coordinates' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Coordinates.php',
    'Faker\\Core\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Core/DateTime.php',
    'Faker\\Core\\File' => $vendorDir . '/fakerphp/faker/src/Faker/Core/File.php',
    'Faker\\Core\\Number' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Number.php',
    'Faker\\Core\\Uuid' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Uuid.php',
    'Faker\\Core\\Version' => $vendorDir . '/fakerphp/faker/src/Faker/Core/Version.php',
    'Faker\\DefaultGenerator' => $vendorDir . '/fakerphp/faker/src/Faker/DefaultGenerator.php',
    'Faker\\Documentor' => $vendorDir . '/fakerphp/faker/src/Faker/Documentor.php',
    'Faker\\Extension\\AddressExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/AddressExtension.php',
    'Faker\\Extension\\BarcodeExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/BarcodeExtension.php',
    'Faker\\Extension\\BloodExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/BloodExtension.php',
    'Faker\\Extension\\ColorExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/ColorExtension.php',
    'Faker\\Extension\\CompanyExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/CompanyExtension.php',
    'Faker\\Extension\\CountryExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/CountryExtension.php',
    'Faker\\Extension\\DateTimeExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/DateTimeExtension.php',
    'Faker\\Extension\\Extension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/Extension.php',
    'Faker\\Extension\\ExtensionNotFound' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/ExtensionNotFound.php',
    'Faker\\Extension\\FileExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/FileExtension.php',
    'Faker\\Extension\\GeneratorAwareExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/GeneratorAwareExtension.php',
    'Faker\\Extension\\GeneratorAwareExtensionTrait' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/GeneratorAwareExtensionTrait.php',
    'Faker\\Extension\\Helper' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/Helper.php',
    'Faker\\Extension\\NumberExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/NumberExtension.php',
    'Faker\\Extension\\PersonExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/PersonExtension.php',
    'Faker\\Extension\\PhoneNumberExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/PhoneNumberExtension.php',
    'Faker\\Extension\\UuidExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/UuidExtension.php',
    'Faker\\Extension\\VersionExtension' => $vendorDir . '/fakerphp/faker/src/Faker/Extension/VersionExtension.php',
    'Faker\\Factory' => $vendorDir . '/fakerphp/faker/src/Faker/Factory.php',
    'Faker\\Generator' => $vendorDir . '/fakerphp/faker/src/Faker/Generator.php',
    'Faker\\Guesser\\Name' => $vendorDir . '/fakerphp/faker/src/Faker/Guesser/Name.php',
    'Faker\\ORM\\CakePHP\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/CakePHP/ColumnTypeGuesser.php',
    'Faker\\ORM\\CakePHP\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/CakePHP/EntityPopulator.php',
    'Faker\\ORM\\CakePHP\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/CakePHP/Populator.php',
    'Faker\\ORM\\Doctrine\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Doctrine/ColumnTypeGuesser.php',
    'Faker\\ORM\\Doctrine\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Doctrine/EntityPopulator.php',
    'Faker\\ORM\\Doctrine\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Doctrine/Populator.php',
    'Faker\\ORM\\Mandango\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Mandango/ColumnTypeGuesser.php',
    'Faker\\ORM\\Mandango\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Mandango/EntityPopulator.php',
    'Faker\\ORM\\Mandango\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Mandango/Populator.php',
    'Faker\\ORM\\Propel2\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel2/ColumnTypeGuesser.php',
    'Faker\\ORM\\Propel2\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel2/EntityPopulator.php',
    'Faker\\ORM\\Propel2\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel2/Populator.php',
    'Faker\\ORM\\Propel\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel/ColumnTypeGuesser.php',
    'Faker\\ORM\\Propel\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel/EntityPopulator.php',
    'Faker\\ORM\\Propel\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Propel/Populator.php',
    'Faker\\ORM\\Spot\\ColumnTypeGuesser' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Spot/ColumnTypeGuesser.php',
    'Faker\\ORM\\Spot\\EntityPopulator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Spot/EntityPopulator.php',
    'Faker\\ORM\\Spot\\Populator' => $vendorDir . '/fakerphp/faker/src/Faker/ORM/Spot/Populator.php',
    'Faker\\Provider\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Address.php',
    'Faker\\Provider\\Barcode' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Barcode.php',
    'Faker\\Provider\\Base' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Base.php',
    'Faker\\Provider\\Biased' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Biased.php',
    'Faker\\Provider\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Color.php',
    'Faker\\Provider\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Company.php',
    'Faker\\Provider\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/DateTime.php',
    'Faker\\Provider\\File' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/File.php',
    'Faker\\Provider\\HtmlLorem' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/HtmlLorem.php',
    'Faker\\Provider\\Image' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Image.php',
    'Faker\\Provider\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Internet.php',
    'Faker\\Provider\\Lorem' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Lorem.php',
    'Faker\\Provider\\Medical' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Medical.php',
    'Faker\\Provider\\Miscellaneous' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Miscellaneous.php',
    'Faker\\Provider\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Payment.php',
    'Faker\\Provider\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Person.php',
    'Faker\\Provider\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/PhoneNumber.php',
    'Faker\\Provider\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Text.php',
    'Faker\\Provider\\UserAgent' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/UserAgent.php',
    'Faker\\Provider\\Uuid' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/Uuid.php',
    'Faker\\Provider\\ar_EG\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Address.php',
    'Faker\\Provider\\ar_EG\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Color.php',
    'Faker\\Provider\\ar_EG\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Company.php',
    'Faker\\Provider\\ar_EG\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Internet.php',
    'Faker\\Provider\\ar_EG\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Payment.php',
    'Faker\\Provider\\ar_EG\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Person.php',
    'Faker\\Provider\\ar_EG\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_EG/Text.php',
    'Faker\\Provider\\ar_JO\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_JO/Address.php',
    'Faker\\Provider\\ar_JO\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_JO/Company.php',
    'Faker\\Provider\\ar_JO\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_JO/Internet.php',
    'Faker\\Provider\\ar_JO\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_JO/Person.php',
    'Faker\\Provider\\ar_JO\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_JO/Text.php',
    'Faker\\Provider\\ar_SA\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Address.php',
    'Faker\\Provider\\ar_SA\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Color.php',
    'Faker\\Provider\\ar_SA\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Company.php',
    'Faker\\Provider\\ar_SA\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Internet.php',
    'Faker\\Provider\\ar_SA\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Payment.php',
    'Faker\\Provider\\ar_SA\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Person.php',
    'Faker\\Provider\\ar_SA\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ar_SA/Text.php',
    'Faker\\Provider\\at_AT\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/at_AT/Payment.php',
    'Faker\\Provider\\bg_BG\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bg_BG/Internet.php',
    'Faker\\Provider\\bg_BG\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bg_BG/Payment.php',
    'Faker\\Provider\\bg_BG\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bg_BG/Person.php',
    'Faker\\Provider\\bg_BG\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bg_BG/PhoneNumber.php',
    'Faker\\Provider\\bn_BD\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bn_BD/Address.php',
    'Faker\\Provider\\bn_BD\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bn_BD/Company.php',
    'Faker\\Provider\\bn_BD\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bn_BD/Person.php',
    'Faker\\Provider\\bn_BD\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bn_BD/PhoneNumber.php',
    'Faker\\Provider\\bn_BD\\Utils' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/bn_BD/Utils.php',
    'Faker\\Provider\\cs_CZ\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Address.php',
    'Faker\\Provider\\cs_CZ\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Company.php',
    'Faker\\Provider\\cs_CZ\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/DateTime.php',
    'Faker\\Provider\\cs_CZ\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Internet.php',
    'Faker\\Provider\\cs_CZ\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Payment.php',
    'Faker\\Provider\\cs_CZ\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Person.php',
    'Faker\\Provider\\cs_CZ\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/PhoneNumber.php',
    'Faker\\Provider\\cs_CZ\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/cs_CZ/Text.php',
    'Faker\\Provider\\da_DK\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/Address.php',
    'Faker\\Provider\\da_DK\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/Company.php',
    'Faker\\Provider\\da_DK\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/Internet.php',
    'Faker\\Provider\\da_DK\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/Payment.php',
    'Faker\\Provider\\da_DK\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/Person.php',
    'Faker\\Provider\\da_DK\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/da_DK/PhoneNumber.php',
    'Faker\\Provider\\de_AT\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Address.php',
    'Faker\\Provider\\de_AT\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Company.php',
    'Faker\\Provider\\de_AT\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Internet.php',
    'Faker\\Provider\\de_AT\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Payment.php',
    'Faker\\Provider\\de_AT\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Person.php',
    'Faker\\Provider\\de_AT\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/PhoneNumber.php',
    'Faker\\Provider\\de_AT\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_AT/Text.php',
    'Faker\\Provider\\de_CH\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Address.php',
    'Faker\\Provider\\de_CH\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Company.php',
    'Faker\\Provider\\de_CH\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Internet.php',
    'Faker\\Provider\\de_CH\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Payment.php',
    'Faker\\Provider\\de_CH\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Person.php',
    'Faker\\Provider\\de_CH\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/PhoneNumber.php',
    'Faker\\Provider\\de_CH\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_CH/Text.php',
    'Faker\\Provider\\de_DE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Address.php',
    'Faker\\Provider\\de_DE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Company.php',
    'Faker\\Provider\\de_DE\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Internet.php',
    'Faker\\Provider\\de_DE\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Payment.php',
    'Faker\\Provider\\de_DE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Person.php',
    'Faker\\Provider\\de_DE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/PhoneNumber.php',
    'Faker\\Provider\\de_DE\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/de_DE/Text.php',
    'Faker\\Provider\\el_CY\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/Address.php',
    'Faker\\Provider\\el_CY\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/Company.php',
    'Faker\\Provider\\el_CY\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/Internet.php',
    'Faker\\Provider\\el_CY\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/Payment.php',
    'Faker\\Provider\\el_CY\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/Person.php',
    'Faker\\Provider\\el_CY\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_CY/PhoneNumber.php',
    'Faker\\Provider\\el_GR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/Address.php',
    'Faker\\Provider\\el_GR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/Company.php',
    'Faker\\Provider\\el_GR\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/Payment.php',
    'Faker\\Provider\\el_GR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/Person.php',
    'Faker\\Provider\\el_GR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/PhoneNumber.php',
    'Faker\\Provider\\el_GR\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/el_GR/Text.php',
    'Faker\\Provider\\en_AU\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_AU/Address.php',
    'Faker\\Provider\\en_AU\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_AU/Internet.php',
    'Faker\\Provider\\en_AU\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_AU/PhoneNumber.php',
    'Faker\\Provider\\en_CA\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_CA/Address.php',
    'Faker\\Provider\\en_CA\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_CA/PhoneNumber.php',
    'Faker\\Provider\\en_GB\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/Address.php',
    'Faker\\Provider\\en_GB\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/Company.php',
    'Faker\\Provider\\en_GB\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/Internet.php',
    'Faker\\Provider\\en_GB\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/Payment.php',
    'Faker\\Provider\\en_GB\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/Person.php',
    'Faker\\Provider\\en_GB\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_GB/PhoneNumber.php',
    'Faker\\Provider\\en_HK\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_HK/Address.php',
    'Faker\\Provider\\en_HK\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_HK/Internet.php',
    'Faker\\Provider\\en_HK\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_HK/PhoneNumber.php',
    'Faker\\Provider\\en_IN\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_IN/Address.php',
    'Faker\\Provider\\en_IN\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_IN/Internet.php',
    'Faker\\Provider\\en_IN\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_IN/Person.php',
    'Faker\\Provider\\en_IN\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_IN/PhoneNumber.php',
    'Faker\\Provider\\en_NG\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NG/Address.php',
    'Faker\\Provider\\en_NG\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NG/Internet.php',
    'Faker\\Provider\\en_NG\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NG/Person.php',
    'Faker\\Provider\\en_NG\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NG/PhoneNumber.php',
    'Faker\\Provider\\en_NZ\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NZ/Address.php',
    'Faker\\Provider\\en_NZ\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NZ/Internet.php',
    'Faker\\Provider\\en_NZ\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_NZ/PhoneNumber.php',
    'Faker\\Provider\\en_PH\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_PH/Address.php',
    'Faker\\Provider\\en_PH\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_PH/PhoneNumber.php',
    'Faker\\Provider\\en_SG\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_SG/Address.php',
    'Faker\\Provider\\en_SG\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_SG/Person.php',
    'Faker\\Provider\\en_SG\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_SG/PhoneNumber.php',
    'Faker\\Provider\\en_UG\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_UG/Address.php',
    'Faker\\Provider\\en_UG\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_UG/Internet.php',
    'Faker\\Provider\\en_UG\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_UG/Person.php',
    'Faker\\Provider\\en_UG\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_UG/PhoneNumber.php',
    'Faker\\Provider\\en_US\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/Address.php',
    'Faker\\Provider\\en_US\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/Company.php',
    'Faker\\Provider\\en_US\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/Payment.php',
    'Faker\\Provider\\en_US\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/Person.php',
    'Faker\\Provider\\en_US\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/PhoneNumber.php',
    'Faker\\Provider\\en_US\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_US/Text.php',
    'Faker\\Provider\\en_ZA\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_ZA/Address.php',
    'Faker\\Provider\\en_ZA\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_ZA/Company.php',
    'Faker\\Provider\\en_ZA\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_ZA/Internet.php',
    'Faker\\Provider\\en_ZA\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_ZA/Person.php',
    'Faker\\Provider\\en_ZA\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/en_ZA/PhoneNumber.php',
    'Faker\\Provider\\es_AR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_AR/Address.php',
    'Faker\\Provider\\es_AR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_AR/Company.php',
    'Faker\\Provider\\es_AR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_AR/Person.php',
    'Faker\\Provider\\es_AR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_AR/PhoneNumber.php',
    'Faker\\Provider\\es_ES\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Address.php',
    'Faker\\Provider\\es_ES\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Color.php',
    'Faker\\Provider\\es_ES\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Company.php',
    'Faker\\Provider\\es_ES\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Internet.php',
    'Faker\\Provider\\es_ES\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Payment.php',
    'Faker\\Provider\\es_ES\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Person.php',
    'Faker\\Provider\\es_ES\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/PhoneNumber.php',
    'Faker\\Provider\\es_ES\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_ES/Text.php',
    'Faker\\Provider\\es_PE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_PE/Address.php',
    'Faker\\Provider\\es_PE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_PE/Company.php',
    'Faker\\Provider\\es_PE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_PE/Person.php',
    'Faker\\Provider\\es_PE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_PE/PhoneNumber.php',
    'Faker\\Provider\\es_VE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_VE/Address.php',
    'Faker\\Provider\\es_VE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_VE/Company.php',
    'Faker\\Provider\\es_VE\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_VE/Internet.php',
    'Faker\\Provider\\es_VE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_VE/Person.php',
    'Faker\\Provider\\es_VE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/es_VE/PhoneNumber.php',
    'Faker\\Provider\\et_EE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/et_EE/Person.php',
    'Faker\\Provider\\fa_IR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/Address.php',
    'Faker\\Provider\\fa_IR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/Company.php',
    'Faker\\Provider\\fa_IR\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/Internet.php',
    'Faker\\Provider\\fa_IR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/Person.php',
    'Faker\\Provider\\fa_IR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/PhoneNumber.php',
    'Faker\\Provider\\fa_IR\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fa_IR/Text.php',
    'Faker\\Provider\\fi_FI\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/Address.php',
    'Faker\\Provider\\fi_FI\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/Company.php',
    'Faker\\Provider\\fi_FI\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/Internet.php',
    'Faker\\Provider\\fi_FI\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/Payment.php',
    'Faker\\Provider\\fi_FI\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/Person.php',
    'Faker\\Provider\\fi_FI\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fi_FI/PhoneNumber.php',
    'Faker\\Provider\\fr_BE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Address.php',
    'Faker\\Provider\\fr_BE\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Color.php',
    'Faker\\Provider\\fr_BE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Company.php',
    'Faker\\Provider\\fr_BE\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Internet.php',
    'Faker\\Provider\\fr_BE\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Payment.php',
    'Faker\\Provider\\fr_BE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/Person.php',
    'Faker\\Provider\\fr_BE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_BE/PhoneNumber.php',
    'Faker\\Provider\\fr_CA\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CA/Address.php',
    'Faker\\Provider\\fr_CA\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CA/Color.php',
    'Faker\\Provider\\fr_CA\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CA/Company.php',
    'Faker\\Provider\\fr_CA\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CA/Person.php',
    'Faker\\Provider\\fr_CA\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CA/Text.php',
    'Faker\\Provider\\fr_CH\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Address.php',
    'Faker\\Provider\\fr_CH\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Color.php',
    'Faker\\Provider\\fr_CH\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Company.php',
    'Faker\\Provider\\fr_CH\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Internet.php',
    'Faker\\Provider\\fr_CH\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Payment.php',
    'Faker\\Provider\\fr_CH\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Person.php',
    'Faker\\Provider\\fr_CH\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/PhoneNumber.php',
    'Faker\\Provider\\fr_CH\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_CH/Text.php',
    'Faker\\Provider\\fr_FR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Address.php',
    'Faker\\Provider\\fr_FR\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Color.php',
    'Faker\\Provider\\fr_FR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Company.php',
    'Faker\\Provider\\fr_FR\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Internet.php',
    'Faker\\Provider\\fr_FR\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Payment.php',
    'Faker\\Provider\\fr_FR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Person.php',
    'Faker\\Provider\\fr_FR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/PhoneNumber.php',
    'Faker\\Provider\\fr_FR\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/fr_FR/Text.php',
    'Faker\\Provider\\he_IL\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/he_IL/Address.php',
    'Faker\\Provider\\he_IL\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/he_IL/Company.php',
    'Faker\\Provider\\he_IL\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/he_IL/Payment.php',
    'Faker\\Provider\\he_IL\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/he_IL/Person.php',
    'Faker\\Provider\\he_IL\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/he_IL/PhoneNumber.php',
    'Faker\\Provider\\hr_HR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hr_HR/Address.php',
    'Faker\\Provider\\hr_HR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hr_HR/Company.php',
    'Faker\\Provider\\hr_HR\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hr_HR/Payment.php',
    'Faker\\Provider\\hr_HR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hr_HR/Person.php',
    'Faker\\Provider\\hr_HR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hr_HR/PhoneNumber.php',
    'Faker\\Provider\\hu_HU\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/Address.php',
    'Faker\\Provider\\hu_HU\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/Company.php',
    'Faker\\Provider\\hu_HU\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/Payment.php',
    'Faker\\Provider\\hu_HU\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/Person.php',
    'Faker\\Provider\\hu_HU\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/PhoneNumber.php',
    'Faker\\Provider\\hu_HU\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hu_HU/Text.php',
    'Faker\\Provider\\hy_AM\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/Address.php',
    'Faker\\Provider\\hy_AM\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/Color.php',
    'Faker\\Provider\\hy_AM\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/Company.php',
    'Faker\\Provider\\hy_AM\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/Internet.php',
    'Faker\\Provider\\hy_AM\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/Person.php',
    'Faker\\Provider\\hy_AM\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/hy_AM/PhoneNumber.php',
    'Faker\\Provider\\id_ID\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/Address.php',
    'Faker\\Provider\\id_ID\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/Color.php',
    'Faker\\Provider\\id_ID\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/Company.php',
    'Faker\\Provider\\id_ID\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/Internet.php',
    'Faker\\Provider\\id_ID\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/Person.php',
    'Faker\\Provider\\id_ID\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/id_ID/PhoneNumber.php',
    'Faker\\Provider\\is_IS\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/Address.php',
    'Faker\\Provider\\is_IS\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/Company.php',
    'Faker\\Provider\\is_IS\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/Internet.php',
    'Faker\\Provider\\is_IS\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/Payment.php',
    'Faker\\Provider\\is_IS\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/Person.php',
    'Faker\\Provider\\is_IS\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/is_IS/PhoneNumber.php',
    'Faker\\Provider\\it_CH\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Address.php',
    'Faker\\Provider\\it_CH\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Company.php',
    'Faker\\Provider\\it_CH\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Internet.php',
    'Faker\\Provider\\it_CH\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Payment.php',
    'Faker\\Provider\\it_CH\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Person.php',
    'Faker\\Provider\\it_CH\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/PhoneNumber.php',
    'Faker\\Provider\\it_CH\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_CH/Text.php',
    'Faker\\Provider\\it_IT\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Address.php',
    'Faker\\Provider\\it_IT\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Company.php',
    'Faker\\Provider\\it_IT\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Internet.php',
    'Faker\\Provider\\it_IT\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Payment.php',
    'Faker\\Provider\\it_IT\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Person.php',
    'Faker\\Provider\\it_IT\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/PhoneNumber.php',
    'Faker\\Provider\\it_IT\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/it_IT/Text.php',
    'Faker\\Provider\\ja_JP\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/Address.php',
    'Faker\\Provider\\ja_JP\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/Company.php',
    'Faker\\Provider\\ja_JP\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/Internet.php',
    'Faker\\Provider\\ja_JP\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/Person.php',
    'Faker\\Provider\\ja_JP\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/PhoneNumber.php',
    'Faker\\Provider\\ja_JP\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ja_JP/Text.php',
    'Faker\\Provider\\ka_GE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Address.php',
    'Faker\\Provider\\ka_GE\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Color.php',
    'Faker\\Provider\\ka_GE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Company.php',
    'Faker\\Provider\\ka_GE\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/DateTime.php',
    'Faker\\Provider\\ka_GE\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Internet.php',
    'Faker\\Provider\\ka_GE\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Payment.php',
    'Faker\\Provider\\ka_GE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Person.php',
    'Faker\\Provider\\ka_GE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/PhoneNumber.php',
    'Faker\\Provider\\ka_GE\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ka_GE/Text.php',
    'Faker\\Provider\\kk_KZ\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Address.php',
    'Faker\\Provider\\kk_KZ\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Color.php',
    'Faker\\Provider\\kk_KZ\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Company.php',
    'Faker\\Provider\\kk_KZ\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Internet.php',
    'Faker\\Provider\\kk_KZ\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Payment.php',
    'Faker\\Provider\\kk_KZ\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Person.php',
    'Faker\\Provider\\kk_KZ\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/PhoneNumber.php',
    'Faker\\Provider\\kk_KZ\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/kk_KZ/Text.php',
    'Faker\\Provider\\ko_KR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/Address.php',
    'Faker\\Provider\\ko_KR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/Company.php',
    'Faker\\Provider\\ko_KR\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/Internet.php',
    'Faker\\Provider\\ko_KR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/Person.php',
    'Faker\\Provider\\ko_KR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/PhoneNumber.php',
    'Faker\\Provider\\ko_KR\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ko_KR/Text.php',
    'Faker\\Provider\\lt_LT\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/Address.php',
    'Faker\\Provider\\lt_LT\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/Company.php',
    'Faker\\Provider\\lt_LT\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/Internet.php',
    'Faker\\Provider\\lt_LT\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/Payment.php',
    'Faker\\Provider\\lt_LT\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/Person.php',
    'Faker\\Provider\\lt_LT\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lt_LT/PhoneNumber.php',
    'Faker\\Provider\\lv_LV\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/Address.php',
    'Faker\\Provider\\lv_LV\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/Color.php',
    'Faker\\Provider\\lv_LV\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/Internet.php',
    'Faker\\Provider\\lv_LV\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/Payment.php',
    'Faker\\Provider\\lv_LV\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/Person.php',
    'Faker\\Provider\\lv_LV\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/lv_LV/PhoneNumber.php',
    'Faker\\Provider\\me_ME\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/me_ME/Address.php',
    'Faker\\Provider\\me_ME\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/me_ME/Company.php',
    'Faker\\Provider\\me_ME\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/me_ME/Payment.php',
    'Faker\\Provider\\me_ME\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/me_ME/Person.php',
    'Faker\\Provider\\me_ME\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/me_ME/PhoneNumber.php',
    'Faker\\Provider\\mn_MN\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/mn_MN/Person.php',
    'Faker\\Provider\\mn_MN\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/mn_MN/PhoneNumber.php',
    'Faker\\Provider\\ms_MY\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/Address.php',
    'Faker\\Provider\\ms_MY\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/Company.php',
    'Faker\\Provider\\ms_MY\\Miscellaneous' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/Miscellaneous.php',
    'Faker\\Provider\\ms_MY\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/Payment.php',
    'Faker\\Provider\\ms_MY\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/Person.php',
    'Faker\\Provider\\ms_MY\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ms_MY/PhoneNumber.php',
    'Faker\\Provider\\nb_NO\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nb_NO/Address.php',
    'Faker\\Provider\\nb_NO\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nb_NO/Company.php',
    'Faker\\Provider\\nb_NO\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nb_NO/Payment.php',
    'Faker\\Provider\\nb_NO\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nb_NO/Person.php',
    'Faker\\Provider\\nb_NO\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nb_NO/PhoneNumber.php',
    'Faker\\Provider\\ne_NP\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ne_NP/Address.php',
    'Faker\\Provider\\ne_NP\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ne_NP/Internet.php',
    'Faker\\Provider\\ne_NP\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ne_NP/Payment.php',
    'Faker\\Provider\\ne_NP\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ne_NP/Person.php',
    'Faker\\Provider\\ne_NP\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ne_NP/PhoneNumber.php',
    'Faker\\Provider\\nl_BE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Address.php',
    'Faker\\Provider\\nl_BE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Company.php',
    'Faker\\Provider\\nl_BE\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Internet.php',
    'Faker\\Provider\\nl_BE\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Payment.php',
    'Faker\\Provider\\nl_BE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Person.php',
    'Faker\\Provider\\nl_BE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/PhoneNumber.php',
    'Faker\\Provider\\nl_BE\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_BE/Text.php',
    'Faker\\Provider\\nl_NL\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Address.php',
    'Faker\\Provider\\nl_NL\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Color.php',
    'Faker\\Provider\\nl_NL\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Company.php',
    'Faker\\Provider\\nl_NL\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Internet.php',
    'Faker\\Provider\\nl_NL\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Payment.php',
    'Faker\\Provider\\nl_NL\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Person.php',
    'Faker\\Provider\\nl_NL\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/PhoneNumber.php',
    'Faker\\Provider\\nl_NL\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/nl_NL/Text.php',
    'Faker\\Provider\\pl_PL\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Address.php',
    'Faker\\Provider\\pl_PL\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Color.php',
    'Faker\\Provider\\pl_PL\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Company.php',
    'Faker\\Provider\\pl_PL\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Internet.php',
    'Faker\\Provider\\pl_PL\\LicensePlate' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/LicensePlate.php',
    'Faker\\Provider\\pl_PL\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Payment.php',
    'Faker\\Provider\\pl_PL\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Person.php',
    'Faker\\Provider\\pl_PL\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/PhoneNumber.php',
    'Faker\\Provider\\pl_PL\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pl_PL/Text.php',
    'Faker\\Provider\\pt_BR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Address.php',
    'Faker\\Provider\\pt_BR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Company.php',
    'Faker\\Provider\\pt_BR\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Internet.php',
    'Faker\\Provider\\pt_BR\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Payment.php',
    'Faker\\Provider\\pt_BR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Person.php',
    'Faker\\Provider\\pt_BR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/PhoneNumber.php',
    'Faker\\Provider\\pt_BR\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_BR/Text.php',
    'Faker\\Provider\\pt_PT\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/Address.php',
    'Faker\\Provider\\pt_PT\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/Company.php',
    'Faker\\Provider\\pt_PT\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/Internet.php',
    'Faker\\Provider\\pt_PT\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/Payment.php',
    'Faker\\Provider\\pt_PT\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/Person.php',
    'Faker\\Provider\\pt_PT\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/pt_PT/PhoneNumber.php',
    'Faker\\Provider\\ro_MD\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_MD/Address.php',
    'Faker\\Provider\\ro_MD\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_MD/Payment.php',
    'Faker\\Provider\\ro_MD\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_MD/Person.php',
    'Faker\\Provider\\ro_MD\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_MD/PhoneNumber.php',
    'Faker\\Provider\\ro_MD\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_MD/Text.php',
    'Faker\\Provider\\ro_RO\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_RO/Address.php',
    'Faker\\Provider\\ro_RO\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_RO/Payment.php',
    'Faker\\Provider\\ro_RO\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_RO/Person.php',
    'Faker\\Provider\\ro_RO\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_RO/PhoneNumber.php',
    'Faker\\Provider\\ro_RO\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ro_RO/Text.php',
    'Faker\\Provider\\ru_RU\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Address.php',
    'Faker\\Provider\\ru_RU\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Color.php',
    'Faker\\Provider\\ru_RU\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Company.php',
    'Faker\\Provider\\ru_RU\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Internet.php',
    'Faker\\Provider\\ru_RU\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Payment.php',
    'Faker\\Provider\\ru_RU\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Person.php',
    'Faker\\Provider\\ru_RU\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/PhoneNumber.php',
    'Faker\\Provider\\ru_RU\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/ru_RU/Text.php',
    'Faker\\Provider\\sk_SK\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/Address.php',
    'Faker\\Provider\\sk_SK\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/Company.php',
    'Faker\\Provider\\sk_SK\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/Internet.php',
    'Faker\\Provider\\sk_SK\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/Payment.php',
    'Faker\\Provider\\sk_SK\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/Person.php',
    'Faker\\Provider\\sk_SK\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sk_SK/PhoneNumber.php',
    'Faker\\Provider\\sl_SI\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/Address.php',
    'Faker\\Provider\\sl_SI\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/Company.php',
    'Faker\\Provider\\sl_SI\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/Internet.php',
    'Faker\\Provider\\sl_SI\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/Payment.php',
    'Faker\\Provider\\sl_SI\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/Person.php',
    'Faker\\Provider\\sl_SI\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sl_SI/PhoneNumber.php',
    'Faker\\Provider\\sr_Cyrl_RS\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Cyrl_RS/Address.php',
    'Faker\\Provider\\sr_Cyrl_RS\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Cyrl_RS/Payment.php',
    'Faker\\Provider\\sr_Cyrl_RS\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Cyrl_RS/Person.php',
    'Faker\\Provider\\sr_Latn_RS\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Latn_RS/Address.php',
    'Faker\\Provider\\sr_Latn_RS\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Latn_RS/Payment.php',
    'Faker\\Provider\\sr_Latn_RS\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_Latn_RS/Person.php',
    'Faker\\Provider\\sr_RS\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_RS/Address.php',
    'Faker\\Provider\\sr_RS\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_RS/Payment.php',
    'Faker\\Provider\\sr_RS\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sr_RS/Person.php',
    'Faker\\Provider\\sv_SE\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/Address.php',
    'Faker\\Provider\\sv_SE\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/Company.php',
    'Faker\\Provider\\sv_SE\\Municipality' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/Municipality.php',
    'Faker\\Provider\\sv_SE\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/Payment.php',
    'Faker\\Provider\\sv_SE\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/Person.php',
    'Faker\\Provider\\sv_SE\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/sv_SE/PhoneNumber.php',
    'Faker\\Provider\\th_TH\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Address.php',
    'Faker\\Provider\\th_TH\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Color.php',
    'Faker\\Provider\\th_TH\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Company.php',
    'Faker\\Provider\\th_TH\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Internet.php',
    'Faker\\Provider\\th_TH\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Payment.php',
    'Faker\\Provider\\th_TH\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/Person.php',
    'Faker\\Provider\\th_TH\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/th_TH/PhoneNumber.php',
    'Faker\\Provider\\tr_TR\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Address.php',
    'Faker\\Provider\\tr_TR\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Color.php',
    'Faker\\Provider\\tr_TR\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Company.php',
    'Faker\\Provider\\tr_TR\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/DateTime.php',
    'Faker\\Provider\\tr_TR\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Internet.php',
    'Faker\\Provider\\tr_TR\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Payment.php',
    'Faker\\Provider\\tr_TR\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/Person.php',
    'Faker\\Provider\\tr_TR\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/tr_TR/PhoneNumber.php',
    'Faker\\Provider\\uk_UA\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Address.php',
    'Faker\\Provider\\uk_UA\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Color.php',
    'Faker\\Provider\\uk_UA\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Company.php',
    'Faker\\Provider\\uk_UA\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Internet.php',
    'Faker\\Provider\\uk_UA\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Payment.php',
    'Faker\\Provider\\uk_UA\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Person.php',
    'Faker\\Provider\\uk_UA\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/PhoneNumber.php',
    'Faker\\Provider\\uk_UA\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/uk_UA/Text.php',
    'Faker\\Provider\\vi_VN\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/vi_VN/Address.php',
    'Faker\\Provider\\vi_VN\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/vi_VN/Color.php',
    'Faker\\Provider\\vi_VN\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/vi_VN/Internet.php',
    'Faker\\Provider\\vi_VN\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/vi_VN/Person.php',
    'Faker\\Provider\\vi_VN\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/vi_VN/PhoneNumber.php',
    'Faker\\Provider\\zh_CN\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Address.php',
    'Faker\\Provider\\zh_CN\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Color.php',
    'Faker\\Provider\\zh_CN\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Company.php',
    'Faker\\Provider\\zh_CN\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/DateTime.php',
    'Faker\\Provider\\zh_CN\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Internet.php',
    'Faker\\Provider\\zh_CN\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Payment.php',
    'Faker\\Provider\\zh_CN\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/Person.php',
    'Faker\\Provider\\zh_CN\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_CN/PhoneNumber.php',
    'Faker\\Provider\\zh_TW\\Address' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Address.php',
    'Faker\\Provider\\zh_TW\\Color' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Color.php',
    'Faker\\Provider\\zh_TW\\Company' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Company.php',
    'Faker\\Provider\\zh_TW\\DateTime' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/DateTime.php',
    'Faker\\Provider\\zh_TW\\Internet' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Internet.php',
    'Faker\\Provider\\zh_TW\\Payment' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Payment.php',
    'Faker\\Provider\\zh_TW\\Person' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Person.php',
    'Faker\\Provider\\zh_TW\\PhoneNumber' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/PhoneNumber.php',
    'Faker\\Provider\\zh_TW\\Text' => $vendorDir . '/fakerphp/faker/src/Faker/Provider/zh_TW/Text.php',
    'Faker\\UniqueGenerator' => $vendorDir . '/fakerphp/faker/src/Faker/UniqueGenerator.php',
    'Faker\\ValidGenerator' => $vendorDir . '/fakerphp/faker/src/Faker/ValidGenerator.php',
    'FedaPay\\Account' => $vendorDir . '/fedapay/fedapay-php/lib/Account.php',
    'FedaPay\\ApiKey' => $vendorDir . '/fedapay/fedapay-php/lib/ApiKey.php',
    'FedaPay\\ApiOperations\\All' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/All.php',
    'FedaPay\\ApiOperations\\Create' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Create.php',
    'FedaPay\\ApiOperations\\CreateInBatch' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/CreateInBatch.php',
    'FedaPay\\ApiOperations\\Delete' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Delete.php',
    'FedaPay\\ApiOperations\\Request' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Request.php',
    'FedaPay\\ApiOperations\\Retrieve' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Retrieve.php',
    'FedaPay\\ApiOperations\\Save' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Save.php',
    'FedaPay\\ApiOperations\\Search' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Search.php',
    'FedaPay\\ApiOperations\\Update' => $vendorDir . '/fedapay/fedapay-php/lib/ApiOperations/Update.php',
    'FedaPay\\Balance' => $vendorDir . '/fedapay/fedapay-php/lib/Balance.php',
    'FedaPay\\Currency' => $vendorDir . '/fedapay/fedapay-php/lib/Currency.php',
    'FedaPay\\Customer' => $vendorDir . '/fedapay/fedapay-php/lib/Customer.php',
    'FedaPay\\Error\\ApiConnection' => $vendorDir . '/fedapay/fedapay-php/lib/Error/ApiConnection.php',
    'FedaPay\\Error\\Base' => $vendorDir . '/fedapay/fedapay-php/lib/Error/Base.php',
    'FedaPay\\Error\\InvalidRequest' => $vendorDir . '/fedapay/fedapay-php/lib/Error/InvalidRequest.php',
    'FedaPay\\Error\\SignatureVerification' => $vendorDir . '/fedapay/fedapay-php/lib/Error/SignatureVerification.php',
    'FedaPay\\Event' => $vendorDir . '/fedapay/fedapay-php/lib/Event.php',
    'FedaPay\\FedaPay' => $vendorDir . '/fedapay/fedapay-php/lib/FedaPay.php',
    'FedaPay\\FedaPayObject' => $vendorDir . '/fedapay/fedapay-php/lib/FedaPayObject.php',
    'FedaPay\\HttpClient\\ClientInterface' => $vendorDir . '/fedapay/fedapay-php/lib/HttpClient/ClientInterface.php',
    'FedaPay\\HttpClient\\CurlClient' => $vendorDir . '/fedapay/fedapay-php/lib/HttpClient/CurlClient.php',
    'FedaPay\\Invoice' => $vendorDir . '/fedapay/fedapay-php/lib/Invoice.php',
    'FedaPay\\Log' => $vendorDir . '/fedapay/fedapay-php/lib/Log.php',
    'FedaPay\\Page' => $vendorDir . '/fedapay/fedapay-php/lib/Page.php',
    'FedaPay\\Payout' => $vendorDir . '/fedapay/fedapay-php/lib/Payout.php',
    'FedaPay\\PhoneNumber' => $vendorDir . '/fedapay/fedapay-php/lib/PhoneNumber.php',
    'FedaPay\\Requestor' => $vendorDir . '/fedapay/fedapay-php/lib/Requestor.php',
    'FedaPay\\Resource' => $vendorDir . '/fedapay/fedapay-php/lib/Resource.php',
    'FedaPay\\Transaction' => $vendorDir . '/fedapay/fedapay-php/lib/Transaction.php',
    'FedaPay\\Util\\Inflector' => $vendorDir . '/fedapay/fedapay-php/lib/Util/Inflector.php',
    'FedaPay\\Util\\RandomGenerator' => $vendorDir . '/fedapay/fedapay-php/lib/Util/RandomGenerator.php',
    'FedaPay\\Util\\Util' => $vendorDir . '/fedapay/fedapay-php/lib/Util/Util.php',
    'FedaPay\\Webhook' => $vendorDir . '/fedapay/fedapay-php/lib/Webhook.php',
    'FedaPay\\WebhookSignature' => $vendorDir . '/fedapay/fedapay-php/lib/WebhookSignature.php',
    'Firebase\\JWT\\BeforeValidException' => $vendorDir . '/firebase/php-jwt/src/BeforeValidException.php',
    'Firebase\\JWT\\CachedKeySet' => $vendorDir . '/firebase/php-jwt/src/CachedKeySet.php',
    'Firebase\\JWT\\ExpiredException' => $vendorDir . '/firebase/php-jwt/src/ExpiredException.php',
    'Firebase\\JWT\\JWK' => $vendorDir . '/firebase/php-jwt/src/JWK.php',
    'Firebase\\JWT\\JWT' => $vendorDir . '/firebase/php-jwt/src/JWT.php',
    'Firebase\\JWT\\JWTExceptionWithPayloadInterface' => $vendorDir . '/firebase/php-jwt/src/JWTExceptionWithPayloadInterface.php',
    'Firebase\\JWT\\Key' => $vendorDir . '/firebase/php-jwt/src/Key.php',
    'Firebase\\JWT\\SignatureInvalidException' => $vendorDir . '/firebase/php-jwt/src/SignatureInvalidException.php',
    'Fruitcake\\Cors\\CorsService' => $vendorDir . '/fruitcake/php-cors/src/CorsService.php',
    'Fruitcake\\Cors\\Exceptions\\InvalidOptionException' => $vendorDir . '/fruitcake/php-cors/src/Exceptions/InvalidOptionException.php',
    'Google\\AccessToken\\Revoke' => $vendorDir . '/google/apiclient/src/AccessToken/Revoke.php',
    'Google\\AccessToken\\Verify' => $vendorDir . '/google/apiclient/src/AccessToken/Verify.php',
    'Google\\AuthHandler\\AuthHandlerFactory' => $vendorDir . '/google/apiclient/src/AuthHandler/AuthHandlerFactory.php',
    'Google\\AuthHandler\\Guzzle6AuthHandler' => $vendorDir . '/google/apiclient/src/AuthHandler/Guzzle6AuthHandler.php',
    'Google\\AuthHandler\\Guzzle7AuthHandler' => $vendorDir . '/google/apiclient/src/AuthHandler/Guzzle7AuthHandler.php',
    'Google\\Auth\\AccessToken' => $vendorDir . '/google/auth/src/AccessToken.php',
    'Google\\Auth\\ApplicationDefaultCredentials' => $vendorDir . '/google/auth/src/ApplicationDefaultCredentials.php',
    'Google\\Auth\\CacheTrait' => $vendorDir . '/google/auth/src/CacheTrait.php',
    'Google\\Auth\\Cache\\FileSystemCacheItemPool' => $vendorDir . '/google/auth/src/Cache/FileSystemCacheItemPool.php',
    'Google\\Auth\\Cache\\InvalidArgumentException' => $vendorDir . '/google/auth/src/Cache/InvalidArgumentException.php',
    'Google\\Auth\\Cache\\Item' => $vendorDir . '/google/auth/src/Cache/Item.php',
    'Google\\Auth\\Cache\\MemoryCacheItemPool' => $vendorDir . '/google/auth/src/Cache/MemoryCacheItemPool.php',
    'Google\\Auth\\Cache\\SysVCacheItemPool' => $vendorDir . '/google/auth/src/Cache/SysVCacheItemPool.php',
    'Google\\Auth\\Cache\\TypedItem' => $vendorDir . '/google/auth/src/Cache/TypedItem.php',
    'Google\\Auth\\CredentialSource\\AwsNativeSource' => $vendorDir . '/google/auth/src/CredentialSource/AwsNativeSource.php',
    'Google\\Auth\\CredentialSource\\ExecutableSource' => $vendorDir . '/google/auth/src/CredentialSource/ExecutableSource.php',
    'Google\\Auth\\CredentialSource\\FileSource' => $vendorDir . '/google/auth/src/CredentialSource/FileSource.php',
    'Google\\Auth\\CredentialSource\\UrlSource' => $vendorDir . '/google/auth/src/CredentialSource/UrlSource.php',
    'Google\\Auth\\CredentialsLoader' => $vendorDir . '/google/auth/src/CredentialsLoader.php',
    'Google\\Auth\\Credentials\\AppIdentityCredentials' => $vendorDir . '/google/auth/src/Credentials/AppIdentityCredentials.php',
    'Google\\Auth\\Credentials\\ExternalAccountCredentials' => $vendorDir . '/google/auth/src/Credentials/ExternalAccountCredentials.php',
    'Google\\Auth\\Credentials\\GCECredentials' => $vendorDir . '/google/auth/src/Credentials/GCECredentials.php',
    'Google\\Auth\\Credentials\\IAMCredentials' => $vendorDir . '/google/auth/src/Credentials/IAMCredentials.php',
    'Google\\Auth\\Credentials\\ImpersonatedServiceAccountCredentials' => $vendorDir . '/google/auth/src/Credentials/ImpersonatedServiceAccountCredentials.php',
    'Google\\Auth\\Credentials\\InsecureCredentials' => $vendorDir . '/google/auth/src/Credentials/InsecureCredentials.php',
    'Google\\Auth\\Credentials\\ServiceAccountCredentials' => $vendorDir . '/google/auth/src/Credentials/ServiceAccountCredentials.php',
    'Google\\Auth\\Credentials\\ServiceAccountJwtAccessCredentials' => $vendorDir . '/google/auth/src/Credentials/ServiceAccountJwtAccessCredentials.php',
    'Google\\Auth\\Credentials\\UserRefreshCredentials' => $vendorDir . '/google/auth/src/Credentials/UserRefreshCredentials.php',
    'Google\\Auth\\ExecutableHandler\\ExecutableHandler' => $vendorDir . '/google/auth/src/ExecutableHandler/ExecutableHandler.php',
    'Google\\Auth\\ExecutableHandler\\ExecutableResponseError' => $vendorDir . '/google/auth/src/ExecutableHandler/ExecutableResponseError.php',
    'Google\\Auth\\ExternalAccountCredentialSourceInterface' => $vendorDir . '/google/auth/src/ExternalAccountCredentialSourceInterface.php',
    'Google\\Auth\\FetchAuthTokenCache' => $vendorDir . '/google/auth/src/FetchAuthTokenCache.php',
    'Google\\Auth\\FetchAuthTokenInterface' => $vendorDir . '/google/auth/src/FetchAuthTokenInterface.php',
    'Google\\Auth\\GCECache' => $vendorDir . '/google/auth/src/GCECache.php',
    'Google\\Auth\\GetQuotaProjectInterface' => $vendorDir . '/google/auth/src/GetQuotaProjectInterface.php',
    'Google\\Auth\\GetUniverseDomainInterface' => $vendorDir . '/google/auth/src/GetUniverseDomainInterface.php',
    'Google\\Auth\\HttpHandler\\Guzzle6HttpHandler' => $vendorDir . '/google/auth/src/HttpHandler/Guzzle6HttpHandler.php',
    'Google\\Auth\\HttpHandler\\Guzzle7HttpHandler' => $vendorDir . '/google/auth/src/HttpHandler/Guzzle7HttpHandler.php',
    'Google\\Auth\\HttpHandler\\HttpClientCache' => $vendorDir . '/google/auth/src/HttpHandler/HttpClientCache.php',
    'Google\\Auth\\HttpHandler\\HttpHandlerFactory' => $vendorDir . '/google/auth/src/HttpHandler/HttpHandlerFactory.php',
    'Google\\Auth\\Iam' => $vendorDir . '/google/auth/src/Iam.php',
    'Google\\Auth\\IamSignerTrait' => $vendorDir . '/google/auth/src/IamSignerTrait.php',
    'Google\\Auth\\MetricsTrait' => $vendorDir . '/google/auth/src/MetricsTrait.php',
    'Google\\Auth\\Middleware\\AuthTokenMiddleware' => $vendorDir . '/google/auth/src/Middleware/AuthTokenMiddleware.php',
    'Google\\Auth\\Middleware\\ProxyAuthTokenMiddleware' => $vendorDir . '/google/auth/src/Middleware/ProxyAuthTokenMiddleware.php',
    'Google\\Auth\\Middleware\\ScopedAccessTokenMiddleware' => $vendorDir . '/google/auth/src/Middleware/ScopedAccessTokenMiddleware.php',
    'Google\\Auth\\Middleware\\SimpleMiddleware' => $vendorDir . '/google/auth/src/Middleware/SimpleMiddleware.php',
    'Google\\Auth\\OAuth2' => $vendorDir . '/google/auth/src/OAuth2.php',
    'Google\\Auth\\ProjectIdProviderInterface' => $vendorDir . '/google/auth/src/ProjectIdProviderInterface.php',
    'Google\\Auth\\ServiceAccountSignerTrait' => $vendorDir . '/google/auth/src/ServiceAccountSignerTrait.php',
    'Google\\Auth\\SignBlobInterface' => $vendorDir . '/google/auth/src/SignBlobInterface.php',
    'Google\\Auth\\UpdateMetadataInterface' => $vendorDir . '/google/auth/src/UpdateMetadataInterface.php',
    'Google\\Auth\\UpdateMetadataTrait' => $vendorDir . '/google/auth/src/UpdateMetadataTrait.php',
    'Google\\Client' => $vendorDir . '/google/apiclient/src/Client.php',
    'Google\\Collection' => $vendorDir . '/google/apiclient/src/Collection.php',
    'Google\\Exception' => $vendorDir . '/google/apiclient/src/Exception.php',
    'Google\\Http\\Batch' => $vendorDir . '/google/apiclient/src/Http/Batch.php',
    'Google\\Http\\MediaFileUpload' => $vendorDir . '/google/apiclient/src/Http/MediaFileUpload.php',
    'Google\\Http\\REST' => $vendorDir . '/google/apiclient/src/Http/REST.php',
    'Google\\Model' => $vendorDir . '/google/apiclient/src/Model.php',
    'Google\\Service' => $vendorDir . '/google/apiclient/src/Service.php',
    'Google\\Service\\ACMEDNS' => $vendorDir . '/google/apiclient-services/src/ACMEDNS.php',
    'Google\\Service\\ACMEDNS\\AcmeChallengeSet' => $vendorDir . '/google/apiclient-services/src/ACMEDNS/AcmeChallengeSet.php',
    'Google\\Service\\ACMEDNS\\AcmeTxtRecord' => $vendorDir . '/google/apiclient-services/src/ACMEDNS/AcmeTxtRecord.php',
    'Google\\Service\\ACMEDNS\\Resource\\AcmeChallengeSets' => $vendorDir . '/google/apiclient-services/src/ACMEDNS/Resource/AcmeChallengeSets.php',
    'Google\\Service\\ACMEDNS\\RotateChallengesRequest' => $vendorDir . '/google/apiclient-services/src/ACMEDNS/RotateChallengesRequest.php',
    'Google\\Service\\AIPlatformNotebooks' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks.php',
    'Google\\Service\\AIPlatformNotebooks\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/AcceleratorConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\AccessConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/AccessConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\Binding' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Binding.php',
    'Google\\Service\\AIPlatformNotebooks\\BootDisk' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/BootDisk.php',
    'Google\\Service\\AIPlatformNotebooks\\BootImage' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/BootImage.php',
    'Google\\Service\\AIPlatformNotebooks\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/CancelOperationRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\CheckInstanceUpgradabilityResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/CheckInstanceUpgradabilityResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\Config' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Config.php',
    'Google\\Service\\AIPlatformNotebooks\\ContainerImage' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ContainerImage.php',
    'Google\\Service\\AIPlatformNotebooks\\DataDisk' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DataDisk.php',
    'Google\\Service\\AIPlatformNotebooks\\DataprocParameters' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DataprocParameters.php',
    'Google\\Service\\AIPlatformNotebooks\\DefaultValues' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DefaultValues.php',
    'Google\\Service\\AIPlatformNotebooks\\DiagnoseInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DiagnoseInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\DiagnoseRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DiagnoseRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\DiagnosticConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/DiagnosticConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\Disk' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Disk.php',
    'Google\\Service\\AIPlatformNotebooks\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/EncryptionConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\Environment' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Environment.php',
    'Google\\Service\\AIPlatformNotebooks\\Event' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Event.php',
    'Google\\Service\\AIPlatformNotebooks\\Execution' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Execution.php',
    'Google\\Service\\AIPlatformNotebooks\\ExecutionTemplate' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ExecutionTemplate.php',
    'Google\\Service\\AIPlatformNotebooks\\Expr' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Expr.php',
    'Google\\Service\\AIPlatformNotebooks\\GPUDriverConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/GPUDriverConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\GceSetup' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/GceSetup.php',
    'Google\\Service\\AIPlatformNotebooks\\GetInstanceHealthResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/GetInstanceHealthResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\GuestOsFeature' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/GuestOsFeature.php',
    'Google\\Service\\AIPlatformNotebooks\\ImageRelease' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ImageRelease.php',
    'Google\\Service\\AIPlatformNotebooks\\Instance' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Instance.php',
    'Google\\Service\\AIPlatformNotebooks\\InstanceConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/InstanceConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\IsInstanceUpgradeableResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/IsInstanceUpgradeableResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListEnvironmentsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListExecutionsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListInstancesResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListLocationsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListOperationsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListRuntimesResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListRuntimesResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\ListSchedulesResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ListSchedulesResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\LocalDisk' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/LocalDisk.php',
    'Google\\Service\\AIPlatformNotebooks\\LocalDiskInitializeParams' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/LocalDiskInitializeParams.php',
    'Google\\Service\\AIPlatformNotebooks\\Location' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Location.php',
    'Google\\Service\\AIPlatformNotebooks\\NetworkInterface' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/NetworkInterface.php',
    'Google\\Service\\AIPlatformNotebooks\\NotebooksEmpty' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/NotebooksEmpty.php',
    'Google\\Service\\AIPlatformNotebooks\\Operation' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Operation.php',
    'Google\\Service\\AIPlatformNotebooks\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/OperationMetadata.php',
    'Google\\Service\\AIPlatformNotebooks\\Policy' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Policy.php',
    'Google\\Service\\AIPlatformNotebooks\\RefreshRuntimeTokenInternalRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RefreshRuntimeTokenInternalRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\RefreshRuntimeTokenInternalResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RefreshRuntimeTokenInternalResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\RegisterInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RegisterInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ReportInstanceEventRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ReportInstanceEventRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ReportInstanceInfoRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ReportInstanceInfoRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ReportInstanceInfoSystemRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ReportInstanceInfoSystemRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ReportRuntimeEventRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ReportRuntimeEventRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ReservationAffinity' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ReservationAffinity.php',
    'Google\\Service\\AIPlatformNotebooks\\ResetInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ResetInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ResetRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ResetRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ResizeDiskRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ResizeDiskRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/Projects.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocations.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsEnvironments' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsEnvironments.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsExecutions' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsExecutions.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsRuntimes' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsRuntimes.php',
    'Google\\Service\\AIPlatformNotebooks\\Resource\\ProjectsLocationsSchedules' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Resource/ProjectsLocationsSchedules.php',
    'Google\\Service\\AIPlatformNotebooks\\RestoreInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RestoreInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\RollbackInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RollbackInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\Runtime' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Runtime.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeAcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeAcceleratorConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeAccessConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeAccessConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeGuestOsFeature' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeGuestOsFeature.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeMetrics' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeMetrics.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeShieldedInstanceConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\RuntimeSoftwareConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/RuntimeSoftwareConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\Schedule' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Schedule.php',
    'Google\\Service\\AIPlatformNotebooks\\SchedulerAcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SchedulerAcceleratorConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ServiceAccount.php',
    'Google\\Service\\AIPlatformNotebooks\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SetIamPolicyRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\SetInstanceAcceleratorRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SetInstanceAcceleratorRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\SetInstanceLabelsRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SetInstanceLabelsRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\SetInstanceMachineTypeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SetInstanceMachineTypeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/ShieldedInstanceConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\Snapshot' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Snapshot.php',
    'Google\\Service\\AIPlatformNotebooks\\StartInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/StartInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\StartRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/StartRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\Status' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/Status.php',
    'Google\\Service\\AIPlatformNotebooks\\StopInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/StopInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\StopRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/StopRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\SupportedValues' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SupportedValues.php',
    'Google\\Service\\AIPlatformNotebooks\\SwitchRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/SwitchRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/TestIamPermissionsRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/TestIamPermissionsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\TriggerScheduleRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/TriggerScheduleRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpdateInstanceConfigRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpdateInstanceConfigRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpdateInstanceMetadataItemsRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpdateInstanceMetadataItemsRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpdateInstanceMetadataItemsResponse' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpdateInstanceMetadataItemsResponse.php',
    'Google\\Service\\AIPlatformNotebooks\\UpdateShieldedInstanceConfigRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpdateShieldedInstanceConfigRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpgradeHistoryEntry' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpgradeHistoryEntry.php',
    'Google\\Service\\AIPlatformNotebooks\\UpgradeInstanceInternalRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpgradeInstanceInternalRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpgradeInstanceRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpgradeInstanceRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpgradeInstanceSystemRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpgradeInstanceSystemRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\UpgradeRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/UpgradeRuntimeRequest.php',
    'Google\\Service\\AIPlatformNotebooks\\VertexAIParameters' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/VertexAIParameters.php',
    'Google\\Service\\AIPlatformNotebooks\\VirtualMachine' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/VirtualMachine.php',
    'Google\\Service\\AIPlatformNotebooks\\VirtualMachineConfig' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/VirtualMachineConfig.php',
    'Google\\Service\\AIPlatformNotebooks\\VmImage' => $vendorDir . '/google/apiclient-services/src/AIPlatformNotebooks/VmImage.php',
    'Google\\Service\\APIManagement' => $vendorDir . '/google/apiclient-services/src/APIManagement.php',
    'Google\\Service\\APIManagement\\ApiObservation' => $vendorDir . '/google/apiclient-services/src/APIManagement/ApiObservation.php',
    'Google\\Service\\APIManagement\\ApiOperation' => $vendorDir . '/google/apiclient-services/src/APIManagement/ApiOperation.php',
    'Google\\Service\\APIManagement\\ApimEmpty' => $vendorDir . '/google/apiclient-services/src/APIManagement/ApimEmpty.php',
    'Google\\Service\\APIManagement\\BatchEditTagsApiObservationsRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/BatchEditTagsApiObservationsRequest.php',
    'Google\\Service\\APIManagement\\BatchEditTagsApiObservationsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/BatchEditTagsApiObservationsResponse.php',
    'Google\\Service\\APIManagement\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/CancelOperationRequest.php',
    'Google\\Service\\APIManagement\\DisableObservationJobRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/DisableObservationJobRequest.php',
    'Google\\Service\\APIManagement\\EditTagsApiObservationsRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/EditTagsApiObservationsRequest.php',
    'Google\\Service\\APIManagement\\EnableObservationJobRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/EnableObservationJobRequest.php',
    'Google\\Service\\APIManagement\\GclbObservationSource' => $vendorDir . '/google/apiclient-services/src/APIManagement/GclbObservationSource.php',
    'Google\\Service\\APIManagement\\GclbObservationSourcePscNetworkConfig' => $vendorDir . '/google/apiclient-services/src/APIManagement/GclbObservationSourcePscNetworkConfig.php',
    'Google\\Service\\APIManagement\\HttpOperation' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperation.php',
    'Google\\Service\\APIManagement\\HttpOperationHeader' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperationHeader.php',
    'Google\\Service\\APIManagement\\HttpOperationHttpRequest' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperationHttpRequest.php',
    'Google\\Service\\APIManagement\\HttpOperationHttpResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperationHttpResponse.php',
    'Google\\Service\\APIManagement\\HttpOperationPathParam' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperationPathParam.php',
    'Google\\Service\\APIManagement\\HttpOperationQueryParam' => $vendorDir . '/google/apiclient-services/src/APIManagement/HttpOperationQueryParam.php',
    'Google\\Service\\APIManagement\\ListApiObservationTagsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListApiObservationTagsResponse.php',
    'Google\\Service\\APIManagement\\ListApiObservationsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListApiObservationsResponse.php',
    'Google\\Service\\APIManagement\\ListApiOperationsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListApiOperationsResponse.php',
    'Google\\Service\\APIManagement\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListLocationsResponse.php',
    'Google\\Service\\APIManagement\\ListObservationJobsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListObservationJobsResponse.php',
    'Google\\Service\\APIManagement\\ListObservationSourcesResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListObservationSourcesResponse.php',
    'Google\\Service\\APIManagement\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/APIManagement/ListOperationsResponse.php',
    'Google\\Service\\APIManagement\\Location' => $vendorDir . '/google/apiclient-services/src/APIManagement/Location.php',
    'Google\\Service\\APIManagement\\ObservationJob' => $vendorDir . '/google/apiclient-services/src/APIManagement/ObservationJob.php',
    'Google\\Service\\APIManagement\\ObservationSource' => $vendorDir . '/google/apiclient-services/src/APIManagement/ObservationSource.php',
    'Google\\Service\\APIManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/APIManagement/Operation.php',
    'Google\\Service\\APIManagement\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/APIManagement/OperationMetadata.php',
    'Google\\Service\\APIManagement\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/Projects.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocations.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocationsObservationJobs' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocationsObservationJobs.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocationsObservationJobsApiObservations' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocationsObservationJobsApiObservations.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocationsObservationJobsApiObservationsApiOperations' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocationsObservationJobsApiObservationsApiOperations.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocationsObservationSources' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocationsObservationSources.php',
    'Google\\Service\\APIManagement\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/APIManagement/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\APIManagement\\Status' => $vendorDir . '/google/apiclient-services/src/APIManagement/Status.php',
    'Google\\Service\\APIManagement\\TagAction' => $vendorDir . '/google/apiclient-services/src/APIManagement/TagAction.php',
    'Google\\Service\\AbusiveExperienceReport' => $vendorDir . '/google/apiclient-services/src/AbusiveExperienceReport.php',
    'Google\\Service\\AbusiveExperienceReport\\Resource\\Sites' => $vendorDir . '/google/apiclient-services/src/AbusiveExperienceReport/Resource/Sites.php',
    'Google\\Service\\AbusiveExperienceReport\\Resource\\ViolatingSites' => $vendorDir . '/google/apiclient-services/src/AbusiveExperienceReport/Resource/ViolatingSites.php',
    'Google\\Service\\AbusiveExperienceReport\\SiteSummaryResponse' => $vendorDir . '/google/apiclient-services/src/AbusiveExperienceReport/SiteSummaryResponse.php',
    'Google\\Service\\AbusiveExperienceReport\\ViolatingSitesResponse' => $vendorDir . '/google/apiclient-services/src/AbusiveExperienceReport/ViolatingSitesResponse.php',
    'Google\\Service\\Acceleratedmobilepageurl' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl.php',
    'Google\\Service\\Acceleratedmobilepageurl\\AmpUrl' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl/AmpUrl.php',
    'Google\\Service\\Acceleratedmobilepageurl\\AmpUrlError' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl/AmpUrlError.php',
    'Google\\Service\\Acceleratedmobilepageurl\\BatchGetAmpUrlsRequest' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl/BatchGetAmpUrlsRequest.php',
    'Google\\Service\\Acceleratedmobilepageurl\\BatchGetAmpUrlsResponse' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl/BatchGetAmpUrlsResponse.php',
    'Google\\Service\\Acceleratedmobilepageurl\\Resource\\AmpUrls' => $vendorDir . '/google/apiclient-services/src/Acceleratedmobilepageurl/Resource/AmpUrls.php',
    'Google\\Service\\AccessApproval' => $vendorDir . '/google/apiclient-services/src/AccessApproval.php',
    'Google\\Service\\AccessApproval\\AccessApprovalServiceAccount' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AccessApprovalServiceAccount.php',
    'Google\\Service\\AccessApproval\\AccessApprovalSettings' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AccessApprovalSettings.php',
    'Google\\Service\\AccessApproval\\AccessLocations' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AccessLocations.php',
    'Google\\Service\\AccessApproval\\AccessReason' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AccessReason.php',
    'Google\\Service\\AccessApproval\\AccessapprovalEmpty' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AccessapprovalEmpty.php',
    'Google\\Service\\AccessApproval\\ApprovalRequest' => $vendorDir . '/google/apiclient-services/src/AccessApproval/ApprovalRequest.php',
    'Google\\Service\\AccessApproval\\ApproveApprovalRequestMessage' => $vendorDir . '/google/apiclient-services/src/AccessApproval/ApproveApprovalRequestMessage.php',
    'Google\\Service\\AccessApproval\\ApproveDecision' => $vendorDir . '/google/apiclient-services/src/AccessApproval/ApproveDecision.php',
    'Google\\Service\\AccessApproval\\AugmentedInfo' => $vendorDir . '/google/apiclient-services/src/AccessApproval/AugmentedInfo.php',
    'Google\\Service\\AccessApproval\\DismissApprovalRequestMessage' => $vendorDir . '/google/apiclient-services/src/AccessApproval/DismissApprovalRequestMessage.php',
    'Google\\Service\\AccessApproval\\DismissDecision' => $vendorDir . '/google/apiclient-services/src/AccessApproval/DismissDecision.php',
    'Google\\Service\\AccessApproval\\EnrolledService' => $vendorDir . '/google/apiclient-services/src/AccessApproval/EnrolledService.php',
    'Google\\Service\\AccessApproval\\InvalidateApprovalRequestMessage' => $vendorDir . '/google/apiclient-services/src/AccessApproval/InvalidateApprovalRequestMessage.php',
    'Google\\Service\\AccessApproval\\ListApprovalRequestsResponse' => $vendorDir . '/google/apiclient-services/src/AccessApproval/ListApprovalRequestsResponse.php',
    'Google\\Service\\AccessApproval\\ResourceProperties' => $vendorDir . '/google/apiclient-services/src/AccessApproval/ResourceProperties.php',
    'Google\\Service\\AccessApproval\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/Folders.php',
    'Google\\Service\\AccessApproval\\Resource\\FoldersApprovalRequests' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/FoldersApprovalRequests.php',
    'Google\\Service\\AccessApproval\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/Organizations.php',
    'Google\\Service\\AccessApproval\\Resource\\OrganizationsApprovalRequests' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/OrganizationsApprovalRequests.php',
    'Google\\Service\\AccessApproval\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/Projects.php',
    'Google\\Service\\AccessApproval\\Resource\\ProjectsApprovalRequests' => $vendorDir . '/google/apiclient-services/src/AccessApproval/Resource/ProjectsApprovalRequests.php',
    'Google\\Service\\AccessApproval\\SignatureInfo' => $vendorDir . '/google/apiclient-services/src/AccessApproval/SignatureInfo.php',
    'Google\\Service\\AccessContextManager' => $vendorDir . '/google/apiclient-services/src/AccessContextManager.php',
    'Google\\Service\\AccessContextManager\\AccessContextManagerOperationMetadata' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AccessContextManagerOperationMetadata.php',
    'Google\\Service\\AccessContextManager\\AccessLevel' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AccessLevel.php',
    'Google\\Service\\AccessContextManager\\AccessPolicy' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AccessPolicy.php',
    'Google\\Service\\AccessContextManager\\AccesscontextmanagerEmpty' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AccesscontextmanagerEmpty.php',
    'Google\\Service\\AccessContextManager\\ApiOperation' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ApiOperation.php',
    'Google\\Service\\AccessContextManager\\Application' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Application.php',
    'Google\\Service\\AccessContextManager\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AuditConfig.php',
    'Google\\Service\\AccessContextManager\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AuditLogConfig.php',
    'Google\\Service\\AccessContextManager\\AuthorizedOrgsDesc' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/AuthorizedOrgsDesc.php',
    'Google\\Service\\AccessContextManager\\BasicLevel' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/BasicLevel.php',
    'Google\\Service\\AccessContextManager\\Binding' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Binding.php',
    'Google\\Service\\AccessContextManager\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/CancelOperationRequest.php',
    'Google\\Service\\AccessContextManager\\CommitServicePerimetersRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/CommitServicePerimetersRequest.php',
    'Google\\Service\\AccessContextManager\\CommitServicePerimetersResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/CommitServicePerimetersResponse.php',
    'Google\\Service\\AccessContextManager\\Condition' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Condition.php',
    'Google\\Service\\AccessContextManager\\CustomLevel' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/CustomLevel.php',
    'Google\\Service\\AccessContextManager\\DevicePolicy' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/DevicePolicy.php',
    'Google\\Service\\AccessContextManager\\EgressFrom' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/EgressFrom.php',
    'Google\\Service\\AccessContextManager\\EgressPolicy' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/EgressPolicy.php',
    'Google\\Service\\AccessContextManager\\EgressSource' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/EgressSource.php',
    'Google\\Service\\AccessContextManager\\EgressTo' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/EgressTo.php',
    'Google\\Service\\AccessContextManager\\Expr' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Expr.php',
    'Google\\Service\\AccessContextManager\\GcpUserAccessBinding' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/GcpUserAccessBinding.php',
    'Google\\Service\\AccessContextManager\\GcpUserAccessBindingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/GcpUserAccessBindingOperationMetadata.php',
    'Google\\Service\\AccessContextManager\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/GetIamPolicyRequest.php',
    'Google\\Service\\AccessContextManager\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/GetPolicyOptions.php',
    'Google\\Service\\AccessContextManager\\IngressFrom' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/IngressFrom.php',
    'Google\\Service\\AccessContextManager\\IngressPolicy' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/IngressPolicy.php',
    'Google\\Service\\AccessContextManager\\IngressSource' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/IngressSource.php',
    'Google\\Service\\AccessContextManager\\IngressTo' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/IngressTo.php',
    'Google\\Service\\AccessContextManager\\ListAccessLevelsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListAccessLevelsResponse.php',
    'Google\\Service\\AccessContextManager\\ListAccessPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListAccessPoliciesResponse.php',
    'Google\\Service\\AccessContextManager\\ListAuthorizedOrgsDescsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListAuthorizedOrgsDescsResponse.php',
    'Google\\Service\\AccessContextManager\\ListGcpUserAccessBindingsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListGcpUserAccessBindingsResponse.php',
    'Google\\Service\\AccessContextManager\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListOperationsResponse.php',
    'Google\\Service\\AccessContextManager\\ListServicePerimetersResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListServicePerimetersResponse.php',
    'Google\\Service\\AccessContextManager\\ListSupportedServicesResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ListSupportedServicesResponse.php',
    'Google\\Service\\AccessContextManager\\MethodSelector' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/MethodSelector.php',
    'Google\\Service\\AccessContextManager\\Operation' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Operation.php',
    'Google\\Service\\AccessContextManager\\OsConstraint' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/OsConstraint.php',
    'Google\\Service\\AccessContextManager\\Policy' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Policy.php',
    'Google\\Service\\AccessContextManager\\ReplaceAccessLevelsRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ReplaceAccessLevelsRequest.php',
    'Google\\Service\\AccessContextManager\\ReplaceAccessLevelsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ReplaceAccessLevelsResponse.php',
    'Google\\Service\\AccessContextManager\\ReplaceServicePerimetersRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ReplaceServicePerimetersRequest.php',
    'Google\\Service\\AccessContextManager\\ReplaceServicePerimetersResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ReplaceServicePerimetersResponse.php',
    'Google\\Service\\AccessContextManager\\Resource\\AccessPolicies' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/AccessPolicies.php',
    'Google\\Service\\AccessContextManager\\Resource\\AccessPoliciesAccessLevels' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/AccessPoliciesAccessLevels.php',
    'Google\\Service\\AccessContextManager\\Resource\\AccessPoliciesAuthorizedOrgsDescs' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/AccessPoliciesAuthorizedOrgsDescs.php',
    'Google\\Service\\AccessContextManager\\Resource\\AccessPoliciesServicePerimeters' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/AccessPoliciesServicePerimeters.php',
    'Google\\Service\\AccessContextManager\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/Operations.php',
    'Google\\Service\\AccessContextManager\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/Organizations.php',
    'Google\\Service\\AccessContextManager\\Resource\\OrganizationsGcpUserAccessBindings' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/OrganizationsGcpUserAccessBindings.php',
    'Google\\Service\\AccessContextManager\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Resource/Services.php',
    'Google\\Service\\AccessContextManager\\ServicePerimeter' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ServicePerimeter.php',
    'Google\\Service\\AccessContextManager\\ServicePerimeterConfig' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/ServicePerimeterConfig.php',
    'Google\\Service\\AccessContextManager\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/SetIamPolicyRequest.php',
    'Google\\Service\\AccessContextManager\\Status' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/Status.php',
    'Google\\Service\\AccessContextManager\\SupportedService' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/SupportedService.php',
    'Google\\Service\\AccessContextManager\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/TestIamPermissionsRequest.php',
    'Google\\Service\\AccessContextManager\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/TestIamPermissionsResponse.php',
    'Google\\Service\\AccessContextManager\\VpcAccessibleServices' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/VpcAccessibleServices.php',
    'Google\\Service\\AccessContextManager\\VpcNetworkSource' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/VpcNetworkSource.php',
    'Google\\Service\\AccessContextManager\\VpcSubNetwork' => $vendorDir . '/google/apiclient-services/src/AccessContextManager/VpcSubNetwork.php',
    'Google\\Service\\AdExchangeBuyer' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer.php',
    'Google\\Service\\AdExchangeBuyerII' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII.php',
    'Google\\Service\\AdExchangeBuyerII\\AbsoluteDateRange' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AbsoluteDateRange.php',
    'Google\\Service\\AdExchangeBuyerII\\AcceptProposalRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AcceptProposalRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\AdSize' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AdSize.php',
    'Google\\Service\\AdExchangeBuyerII\\AdTechnologyProviders' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AdTechnologyProviders.php',
    'Google\\Service\\AdExchangeBuyerII\\AddDealAssociationRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AddDealAssociationRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\AddNoteRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AddNoteRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\Adexchangebuyer2Empty' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Adexchangebuyer2Empty.php',
    'Google\\Service\\AdExchangeBuyerII\\AppContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AppContext.php',
    'Google\\Service\\AdExchangeBuyerII\\AuctionContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/AuctionContext.php',
    'Google\\Service\\AdExchangeBuyerII\\BidMetricsRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/BidMetricsRow.php',
    'Google\\Service\\AdExchangeBuyerII\\BidResponseWithoutBidsStatusRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/BidResponseWithoutBidsStatusRow.php',
    'Google\\Service\\AdExchangeBuyerII\\Buyer' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Buyer.php',
    'Google\\Service\\AdExchangeBuyerII\\CalloutStatusRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CalloutStatusRow.php',
    'Google\\Service\\AdExchangeBuyerII\\CancelNegotiationRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CancelNegotiationRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\Client' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Client.php',
    'Google\\Service\\AdExchangeBuyerII\\ClientUser' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ClientUser.php',
    'Google\\Service\\AdExchangeBuyerII\\ClientUserInvitation' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ClientUserInvitation.php',
    'Google\\Service\\AdExchangeBuyerII\\CompleteSetupRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CompleteSetupRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\ContactInformation' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ContactInformation.php',
    'Google\\Service\\AdExchangeBuyerII\\Correction' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Correction.php',
    'Google\\Service\\AdExchangeBuyerII\\Creative' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Creative.php',
    'Google\\Service\\AdExchangeBuyerII\\CreativeDealAssociation' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CreativeDealAssociation.php',
    'Google\\Service\\AdExchangeBuyerII\\CreativeRestrictions' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CreativeRestrictions.php',
    'Google\\Service\\AdExchangeBuyerII\\CreativeSize' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CreativeSize.php',
    'Google\\Service\\AdExchangeBuyerII\\CreativeSpecification' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CreativeSpecification.php',
    'Google\\Service\\AdExchangeBuyerII\\CreativeStatusRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CreativeStatusRow.php',
    'Google\\Service\\AdExchangeBuyerII\\CriteriaTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/CriteriaTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\Date' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Date.php',
    'Google\\Service\\AdExchangeBuyerII\\DayPart' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DayPart.php',
    'Google\\Service\\AdExchangeBuyerII\\DayPartTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DayPartTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\Deal' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Deal.php',
    'Google\\Service\\AdExchangeBuyerII\\DealPauseStatus' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DealPauseStatus.php',
    'Google\\Service\\AdExchangeBuyerII\\DealServingMetadata' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DealServingMetadata.php',
    'Google\\Service\\AdExchangeBuyerII\\DealTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DealTerms.php',
    'Google\\Service\\AdExchangeBuyerII\\DeliveryControl' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/DeliveryControl.php',
    'Google\\Service\\AdExchangeBuyerII\\Disapproval' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Disapproval.php',
    'Google\\Service\\AdExchangeBuyerII\\FilterSet' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/FilterSet.php',
    'Google\\Service\\AdExchangeBuyerII\\FilteredBidCreativeRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/FilteredBidCreativeRow.php',
    'Google\\Service\\AdExchangeBuyerII\\FilteredBidDetailRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/FilteredBidDetailRow.php',
    'Google\\Service\\AdExchangeBuyerII\\FirstPartyMobileApplicationTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/FirstPartyMobileApplicationTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\FrequencyCap' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/FrequencyCap.php',
    'Google\\Service\\AdExchangeBuyerII\\GuaranteedFixedPriceTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/GuaranteedFixedPriceTerms.php',
    'Google\\Service\\AdExchangeBuyerII\\HtmlContent' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/HtmlContent.php',
    'Google\\Service\\AdExchangeBuyerII\\Image' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Image.php',
    'Google\\Service\\AdExchangeBuyerII\\ImpressionMetricsRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ImpressionMetricsRow.php',
    'Google\\Service\\AdExchangeBuyerII\\InventorySizeTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/InventorySizeTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\ListBidMetricsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListBidMetricsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListBidResponseErrorsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListBidResponseErrorsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListBidResponsesWithoutBidsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListBidResponsesWithoutBidsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListClientUserInvitationsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListClientUserInvitationsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListClientUsersResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListClientUsersResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListClientsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListClientsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListCreativeStatusBreakdownByCreativeResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListCreativeStatusBreakdownByCreativeResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListCreativeStatusBreakdownByDetailResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListCreativeStatusBreakdownByDetailResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListCreativesResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListCreativesResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListDealAssociationsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListDealAssociationsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListFilterSetsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListFilterSetsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListFilteredBidRequestsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListFilteredBidRequestsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListFilteredBidsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListFilteredBidsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListImpressionMetricsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListImpressionMetricsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListLosingBidsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListLosingBidsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListNonBillableWinningBidsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListNonBillableWinningBidsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListProductsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListProposalsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListProposalsResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\ListPublisherProfilesResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ListPublisherProfilesResponse.php',
    'Google\\Service\\AdExchangeBuyerII\\LocationContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/LocationContext.php',
    'Google\\Service\\AdExchangeBuyerII\\MarketplaceTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/MarketplaceTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\MetricValue' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/MetricValue.php',
    'Google\\Service\\AdExchangeBuyerII\\MobileApplicationTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/MobileApplicationTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\Money' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Money.php',
    'Google\\Service\\AdExchangeBuyerII\\NativeContent' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/NativeContent.php',
    'Google\\Service\\AdExchangeBuyerII\\NonBillableWinningBidStatusRow' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/NonBillableWinningBidStatusRow.php',
    'Google\\Service\\AdExchangeBuyerII\\NonGuaranteedAuctionTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/NonGuaranteedAuctionTerms.php',
    'Google\\Service\\AdExchangeBuyerII\\NonGuaranteedFixedPriceTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/NonGuaranteedFixedPriceTerms.php',
    'Google\\Service\\AdExchangeBuyerII\\Note' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Note.php',
    'Google\\Service\\AdExchangeBuyerII\\OperatingSystemTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/OperatingSystemTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\PauseProposalDealsRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PauseProposalDealsRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\PauseProposalRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PauseProposalRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\PlacementTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PlacementTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\PlatformContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PlatformContext.php',
    'Google\\Service\\AdExchangeBuyerII\\Price' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Price.php',
    'Google\\Service\\AdExchangeBuyerII\\PricePerBuyer' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PricePerBuyer.php',
    'Google\\Service\\AdExchangeBuyerII\\PrivateData' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PrivateData.php',
    'Google\\Service\\AdExchangeBuyerII\\Product' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Product.php',
    'Google\\Service\\AdExchangeBuyerII\\Proposal' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Proposal.php',
    'Google\\Service\\AdExchangeBuyerII\\PublisherProfile' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PublisherProfile.php',
    'Google\\Service\\AdExchangeBuyerII\\PublisherProfileMobileApplication' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/PublisherProfileMobileApplication.php',
    'Google\\Service\\AdExchangeBuyerII\\RealtimeTimeRange' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/RealtimeTimeRange.php',
    'Google\\Service\\AdExchangeBuyerII\\RelativeDateRange' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/RelativeDateRange.php',
    'Google\\Service\\AdExchangeBuyerII\\RemoveDealAssociationRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/RemoveDealAssociationRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/Accounts.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsClients' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsClients.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsClientsInvitations' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsClientsInvitations.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsClientsUsers' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsClientsUsers.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsCreatives' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsCreatives.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsCreativesDealAssociations' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsCreativesDealAssociations.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsFinalizedProposals' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsFinalizedProposals.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsProducts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsProducts.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsProposals' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsProposals.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\AccountsPublisherProfiles' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/AccountsPublisherProfiles.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\Bidders' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/Bidders.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccounts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccounts.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSets' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSets.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsBidMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsBidMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsBidResponseErrors' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsBidResponseErrors.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsBidResponsesWithoutBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsBidResponsesWithoutBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsFilteredBidRequests' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsFilteredBidRequests.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsFilteredBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsFilteredBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsFilteredBidsCreatives' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsFilteredBidsCreatives.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsFilteredBidsDetails' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsFilteredBidsDetails.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsImpressionMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsImpressionMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsLosingBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsLosingBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersAccountsFilterSetsNonBillableWinningBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersAccountsFilterSetsNonBillableWinningBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSets' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSets.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsBidMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsBidMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsBidResponseErrors' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsBidResponseErrors.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsBidResponsesWithoutBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsBidResponsesWithoutBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsFilteredBidRequests' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsFilteredBidRequests.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsFilteredBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsFilteredBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsFilteredBidsCreatives' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsFilteredBidsCreatives.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsFilteredBidsDetails' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsFilteredBidsDetails.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsImpressionMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsImpressionMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsLosingBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsLosingBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BiddersFilterSetsNonBillableWinningBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BiddersFilterSetsNonBillableWinningBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\Buyers' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/Buyers.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSets' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSets.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsBidMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsBidMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsBidResponseErrors' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsBidResponseErrors.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsBidResponsesWithoutBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsBidResponsesWithoutBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsFilteredBidRequests' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsFilteredBidRequests.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsFilteredBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsFilteredBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsFilteredBidsCreatives' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsFilteredBidsCreatives.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsFilteredBidsDetails' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsFilteredBidsDetails.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsImpressionMetrics' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsImpressionMetrics.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsLosingBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsLosingBids.php',
    'Google\\Service\\AdExchangeBuyerII\\Resource\\BuyersFilterSetsNonBillableWinningBids' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Resource/BuyersFilterSetsNonBillableWinningBids.php',
    'Google\\Service\\AdExchangeBuyerII\\ResumeProposalDealsRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ResumeProposalDealsRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\ResumeProposalRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ResumeProposalRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\RowDimensions' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/RowDimensions.php',
    'Google\\Service\\AdExchangeBuyerII\\SecurityContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/SecurityContext.php',
    'Google\\Service\\AdExchangeBuyerII\\Seller' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Seller.php',
    'Google\\Service\\AdExchangeBuyerII\\ServingContext' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ServingContext.php',
    'Google\\Service\\AdExchangeBuyerII\\ServingRestriction' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/ServingRestriction.php',
    'Google\\Service\\AdExchangeBuyerII\\Size' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/Size.php',
    'Google\\Service\\AdExchangeBuyerII\\StopWatchingCreativeRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/StopWatchingCreativeRequest.php',
    'Google\\Service\\AdExchangeBuyerII\\TargetingCriteria' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/TargetingCriteria.php',
    'Google\\Service\\AdExchangeBuyerII\\TargetingValue' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/TargetingValue.php',
    'Google\\Service\\AdExchangeBuyerII\\TechnologyTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/TechnologyTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\TimeInterval' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/TimeInterval.php',
    'Google\\Service\\AdExchangeBuyerII\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/TimeOfDay.php',
    'Google\\Service\\AdExchangeBuyerII\\UrlTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/UrlTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\VideoContent' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/VideoContent.php',
    'Google\\Service\\AdExchangeBuyerII\\VideoTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/VideoTargeting.php',
    'Google\\Service\\AdExchangeBuyerII\\WatchCreativeRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyerII/WatchCreativeRequest.php',
    'Google\\Service\\AdExchangeBuyer\\Account' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Account.php',
    'Google\\Service\\AdExchangeBuyer\\AccountBidderLocation' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AccountBidderLocation.php',
    'Google\\Service\\AdExchangeBuyer\\AccountsList' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AccountsList.php',
    'Google\\Service\\AdExchangeBuyer\\AddOrderDealsRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AddOrderDealsRequest.php',
    'Google\\Service\\AdExchangeBuyer\\AddOrderDealsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AddOrderDealsResponse.php',
    'Google\\Service\\AdExchangeBuyer\\AddOrderNotesRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AddOrderNotesRequest.php',
    'Google\\Service\\AdExchangeBuyer\\AddOrderNotesResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/AddOrderNotesResponse.php',
    'Google\\Service\\AdExchangeBuyer\\BillingInfo' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/BillingInfo.php',
    'Google\\Service\\AdExchangeBuyer\\BillingInfoList' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/BillingInfoList.php',
    'Google\\Service\\AdExchangeBuyer\\Budget' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Budget.php',
    'Google\\Service\\AdExchangeBuyer\\Buyer' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Buyer.php',
    'Google\\Service\\AdExchangeBuyer\\ContactInformation' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/ContactInformation.php',
    'Google\\Service\\AdExchangeBuyer\\CreateOrdersRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreateOrdersRequest.php',
    'Google\\Service\\AdExchangeBuyer\\CreateOrdersResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreateOrdersResponse.php',
    'Google\\Service\\AdExchangeBuyer\\Creative' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Creative.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeAdTechnologyProviders' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeAdTechnologyProviders.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeCorrections' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeCorrections.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeCorrectionsContexts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeCorrectionsContexts.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeDealIds' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeDealIds.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeDealIdsDealStatuses' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeDealIdsDealStatuses.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeFilteringReasons' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeFilteringReasons.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeFilteringReasonsReasons' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeFilteringReasonsReasons.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeNativeAd' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeNativeAd.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeNativeAdAppIcon' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeNativeAdAppIcon.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeNativeAdImage' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeNativeAdImage.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeNativeAdLogo' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeNativeAdLogo.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeServingRestrictions' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeServingRestrictions.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeServingRestrictionsContexts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeServingRestrictionsContexts.php',
    'Google\\Service\\AdExchangeBuyer\\CreativeServingRestrictionsDisapprovalReasons' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativeServingRestrictionsDisapprovalReasons.php',
    'Google\\Service\\AdExchangeBuyer\\CreativesList' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/CreativesList.php',
    'Google\\Service\\AdExchangeBuyer\\DealServingMetadata' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealServingMetadata.php',
    'Google\\Service\\AdExchangeBuyer\\DealServingMetadataDealPauseStatus' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealServingMetadataDealPauseStatus.php',
    'Google\\Service\\AdExchangeBuyer\\DealTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTerms.php',
    'Google\\Service\\AdExchangeBuyer\\DealTermsGuaranteedFixedPriceTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTermsGuaranteedFixedPriceTerms.php',
    'Google\\Service\\AdExchangeBuyer\\DealTermsGuaranteedFixedPriceTermsBillingInfo' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTermsGuaranteedFixedPriceTermsBillingInfo.php',
    'Google\\Service\\AdExchangeBuyer\\DealTermsNonGuaranteedAuctionTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTermsNonGuaranteedAuctionTerms.php',
    'Google\\Service\\AdExchangeBuyer\\DealTermsNonGuaranteedFixedPriceTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTermsNonGuaranteedFixedPriceTerms.php',
    'Google\\Service\\AdExchangeBuyer\\DealTermsRubiconNonGuaranteedTerms' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DealTermsRubiconNonGuaranteedTerms.php',
    'Google\\Service\\AdExchangeBuyer\\DeleteOrderDealsRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DeleteOrderDealsRequest.php',
    'Google\\Service\\AdExchangeBuyer\\DeleteOrderDealsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DeleteOrderDealsResponse.php',
    'Google\\Service\\AdExchangeBuyer\\DeliveryControl' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DeliveryControl.php',
    'Google\\Service\\AdExchangeBuyer\\DeliveryControlFrequencyCap' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DeliveryControlFrequencyCap.php',
    'Google\\Service\\AdExchangeBuyer\\Dimension' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Dimension.php',
    'Google\\Service\\AdExchangeBuyer\\DimensionDimensionValue' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/DimensionDimensionValue.php',
    'Google\\Service\\AdExchangeBuyer\\EditAllOrderDealsRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/EditAllOrderDealsRequest.php',
    'Google\\Service\\AdExchangeBuyer\\EditAllOrderDealsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/EditAllOrderDealsResponse.php',
    'Google\\Service\\AdExchangeBuyer\\GetOffersResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/GetOffersResponse.php',
    'Google\\Service\\AdExchangeBuyer\\GetOrderDealsResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/GetOrderDealsResponse.php',
    'Google\\Service\\AdExchangeBuyer\\GetOrderNotesResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/GetOrderNotesResponse.php',
    'Google\\Service\\AdExchangeBuyer\\GetOrdersResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/GetOrdersResponse.php',
    'Google\\Service\\AdExchangeBuyer\\GetPublisherProfilesByAccountIdResponse' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/GetPublisherProfilesByAccountIdResponse.php',
    'Google\\Service\\AdExchangeBuyer\\MarketplaceDeal' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/MarketplaceDeal.php',
    'Google\\Service\\AdExchangeBuyer\\MarketplaceDealParty' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/MarketplaceDealParty.php',
    'Google\\Service\\AdExchangeBuyer\\MarketplaceLabel' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/MarketplaceLabel.php',
    'Google\\Service\\AdExchangeBuyer\\MarketplaceNote' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/MarketplaceNote.php',
    'Google\\Service\\AdExchangeBuyer\\MobileApplication' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/MobileApplication.php',
    'Google\\Service\\AdExchangeBuyer\\PerformanceReport' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PerformanceReport.php',
    'Google\\Service\\AdExchangeBuyer\\PerformanceReportList' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PerformanceReportList.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfig' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfig.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfigDimensions' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfigDimensions.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfigExcludedPlacements' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfigExcludedPlacements.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfigList' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfigList.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfigPlacements' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfigPlacements.php',
    'Google\\Service\\AdExchangeBuyer\\PretargetingConfigVideoPlayerSizes' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PretargetingConfigVideoPlayerSizes.php',
    'Google\\Service\\AdExchangeBuyer\\Price' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Price.php',
    'Google\\Service\\AdExchangeBuyer\\PricePerBuyer' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PricePerBuyer.php',
    'Google\\Service\\AdExchangeBuyer\\PrivateData' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PrivateData.php',
    'Google\\Service\\AdExchangeBuyer\\Product' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Product.php',
    'Google\\Service\\AdExchangeBuyer\\Proposal' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Proposal.php',
    'Google\\Service\\AdExchangeBuyer\\PublisherProfileApiProto' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PublisherProfileApiProto.php',
    'Google\\Service\\AdExchangeBuyer\\PublisherProvidedForecast' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/PublisherProvidedForecast.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Accounts.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\BillingInfo' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/BillingInfo.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Budget' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Budget.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Creatives' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Creatives.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Marketplacedeals' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Marketplacedeals.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Marketplacenotes' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Marketplacenotes.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Marketplaceprivateauction' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Marketplaceprivateauction.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\PerformanceReport' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/PerformanceReport.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\PretargetingConfig' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/PretargetingConfig.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Products' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Products.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Proposals' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Proposals.php',
    'Google\\Service\\AdExchangeBuyer\\Resource\\Pubprofiles' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Resource/Pubprofiles.php',
    'Google\\Service\\AdExchangeBuyer\\Seller' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/Seller.php',
    'Google\\Service\\AdExchangeBuyer\\SharedTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/SharedTargeting.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValue' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValue.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueCreativeSize' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueCreativeSize.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueDayPartTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueDayPartTargeting.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueDayPartTargetingDayPart' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueDayPartTargetingDayPart.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueDemogAgeCriteria' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueDemogAgeCriteria.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueDemogGenderCriteria' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueDemogGenderCriteria.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueRequestPlatformTargeting' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueRequestPlatformTargeting.php',
    'Google\\Service\\AdExchangeBuyer\\TargetingValueSize' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/TargetingValueSize.php',
    'Google\\Service\\AdExchangeBuyer\\UpdatePrivateAuctionProposalRequest' => $vendorDir . '/google/apiclient-services/src/AdExchangeBuyer/UpdatePrivateAuctionProposalRequest.php',
    'Google\\Service\\AdExperienceReport' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport.php',
    'Google\\Service\\AdExperienceReport\\PlatformSummary' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport/PlatformSummary.php',
    'Google\\Service\\AdExperienceReport\\Resource\\Sites' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport/Resource/Sites.php',
    'Google\\Service\\AdExperienceReport\\Resource\\ViolatingSites' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport/Resource/ViolatingSites.php',
    'Google\\Service\\AdExperienceReport\\SiteSummaryResponse' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport/SiteSummaryResponse.php',
    'Google\\Service\\AdExperienceReport\\ViolatingSitesResponse' => $vendorDir . '/google/apiclient-services/src/AdExperienceReport/ViolatingSitesResponse.php',
    'Google\\Service\\AdMob' => $vendorDir . '/google/apiclient-services/src/AdMob.php',
    'Google\\Service\\AdMob\\AdUnit' => $vendorDir . '/google/apiclient-services/src/AdMob/AdUnit.php',
    'Google\\Service\\AdMob\\App' => $vendorDir . '/google/apiclient-services/src/AdMob/App.php',
    'Google\\Service\\AdMob\\AppLinkedAppInfo' => $vendorDir . '/google/apiclient-services/src/AdMob/AppLinkedAppInfo.php',
    'Google\\Service\\AdMob\\AppManualAppInfo' => $vendorDir . '/google/apiclient-services/src/AdMob/AppManualAppInfo.php',
    'Google\\Service\\AdMob\\Date' => $vendorDir . '/google/apiclient-services/src/AdMob/Date.php',
    'Google\\Service\\AdMob\\DateRange' => $vendorDir . '/google/apiclient-services/src/AdMob/DateRange.php',
    'Google\\Service\\AdMob\\GenerateMediationReportRequest' => $vendorDir . '/google/apiclient-services/src/AdMob/GenerateMediationReportRequest.php',
    'Google\\Service\\AdMob\\GenerateMediationReportResponse' => $vendorDir . '/google/apiclient-services/src/AdMob/GenerateMediationReportResponse.php',
    'Google\\Service\\AdMob\\GenerateNetworkReportRequest' => $vendorDir . '/google/apiclient-services/src/AdMob/GenerateNetworkReportRequest.php',
    'Google\\Service\\AdMob\\GenerateNetworkReportResponse' => $vendorDir . '/google/apiclient-services/src/AdMob/GenerateNetworkReportResponse.php',
    'Google\\Service\\AdMob\\ListAdUnitsResponse' => $vendorDir . '/google/apiclient-services/src/AdMob/ListAdUnitsResponse.php',
    'Google\\Service\\AdMob\\ListAppsResponse' => $vendorDir . '/google/apiclient-services/src/AdMob/ListAppsResponse.php',
    'Google\\Service\\AdMob\\ListPublisherAccountsResponse' => $vendorDir . '/google/apiclient-services/src/AdMob/ListPublisherAccountsResponse.php',
    'Google\\Service\\AdMob\\LocalizationSettings' => $vendorDir . '/google/apiclient-services/src/AdMob/LocalizationSettings.php',
    'Google\\Service\\AdMob\\MediationReportSpec' => $vendorDir . '/google/apiclient-services/src/AdMob/MediationReportSpec.php',
    'Google\\Service\\AdMob\\MediationReportSpecDimensionFilter' => $vendorDir . '/google/apiclient-services/src/AdMob/MediationReportSpecDimensionFilter.php',
    'Google\\Service\\AdMob\\MediationReportSpecSortCondition' => $vendorDir . '/google/apiclient-services/src/AdMob/MediationReportSpecSortCondition.php',
    'Google\\Service\\AdMob\\NetworkReportSpec' => $vendorDir . '/google/apiclient-services/src/AdMob/NetworkReportSpec.php',
    'Google\\Service\\AdMob\\NetworkReportSpecDimensionFilter' => $vendorDir . '/google/apiclient-services/src/AdMob/NetworkReportSpecDimensionFilter.php',
    'Google\\Service\\AdMob\\NetworkReportSpecSortCondition' => $vendorDir . '/google/apiclient-services/src/AdMob/NetworkReportSpecSortCondition.php',
    'Google\\Service\\AdMob\\PublisherAccount' => $vendorDir . '/google/apiclient-services/src/AdMob/PublisherAccount.php',
    'Google\\Service\\AdMob\\ReportFooter' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportFooter.php',
    'Google\\Service\\AdMob\\ReportHeader' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportHeader.php',
    'Google\\Service\\AdMob\\ReportRow' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportRow.php',
    'Google\\Service\\AdMob\\ReportRowDimensionValue' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportRowDimensionValue.php',
    'Google\\Service\\AdMob\\ReportRowMetricValue' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportRowMetricValue.php',
    'Google\\Service\\AdMob\\ReportWarning' => $vendorDir . '/google/apiclient-services/src/AdMob/ReportWarning.php',
    'Google\\Service\\AdMob\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/AdMob/Resource/Accounts.php',
    'Google\\Service\\AdMob\\Resource\\AccountsAdUnits' => $vendorDir . '/google/apiclient-services/src/AdMob/Resource/AccountsAdUnits.php',
    'Google\\Service\\AdMob\\Resource\\AccountsApps' => $vendorDir . '/google/apiclient-services/src/AdMob/Resource/AccountsApps.php',
    'Google\\Service\\AdMob\\Resource\\AccountsMediationReport' => $vendorDir . '/google/apiclient-services/src/AdMob/Resource/AccountsMediationReport.php',
    'Google\\Service\\AdMob\\Resource\\AccountsNetworkReport' => $vendorDir . '/google/apiclient-services/src/AdMob/Resource/AccountsNetworkReport.php',
    'Google\\Service\\AdMob\\StringList' => $vendorDir . '/google/apiclient-services/src/AdMob/StringList.php',
    'Google\\Service\\AdSenseHost' => $vendorDir . '/google/apiclient-services/src/AdSenseHost.php',
    'Google\\Service\\AdSenseHost\\Account' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Account.php',
    'Google\\Service\\AdSenseHost\\Accounts' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Accounts.php',
    'Google\\Service\\AdSenseHost\\AdClient' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdClient.php',
    'Google\\Service\\AdSenseHost\\AdClients' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdClients.php',
    'Google\\Service\\AdSenseHost\\AdCode' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdCode.php',
    'Google\\Service\\AdSenseHost\\AdStyle' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdStyle.php',
    'Google\\Service\\AdSenseHost\\AdStyleColors' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdStyleColors.php',
    'Google\\Service\\AdSenseHost\\AdStyleFont' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdStyleFont.php',
    'Google\\Service\\AdSenseHost\\AdUnit' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdUnit.php',
    'Google\\Service\\AdSenseHost\\AdUnitContentAdsSettings' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdUnitContentAdsSettings.php',
    'Google\\Service\\AdSenseHost\\AdUnitContentAdsSettingsBackupOption' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdUnitContentAdsSettingsBackupOption.php',
    'Google\\Service\\AdSenseHost\\AdUnitMobileContentAdsSettings' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdUnitMobileContentAdsSettings.php',
    'Google\\Service\\AdSenseHost\\AdUnits' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AdUnits.php',
    'Google\\Service\\AdSenseHost\\AssociationSession' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/AssociationSession.php',
    'Google\\Service\\AdSenseHost\\CustomChannel' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/CustomChannel.php',
    'Google\\Service\\AdSenseHost\\CustomChannels' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/CustomChannels.php',
    'Google\\Service\\AdSenseHost\\Report' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Report.php',
    'Google\\Service\\AdSenseHost\\ReportHeaders' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/ReportHeaders.php',
    'Google\\Service\\AdSenseHost\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Accounts.php',
    'Google\\Service\\AdSenseHost\\Resource\\AccountsAdclients' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/AccountsAdclients.php',
    'Google\\Service\\AdSenseHost\\Resource\\AccountsAdunits' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/AccountsAdunits.php',
    'Google\\Service\\AdSenseHost\\Resource\\AccountsReports' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/AccountsReports.php',
    'Google\\Service\\AdSenseHost\\Resource\\Adclients' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Adclients.php',
    'Google\\Service\\AdSenseHost\\Resource\\Associationsessions' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Associationsessions.php',
    'Google\\Service\\AdSenseHost\\Resource\\Customchannels' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Customchannels.php',
    'Google\\Service\\AdSenseHost\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Reports.php',
    'Google\\Service\\AdSenseHost\\Resource\\Urlchannels' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/Resource/Urlchannels.php',
    'Google\\Service\\AdSenseHost\\UrlChannel' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/UrlChannel.php',
    'Google\\Service\\AdSenseHost\\UrlChannels' => $vendorDir . '/google/apiclient-services/src/AdSenseHost/UrlChannels.php',
    'Google\\Service\\AdSensePlatform' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform.php',
    'Google\\Service\\AdSensePlatform\\Account' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Account.php',
    'Google\\Service\\AdSensePlatform\\Address' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Address.php',
    'Google\\Service\\AdSensePlatform\\AdsenseplatformEmpty' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/AdsenseplatformEmpty.php',
    'Google\\Service\\AdSensePlatform\\CloseAccountRequest' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/CloseAccountRequest.php',
    'Google\\Service\\AdSensePlatform\\CloseAccountResponse' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/CloseAccountResponse.php',
    'Google\\Service\\AdSensePlatform\\Event' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Event.php',
    'Google\\Service\\AdSensePlatform\\EventInfo' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/EventInfo.php',
    'Google\\Service\\AdSensePlatform\\ListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/ListAccountsResponse.php',
    'Google\\Service\\AdSensePlatform\\ListSitesResponse' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/ListSitesResponse.php',
    'Google\\Service\\AdSensePlatform\\LookupAccountResponse' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/LookupAccountResponse.php',
    'Google\\Service\\AdSensePlatform\\RequestSiteReviewResponse' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/RequestSiteReviewResponse.php',
    'Google\\Service\\AdSensePlatform\\Resource\\Platforms' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Resource/Platforms.php',
    'Google\\Service\\AdSensePlatform\\Resource\\PlatformsAccounts' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Resource/PlatformsAccounts.php',
    'Google\\Service\\AdSensePlatform\\Resource\\PlatformsAccountsEvents' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Resource/PlatformsAccountsEvents.php',
    'Google\\Service\\AdSensePlatform\\Resource\\PlatformsAccountsSites' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Resource/PlatformsAccountsSites.php',
    'Google\\Service\\AdSensePlatform\\Site' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/Site.php',
    'Google\\Service\\AdSensePlatform\\TimeZone' => $vendorDir . '/google/apiclient-services/src/AdSensePlatform/TimeZone.php',
    'Google\\Service\\AddressValidation' => $vendorDir . '/google/apiclient-services/src/AddressValidation.php',
    'Google\\Service\\AddressValidation\\GoogleGeoTypeViewport' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleGeoTypeViewport.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1Address' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1Address.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1AddressComponent' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1AddressComponent.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1AddressMetadata' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1AddressMetadata.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ComponentName' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ComponentName.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1Geocode' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1Geocode.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1LanguageOptions' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1LanguageOptions.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1PlusCode' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1PlusCode.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ProvideValidationFeedbackRequest' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ProvideValidationFeedbackRequest.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ProvideValidationFeedbackResponse' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ProvideValidationFeedbackResponse.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1UspsAddress' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1UspsAddress.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1UspsData' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1UspsData.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ValidateAddressRequest' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ValidateAddressRequest.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ValidateAddressResponse' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ValidateAddressResponse.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1ValidationResult' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1ValidationResult.php',
    'Google\\Service\\AddressValidation\\GoogleMapsAddressvalidationV1Verdict' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleMapsAddressvalidationV1Verdict.php',
    'Google\\Service\\AddressValidation\\GoogleTypeLatLng' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleTypeLatLng.php',
    'Google\\Service\\AddressValidation\\GoogleTypePostalAddress' => $vendorDir . '/google/apiclient-services/src/AddressValidation/GoogleTypePostalAddress.php',
    'Google\\Service\\AddressValidation\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/AddressValidation/Resource/V1.php',
    'Google\\Service\\Adsense' => $vendorDir . '/google/apiclient-services/src/Adsense.php',
    'Google\\Service\\Adsense\\Account' => $vendorDir . '/google/apiclient-services/src/Adsense/Account.php',
    'Google\\Service\\Adsense\\AdBlockingRecoveryTag' => $vendorDir . '/google/apiclient-services/src/Adsense/AdBlockingRecoveryTag.php',
    'Google\\Service\\Adsense\\AdClient' => $vendorDir . '/google/apiclient-services/src/Adsense/AdClient.php',
    'Google\\Service\\Adsense\\AdClientAdCode' => $vendorDir . '/google/apiclient-services/src/Adsense/AdClientAdCode.php',
    'Google\\Service\\Adsense\\AdUnit' => $vendorDir . '/google/apiclient-services/src/Adsense/AdUnit.php',
    'Google\\Service\\Adsense\\AdUnitAdCode' => $vendorDir . '/google/apiclient-services/src/Adsense/AdUnitAdCode.php',
    'Google\\Service\\Adsense\\AdsenseEmpty' => $vendorDir . '/google/apiclient-services/src/Adsense/AdsenseEmpty.php',
    'Google\\Service\\Adsense\\Alert' => $vendorDir . '/google/apiclient-services/src/Adsense/Alert.php',
    'Google\\Service\\Adsense\\Cell' => $vendorDir . '/google/apiclient-services/src/Adsense/Cell.php',
    'Google\\Service\\Adsense\\ContentAdsSettings' => $vendorDir . '/google/apiclient-services/src/Adsense/ContentAdsSettings.php',
    'Google\\Service\\Adsense\\CustomChannel' => $vendorDir . '/google/apiclient-services/src/Adsense/CustomChannel.php',
    'Google\\Service\\Adsense\\Date' => $vendorDir . '/google/apiclient-services/src/Adsense/Date.php',
    'Google\\Service\\Adsense\\Header' => $vendorDir . '/google/apiclient-services/src/Adsense/Header.php',
    'Google\\Service\\Adsense\\HttpBody' => $vendorDir . '/google/apiclient-services/src/Adsense/HttpBody.php',
    'Google\\Service\\Adsense\\ListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListAccountsResponse.php',
    'Google\\Service\\Adsense\\ListAdClientsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListAdClientsResponse.php',
    'Google\\Service\\Adsense\\ListAdUnitsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListAdUnitsResponse.php',
    'Google\\Service\\Adsense\\ListAlertsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListAlertsResponse.php',
    'Google\\Service\\Adsense\\ListChildAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListChildAccountsResponse.php',
    'Google\\Service\\Adsense\\ListCustomChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListCustomChannelsResponse.php',
    'Google\\Service\\Adsense\\ListLinkedAdUnitsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListLinkedAdUnitsResponse.php',
    'Google\\Service\\Adsense\\ListLinkedCustomChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListLinkedCustomChannelsResponse.php',
    'Google\\Service\\Adsense\\ListPaymentsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListPaymentsResponse.php',
    'Google\\Service\\Adsense\\ListPolicyIssuesResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListPolicyIssuesResponse.php',
    'Google\\Service\\Adsense\\ListSavedReportsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListSavedReportsResponse.php',
    'Google\\Service\\Adsense\\ListSitesResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListSitesResponse.php',
    'Google\\Service\\Adsense\\ListUrlChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Adsense/ListUrlChannelsResponse.php',
    'Google\\Service\\Adsense\\Payment' => $vendorDir . '/google/apiclient-services/src/Adsense/Payment.php',
    'Google\\Service\\Adsense\\PolicyIssue' => $vendorDir . '/google/apiclient-services/src/Adsense/PolicyIssue.php',
    'Google\\Service\\Adsense\\PolicyTopic' => $vendorDir . '/google/apiclient-services/src/Adsense/PolicyTopic.php',
    'Google\\Service\\Adsense\\ReportResult' => $vendorDir . '/google/apiclient-services/src/Adsense/ReportResult.php',
    'Google\\Service\\Adsense\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/Accounts.php',
    'Google\\Service\\Adsense\\Resource\\AccountsAdclients' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsAdclients.php',
    'Google\\Service\\Adsense\\Resource\\AccountsAdclientsAdunits' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsAdclientsAdunits.php',
    'Google\\Service\\Adsense\\Resource\\AccountsAdclientsCustomchannels' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsAdclientsCustomchannels.php',
    'Google\\Service\\Adsense\\Resource\\AccountsAdclientsUrlchannels' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsAdclientsUrlchannels.php',
    'Google\\Service\\Adsense\\Resource\\AccountsAlerts' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsAlerts.php',
    'Google\\Service\\Adsense\\Resource\\AccountsPayments' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsPayments.php',
    'Google\\Service\\Adsense\\Resource\\AccountsPolicyIssues' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsPolicyIssues.php',
    'Google\\Service\\Adsense\\Resource\\AccountsReports' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsReports.php',
    'Google\\Service\\Adsense\\Resource\\AccountsReportsSaved' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsReportsSaved.php',
    'Google\\Service\\Adsense\\Resource\\AccountsSites' => $vendorDir . '/google/apiclient-services/src/Adsense/Resource/AccountsSites.php',
    'Google\\Service\\Adsense\\Row' => $vendorDir . '/google/apiclient-services/src/Adsense/Row.php',
    'Google\\Service\\Adsense\\SavedReport' => $vendorDir . '/google/apiclient-services/src/Adsense/SavedReport.php',
    'Google\\Service\\Adsense\\Site' => $vendorDir . '/google/apiclient-services/src/Adsense/Site.php',
    'Google\\Service\\Adsense\\TimeZone' => $vendorDir . '/google/apiclient-services/src/Adsense/TimeZone.php',
    'Google\\Service\\Adsense\\UrlChannel' => $vendorDir . '/google/apiclient-services/src/Adsense/UrlChannel.php',
    'Google\\Service\\Advisorynotifications' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Attachment' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Attachment.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Csv' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Csv.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1CsvCsvRow' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1CsvCsvRow.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1ListNotificationsResponse' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1ListNotificationsResponse.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Message' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Message.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1MessageBody' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1MessageBody.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Notification' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Notification.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1NotificationSettings' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1NotificationSettings.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Settings' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Settings.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Subject' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Subject.php',
    'Google\\Service\\Advisorynotifications\\GoogleCloudAdvisorynotificationsV1Text' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/GoogleCloudAdvisorynotificationsV1Text.php',
    'Google\\Service\\Advisorynotifications\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/Organizations.php',
    'Google\\Service\\Advisorynotifications\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/OrganizationsLocations.php',
    'Google\\Service\\Advisorynotifications\\Resource\\OrganizationsLocationsNotifications' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/OrganizationsLocationsNotifications.php',
    'Google\\Service\\Advisorynotifications\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/Projects.php',
    'Google\\Service\\Advisorynotifications\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/ProjectsLocations.php',
    'Google\\Service\\Advisorynotifications\\Resource\\ProjectsLocationsNotifications' => $vendorDir . '/google/apiclient-services/src/Advisorynotifications/Resource/ProjectsLocationsNotifications.php',
    'Google\\Service\\Aiplatform' => $vendorDir . '/google/apiclient-services/src/Aiplatform.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionFilteredText' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionFilteredText.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionGenerateVideoResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionGenerateVideoResponse.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionImage' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionImage.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionImageRAIScores' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionImageRAIScores.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionMedia' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionMedia.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionNamedBoundingBox' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionNamedBoundingBox.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionRaiInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionRaiInfo.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionRaiInfoDetectedLabels' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionRaiInfoDetectedLabels.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionRaiInfoDetectedLabelsBoundingBox' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionRaiInfoDetectedLabelsBoundingBox.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionSemanticFilterResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionSemanticFilterResponse.php',
    'Google\\Service\\Aiplatform\\CloudAiLargeModelsVisionVideo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiLargeModelsVisionVideo.php',
    'Google\\Service\\Aiplatform\\CloudAiPlatformCommonCreatePipelineJobApiErrorDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/CloudAiPlatformCommonCreatePipelineJobApiErrorDetail.php',
    'Google\\Service\\Aiplatform\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleApiHttpBody.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ActiveLearningConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ActiveLearningConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddContextChildrenRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddContextChildrenRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddContextChildrenResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddContextChildrenResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddExecutionEventsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddExecutionEventsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddExecutionEventsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddExecutionEventsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AddTrialMeasurementRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AddTrialMeasurementRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Annotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Annotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AnnotationSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AnnotationSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Artifact' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Artifact.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AssignNotebookRuntimeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AssignNotebookRuntimeOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AssignNotebookRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AssignNotebookRuntimeRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Attribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Attribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AutomaticResources' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AutomaticResources.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AutoscalingMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AutoscalingMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1AvroSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1AvroSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCancelPipelineJobsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCancelPipelineJobsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateFeaturesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateFeaturesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateFeaturesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateFeaturesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateFeaturesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateFeaturesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateTensorboardRunsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateTensorboardRunsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchDedicatedResources' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchDedicatedResources.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchDeletePipelineJobsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchDeletePipelineJobsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchMigrateResourcesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchMigrateResourcesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchMigrateResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchMigrateResourcesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchPredictionJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchPredictionJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchPredictionJobInputConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchPredictionJobInputConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchPredictionJobOutputConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchPredictionJobOutputInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchPredictionJobOutputInfo.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadFeatureValuesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadFeatureValuesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BigQueryDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BigQueryDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BigQuerySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BigQuerySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BleuInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BleuInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BleuInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BleuInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BleuMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BleuMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BleuResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BleuResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BleuSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BleuSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Blob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Blob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BlurBaselineConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BlurBaselineConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1BoolArray' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1BoolArray.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelBatchPredictionJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelBatchPredictionJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelCustomJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelCustomJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelDataLabelingJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelDataLabelingJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelHyperparameterTuningJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelHyperparameterTuningJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelNasJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelNasJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelPipelineJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelPipelineJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelTrainingPipelineRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelTrainingPipelineRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CancelTuningJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CancelTuningJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Candidate' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Candidate.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateMetatdata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateMetatdata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Citation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Citation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CitationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CitationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CoherenceInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CoherenceInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CoherenceInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CoherenceInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CoherenceResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CoherenceResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CoherenceSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CoherenceSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CompleteTrialRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CompleteTrialRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CompletionStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CompletionStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ComputeTokensRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ComputeTokensRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ComputeTokensResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ComputeTokensResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ContainerRegistryDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ContainerRegistryDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ContainerSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ContainerSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Content' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Content.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Context' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Context.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CopyModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CopyModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CopyModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CopyModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CopyModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CopyModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CountTokensRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CountTokensRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CountTokensResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CountTokensResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateDatasetOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateDatasetVersionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateDatasetVersionOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateDeploymentResourcePoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateDeploymentResourcePoolOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateDeploymentResourcePoolRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateDeploymentResourcePoolRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateEndpointOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateEndpointOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateEntityTypeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateEntityTypeOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeatureGroupOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeatureGroupOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeatureOnlineStoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeatureOnlineStoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeatureOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeatureOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeatureRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeatureRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeatureViewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeatureViewOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateFeaturestoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateFeaturestoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateIndexEndpointOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateIndexEndpointOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateIndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateIndexOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateMetadataStoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateMetadataStoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateNotebookExecutionJobOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateNotebookExecutionJobOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateNotebookRuntimeTemplateOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateNotebookRuntimeTemplateOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreatePersistentResourceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreatePersistentResourceOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreatePipelineJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreatePipelineJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateRegistryFeatureOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateRegistryFeatureOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateSpecialistPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateSpecialistPoolOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateTensorboardOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateTensorboardOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateTensorboardRunRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateTensorboardRunRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CreateTensorboardTimeSeriesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CreateTensorboardTimeSeriesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CsvDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CsvDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CsvSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CsvSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CustomJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CustomJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1CustomJobSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1CustomJobSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DataItem' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DataItem.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DataItemView' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DataItemView.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DataLabelingJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DataLabelingJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Dataset' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Dataset.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DatasetDistribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DatasetDistribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DatasetDistributionDistributionBucket' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DatasetDistributionDistributionBucket.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DatasetStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DatasetStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DatasetVersion' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DatasetVersion.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DedicatedResources' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DedicatedResources.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteMetadataStoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteMetadataStoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeleteOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeleteOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployIndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployIndexOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployIndexRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployIndexRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployIndexResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployIndexResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedIndex' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedIndex.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedIndexAuthConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedIndexAuthConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedIndexAuthConfigAuthProvider' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedIndexAuthConfigAuthProvider.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedIndexRef' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedIndexRef.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedModel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedModel.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeployedModelRef' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeployedModelRef.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DeploymentResourcePool' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DeploymentResourcePool.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DestinationFeatureSetting' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DestinationFeatureSetting.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DirectPredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DirectPredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DirectPredictResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DirectPredictResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DirectRawPredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DirectRawPredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DirectRawPredictResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DirectRawPredictResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DiskSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DiskSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DistillationDataStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DistillationDataStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1DoubleArray' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1DoubleArray.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EncryptionSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Endpoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Endpoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EntityIdSelector' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EntityIdSelector.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EntityType' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EntityType.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EnvVar' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EnvVar.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ErrorAnalysisAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ErrorAnalysisAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EvaluateInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EvaluateInstancesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EvaluateInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EvaluateInstancesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EvaluatedAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EvaluatedAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1EvaluatedAnnotationExplanation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1EvaluatedAnnotationExplanation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Event' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Event.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExactMatchInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExactMatchInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExactMatchInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExactMatchInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExactMatchMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExactMatchMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExactMatchResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExactMatchResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExactMatchSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExactMatchSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Examples' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Examples.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExamplesExampleGcsSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExamplesExampleGcsSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExamplesOverride' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExamplesOverride.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExamplesRestrictionsNamespace' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExamplesRestrictionsNamespace.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Execution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Execution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplainRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplainRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplainResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplainResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Explanation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Explanation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataInputMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataOverride' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataOverride.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationParameters' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationParameters.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExplanationSpecOverride' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExplanationSpecOverride.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportDataConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportDataConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportDataOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportDataRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportDataRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFeatureValuesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFeatureValuesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFilterSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFilterSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportFractionSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportFractionSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportModelRequestOutputConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportModelRequestOutputConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Feature' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Feature.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureGroup' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureGroup.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureGroupBigQuery' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureGroupBigQuery.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureGroupBigQueryTimeSeries' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureGroupBigQueryTimeSeries.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureNoiseSigma' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureNoiseSigma.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureOnlineStore' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureOnlineStore.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureOnlineStoreBigtable' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureOnlineStoreOptimized' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureOnlineStoreOptimized.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureSelector' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureSelector.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureStatsAnomaly' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureStatsAnomaly.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureValueDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureValueDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureValueList' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureValueList.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureValueMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureValueMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureView' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureView.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewBigQuerySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewBigQuerySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewDataKey' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewDataKey.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewDataKeyCompositeKey' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewDataKeyCompositeKey.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewFeatureRegistrySourceFeatureGroup' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewFeatureRegistrySourceFeatureGroup.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewIndexConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewIndexConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewIndexConfigBruteForceConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewIndexConfigBruteForceConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewIndexConfigTreeAHConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewIndexConfigTreeAHConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewSync' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewSync.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewSyncConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewSyncConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewSyncSyncSummary' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewSyncSyncSummary.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeatureViewVertexRagSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeatureViewVertexRagSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Featurestore' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Featurestore.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreMonitoringConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreMonitoringConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FetchFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FetchFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FetchFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FetchFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FetchFeatureValuesResponseFeatureNameValuePairList' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FetchFeatureValuesResponseFeatureNameValuePairList.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FetchFeatureValuesResponseFeatureNameValuePairListFeatureNameValuePair' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FetchFeatureValuesResponseFeatureNameValuePairListFeatureNameValuePair.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FileData' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FileData.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FilterSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FilterSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsRequestQuery' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsRequestQuery.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsRequestQueryRRF' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsRequestQueryRRF.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsResponseNearestNeighbors' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsResponseNearestNeighbors.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FindNeighborsResponseNeighbor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FluencyInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FluencyInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FluencyInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FluencyInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FluencyResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FluencyResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FluencySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FluencySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FractionSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FractionSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FulfillmentInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FulfillmentInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FulfillmentInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FulfillmentInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FulfillmentResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FulfillmentResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FulfillmentSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FulfillmentSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FunctionCall' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FunctionCall.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FunctionCallingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FunctionCallingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FunctionDeclaration' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FunctionDeclaration.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1FunctionResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1FunctionResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GcsDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GcsSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GcsSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerateContentRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerateContentRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerateContentResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerateContentResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerationConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerationConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerationConfigRoutingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerationConfigRoutingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenericOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenericOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GenieSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GenieSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GoogleSearchRetrieval' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GoogleSearchRetrieval.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundednessInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundednessInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundednessInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundednessInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundednessResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundednessResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundednessSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundednessSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingAttribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingAttribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingAttributionWeb' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingAttributionWeb.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingChunk' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingChunk.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingChunkRetrievedContext' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingChunkRetrievedContext.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingChunkWeb' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingChunkWeb.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1GroundingSupport' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1GroundingSupport.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1HyperparameterTuningJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1HyperparameterTuningJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IdMatcher' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IdMatcher.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportDataConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportDataConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportDataOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportDataRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportDataRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ImportModelEvaluationRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ImportModelEvaluationRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Index' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Index.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexDatapoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexDatapoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexDatapointCrowdingTag' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexDatapointCrowdingTag.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexDatapointNumericRestriction' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexDatapointNumericRestriction.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexDatapointRestriction' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexDatapointRestriction.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexDatapointSparseEmbedding' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexEndpoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexEndpoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexPrivateEndpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexPrivateEndpoints.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IndexStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IndexStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1InputDataConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1InputDataConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Int64Array' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Int64Array.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1IntegratedGradientsAttribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1IntegratedGradientsAttribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1LargeModelReference' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1LargeModelReference.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1LineageSubgraph' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1LineageSubgraph.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListAnnotationsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListAnnotationsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListArtifactsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListBatchPredictionJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListBatchPredictionJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListContextsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListContextsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListCustomJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListCustomJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListDataItemsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListDataItemsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListDataLabelingJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListDataLabelingJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListDatasetVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListDatasetVersionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListDatasetsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListDeploymentResourcePoolsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListDeploymentResourcePoolsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListEndpointsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListEntityTypesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListExecutionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeatureGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeatureGroupsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeatureOnlineStoresResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeatureOnlineStoresResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeatureViewSyncsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeatureViewSyncsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeatureViewsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeatureViewsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeaturesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeaturesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListFeaturestoresResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListFeaturestoresResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListIndexEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListIndexEndpointsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListIndexesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListIndexesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListMetadataSchemasResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListMetadataSchemasResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListMetadataStoresResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListMetadataStoresResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListModelEvaluationsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListModelEvaluationsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListModelVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListModelVersionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListModelsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListModelsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListNasJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListNasJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListNasTrialDetailsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListNasTrialDetailsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListNotebookExecutionJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListNotebookExecutionJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListNotebookRuntimesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListNotebookRuntimesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListOptimalTrialsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListOptimalTrialsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListOptimalTrialsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListOptimalTrialsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListPersistentResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListPersistentResourcesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListPipelineJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListPipelineJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListSavedQueriesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListSavedQueriesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListSchedulesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListSchedulesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListSpecialistPoolsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListSpecialistPoolsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListStudiesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListStudiesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTensorboardExperimentsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTensorboardExperimentsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTensorboardRunsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTensorboardRunsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTensorboardsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTensorboardsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTrainingPipelinesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTrainingPipelinesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTrialsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTrialsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ListTuningJobsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ListTuningJobsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1LookupStudyRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1LookupStudyRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MachineSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MachineSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ManualBatchTuningParameters' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ManualBatchTuningParameters.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Measurement' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Measurement.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MeasurementMetric' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MeasurementMetric.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MergeVersionAliasesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MergeVersionAliasesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MetadataSchema' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MetadataSchema.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MetadataStore' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MetadataStore.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MetadataStoreDataplexConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MetadataStoreDataplexConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MetadataStoreMetadataStoreState' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MetadataStoreMetadataStoreState.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResourceAutomlDataset' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResourceAutomlDataset.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResourceAutomlModel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResourceAutomlModel.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResourceDataLabelingDataset' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResourceDataLabelingDataset.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResourceDataLabelingDatasetDataLabelingAnnotatedDataset' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResourceDataLabelingDatasetDataLabelingAnnotatedDataset.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigratableResourceMlEngineModelVersion' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigratableResourceMlEngineModelVersion.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlDatasetConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlDatasetConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlModelConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlModelConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfigMigrateDataLabelingAnnotatedDatasetConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfigMigrateDataLabelingAnnotatedDatasetConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceRequestMigrateMlEngineModelVersionConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceRequestMigrateMlEngineModelVersionConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MigrateResourceResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MigrateResourceResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Model' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Model.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelBaseModelSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelBaseModelSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelContainerSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelContainerSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDataStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDataStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDeploymentMonitoringJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDeploymentMonitoringJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSlice' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSlice.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSliceSlice' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSliceSlice.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecRange' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecRange.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecSliceConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecSliceConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelExplanation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelExplanation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelExportFormat' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelExportFormat.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelGardenSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelGardenSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringAlertConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringAlertConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelOriginalModelInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelOriginalModelInfo.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ModelSourceInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ModelSourceInfo.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MutateDeployedIndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MutateDeployedIndexOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MutateDeployedIndexResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MutateDeployedIndexResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MutateDeployedModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MutateDeployedModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MutateDeployedModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MutateDeployedModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1MutateDeployedModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1MutateDeployedModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobOutput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobOutput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobOutputMultiTrialJobOutput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobOutputMultiTrialJobOutput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecTrainTrialSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecTrainTrialSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasTrial' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasTrial.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NasTrialDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NasTrialDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborQuery' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborQuery.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborQueryEmbedding' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborQueryEmbedding.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborQueryParameters' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborQueryParameters.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborQueryStringFilter' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborQueryStringFilter.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataRecordError' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataRecordError.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighbors' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighbors.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NearestNeighborsNeighbor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NearestNeighborsNeighbor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Neighbor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Neighbor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NetworkSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NetworkSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NfsMount' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NfsMount.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookEucConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookEucConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookExecutionJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookExecutionJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookIdleShutdownConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookIdleShutdownConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookReservationAffinity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookReservationAffinity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookRuntime' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookRuntime.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookRuntimeTemplate' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookRuntimeTemplate.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1NotebookRuntimeTemplateRef' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1NotebookRuntimeTemplateRef.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseMetricInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseMetricInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseMetricInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseMetricInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseMetricResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseMetricResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualitySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualitySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseSummarizationQualityInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseSummarizationQualityInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseSummarizationQualityInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseSummarizationQualityInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseSummarizationQualityResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseSummarizationQualityResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PairwiseSummarizationQualitySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PairwiseSummarizationQualitySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Part' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Part.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PauseModelDeploymentMonitoringJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PauseModelDeploymentMonitoringJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PauseScheduleRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PauseScheduleRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PersistentDiskSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PersistentDiskSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PersistentResource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PersistentResource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineJobDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineJobDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineJobRuntimeConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineJobRuntimeConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineJobRuntimeConfigInputArtifact' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineJobRuntimeConfigInputArtifact.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskDetailArtifactList' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskDetailArtifactList.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskExecutorDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskExecutorDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTaskExecutorDetailCustomJobDetail' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTaskExecutorDetailCustomJobDetail.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PipelineTemplateMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PipelineTemplateMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PointwiseMetricInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PointwiseMetricInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PointwiseMetricInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PointwiseMetricInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PointwiseMetricResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PointwiseMetricResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PointwiseMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PointwiseMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Port' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Port.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PredefinedSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PredefinedSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PredictResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PredictResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PredictSchemata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PredictSchemata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Presets' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Presets.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PrivateEndpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PrivateEndpoints.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PrivateServiceConnectConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PrivateServiceConnectConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Probe' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Probe.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ProbeExecAction' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ProbeExecAction.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PscAutomatedEndpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PscAutomatedEndpoints.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModel.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToAction' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToAction.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionDeploy' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionDeployGke' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionDeployGke.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionDeployVertex' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionDeployVertex.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionOpenFineTuningPipelines' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionOpenFineTuningPipelines.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionOpenNotebooks' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionOpenNotebooks.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelCallToActionViewRestApi' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelCallToActionViewRestApi.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelDocumentation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelDocumentation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PublisherModelResourceReference' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PublisherModelResourceReference.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeArtifactsMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeArtifactsMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeArtifactsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeArtifactsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeArtifactsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeContextsMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeContextsMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeContextsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeContextsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeContextsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeContextsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeExecutionsMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeExecutionsMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeExecutionsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeExecutionsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PurgeExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PurgeExecutionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1PythonPackageSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1PythonPackageSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QueryDeployedModelsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QueryDeployedModelsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringCorrectnessSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringCorrectnessSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringQualityInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringQualityInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringQualityInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringQualityInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringQualityResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringQualityResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringQualitySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringQualitySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringRelevanceInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringRelevanceInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringRelevanceInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringRelevanceInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1QuestionAnsweringRelevanceSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1QuestionAnsweringRelevanceSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RawPredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RawPredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RayLogsSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RayLogsSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RayMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RayMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RaySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RaySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesResponseFeatureDescriptor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesResponseFeatureDescriptor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadFeatureValuesResponseHeader' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadFeatureValuesResponseHeader.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadIndexDatapointsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadIndexDatapointsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadIndexDatapointsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadIndexDatapointsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardSizeResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardSizeResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardUsageResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardUsageResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerMonthUsageData' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerMonthUsageData.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RebootPersistentResourceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RebootPersistentResourceOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RebootPersistentResourceRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RebootPersistentResourceRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReinforcementLearningDataStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReinforcementLearningDataStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RemoveContextChildrenRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RemoveContextChildrenRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RemoveContextChildrenResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RemoveContextChildrenResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RemoveDatapointsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RemoveDatapointsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RemoveDatapointsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RemoveDatapointsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ReservationAffinity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ReservationAffinity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResourcePool' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResourcePool.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResourceRuntime' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResourceRuntime.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResourceRuntimeSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResourceRuntimeSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResourcesConsumed' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResourcesConsumed.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RestoreDatasetVersionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RestoreDatasetVersionOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResumeModelDeploymentMonitoringJobRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResumeModelDeploymentMonitoringJobRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ResumeScheduleRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ResumeScheduleRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Retrieval' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Retrieval.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RougeInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RougeInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RougeInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RougeInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RougeMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RougeMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RougeResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RougeResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1RougeSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1RougeSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetyInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetyInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetyInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetyInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetyRating' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetyRating.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetyResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetyResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetySetting' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetySetting.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SafetySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SafetySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SampleConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SampleConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SampledShapleyAttribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SampledShapleyAttribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SamplingStrategy' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SamplingStrategy.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SamplingStrategyRandomSampleConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SamplingStrategyRandomSampleConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SavedQuery' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SavedQuery.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Scalar' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Scalar.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Schedule' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Schedule.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ScheduleRunResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ScheduleRunResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Scheduling' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Scheduling.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Schema' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Schema.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaAnnotationSpecColor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaAnnotationSpecColor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageBoundingBoxAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageBoundingBoxAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageClassificationAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageDataItem' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageDataItem.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageSegmentationAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageSegmentationAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrixAnnotationSpecRef' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrixAnnotationSpecRef.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsGeneralTextGenerationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsGeneralTextGenerationEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageObjectDetectionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageObjectDetectionEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsQuestionAnsweringEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsQuestionAnsweringEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsRegressionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsRegressionEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsSummarizationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsSummarizationEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextSentimentEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextSentimentEvaluationMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionRecognitionMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionRecognitionMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceImageClassificationPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceImageClassificationPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceImageObjectDetectionPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceImageObjectDetectionPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceImageSegmentationPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceImageSegmentationPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceTextClassificationPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceTextClassificationPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceTextSentimentPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceTextSentimentPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionClassificationPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionClassificationPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTabularClassificationPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTabularClassificationPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTabularRegressionPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTabularRegressionPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTextSentimentPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTextSentimentPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTftFeatureImportance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTftFeatureImportance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionTimeSeriesForecastingPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionTimeSeriesForecastingPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictionResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictionResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaPredictionResultError' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaPredictionResultError.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTablesDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTablesDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTablesDatasetMetadataBigQuerySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTablesDatasetMetadataBigQuerySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTablesDatasetMetadataGcsSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTablesDatasetMetadataGcsSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTablesDatasetMetadataInputConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTablesDatasetMetadataInputConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextClassificationAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextDataItem' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextDataItem.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextExtractionAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextExtractionAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextSegment' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextSegment.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextSentimentAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextSentimentAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTextSentimentSavedQueryMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTextSentimentSavedQueryMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTimeSegment' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTimeSegment.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataBigQuerySource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataBigQuerySource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataGcsSource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataGcsSource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataInputConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataInputConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecasting' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecasting.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsGranularity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsGranularity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassification' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassification.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetection' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetection.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTables' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTables.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassification' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassification.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassificationInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassificationInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtraction' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtraction.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtractionInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtractionInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentiment' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentiment.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognition' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognition.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognitionInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognitionInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassification' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassification.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassificationInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassificationInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTracking' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTracking.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTrackingInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTrackingInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomJobMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomJobMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomTask' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomTask.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningTask' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningTask.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecasting' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecasting.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsGranularity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsGranularity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecasting' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecasting.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputs.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsGranularity' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsGranularity.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationAutoTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationAutoTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationCategoricalTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationCategoricalTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationNumericTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationNumericTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTextTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTextTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTimestampTransformation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTimestampTransformation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVertex' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVertex.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVideoActionRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVideoActionRecognitionAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVideoClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVideoClassificationAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVideoDataItem' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVideoDataItem.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVideoDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVideoDatasetMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVisualInspectionClassificationLabelSavedQueryMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVisualInspectionClassificationLabelSavedQueryMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SchemaVisualInspectionMaskSavedQueryMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SchemaVisualInspectionMaskSavedQueryMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchDataItemsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchDataItemsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchEntryPoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchEntryPoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchFeaturesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchFeaturesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchMigratableResourcesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchMigratableResourcesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchMigratableResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchMigratableResourcesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchNearestEntitiesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchNearestEntitiesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SearchNearestEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SearchNearestEntitiesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Segment' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Segment.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ServiceAccountSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ServiceAccountSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ShieldedVmConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ShieldedVmConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SmoothGradConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SmoothGradConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SpecialistPool' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SpecialistPool.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StartNotebookRuntimeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StartNotebookRuntimeOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StartNotebookRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StartNotebookRuntimeRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StopTrialRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StopTrialRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StratifiedSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StratifiedSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StreamRawPredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StreamRawPredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StreamingPredictRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StreamingPredictRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StreamingPredictResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StreamingPredictResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StreamingReadFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StreamingReadFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StringArray' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StringArray.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StructFieldValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StructFieldValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StructValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StructValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Study' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Study.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecMetricSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecMetricSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudySpecStudyStoppingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1StudyTimeConstraint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1StudyTimeConstraint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SuggestTrialsMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SuggestTrialsMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SuggestTrialsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SuggestTrialsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SuggestTrialsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SuggestTrialsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationHelpfulnessInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationHelpfulnessInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationHelpfulnessInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationHelpfulnessInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationHelpfulnessResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationHelpfulnessResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationHelpfulnessSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationHelpfulnessSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationQualityInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationQualityInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationQualityInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationQualityInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationQualityResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationQualityResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationQualitySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationQualitySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationVerbosityInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationVerbosityInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationVerbosityInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationVerbosityInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationVerbosityResult' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationVerbosityResult.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SummarizationVerbositySpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SummarizationVerbositySpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SupervisedHyperParameters' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SupervisedHyperParameters.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SupervisedTuningDataStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SupervisedTuningDataStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SupervisedTuningSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SupervisedTuningSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SyncFeatureViewRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SyncFeatureViewRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1SyncFeatureViewResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1SyncFeatureViewResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TFRecordDestination' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TFRecordDestination.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Tensor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Tensor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Tensorboard' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Tensorboard.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardBlob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardBlob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardBlobSequence' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardBlobSequence.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardExperiment' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardExperiment.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardRun' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardRun.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardTensor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardTensor.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardTimeSeries' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardTimeSeries.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ThresholdConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ThresholdConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TimeSeriesData' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TimeSeriesData.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TimeSeriesDataPoint' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TimeSeriesDataPoint.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TimestampSplit' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TimestampSplit.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TokensInfo' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TokensInfo.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Tool' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Tool.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolCallValidInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolCallValidInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolCallValidInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolCallValidInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolCallValidMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolCallValidMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolCallValidResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolCallValidResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolCallValidSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolCallValidSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolNameMatchInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolNameMatchInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolNameMatchInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolNameMatchInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolNameMatchMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolNameMatchMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolNameMatchResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolNameMatchResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolNameMatchSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolNameMatchSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKVMatchInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKVMatchInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKVMatchInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKVMatchInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKVMatchMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKVMatchMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKVMatchResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKVMatchResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKVMatchSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKVMatchSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKeyMatchInput' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKeyMatchInput.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKeyMatchInstance' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKeyMatchInstance.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKeyMatchMetricValue' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKeyMatchMetricValue.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKeyMatchResults' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKeyMatchResults.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1ToolParameterKeyMatchSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1ToolParameterKeyMatchSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TrainingConfig' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TrainingConfig.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TrainingPipeline' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TrainingPipeline.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Trial' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Trial.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TrialContext' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TrialContext.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TrialParameter' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TrialParameter.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TunedModel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TunedModel.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TuningDataStats' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TuningDataStats.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1TuningJob' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1TuningJob.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployIndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployIndexOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployIndexRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployIndexRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployIndexResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployIndexResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UndeployModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UndeployModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UnmanagedContainerModel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UnmanagedContainerModel.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateDeploymentResourcePoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateDeploymentResourcePoolOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateExplanationDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateExplanationDatasetOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateExplanationDatasetRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateExplanationDatasetRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateExplanationDatasetResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateExplanationDatasetResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateFeatureGroupOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateFeatureGroupOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateFeatureOnlineStoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateFeatureOnlineStoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateFeatureOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateFeatureOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateFeatureViewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateFeatureViewOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateFeaturestoreOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateFeaturestoreOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateIndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateIndexOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateModelDeploymentMonitoringJobOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateModelDeploymentMonitoringJobOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdatePersistentResourceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdatePersistentResourceOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateSpecialistPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateSpecialistPoolOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpdateTensorboardOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpdateTensorboardOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpgradeNotebookRuntimeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpgradeNotebookRuntimeOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpgradeNotebookRuntimeRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpgradeNotebookRuntimeRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UploadModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UploadModelOperationMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UploadModelRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UploadModelRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UploadModelResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UploadModelResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpsertDatapointsRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpsertDatapointsRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UpsertDatapointsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UpsertDatapointsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1UserActionReference' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1UserActionReference.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1Value' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1Value.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1VertexAISearch' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1VertexAISearch.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1VertexRagStore' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1VertexRagStore.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1VertexRagStoreRagResource' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1VertexRagStoreRagResource.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1VideoMetadata' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1VideoMetadata.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WorkerPoolSpec' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WorkerPoolSpec.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteFeatureValuesPayload' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteFeatureValuesPayload.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteFeatureValuesRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteFeatureValuesRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteFeatureValuesResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteFeatureValuesResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteTensorboardExperimentDataRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteTensorboardExperimentDataRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteTensorboardRunDataRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteTensorboardRunDataRequest.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1WriteTensorboardRunDataResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1WriteTensorboardRunDataResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudAiplatformV1XraiAttribution' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudAiplatformV1XraiAttribution.php',
    'Google\\Service\\Aiplatform\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleCloudLocationLocation.php',
    'Google\\Service\\Aiplatform\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleIamV1Binding.php',
    'Google\\Service\\Aiplatform\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleIamV1Policy.php',
    'Google\\Service\\Aiplatform\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\Aiplatform\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Aiplatform\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleLongrunningOperation.php',
    'Google\\Service\\Aiplatform\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleProtobufEmpty.php',
    'Google\\Service\\Aiplatform\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleRpcStatus.php',
    'Google\\Service\\Aiplatform\\GoogleTypeColor' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleTypeColor.php',
    'Google\\Service\\Aiplatform\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleTypeDate.php',
    'Google\\Service\\Aiplatform\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleTypeExpr.php',
    'Google\\Service\\Aiplatform\\GoogleTypeInterval' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleTypeInterval.php',
    'Google\\Service\\Aiplatform\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Aiplatform/GoogleTypeMoney.php',
    'Google\\Service\\Aiplatform\\IntelligenceCloudAutomlXpsMetricEntry' => $vendorDir . '/google/apiclient-services/src/Aiplatform/IntelligenceCloudAutomlXpsMetricEntry.php',
    'Google\\Service\\Aiplatform\\IntelligenceCloudAutomlXpsMetricEntryLabel' => $vendorDir . '/google/apiclient-services/src/Aiplatform/IntelligenceCloudAutomlXpsMetricEntryLabel.php',
    'Google\\Service\\Aiplatform\\IntelligenceCloudAutomlXpsReportingMetrics' => $vendorDir . '/google/apiclient-services/src/Aiplatform/IntelligenceCloudAutomlXpsReportingMetrics.php',
    'Google\\Service\\Aiplatform\\Resource\\Datasets' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/Datasets.php',
    'Google\\Service\\Aiplatform\\Resource\\DatasetsDatasetVersions' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/DatasetsDatasetVersions.php',
    'Google\\Service\\Aiplatform\\Resource\\Endpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/Endpoints.php',
    'Google\\Service\\Aiplatform\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/Projects.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsBatchPredictionJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsBatchPredictionJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsCustomJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsCustomJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsCustomJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsCustomJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDataLabelingJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDataLabelingJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDataLabelingJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDataLabelingJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasets' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasets.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsAnnotationSpecs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsAnnotationSpecs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsAnnotationSpecsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsAnnotationSpecsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsDataItems' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsDataItems.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsDataItemsAnnotations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsDataItemsAnnotations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsDataItemsAnnotationsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsDataItemsAnnotationsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsDataItemsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsDataItemsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsDatasetVersions' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsDatasetVersions.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsSavedQueries' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsSavedQueries.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDatasetsSavedQueriesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDatasetsSavedQueriesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDeploymentResourcePools' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDeploymentResourcePools.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsDeploymentResourcePoolsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsDeploymentResourcePoolsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsEndpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsEndpoints.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsEndpointsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsEndpointsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureGroups' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureGroups.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureGroupsFeatures' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureGroupsFeatures.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureGroupsFeaturesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureGroupsFeaturesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureGroupsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureGroupsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureOnlineStores' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureOnlineStores.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureOnlineStoresFeatureViews' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureOnlineStoresFeatureViews.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureOnlineStoresFeatureViewsFeatureViewSyncs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureOnlineStoresFeatureViewsFeatureViewSyncs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureOnlineStoresFeatureViewsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureOnlineStoresFeatureViewsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeatureOnlineStoresOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeatureOnlineStoresOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestores' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestores.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestoresEntityTypes' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestoresEntityTypes.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestoresEntityTypesFeatures' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestoresEntityTypesFeatures.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestoresEntityTypesFeaturesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestoresEntityTypesFeaturesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestoresEntityTypesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestoresEntityTypesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsFeaturestoresOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsFeaturestoresOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsHyperparameterTuningJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsHyperparameterTuningJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsHyperparameterTuningJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsHyperparameterTuningJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsIndexEndpoints' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsIndexEndpoints.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsIndexEndpointsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsIndexEndpointsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsIndexes' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsIndexes.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsIndexesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsIndexesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStores' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStores.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresArtifacts' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresArtifacts.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresArtifactsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresArtifactsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresContexts' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresContexts.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresContextsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresContextsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresExecutions' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresExecutions.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresExecutionsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresExecutionsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresMetadataSchemas' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresMetadataSchemas.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMetadataStoresOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMetadataStoresOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMigratableResources' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMigratableResources.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsMigratableResourcesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsMigratableResourcesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelDeploymentMonitoringJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelDeploymentMonitoringJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelDeploymentMonitoringJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelDeploymentMonitoringJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModels' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModels.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelsEvaluations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelsEvaluations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelsEvaluationsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelsEvaluationsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelsEvaluationsSlices' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelsEvaluationsSlices.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsModelsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsModelsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNasJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNasJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNasJobsNasTrialDetails' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNasJobsNasTrialDetails.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookExecutionJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookExecutionJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookExecutionJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookExecutionJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookRuntimeTemplates' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookRuntimeTemplates.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookRuntimeTemplatesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookRuntimeTemplatesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookRuntimes' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookRuntimes.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsNotebookRuntimesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsNotebookRuntimesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPersistentResources' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPersistentResources.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPersistentResourcesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPersistentResourcesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPipelineJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPipelineJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPipelineJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPipelineJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPublishers' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPublishers.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsPublishersModels' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsPublishersModels.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsSchedules' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsSchedules.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsSchedulesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsSchedulesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsSpecialistPools' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsSpecialistPools.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsSpecialistPoolsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsSpecialistPoolsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsStudies' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsStudies.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsStudiesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsStudiesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsStudiesTrials' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsStudiesTrials.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsStudiesTrialsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsStudiesTrialsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboards' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboards.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperiments' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperiments.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperimentsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperimentsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperimentsRuns' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperimentsRuns.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperimentsRunsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperimentsRunsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperimentsRunsTimeSeries' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperimentsRunsTimeSeries.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsExperimentsRunsTimeSeriesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsExperimentsRunsTimeSeriesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTensorboardsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTensorboardsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTrainingPipelines' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTrainingPipelines.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTrainingPipelinesOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTrainingPipelinesOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTuningJobs' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTuningJobs.php',
    'Google\\Service\\Aiplatform\\Resource\\ProjectsLocationsTuningJobsOperations' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/ProjectsLocationsTuningJobsOperations.php',
    'Google\\Service\\Aiplatform\\Resource\\Publishers' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/Publishers.php',
    'Google\\Service\\Aiplatform\\Resource\\PublishersModels' => $vendorDir . '/google/apiclient-services/src/Aiplatform/Resource/PublishersModels.php',
    'Google\\Service\\AirQuality' => $vendorDir . '/google/apiclient-services/src/AirQuality.php',
    'Google\\Service\\AirQuality\\AdditionalInfo' => $vendorDir . '/google/apiclient-services/src/AirQuality/AdditionalInfo.php',
    'Google\\Service\\AirQuality\\AirQualityIndex' => $vendorDir . '/google/apiclient-services/src/AirQuality/AirQualityIndex.php',
    'Google\\Service\\AirQuality\\Color' => $vendorDir . '/google/apiclient-services/src/AirQuality/Color.php',
    'Google\\Service\\AirQuality\\Concentration' => $vendorDir . '/google/apiclient-services/src/AirQuality/Concentration.php',
    'Google\\Service\\AirQuality\\CustomLocalAqi' => $vendorDir . '/google/apiclient-services/src/AirQuality/CustomLocalAqi.php',
    'Google\\Service\\AirQuality\\HealthRecommendations' => $vendorDir . '/google/apiclient-services/src/AirQuality/HealthRecommendations.php',
    'Google\\Service\\AirQuality\\HourInfo' => $vendorDir . '/google/apiclient-services/src/AirQuality/HourInfo.php',
    'Google\\Service\\AirQuality\\HourlyForecast' => $vendorDir . '/google/apiclient-services/src/AirQuality/HourlyForecast.php',
    'Google\\Service\\AirQuality\\HttpBody' => $vendorDir . '/google/apiclient-services/src/AirQuality/HttpBody.php',
    'Google\\Service\\AirQuality\\Interval' => $vendorDir . '/google/apiclient-services/src/AirQuality/Interval.php',
    'Google\\Service\\AirQuality\\LatLng' => $vendorDir . '/google/apiclient-services/src/AirQuality/LatLng.php',
    'Google\\Service\\AirQuality\\LookupCurrentConditionsRequest' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupCurrentConditionsRequest.php',
    'Google\\Service\\AirQuality\\LookupCurrentConditionsResponse' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupCurrentConditionsResponse.php',
    'Google\\Service\\AirQuality\\LookupForecastRequest' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupForecastRequest.php',
    'Google\\Service\\AirQuality\\LookupForecastResponse' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupForecastResponse.php',
    'Google\\Service\\AirQuality\\LookupHistoryRequest' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupHistoryRequest.php',
    'Google\\Service\\AirQuality\\LookupHistoryResponse' => $vendorDir . '/google/apiclient-services/src/AirQuality/LookupHistoryResponse.php',
    'Google\\Service\\AirQuality\\Pollutant' => $vendorDir . '/google/apiclient-services/src/AirQuality/Pollutant.php',
    'Google\\Service\\AirQuality\\Resource\\CurrentConditions' => $vendorDir . '/google/apiclient-services/src/AirQuality/Resource/CurrentConditions.php',
    'Google\\Service\\AirQuality\\Resource\\Forecast' => $vendorDir . '/google/apiclient-services/src/AirQuality/Resource/Forecast.php',
    'Google\\Service\\AirQuality\\Resource\\History' => $vendorDir . '/google/apiclient-services/src/AirQuality/Resource/History.php',
    'Google\\Service\\AirQuality\\Resource\\MapTypes' => $vendorDir . '/google/apiclient-services/src/AirQuality/Resource/MapTypes.php',
    'Google\\Service\\AirQuality\\Resource\\MapTypesHeatmapTiles' => $vendorDir . '/google/apiclient-services/src/AirQuality/Resource/MapTypesHeatmapTiles.php',
    'Google\\Service\\AlertCenter' => $vendorDir . '/google/apiclient-services/src/AlertCenter.php',
    'Google\\Service\\AlertCenter\\AbuseDetected' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AbuseDetected.php',
    'Google\\Service\\AlertCenter\\AccessApproval' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AccessApproval.php',
    'Google\\Service\\AlertCenter\\AccountSuspensionDetails' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AccountSuspensionDetails.php',
    'Google\\Service\\AlertCenter\\AccountSuspensionWarning' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AccountSuspensionWarning.php',
    'Google\\Service\\AlertCenter\\AccountWarning' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AccountWarning.php',
    'Google\\Service\\AlertCenter\\ActionInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ActionInfo.php',
    'Google\\Service\\AlertCenter\\ActivityRule' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ActivityRule.php',
    'Google\\Service\\AlertCenter\\Alert' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Alert.php',
    'Google\\Service\\AlertCenter\\AlertFeedback' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AlertFeedback.php',
    'Google\\Service\\AlertCenter\\AlertMetadata' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AlertMetadata.php',
    'Google\\Service\\AlertCenter\\AlertcenterEmpty' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AlertcenterEmpty.php',
    'Google\\Service\\AlertCenter\\ApnsCertificateExpirationInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ApnsCertificateExpirationInfo.php',
    'Google\\Service\\AlertCenter\\AppMakerSqlSetupNotification' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AppMakerSqlSetupNotification.php',
    'Google\\Service\\AlertCenter\\AppSettingsChanged' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AppSettingsChanged.php',
    'Google\\Service\\AlertCenter\\AppsOutage' => $vendorDir . '/google/apiclient-services/src/AlertCenter/AppsOutage.php',
    'Google\\Service\\AlertCenter\\Attachment' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Attachment.php',
    'Google\\Service\\AlertCenter\\BadWhitelist' => $vendorDir . '/google/apiclient-services/src/AlertCenter/BadWhitelist.php',
    'Google\\Service\\AlertCenter\\BatchDeleteAlertsRequest' => $vendorDir . '/google/apiclient-services/src/AlertCenter/BatchDeleteAlertsRequest.php',
    'Google\\Service\\AlertCenter\\BatchDeleteAlertsResponse' => $vendorDir . '/google/apiclient-services/src/AlertCenter/BatchDeleteAlertsResponse.php',
    'Google\\Service\\AlertCenter\\BatchUndeleteAlertsRequest' => $vendorDir . '/google/apiclient-services/src/AlertCenter/BatchUndeleteAlertsRequest.php',
    'Google\\Service\\AlertCenter\\BatchUndeleteAlertsResponse' => $vendorDir . '/google/apiclient-services/src/AlertCenter/BatchUndeleteAlertsResponse.php',
    'Google\\Service\\AlertCenter\\CloudPubsubTopic' => $vendorDir . '/google/apiclient-services/src/AlertCenter/CloudPubsubTopic.php',
    'Google\\Service\\AlertCenter\\Csv' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Csv.php',
    'Google\\Service\\AlertCenter\\CsvRow' => $vendorDir . '/google/apiclient-services/src/AlertCenter/CsvRow.php',
    'Google\\Service\\AlertCenter\\DeviceCompromised' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DeviceCompromised.php',
    'Google\\Service\\AlertCenter\\DeviceCompromisedSecurityDetail' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DeviceCompromisedSecurityDetail.php',
    'Google\\Service\\AlertCenter\\DeviceManagementRule' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DeviceManagementRule.php',
    'Google\\Service\\AlertCenter\\DlpRuleViolation' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DlpRuleViolation.php',
    'Google\\Service\\AlertCenter\\DomainId' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DomainId.php',
    'Google\\Service\\AlertCenter\\DomainWideTakeoutInitiated' => $vendorDir . '/google/apiclient-services/src/AlertCenter/DomainWideTakeoutInitiated.php',
    'Google\\Service\\AlertCenter\\Entity' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Entity.php',
    'Google\\Service\\AlertCenter\\EntityList' => $vendorDir . '/google/apiclient-services/src/AlertCenter/EntityList.php',
    'Google\\Service\\AlertCenter\\GmailMessageInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/GmailMessageInfo.php',
    'Google\\Service\\AlertCenter\\GoogleOperations' => $vendorDir . '/google/apiclient-services/src/AlertCenter/GoogleOperations.php',
    'Google\\Service\\AlertCenter\\ListAlertFeedbackResponse' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ListAlertFeedbackResponse.php',
    'Google\\Service\\AlertCenter\\ListAlertsResponse' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ListAlertsResponse.php',
    'Google\\Service\\AlertCenter\\LoginDetails' => $vendorDir . '/google/apiclient-services/src/AlertCenter/LoginDetails.php',
    'Google\\Service\\AlertCenter\\MailPhishing' => $vendorDir . '/google/apiclient-services/src/AlertCenter/MailPhishing.php',
    'Google\\Service\\AlertCenter\\MaliciousEntity' => $vendorDir . '/google/apiclient-services/src/AlertCenter/MaliciousEntity.php',
    'Google\\Service\\AlertCenter\\MandatoryServiceAnnouncement' => $vendorDir . '/google/apiclient-services/src/AlertCenter/MandatoryServiceAnnouncement.php',
    'Google\\Service\\AlertCenter\\MatchInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/MatchInfo.php',
    'Google\\Service\\AlertCenter\\MergeInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/MergeInfo.php',
    'Google\\Service\\AlertCenter\\Notification' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Notification.php',
    'Google\\Service\\AlertCenter\\OutOfDomainForwarding' => $vendorDir . '/google/apiclient-services/src/AlertCenter/OutOfDomainForwarding.php',
    'Google\\Service\\AlertCenter\\PhishingSpike' => $vendorDir . '/google/apiclient-services/src/AlertCenter/PhishingSpike.php',
    'Google\\Service\\AlertCenter\\PredefinedDetectorInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/PredefinedDetectorInfo.php',
    'Google\\Service\\AlertCenter\\PrimaryAdminChangedEvent' => $vendorDir . '/google/apiclient-services/src/AlertCenter/PrimaryAdminChangedEvent.php',
    'Google\\Service\\AlertCenter\\ReportingRule' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ReportingRule.php',
    'Google\\Service\\AlertCenter\\RequestInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/RequestInfo.php',
    'Google\\Service\\AlertCenter\\ResourceInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/ResourceInfo.php',
    'Google\\Service\\AlertCenter\\Resource\\Alerts' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Resource/Alerts.php',
    'Google\\Service\\AlertCenter\\Resource\\AlertsFeedback' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Resource/AlertsFeedback.php',
    'Google\\Service\\AlertCenter\\Resource\\V1beta1' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Resource/V1beta1.php',
    'Google\\Service\\AlertCenter\\RuleInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/RuleInfo.php',
    'Google\\Service\\AlertCenter\\RuleViolationInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/RuleViolationInfo.php',
    'Google\\Service\\AlertCenter\\SSOProfileCreatedEvent' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SSOProfileCreatedEvent.php',
    'Google\\Service\\AlertCenter\\SSOProfileDeletedEvent' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SSOProfileDeletedEvent.php',
    'Google\\Service\\AlertCenter\\SSOProfileUpdatedEvent' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SSOProfileUpdatedEvent.php',
    'Google\\Service\\AlertCenter\\SensitiveAdminAction' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SensitiveAdminAction.php',
    'Google\\Service\\AlertCenter\\Settings' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Settings.php',
    'Google\\Service\\AlertCenter\\StateSponsoredAttack' => $vendorDir . '/google/apiclient-services/src/AlertCenter/StateSponsoredAttack.php',
    'Google\\Service\\AlertCenter\\Status' => $vendorDir . '/google/apiclient-services/src/AlertCenter/Status.php',
    'Google\\Service\\AlertCenter\\SuperAdminPasswordResetEvent' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SuperAdminPasswordResetEvent.php',
    'Google\\Service\\AlertCenter\\SupportTicket' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SupportTicket.php',
    'Google\\Service\\AlertCenter\\SuspiciousActivity' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SuspiciousActivity.php',
    'Google\\Service\\AlertCenter\\SuspiciousActivitySecurityDetail' => $vendorDir . '/google/apiclient-services/src/AlertCenter/SuspiciousActivitySecurityDetail.php',
    'Google\\Service\\AlertCenter\\TransferError' => $vendorDir . '/google/apiclient-services/src/AlertCenter/TransferError.php',
    'Google\\Service\\AlertCenter\\TransferMisconfiguration' => $vendorDir . '/google/apiclient-services/src/AlertCenter/TransferMisconfiguration.php',
    'Google\\Service\\AlertCenter\\UndeleteAlertRequest' => $vendorDir . '/google/apiclient-services/src/AlertCenter/UndeleteAlertRequest.php',
    'Google\\Service\\AlertCenter\\User' => $vendorDir . '/google/apiclient-services/src/AlertCenter/User.php',
    'Google\\Service\\AlertCenter\\UserChanges' => $vendorDir . '/google/apiclient-services/src/AlertCenter/UserChanges.php',
    'Google\\Service\\AlertCenter\\UserDefinedDetectorInfo' => $vendorDir . '/google/apiclient-services/src/AlertCenter/UserDefinedDetectorInfo.php',
    'Google\\Service\\AlertCenter\\VoiceMisconfiguration' => $vendorDir . '/google/apiclient-services/src/AlertCenter/VoiceMisconfiguration.php',
    'Google\\Service\\AlertCenter\\VoicemailMisconfiguration' => $vendorDir . '/google/apiclient-services/src/AlertCenter/VoicemailMisconfiguration.php',
    'Google\\Service\\AlertCenter\\VoicemailRecipientError' => $vendorDir . '/google/apiclient-services/src/AlertCenter/VoicemailRecipientError.php',
    'Google\\Service\\Analytics' => $vendorDir . '/google/apiclient-services/src/Analytics.php',
    'Google\\Service\\AnalyticsData' => $vendorDir . '/google/apiclient-services/src/AnalyticsData.php',
    'Google\\Service\\AnalyticsData\\ActiveMetricRestriction' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/ActiveMetricRestriction.php',
    'Google\\Service\\AnalyticsData\\AudienceExport' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/AudienceExport.php',
    'Google\\Service\\AnalyticsData\\AudienceListMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/AudienceListMetadata.php',
    'Google\\Service\\AnalyticsData\\BatchRunPivotReportsRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/BatchRunPivotReportsRequest.php',
    'Google\\Service\\AnalyticsData\\BatchRunPivotReportsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/BatchRunPivotReportsResponse.php',
    'Google\\Service\\AnalyticsData\\BatchRunReportsRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/BatchRunReportsRequest.php',
    'Google\\Service\\AnalyticsData\\BatchRunReportsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/BatchRunReportsResponse.php',
    'Google\\Service\\AnalyticsData\\BetweenFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/BetweenFilter.php',
    'Google\\Service\\AnalyticsData\\CaseExpression' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CaseExpression.php',
    'Google\\Service\\AnalyticsData\\CheckCompatibilityRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CheckCompatibilityRequest.php',
    'Google\\Service\\AnalyticsData\\CheckCompatibilityResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CheckCompatibilityResponse.php',
    'Google\\Service\\AnalyticsData\\Cohort' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Cohort.php',
    'Google\\Service\\AnalyticsData\\CohortReportSettings' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CohortReportSettings.php',
    'Google\\Service\\AnalyticsData\\CohortSpec' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CohortSpec.php',
    'Google\\Service\\AnalyticsData\\CohortsRange' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/CohortsRange.php',
    'Google\\Service\\AnalyticsData\\Comparison' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Comparison.php',
    'Google\\Service\\AnalyticsData\\ComparisonMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/ComparisonMetadata.php',
    'Google\\Service\\AnalyticsData\\ConcatenateExpression' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/ConcatenateExpression.php',
    'Google\\Service\\AnalyticsData\\DateRange' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DateRange.php',
    'Google\\Service\\AnalyticsData\\Dimension' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Dimension.php',
    'Google\\Service\\AnalyticsData\\DimensionCompatibility' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionCompatibility.php',
    'Google\\Service\\AnalyticsData\\DimensionExpression' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionExpression.php',
    'Google\\Service\\AnalyticsData\\DimensionHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionHeader.php',
    'Google\\Service\\AnalyticsData\\DimensionMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionMetadata.php',
    'Google\\Service\\AnalyticsData\\DimensionOrderBy' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionOrderBy.php',
    'Google\\Service\\AnalyticsData\\DimensionValue' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/DimensionValue.php',
    'Google\\Service\\AnalyticsData\\Filter' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Filter.php',
    'Google\\Service\\AnalyticsData\\FilterExpression' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/FilterExpression.php',
    'Google\\Service\\AnalyticsData\\FilterExpressionList' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/FilterExpressionList.php',
    'Google\\Service\\AnalyticsData\\InListFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/InListFilter.php',
    'Google\\Service\\AnalyticsData\\ListAudienceExportsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/ListAudienceExportsResponse.php',
    'Google\\Service\\AnalyticsData\\Metadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Metadata.php',
    'Google\\Service\\AnalyticsData\\Metric' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Metric.php',
    'Google\\Service\\AnalyticsData\\MetricCompatibility' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MetricCompatibility.php',
    'Google\\Service\\AnalyticsData\\MetricHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MetricHeader.php',
    'Google\\Service\\AnalyticsData\\MetricMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MetricMetadata.php',
    'Google\\Service\\AnalyticsData\\MetricOrderBy' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MetricOrderBy.php',
    'Google\\Service\\AnalyticsData\\MetricValue' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MetricValue.php',
    'Google\\Service\\AnalyticsData\\MinuteRange' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/MinuteRange.php',
    'Google\\Service\\AnalyticsData\\NumericFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/NumericFilter.php',
    'Google\\Service\\AnalyticsData\\NumericValue' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/NumericValue.php',
    'Google\\Service\\AnalyticsData\\Operation' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Operation.php',
    'Google\\Service\\AnalyticsData\\OrderBy' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/OrderBy.php',
    'Google\\Service\\AnalyticsData\\Pivot' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Pivot.php',
    'Google\\Service\\AnalyticsData\\PivotDimensionHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/PivotDimensionHeader.php',
    'Google\\Service\\AnalyticsData\\PivotHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/PivotHeader.php',
    'Google\\Service\\AnalyticsData\\PivotOrderBy' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/PivotOrderBy.php',
    'Google\\Service\\AnalyticsData\\PivotSelection' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/PivotSelection.php',
    'Google\\Service\\AnalyticsData\\PropertyQuota' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/PropertyQuota.php',
    'Google\\Service\\AnalyticsData\\QueryAudienceExportRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/QueryAudienceExportRequest.php',
    'Google\\Service\\AnalyticsData\\QueryAudienceExportResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/QueryAudienceExportResponse.php',
    'Google\\Service\\AnalyticsData\\QuotaStatus' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/QuotaStatus.php',
    'Google\\Service\\AnalyticsData\\Resource\\Properties' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Resource/Properties.php',
    'Google\\Service\\AnalyticsData\\Resource\\PropertiesAudienceExports' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Resource/PropertiesAudienceExports.php',
    'Google\\Service\\AnalyticsData\\ResponseMetaData' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/ResponseMetaData.php',
    'Google\\Service\\AnalyticsData\\Row' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Row.php',
    'Google\\Service\\AnalyticsData\\RunPivotReportRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunPivotReportRequest.php',
    'Google\\Service\\AnalyticsData\\RunPivotReportResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunPivotReportResponse.php',
    'Google\\Service\\AnalyticsData\\RunRealtimeReportRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunRealtimeReportRequest.php',
    'Google\\Service\\AnalyticsData\\RunRealtimeReportResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunRealtimeReportResponse.php',
    'Google\\Service\\AnalyticsData\\RunReportRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunReportRequest.php',
    'Google\\Service\\AnalyticsData\\RunReportResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/RunReportResponse.php',
    'Google\\Service\\AnalyticsData\\SamplingMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/SamplingMetadata.php',
    'Google\\Service\\AnalyticsData\\SchemaRestrictionResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/SchemaRestrictionResponse.php',
    'Google\\Service\\AnalyticsData\\Status' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/Status.php',
    'Google\\Service\\AnalyticsData\\StringFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/StringFilter.php',
    'Google\\Service\\AnalyticsData\\V1betaAudienceDimension' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/V1betaAudienceDimension.php',
    'Google\\Service\\AnalyticsData\\V1betaAudienceDimensionValue' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/V1betaAudienceDimensionValue.php',
    'Google\\Service\\AnalyticsData\\V1betaAudienceRow' => $vendorDir . '/google/apiclient-services/src/AnalyticsData/V1betaAudienceRow.php',
    'Google\\Service\\AnalyticsHub' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub.php',
    'Google\\Service\\AnalyticsHub\\AnalyticsHubSubscriptionInfo' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/AnalyticsHubSubscriptionInfo.php',
    'Google\\Service\\AnalyticsHub\\AnalyticshubEmpty' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/AnalyticshubEmpty.php',
    'Google\\Service\\AnalyticsHub\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/AuditConfig.php',
    'Google\\Service\\AnalyticsHub\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/AuditLogConfig.php',
    'Google\\Service\\AnalyticsHub\\AvroConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/AvroConfig.php',
    'Google\\Service\\AnalyticsHub\\BigQueryConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/BigQueryConfig.php',
    'Google\\Service\\AnalyticsHub\\BigQueryDatasetSource' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/BigQueryDatasetSource.php',
    'Google\\Service\\AnalyticsHub\\Binding' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Binding.php',
    'Google\\Service\\AnalyticsHub\\CloudStorageConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/CloudStorageConfig.php',
    'Google\\Service\\AnalyticsHub\\DataExchange' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DataExchange.php',
    'Google\\Service\\AnalyticsHub\\DataProvider' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DataProvider.php',
    'Google\\Service\\AnalyticsHub\\DcrExchangeConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DcrExchangeConfig.php',
    'Google\\Service\\AnalyticsHub\\DeadLetterPolicy' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DeadLetterPolicy.php',
    'Google\\Service\\AnalyticsHub\\DefaultExchangeConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DefaultExchangeConfig.php',
    'Google\\Service\\AnalyticsHub\\DestinationDataset' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DestinationDataset.php',
    'Google\\Service\\AnalyticsHub\\DestinationDatasetReference' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DestinationDatasetReference.php',
    'Google\\Service\\AnalyticsHub\\DestinationPubSubSubscription' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/DestinationPubSubSubscription.php',
    'Google\\Service\\AnalyticsHub\\ExpirationPolicy' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ExpirationPolicy.php',
    'Google\\Service\\AnalyticsHub\\Expr' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Expr.php',
    'Google\\Service\\AnalyticsHub\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/GetIamPolicyRequest.php',
    'Google\\Service\\AnalyticsHub\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/GetPolicyOptions.php',
    'Google\\Service\\AnalyticsHub\\GooglePubsubV1Subscription' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/GooglePubsubV1Subscription.php',
    'Google\\Service\\AnalyticsHub\\LinkedResource' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/LinkedResource.php',
    'Google\\Service\\AnalyticsHub\\ListDataExchangesResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListDataExchangesResponse.php',
    'Google\\Service\\AnalyticsHub\\ListListingsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListListingsResponse.php',
    'Google\\Service\\AnalyticsHub\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListLocationsResponse.php',
    'Google\\Service\\AnalyticsHub\\ListOrgDataExchangesResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListOrgDataExchangesResponse.php',
    'Google\\Service\\AnalyticsHub\\ListSharedResourceSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListSharedResourceSubscriptionsResponse.php',
    'Google\\Service\\AnalyticsHub\\ListSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/ListSubscriptionsResponse.php',
    'Google\\Service\\AnalyticsHub\\Listing' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Listing.php',
    'Google\\Service\\AnalyticsHub\\Location' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Location.php',
    'Google\\Service\\AnalyticsHub\\NoWrapper' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/NoWrapper.php',
    'Google\\Service\\AnalyticsHub\\OidcToken' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/OidcToken.php',
    'Google\\Service\\AnalyticsHub\\Operation' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Operation.php',
    'Google\\Service\\AnalyticsHub\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/OperationMetadata.php',
    'Google\\Service\\AnalyticsHub\\Policy' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Policy.php',
    'Google\\Service\\AnalyticsHub\\PubSubTopicSource' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/PubSubTopicSource.php',
    'Google\\Service\\AnalyticsHub\\Publisher' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Publisher.php',
    'Google\\Service\\AnalyticsHub\\PubsubWrapper' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/PubsubWrapper.php',
    'Google\\Service\\AnalyticsHub\\PushConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/PushConfig.php',
    'Google\\Service\\AnalyticsHub\\RefreshSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RefreshSubscriptionRequest.php',
    'Google\\Service\\AnalyticsHub\\RefreshSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RefreshSubscriptionResponse.php',
    'Google\\Service\\AnalyticsHub\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/Organizations.php',
    'Google\\Service\\AnalyticsHub\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/OrganizationsLocations.php',
    'Google\\Service\\AnalyticsHub\\Resource\\OrganizationsLocationsDataExchanges' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/OrganizationsLocationsDataExchanges.php',
    'Google\\Service\\AnalyticsHub\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/Projects.php',
    'Google\\Service\\AnalyticsHub\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/ProjectsLocations.php',
    'Google\\Service\\AnalyticsHub\\Resource\\ProjectsLocationsDataExchanges' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/ProjectsLocationsDataExchanges.php',
    'Google\\Service\\AnalyticsHub\\Resource\\ProjectsLocationsDataExchangesListings' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/ProjectsLocationsDataExchangesListings.php',
    'Google\\Service\\AnalyticsHub\\Resource\\ProjectsLocationsSubscriptions' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Resource/ProjectsLocationsSubscriptions.php',
    'Google\\Service\\AnalyticsHub\\RestrictedExportConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RestrictedExportConfig.php',
    'Google\\Service\\AnalyticsHub\\RestrictedExportPolicy' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RestrictedExportPolicy.php',
    'Google\\Service\\AnalyticsHub\\RetryPolicy' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RetryPolicy.php',
    'Google\\Service\\AnalyticsHub\\RevokeSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RevokeSubscriptionRequest.php',
    'Google\\Service\\AnalyticsHub\\RevokeSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/RevokeSubscriptionResponse.php',
    'Google\\Service\\AnalyticsHub\\SelectedResource' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SelectedResource.php',
    'Google\\Service\\AnalyticsHub\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SetIamPolicyRequest.php',
    'Google\\Service\\AnalyticsHub\\SharingEnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SharingEnvironmentConfig.php',
    'Google\\Service\\AnalyticsHub\\Status' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Status.php',
    'Google\\Service\\AnalyticsHub\\SubscribeDataExchangeRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SubscribeDataExchangeRequest.php',
    'Google\\Service\\AnalyticsHub\\SubscribeDataExchangeResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SubscribeDataExchangeResponse.php',
    'Google\\Service\\AnalyticsHub\\SubscribeListingRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SubscribeListingRequest.php',
    'Google\\Service\\AnalyticsHub\\SubscribeListingResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/SubscribeListingResponse.php',
    'Google\\Service\\AnalyticsHub\\Subscription' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/Subscription.php',
    'Google\\Service\\AnalyticsHub\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/TestIamPermissionsRequest.php',
    'Google\\Service\\AnalyticsHub\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/TestIamPermissionsResponse.php',
    'Google\\Service\\AnalyticsHub\\TextConfig' => $vendorDir . '/google/apiclient-services/src/AnalyticsHub/TextConfig.php',
    'Google\\Service\\AnalyticsReporting' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting.php',
    'Google\\Service\\AnalyticsReporting\\Activity' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Activity.php',
    'Google\\Service\\AnalyticsReporting\\Cohort' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Cohort.php',
    'Google\\Service\\AnalyticsReporting\\CohortGroup' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/CohortGroup.php',
    'Google\\Service\\AnalyticsReporting\\ColumnHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ColumnHeader.php',
    'Google\\Service\\AnalyticsReporting\\CustomDimension' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/CustomDimension.php',
    'Google\\Service\\AnalyticsReporting\\DateRange' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/DateRange.php',
    'Google\\Service\\AnalyticsReporting\\DateRangeValues' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/DateRangeValues.php',
    'Google\\Service\\AnalyticsReporting\\Dimension' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Dimension.php',
    'Google\\Service\\AnalyticsReporting\\DimensionFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/DimensionFilter.php',
    'Google\\Service\\AnalyticsReporting\\DimensionFilterClause' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/DimensionFilterClause.php',
    'Google\\Service\\AnalyticsReporting\\DynamicSegment' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/DynamicSegment.php',
    'Google\\Service\\AnalyticsReporting\\EcommerceData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/EcommerceData.php',
    'Google\\Service\\AnalyticsReporting\\EventData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/EventData.php',
    'Google\\Service\\AnalyticsReporting\\GetReportsRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/GetReportsRequest.php',
    'Google\\Service\\AnalyticsReporting\\GetReportsResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/GetReportsResponse.php',
    'Google\\Service\\AnalyticsReporting\\GoalData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/GoalData.php',
    'Google\\Service\\AnalyticsReporting\\GoalSetData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/GoalSetData.php',
    'Google\\Service\\AnalyticsReporting\\Metric' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Metric.php',
    'Google\\Service\\AnalyticsReporting\\MetricFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/MetricFilter.php',
    'Google\\Service\\AnalyticsReporting\\MetricFilterClause' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/MetricFilterClause.php',
    'Google\\Service\\AnalyticsReporting\\MetricHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/MetricHeader.php',
    'Google\\Service\\AnalyticsReporting\\MetricHeaderEntry' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/MetricHeaderEntry.php',
    'Google\\Service\\AnalyticsReporting\\OrFiltersForSegment' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/OrFiltersForSegment.php',
    'Google\\Service\\AnalyticsReporting\\OrderBy' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/OrderBy.php',
    'Google\\Service\\AnalyticsReporting\\PageviewData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/PageviewData.php',
    'Google\\Service\\AnalyticsReporting\\Pivot' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Pivot.php',
    'Google\\Service\\AnalyticsReporting\\PivotHeader' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/PivotHeader.php',
    'Google\\Service\\AnalyticsReporting\\PivotHeaderEntry' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/PivotHeaderEntry.php',
    'Google\\Service\\AnalyticsReporting\\PivotValueRegion' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/PivotValueRegion.php',
    'Google\\Service\\AnalyticsReporting\\ProductData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ProductData.php',
    'Google\\Service\\AnalyticsReporting\\Report' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Report.php',
    'Google\\Service\\AnalyticsReporting\\ReportData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ReportData.php',
    'Google\\Service\\AnalyticsReporting\\ReportRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ReportRequest.php',
    'Google\\Service\\AnalyticsReporting\\ReportRow' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ReportRow.php',
    'Google\\Service\\AnalyticsReporting\\ResourceQuotasRemaining' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ResourceQuotasRemaining.php',
    'Google\\Service\\AnalyticsReporting\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Resource/Reports.php',
    'Google\\Service\\AnalyticsReporting\\Resource\\UserActivity' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Resource/UserActivity.php',
    'Google\\Service\\AnalyticsReporting\\ScreenviewData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/ScreenviewData.php',
    'Google\\Service\\AnalyticsReporting\\SearchUserActivityRequest' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SearchUserActivityRequest.php',
    'Google\\Service\\AnalyticsReporting\\SearchUserActivityResponse' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SearchUserActivityResponse.php',
    'Google\\Service\\AnalyticsReporting\\Segment' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/Segment.php',
    'Google\\Service\\AnalyticsReporting\\SegmentDefinition' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentDefinition.php',
    'Google\\Service\\AnalyticsReporting\\SegmentDimensionFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentDimensionFilter.php',
    'Google\\Service\\AnalyticsReporting\\SegmentFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentFilter.php',
    'Google\\Service\\AnalyticsReporting\\SegmentFilterClause' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentFilterClause.php',
    'Google\\Service\\AnalyticsReporting\\SegmentMetricFilter' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentMetricFilter.php',
    'Google\\Service\\AnalyticsReporting\\SegmentSequenceStep' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SegmentSequenceStep.php',
    'Google\\Service\\AnalyticsReporting\\SequenceSegment' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SequenceSegment.php',
    'Google\\Service\\AnalyticsReporting\\SimpleSegment' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/SimpleSegment.php',
    'Google\\Service\\AnalyticsReporting\\TransactionData' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/TransactionData.php',
    'Google\\Service\\AnalyticsReporting\\User' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/User.php',
    'Google\\Service\\AnalyticsReporting\\UserActivitySession' => $vendorDir . '/google/apiclient-services/src/AnalyticsReporting/UserActivitySession.php',
    'Google\\Service\\Analytics\\Account' => $vendorDir . '/google/apiclient-services/src/Analytics/Account.php',
    'Google\\Service\\Analytics\\AccountChildLink' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountChildLink.php',
    'Google\\Service\\Analytics\\AccountPermissions' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountPermissions.php',
    'Google\\Service\\Analytics\\AccountRef' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountRef.php',
    'Google\\Service\\Analytics\\AccountSummaries' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountSummaries.php',
    'Google\\Service\\Analytics\\AccountSummary' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountSummary.php',
    'Google\\Service\\Analytics\\AccountTicket' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountTicket.php',
    'Google\\Service\\Analytics\\AccountTreeRequest' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountTreeRequest.php',
    'Google\\Service\\Analytics\\AccountTreeResponse' => $vendorDir . '/google/apiclient-services/src/Analytics/AccountTreeResponse.php',
    'Google\\Service\\Analytics\\Accounts' => $vendorDir . '/google/apiclient-services/src/Analytics/Accounts.php',
    'Google\\Service\\Analytics\\AdWordsAccount' => $vendorDir . '/google/apiclient-services/src/Analytics/AdWordsAccount.php',
    'Google\\Service\\Analytics\\AnalyticsDataimportDeleteUploadDataRequest' => $vendorDir . '/google/apiclient-services/src/Analytics/AnalyticsDataimportDeleteUploadDataRequest.php',
    'Google\\Service\\Analytics\\Column' => $vendorDir . '/google/apiclient-services/src/Analytics/Column.php',
    'Google\\Service\\Analytics\\Columns' => $vendorDir . '/google/apiclient-services/src/Analytics/Columns.php',
    'Google\\Service\\Analytics\\CustomDataSource' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDataSource.php',
    'Google\\Service\\Analytics\\CustomDataSourceChildLink' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDataSourceChildLink.php',
    'Google\\Service\\Analytics\\CustomDataSourceParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDataSourceParentLink.php',
    'Google\\Service\\Analytics\\CustomDataSources' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDataSources.php',
    'Google\\Service\\Analytics\\CustomDimension' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDimension.php',
    'Google\\Service\\Analytics\\CustomDimensionParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDimensionParentLink.php',
    'Google\\Service\\Analytics\\CustomDimensions' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomDimensions.php',
    'Google\\Service\\Analytics\\CustomMetric' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomMetric.php',
    'Google\\Service\\Analytics\\CustomMetricParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomMetricParentLink.php',
    'Google\\Service\\Analytics\\CustomMetrics' => $vendorDir . '/google/apiclient-services/src/Analytics/CustomMetrics.php',
    'Google\\Service\\Analytics\\EntityAdWordsLink' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityAdWordsLink.php',
    'Google\\Service\\Analytics\\EntityAdWordsLinkEntity' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityAdWordsLinkEntity.php',
    'Google\\Service\\Analytics\\EntityAdWordsLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityAdWordsLinks.php',
    'Google\\Service\\Analytics\\EntityUserLink' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityUserLink.php',
    'Google\\Service\\Analytics\\EntityUserLinkEntity' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityUserLinkEntity.php',
    'Google\\Service\\Analytics\\EntityUserLinkPermissions' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityUserLinkPermissions.php',
    'Google\\Service\\Analytics\\EntityUserLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/EntityUserLinks.php',
    'Google\\Service\\Analytics\\Experiment' => $vendorDir . '/google/apiclient-services/src/Analytics/Experiment.php',
    'Google\\Service\\Analytics\\ExperimentParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/ExperimentParentLink.php',
    'Google\\Service\\Analytics\\ExperimentVariations' => $vendorDir . '/google/apiclient-services/src/Analytics/ExperimentVariations.php',
    'Google\\Service\\Analytics\\Experiments' => $vendorDir . '/google/apiclient-services/src/Analytics/Experiments.php',
    'Google\\Service\\Analytics\\Filter' => $vendorDir . '/google/apiclient-services/src/Analytics/Filter.php',
    'Google\\Service\\Analytics\\FilterAdvancedDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterAdvancedDetails.php',
    'Google\\Service\\Analytics\\FilterExpression' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterExpression.php',
    'Google\\Service\\Analytics\\FilterLowercaseDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterLowercaseDetails.php',
    'Google\\Service\\Analytics\\FilterParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterParentLink.php',
    'Google\\Service\\Analytics\\FilterRef' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterRef.php',
    'Google\\Service\\Analytics\\FilterSearchAndReplaceDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterSearchAndReplaceDetails.php',
    'Google\\Service\\Analytics\\FilterUppercaseDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/FilterUppercaseDetails.php',
    'Google\\Service\\Analytics\\Filters' => $vendorDir . '/google/apiclient-services/src/Analytics/Filters.php',
    'Google\\Service\\Analytics\\GaData' => $vendorDir . '/google/apiclient-services/src/Analytics/GaData.php',
    'Google\\Service\\Analytics\\GaDataColumnHeaders' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataColumnHeaders.php',
    'Google\\Service\\Analytics\\GaDataDataTable' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataDataTable.php',
    'Google\\Service\\Analytics\\GaDataDataTableCols' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataDataTableCols.php',
    'Google\\Service\\Analytics\\GaDataDataTableRows' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataDataTableRows.php',
    'Google\\Service\\Analytics\\GaDataDataTableRowsC' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataDataTableRowsC.php',
    'Google\\Service\\Analytics\\GaDataProfileInfo' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataProfileInfo.php',
    'Google\\Service\\Analytics\\GaDataQuery' => $vendorDir . '/google/apiclient-services/src/Analytics/GaDataQuery.php',
    'Google\\Service\\Analytics\\Goal' => $vendorDir . '/google/apiclient-services/src/Analytics/Goal.php',
    'Google\\Service\\Analytics\\GoalEventDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalEventDetails.php',
    'Google\\Service\\Analytics\\GoalEventDetailsEventConditions' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalEventDetailsEventConditions.php',
    'Google\\Service\\Analytics\\GoalParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalParentLink.php',
    'Google\\Service\\Analytics\\GoalUrlDestinationDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalUrlDestinationDetails.php',
    'Google\\Service\\Analytics\\GoalUrlDestinationDetailsSteps' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalUrlDestinationDetailsSteps.php',
    'Google\\Service\\Analytics\\GoalVisitNumPagesDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalVisitNumPagesDetails.php',
    'Google\\Service\\Analytics\\GoalVisitTimeOnSiteDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/GoalVisitTimeOnSiteDetails.php',
    'Google\\Service\\Analytics\\Goals' => $vendorDir . '/google/apiclient-services/src/Analytics/Goals.php',
    'Google\\Service\\Analytics\\HashClientIdRequest' => $vendorDir . '/google/apiclient-services/src/Analytics/HashClientIdRequest.php',
    'Google\\Service\\Analytics\\HashClientIdResponse' => $vendorDir . '/google/apiclient-services/src/Analytics/HashClientIdResponse.php',
    'Google\\Service\\Analytics\\IncludeConditions' => $vendorDir . '/google/apiclient-services/src/Analytics/IncludeConditions.php',
    'Google\\Service\\Analytics\\LinkedForeignAccount' => $vendorDir . '/google/apiclient-services/src/Analytics/LinkedForeignAccount.php',
    'Google\\Service\\Analytics\\McfData' => $vendorDir . '/google/apiclient-services/src/Analytics/McfData.php',
    'Google\\Service\\Analytics\\McfDataColumnHeaders' => $vendorDir . '/google/apiclient-services/src/Analytics/McfDataColumnHeaders.php',
    'Google\\Service\\Analytics\\McfDataProfileInfo' => $vendorDir . '/google/apiclient-services/src/Analytics/McfDataProfileInfo.php',
    'Google\\Service\\Analytics\\McfDataQuery' => $vendorDir . '/google/apiclient-services/src/Analytics/McfDataQuery.php',
    'Google\\Service\\Analytics\\McfDataRows' => $vendorDir . '/google/apiclient-services/src/Analytics/McfDataRows.php',
    'Google\\Service\\Analytics\\McfDataRowsConversionPathValue' => $vendorDir . '/google/apiclient-services/src/Analytics/McfDataRowsConversionPathValue.php',
    'Google\\Service\\Analytics\\Profile' => $vendorDir . '/google/apiclient-services/src/Analytics/Profile.php',
    'Google\\Service\\Analytics\\ProfileChildLink' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileChildLink.php',
    'Google\\Service\\Analytics\\ProfileFilterLink' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileFilterLink.php',
    'Google\\Service\\Analytics\\ProfileFilterLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileFilterLinks.php',
    'Google\\Service\\Analytics\\ProfileParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileParentLink.php',
    'Google\\Service\\Analytics\\ProfilePermissions' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfilePermissions.php',
    'Google\\Service\\Analytics\\ProfileRef' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileRef.php',
    'Google\\Service\\Analytics\\ProfileSummary' => $vendorDir . '/google/apiclient-services/src/Analytics/ProfileSummary.php',
    'Google\\Service\\Analytics\\Profiles' => $vendorDir . '/google/apiclient-services/src/Analytics/Profiles.php',
    'Google\\Service\\Analytics\\RealtimeData' => $vendorDir . '/google/apiclient-services/src/Analytics/RealtimeData.php',
    'Google\\Service\\Analytics\\RealtimeDataColumnHeaders' => $vendorDir . '/google/apiclient-services/src/Analytics/RealtimeDataColumnHeaders.php',
    'Google\\Service\\Analytics\\RealtimeDataProfileInfo' => $vendorDir . '/google/apiclient-services/src/Analytics/RealtimeDataProfileInfo.php',
    'Google\\Service\\Analytics\\RealtimeDataQuery' => $vendorDir . '/google/apiclient-services/src/Analytics/RealtimeDataQuery.php',
    'Google\\Service\\Analytics\\RemarketingAudience' => $vendorDir . '/google/apiclient-services/src/Analytics/RemarketingAudience.php',
    'Google\\Service\\Analytics\\RemarketingAudienceAudienceDefinition' => $vendorDir . '/google/apiclient-services/src/Analytics/RemarketingAudienceAudienceDefinition.php',
    'Google\\Service\\Analytics\\RemarketingAudienceStateBasedAudienceDefinition' => $vendorDir . '/google/apiclient-services/src/Analytics/RemarketingAudienceStateBasedAudienceDefinition.php',
    'Google\\Service\\Analytics\\RemarketingAudienceStateBasedAudienceDefinitionExcludeConditions' => $vendorDir . '/google/apiclient-services/src/Analytics/RemarketingAudienceStateBasedAudienceDefinitionExcludeConditions.php',
    'Google\\Service\\Analytics\\RemarketingAudiences' => $vendorDir . '/google/apiclient-services/src/Analytics/RemarketingAudiences.php',
    'Google\\Service\\Analytics\\Resource\\Data' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/Data.php',
    'Google\\Service\\Analytics\\Resource\\DataGa' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/DataGa.php',
    'Google\\Service\\Analytics\\Resource\\DataMcf' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/DataMcf.php',
    'Google\\Service\\Analytics\\Resource\\DataRealtime' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/DataRealtime.php',
    'Google\\Service\\Analytics\\Resource\\Management' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/Management.php',
    'Google\\Service\\Analytics\\Resource\\ManagementAccountSummaries' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementAccountSummaries.php',
    'Google\\Service\\Analytics\\Resource\\ManagementAccountUserLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementAccountUserLinks.php',
    'Google\\Service\\Analytics\\Resource\\ManagementAccounts' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementAccounts.php',
    'Google\\Service\\Analytics\\Resource\\ManagementClientId' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementClientId.php',
    'Google\\Service\\Analytics\\Resource\\ManagementCustomDataSources' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementCustomDataSources.php',
    'Google\\Service\\Analytics\\Resource\\ManagementCustomDimensions' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementCustomDimensions.php',
    'Google\\Service\\Analytics\\Resource\\ManagementCustomMetrics' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementCustomMetrics.php',
    'Google\\Service\\Analytics\\Resource\\ManagementExperiments' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementExperiments.php',
    'Google\\Service\\Analytics\\Resource\\ManagementFilters' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementFilters.php',
    'Google\\Service\\Analytics\\Resource\\ManagementGoals' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementGoals.php',
    'Google\\Service\\Analytics\\Resource\\ManagementProfileFilterLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementProfileFilterLinks.php',
    'Google\\Service\\Analytics\\Resource\\ManagementProfileUserLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementProfileUserLinks.php',
    'Google\\Service\\Analytics\\Resource\\ManagementProfiles' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementProfiles.php',
    'Google\\Service\\Analytics\\Resource\\ManagementRemarketingAudience' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementRemarketingAudience.php',
    'Google\\Service\\Analytics\\Resource\\ManagementSegments' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementSegments.php',
    'Google\\Service\\Analytics\\Resource\\ManagementUnsampledReports' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementUnsampledReports.php',
    'Google\\Service\\Analytics\\Resource\\ManagementUploads' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementUploads.php',
    'Google\\Service\\Analytics\\Resource\\ManagementWebPropertyAdWordsLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementWebPropertyAdWordsLinks.php',
    'Google\\Service\\Analytics\\Resource\\ManagementWebproperties' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementWebproperties.php',
    'Google\\Service\\Analytics\\Resource\\ManagementWebpropertyUserLinks' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/ManagementWebpropertyUserLinks.php',
    'Google\\Service\\Analytics\\Resource\\Metadata' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/Metadata.php',
    'Google\\Service\\Analytics\\Resource\\MetadataColumns' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/MetadataColumns.php',
    'Google\\Service\\Analytics\\Resource\\Provisioning' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/Provisioning.php',
    'Google\\Service\\Analytics\\Resource\\UserDeletion' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/UserDeletion.php',
    'Google\\Service\\Analytics\\Resource\\UserDeletionUserDeletionRequest' => $vendorDir . '/google/apiclient-services/src/Analytics/Resource/UserDeletionUserDeletionRequest.php',
    'Google\\Service\\Analytics\\Segment' => $vendorDir . '/google/apiclient-services/src/Analytics/Segment.php',
    'Google\\Service\\Analytics\\Segments' => $vendorDir . '/google/apiclient-services/src/Analytics/Segments.php',
    'Google\\Service\\Analytics\\UnsampledReport' => $vendorDir . '/google/apiclient-services/src/Analytics/UnsampledReport.php',
    'Google\\Service\\Analytics\\UnsampledReportCloudStorageDownloadDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/UnsampledReportCloudStorageDownloadDetails.php',
    'Google\\Service\\Analytics\\UnsampledReportDriveDownloadDetails' => $vendorDir . '/google/apiclient-services/src/Analytics/UnsampledReportDriveDownloadDetails.php',
    'Google\\Service\\Analytics\\UnsampledReports' => $vendorDir . '/google/apiclient-services/src/Analytics/UnsampledReports.php',
    'Google\\Service\\Analytics\\Upload' => $vendorDir . '/google/apiclient-services/src/Analytics/Upload.php',
    'Google\\Service\\Analytics\\Uploads' => $vendorDir . '/google/apiclient-services/src/Analytics/Uploads.php',
    'Google\\Service\\Analytics\\UserDeletionRequest' => $vendorDir . '/google/apiclient-services/src/Analytics/UserDeletionRequest.php',
    'Google\\Service\\Analytics\\UserDeletionRequestId' => $vendorDir . '/google/apiclient-services/src/Analytics/UserDeletionRequestId.php',
    'Google\\Service\\Analytics\\UserRef' => $vendorDir . '/google/apiclient-services/src/Analytics/UserRef.php',
    'Google\\Service\\Analytics\\WebPropertyRef' => $vendorDir . '/google/apiclient-services/src/Analytics/WebPropertyRef.php',
    'Google\\Service\\Analytics\\WebPropertySummary' => $vendorDir . '/google/apiclient-services/src/Analytics/WebPropertySummary.php',
    'Google\\Service\\Analytics\\Webproperties' => $vendorDir . '/google/apiclient-services/src/Analytics/Webproperties.php',
    'Google\\Service\\Analytics\\Webproperty' => $vendorDir . '/google/apiclient-services/src/Analytics/Webproperty.php',
    'Google\\Service\\Analytics\\WebpropertyChildLink' => $vendorDir . '/google/apiclient-services/src/Analytics/WebpropertyChildLink.php',
    'Google\\Service\\Analytics\\WebpropertyParentLink' => $vendorDir . '/google/apiclient-services/src/Analytics/WebpropertyParentLink.php',
    'Google\\Service\\Analytics\\WebpropertyPermissions' => $vendorDir . '/google/apiclient-services/src/Analytics/WebpropertyPermissions.php',
    'Google\\Service\\AndroidEnterprise' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise.php',
    'Google\\Service\\AndroidEnterprise\\Administrator' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Administrator.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebToken' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebToken.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpec' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpec.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecManagedConfigurations' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecManagedConfigurations.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecPlaySearch' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecPlaySearch.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecPrivateApps' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecPrivateApps.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecStoreBuilder' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecStoreBuilder.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecWebApps' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecWebApps.php',
    'Google\\Service\\AndroidEnterprise\\AdministratorWebTokenSpecZeroTouch' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AdministratorWebTokenSpecZeroTouch.php',
    'Google\\Service\\AndroidEnterprise\\AppRestrictionsSchema' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppRestrictionsSchema.php',
    'Google\\Service\\AndroidEnterprise\\AppRestrictionsSchemaChangeEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppRestrictionsSchemaChangeEvent.php',
    'Google\\Service\\AndroidEnterprise\\AppRestrictionsSchemaRestriction' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppRestrictionsSchemaRestriction.php',
    'Google\\Service\\AndroidEnterprise\\AppRestrictionsSchemaRestrictionRestrictionValue' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppRestrictionsSchemaRestrictionRestrictionValue.php',
    'Google\\Service\\AndroidEnterprise\\AppState' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppState.php',
    'Google\\Service\\AndroidEnterprise\\AppUpdateEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppUpdateEvent.php',
    'Google\\Service\\AndroidEnterprise\\AppVersion' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AppVersion.php',
    'Google\\Service\\AndroidEnterprise\\ApprovalUrlInfo' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ApprovalUrlInfo.php',
    'Google\\Service\\AndroidEnterprise\\AuthenticationToken' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AuthenticationToken.php',
    'Google\\Service\\AndroidEnterprise\\AutoInstallConstraint' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AutoInstallConstraint.php',
    'Google\\Service\\AndroidEnterprise\\AutoInstallPolicy' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/AutoInstallPolicy.php',
    'Google\\Service\\AndroidEnterprise\\ConfigurationVariables' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ConfigurationVariables.php',
    'Google\\Service\\AndroidEnterprise\\CreateEnrollmentTokenResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/CreateEnrollmentTokenResponse.php',
    'Google\\Service\\AndroidEnterprise\\Device' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Device.php',
    'Google\\Service\\AndroidEnterprise\\DeviceReport' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/DeviceReport.php',
    'Google\\Service\\AndroidEnterprise\\DeviceReportUpdateEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/DeviceReportUpdateEvent.php',
    'Google\\Service\\AndroidEnterprise\\DeviceState' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/DeviceState.php',
    'Google\\Service\\AndroidEnterprise\\DevicesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/DevicesListResponse.php',
    'Google\\Service\\AndroidEnterprise\\Enterprise' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Enterprise.php',
    'Google\\Service\\AndroidEnterprise\\EnterpriseAccount' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/EnterpriseAccount.php',
    'Google\\Service\\AndroidEnterprise\\EnterpriseAuthenticationAppLinkConfig' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/EnterpriseAuthenticationAppLinkConfig.php',
    'Google\\Service\\AndroidEnterprise\\EnterprisesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/EnterprisesListResponse.php',
    'Google\\Service\\AndroidEnterprise\\EnterprisesSendTestPushNotificationResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/EnterprisesSendTestPushNotificationResponse.php',
    'Google\\Service\\AndroidEnterprise\\Entitlement' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Entitlement.php',
    'Google\\Service\\AndroidEnterprise\\EntitlementsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/EntitlementsListResponse.php',
    'Google\\Service\\AndroidEnterprise\\GoogleAuthenticationSettings' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/GoogleAuthenticationSettings.php',
    'Google\\Service\\AndroidEnterprise\\GroupLicense' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/GroupLicense.php',
    'Google\\Service\\AndroidEnterprise\\GroupLicenseUsersListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/GroupLicenseUsersListResponse.php',
    'Google\\Service\\AndroidEnterprise\\GroupLicensesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/GroupLicensesListResponse.php',
    'Google\\Service\\AndroidEnterprise\\Install' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Install.php',
    'Google\\Service\\AndroidEnterprise\\InstallFailureEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/InstallFailureEvent.php',
    'Google\\Service\\AndroidEnterprise\\InstallsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/InstallsListResponse.php',
    'Google\\Service\\AndroidEnterprise\\KeyedAppState' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/KeyedAppState.php',
    'Google\\Service\\AndroidEnterprise\\LocalizedText' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/LocalizedText.php',
    'Google\\Service\\AndroidEnterprise\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/MaintenanceWindow.php',
    'Google\\Service\\AndroidEnterprise\\ManagedConfiguration' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedConfiguration.php',
    'Google\\Service\\AndroidEnterprise\\ManagedConfigurationsForDeviceListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedConfigurationsForDeviceListResponse.php',
    'Google\\Service\\AndroidEnterprise\\ManagedConfigurationsForUserListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedConfigurationsForUserListResponse.php',
    'Google\\Service\\AndroidEnterprise\\ManagedConfigurationsSettings' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedConfigurationsSettings.php',
    'Google\\Service\\AndroidEnterprise\\ManagedConfigurationsSettingsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedConfigurationsSettingsListResponse.php',
    'Google\\Service\\AndroidEnterprise\\ManagedProperty' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedProperty.php',
    'Google\\Service\\AndroidEnterprise\\ManagedPropertyBundle' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ManagedPropertyBundle.php',
    'Google\\Service\\AndroidEnterprise\\NewDeviceEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/NewDeviceEvent.php',
    'Google\\Service\\AndroidEnterprise\\NewPermissionsEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/NewPermissionsEvent.php',
    'Google\\Service\\AndroidEnterprise\\Notification' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Notification.php',
    'Google\\Service\\AndroidEnterprise\\NotificationSet' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/NotificationSet.php',
    'Google\\Service\\AndroidEnterprise\\PageInfo' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/PageInfo.php',
    'Google\\Service\\AndroidEnterprise\\Permission' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Permission.php',
    'Google\\Service\\AndroidEnterprise\\Policy' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Policy.php',
    'Google\\Service\\AndroidEnterprise\\Product' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Product.php',
    'Google\\Service\\AndroidEnterprise\\ProductApprovalEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductApprovalEvent.php',
    'Google\\Service\\AndroidEnterprise\\ProductAvailabilityChangeEvent' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductAvailabilityChangeEvent.php',
    'Google\\Service\\AndroidEnterprise\\ProductPermission' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductPermission.php',
    'Google\\Service\\AndroidEnterprise\\ProductPermissions' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductPermissions.php',
    'Google\\Service\\AndroidEnterprise\\ProductPolicy' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductPolicy.php',
    'Google\\Service\\AndroidEnterprise\\ProductSet' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductSet.php',
    'Google\\Service\\AndroidEnterprise\\ProductSigningCertificate' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductSigningCertificate.php',
    'Google\\Service\\AndroidEnterprise\\ProductVisibility' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductVisibility.php',
    'Google\\Service\\AndroidEnterprise\\ProductsApproveRequest' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductsApproveRequest.php',
    'Google\\Service\\AndroidEnterprise\\ProductsGenerateApprovalUrlResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductsGenerateApprovalUrlResponse.php',
    'Google\\Service\\AndroidEnterprise\\ProductsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ProductsListResponse.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Devices' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Devices.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Enterprises' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Enterprises.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Entitlements' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Entitlements.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Grouplicenses' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Grouplicenses.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Grouplicenseusers' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Grouplicenseusers.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Installs' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Installs.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Managedconfigurationsfordevice' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Managedconfigurationsfordevice.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Managedconfigurationsforuser' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Managedconfigurationsforuser.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Managedconfigurationssettings' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Managedconfigurationssettings.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Permissions' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Permissions.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Products' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Products.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Serviceaccountkeys' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Serviceaccountkeys.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Storelayoutclusters' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Storelayoutclusters.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Storelayoutpages' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Storelayoutpages.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Users.php',
    'Google\\Service\\AndroidEnterprise\\Resource\\Webapps' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/Resource/Webapps.php',
    'Google\\Service\\AndroidEnterprise\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ServiceAccount.php',
    'Google\\Service\\AndroidEnterprise\\ServiceAccountKey' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ServiceAccountKey.php',
    'Google\\Service\\AndroidEnterprise\\ServiceAccountKeysListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/ServiceAccountKeysListResponse.php',
    'Google\\Service\\AndroidEnterprise\\SignupInfo' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/SignupInfo.php',
    'Google\\Service\\AndroidEnterprise\\StoreCluster' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/StoreCluster.php',
    'Google\\Service\\AndroidEnterprise\\StoreLayout' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/StoreLayout.php',
    'Google\\Service\\AndroidEnterprise\\StoreLayoutClustersListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/StoreLayoutClustersListResponse.php',
    'Google\\Service\\AndroidEnterprise\\StoreLayoutPagesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/StoreLayoutPagesListResponse.php',
    'Google\\Service\\AndroidEnterprise\\StorePage' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/StorePage.php',
    'Google\\Service\\AndroidEnterprise\\TokenPagination' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/TokenPagination.php',
    'Google\\Service\\AndroidEnterprise\\TrackInfo' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/TrackInfo.php',
    'Google\\Service\\AndroidEnterprise\\User' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/User.php',
    'Google\\Service\\AndroidEnterprise\\UsersListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/UsersListResponse.php',
    'Google\\Service\\AndroidEnterprise\\VariableSet' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/VariableSet.php',
    'Google\\Service\\AndroidEnterprise\\WebApp' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/WebApp.php',
    'Google\\Service\\AndroidEnterprise\\WebAppIcon' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/WebAppIcon.php',
    'Google\\Service\\AndroidEnterprise\\WebAppsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidEnterprise/WebAppsListResponse.php',
    'Google\\Service\\AndroidManagement' => $vendorDir . '/google/apiclient-services/src/AndroidManagement.php',
    'Google\\Service\\AndroidManagement\\AdbShellCommandEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AdbShellCommandEvent.php',
    'Google\\Service\\AndroidManagement\\AdbShellInteractiveEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AdbShellInteractiveEvent.php',
    'Google\\Service\\AndroidManagement\\AdvancedSecurityOverrides' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AdvancedSecurityOverrides.php',
    'Google\\Service\\AndroidManagement\\AlwaysOnVpnPackage' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AlwaysOnVpnPackage.php',
    'Google\\Service\\AndroidManagement\\AndroidmanagementEmpty' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AndroidmanagementEmpty.php',
    'Google\\Service\\AndroidManagement\\ApiLevelCondition' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApiLevelCondition.php',
    'Google\\Service\\AndroidManagement\\AppProcessInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AppProcessInfo.php',
    'Google\\Service\\AndroidManagement\\AppProcessStartEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AppProcessStartEvent.php',
    'Google\\Service\\AndroidManagement\\AppTrackInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AppTrackInfo.php',
    'Google\\Service\\AndroidManagement\\AppVersion' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/AppVersion.php',
    'Google\\Service\\AndroidManagement\\Application' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Application.php',
    'Google\\Service\\AndroidManagement\\ApplicationEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApplicationEvent.php',
    'Google\\Service\\AndroidManagement\\ApplicationPermission' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApplicationPermission.php',
    'Google\\Service\\AndroidManagement\\ApplicationPolicy' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApplicationPolicy.php',
    'Google\\Service\\AndroidManagement\\ApplicationReport' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApplicationReport.php',
    'Google\\Service\\AndroidManagement\\ApplicationReportingSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ApplicationReportingSettings.php',
    'Google\\Service\\AndroidManagement\\BatchUsageLogEvents' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/BatchUsageLogEvents.php',
    'Google\\Service\\AndroidManagement\\BlockAction' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/BlockAction.php',
    'Google\\Service\\AndroidManagement\\CertAuthorityInstalledEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CertAuthorityInstalledEvent.php',
    'Google\\Service\\AndroidManagement\\CertAuthorityRemovedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CertAuthorityRemovedEvent.php',
    'Google\\Service\\AndroidManagement\\CertValidationFailureEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CertValidationFailureEvent.php',
    'Google\\Service\\AndroidManagement\\ChoosePrivateKeyRule' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ChoosePrivateKeyRule.php',
    'Google\\Service\\AndroidManagement\\ClearAppsDataParams' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ClearAppsDataParams.php',
    'Google\\Service\\AndroidManagement\\ClearAppsDataStatus' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ClearAppsDataStatus.php',
    'Google\\Service\\AndroidManagement\\Command' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Command.php',
    'Google\\Service\\AndroidManagement\\CommonCriteriaModeInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CommonCriteriaModeInfo.php',
    'Google\\Service\\AndroidManagement\\ComplianceRule' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ComplianceRule.php',
    'Google\\Service\\AndroidManagement\\ConnectEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ConnectEvent.php',
    'Google\\Service\\AndroidManagement\\ContactInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ContactInfo.php',
    'Google\\Service\\AndroidManagement\\ContentProviderEndpoint' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ContentProviderEndpoint.php',
    'Google\\Service\\AndroidManagement\\CrossProfilePolicies' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CrossProfilePolicies.php',
    'Google\\Service\\AndroidManagement\\CryptoSelfTestCompletedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/CryptoSelfTestCompletedEvent.php',
    'Google\\Service\\AndroidManagement\\Date' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Date.php',
    'Google\\Service\\AndroidManagement\\Device' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Device.php',
    'Google\\Service\\AndroidManagement\\DeviceConnectivityManagement' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DeviceConnectivityManagement.php',
    'Google\\Service\\AndroidManagement\\DeviceRadioState' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DeviceRadioState.php',
    'Google\\Service\\AndroidManagement\\DeviceSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DeviceSettings.php',
    'Google\\Service\\AndroidManagement\\Display' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Display.php',
    'Google\\Service\\AndroidManagement\\DisplaySettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DisplaySettings.php',
    'Google\\Service\\AndroidManagement\\DnsEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DnsEvent.php',
    'Google\\Service\\AndroidManagement\\DpcMigrationInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/DpcMigrationInfo.php',
    'Google\\Service\\AndroidManagement\\EnrollmentCompleteEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/EnrollmentCompleteEvent.php',
    'Google\\Service\\AndroidManagement\\EnrollmentToken' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/EnrollmentToken.php',
    'Google\\Service\\AndroidManagement\\Enterprise' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Enterprise.php',
    'Google\\Service\\AndroidManagement\\ExtensionConfig' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ExtensionConfig.php',
    'Google\\Service\\AndroidManagement\\ExternalData' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ExternalData.php',
    'Google\\Service\\AndroidManagement\\FilePulledEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/FilePulledEvent.php',
    'Google\\Service\\AndroidManagement\\FilePushedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/FilePushedEvent.php',
    'Google\\Service\\AndroidManagement\\FreezePeriod' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/FreezePeriod.php',
    'Google\\Service\\AndroidManagement\\GoogleAuthenticationSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/GoogleAuthenticationSettings.php',
    'Google\\Service\\AndroidManagement\\HardwareInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/HardwareInfo.php',
    'Google\\Service\\AndroidManagement\\HardwareStatus' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/HardwareStatus.php',
    'Google\\Service\\AndroidManagement\\InstallConstraint' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/InstallConstraint.php',
    'Google\\Service\\AndroidManagement\\IssueCommandResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/IssueCommandResponse.php',
    'Google\\Service\\AndroidManagement\\KeyDestructionEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyDestructionEvent.php',
    'Google\\Service\\AndroidManagement\\KeyGeneratedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyGeneratedEvent.php',
    'Google\\Service\\AndroidManagement\\KeyImportEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyImportEvent.php',
    'Google\\Service\\AndroidManagement\\KeyIntegrityViolationEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyIntegrityViolationEvent.php',
    'Google\\Service\\AndroidManagement\\KeyedAppState' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyedAppState.php',
    'Google\\Service\\AndroidManagement\\KeyguardDismissAuthAttemptEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyguardDismissAuthAttemptEvent.php',
    'Google\\Service\\AndroidManagement\\KeyguardDismissedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyguardDismissedEvent.php',
    'Google\\Service\\AndroidManagement\\KeyguardSecuredEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KeyguardSecuredEvent.php',
    'Google\\Service\\AndroidManagement\\KioskCustomization' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/KioskCustomization.php',
    'Google\\Service\\AndroidManagement\\LaunchAppAction' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LaunchAppAction.php',
    'Google\\Service\\AndroidManagement\\ListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListDevicesResponse.php',
    'Google\\Service\\AndroidManagement\\ListEnrollmentTokensResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListEnrollmentTokensResponse.php',
    'Google\\Service\\AndroidManagement\\ListEnterprisesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListEnterprisesResponse.php',
    'Google\\Service\\AndroidManagement\\ListMigrationTokensResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListMigrationTokensResponse.php',
    'Google\\Service\\AndroidManagement\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListOperationsResponse.php',
    'Google\\Service\\AndroidManagement\\ListPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListPoliciesResponse.php',
    'Google\\Service\\AndroidManagement\\ListWebAppsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ListWebAppsResponse.php',
    'Google\\Service\\AndroidManagement\\Location' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Location.php',
    'Google\\Service\\AndroidManagement\\LogBufferSizeCriticalEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LogBufferSizeCriticalEvent.php',
    'Google\\Service\\AndroidManagement\\LoggingStartedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LoggingStartedEvent.php',
    'Google\\Service\\AndroidManagement\\LoggingStoppedEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LoggingStoppedEvent.php',
    'Google\\Service\\AndroidManagement\\LostModeLocationEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LostModeLocationEvent.php',
    'Google\\Service\\AndroidManagement\\LostModeOutgoingPhoneCallEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/LostModeOutgoingPhoneCallEvent.php',
    'Google\\Service\\AndroidManagement\\ManagedConfigurationTemplate' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ManagedConfigurationTemplate.php',
    'Google\\Service\\AndroidManagement\\ManagedProperty' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ManagedProperty.php',
    'Google\\Service\\AndroidManagement\\ManagedPropertyEntry' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ManagedPropertyEntry.php',
    'Google\\Service\\AndroidManagement\\MediaMountEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/MediaMountEvent.php',
    'Google\\Service\\AndroidManagement\\MediaUnmountEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/MediaUnmountEvent.php',
    'Google\\Service\\AndroidManagement\\MemoryEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/MemoryEvent.php',
    'Google\\Service\\AndroidManagement\\MemoryInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/MemoryInfo.php',
    'Google\\Service\\AndroidManagement\\MigrationToken' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/MigrationToken.php',
    'Google\\Service\\AndroidManagement\\NetworkInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/NetworkInfo.php',
    'Google\\Service\\AndroidManagement\\NonComplianceDetail' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/NonComplianceDetail.php',
    'Google\\Service\\AndroidManagement\\NonComplianceDetailCondition' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/NonComplianceDetailCondition.php',
    'Google\\Service\\AndroidManagement\\OncCertificateProvider' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/OncCertificateProvider.php',
    'Google\\Service\\AndroidManagement\\OncWifiContext' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/OncWifiContext.php',
    'Google\\Service\\AndroidManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Operation.php',
    'Google\\Service\\AndroidManagement\\OsShutdownEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/OsShutdownEvent.php',
    'Google\\Service\\AndroidManagement\\OsStartupEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/OsStartupEvent.php',
    'Google\\Service\\AndroidManagement\\PackageNameList' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PackageNameList.php',
    'Google\\Service\\AndroidManagement\\PasswordPoliciesContext' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PasswordPoliciesContext.php',
    'Google\\Service\\AndroidManagement\\PasswordRequirements' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PasswordRequirements.php',
    'Google\\Service\\AndroidManagement\\PerAppResult' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PerAppResult.php',
    'Google\\Service\\AndroidManagement\\PermissionGrant' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PermissionGrant.php',
    'Google\\Service\\AndroidManagement\\PersistentPreferredActivity' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PersistentPreferredActivity.php',
    'Google\\Service\\AndroidManagement\\PersonalApplicationPolicy' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PersonalApplicationPolicy.php',
    'Google\\Service\\AndroidManagement\\PersonalUsagePolicies' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PersonalUsagePolicies.php',
    'Google\\Service\\AndroidManagement\\Policy' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Policy.php',
    'Google\\Service\\AndroidManagement\\PolicyEnforcementRule' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PolicyEnforcementRule.php',
    'Google\\Service\\AndroidManagement\\PostureDetail' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PostureDetail.php',
    'Google\\Service\\AndroidManagement\\PowerManagementEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/PowerManagementEvent.php',
    'Google\\Service\\AndroidManagement\\ProvisioningInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ProvisioningInfo.php',
    'Google\\Service\\AndroidManagement\\ProxyInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ProxyInfo.php',
    'Google\\Service\\AndroidManagement\\RemoteLockEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/RemoteLockEvent.php',
    'Google\\Service\\AndroidManagement\\Resource\\Enterprises' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/Enterprises.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesApplications' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesApplications.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesDevices' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesDevices.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesDevicesOperations' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesDevicesOperations.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesEnrollmentTokens' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesEnrollmentTokens.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesMigrationTokens' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesMigrationTokens.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesPolicies' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesPolicies.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesWebApps' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesWebApps.php',
    'Google\\Service\\AndroidManagement\\Resource\\EnterprisesWebTokens' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/EnterprisesWebTokens.php',
    'Google\\Service\\AndroidManagement\\Resource\\ProvisioningInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/ProvisioningInfo.php',
    'Google\\Service\\AndroidManagement\\Resource\\SignupUrls' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Resource/SignupUrls.php',
    'Google\\Service\\AndroidManagement\\ScreenBrightnessSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ScreenBrightnessSettings.php',
    'Google\\Service\\AndroidManagement\\ScreenTimeoutSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/ScreenTimeoutSettings.php',
    'Google\\Service\\AndroidManagement\\SecurityPosture' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SecurityPosture.php',
    'Google\\Service\\AndroidManagement\\SetupAction' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SetupAction.php',
    'Google\\Service\\AndroidManagement\\SigninDetail' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SigninDetail.php',
    'Google\\Service\\AndroidManagement\\SignupUrl' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SignupUrl.php',
    'Google\\Service\\AndroidManagement\\SoftwareInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SoftwareInfo.php',
    'Google\\Service\\AndroidManagement\\SpecificNonComplianceContext' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SpecificNonComplianceContext.php',
    'Google\\Service\\AndroidManagement\\StartLostModeParams' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StartLostModeParams.php',
    'Google\\Service\\AndroidManagement\\StartLostModeStatus' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StartLostModeStatus.php',
    'Google\\Service\\AndroidManagement\\Status' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/Status.php',
    'Google\\Service\\AndroidManagement\\StatusReportingSettings' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StatusReportingSettings.php',
    'Google\\Service\\AndroidManagement\\StopLostModeParams' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StopLostModeParams.php',
    'Google\\Service\\AndroidManagement\\StopLostModeStatus' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StopLostModeStatus.php',
    'Google\\Service\\AndroidManagement\\StopLostModeUserAttemptEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/StopLostModeUserAttemptEvent.php',
    'Google\\Service\\AndroidManagement\\SystemUpdate' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SystemUpdate.php',
    'Google\\Service\\AndroidManagement\\SystemUpdateInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/SystemUpdateInfo.php',
    'Google\\Service\\AndroidManagement\\TelephonyInfo' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/TelephonyInfo.php',
    'Google\\Service\\AndroidManagement\\TermsAndConditions' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/TermsAndConditions.php',
    'Google\\Service\\AndroidManagement\\UsageLog' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/UsageLog.php',
    'Google\\Service\\AndroidManagement\\UsageLogEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/UsageLogEvent.php',
    'Google\\Service\\AndroidManagement\\User' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/User.php',
    'Google\\Service\\AndroidManagement\\UserFacingMessage' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/UserFacingMessage.php',
    'Google\\Service\\AndroidManagement\\WebApp' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WebApp.php',
    'Google\\Service\\AndroidManagement\\WebAppIcon' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WebAppIcon.php',
    'Google\\Service\\AndroidManagement\\WebToken' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WebToken.php',
    'Google\\Service\\AndroidManagement\\WifiSsid' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WifiSsid.php',
    'Google\\Service\\AndroidManagement\\WifiSsidPolicy' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WifiSsidPolicy.php',
    'Google\\Service\\AndroidManagement\\WipeAction' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WipeAction.php',
    'Google\\Service\\AndroidManagement\\WipeFailureEvent' => $vendorDir . '/google/apiclient-services/src/AndroidManagement/WipeFailureEvent.php',
    'Google\\Service\\AndroidProvisioningPartner' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner.php',
    'Google\\Service\\AndroidProvisioningPartner\\AndroiddeviceprovisioningEmpty' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/AndroiddeviceprovisioningEmpty.php',
    'Google\\Service\\AndroidProvisioningPartner\\ClaimDeviceRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ClaimDeviceRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\ClaimDeviceResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ClaimDeviceResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\ClaimDevicesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ClaimDevicesRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\Company' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Company.php',
    'Google\\Service\\AndroidProvisioningPartner\\Configuration' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Configuration.php',
    'Google\\Service\\AndroidProvisioningPartner\\CreateCustomerRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CreateCustomerRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerApplyConfigurationRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerApplyConfigurationRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerListConfigurationsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerListConfigurationsResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerListCustomersResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerListDevicesResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerListDpcsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerListDpcsResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerRemoveConfigurationRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerRemoveConfigurationRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\CustomerUnclaimDeviceRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/CustomerUnclaimDeviceRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\Device' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Device.php',
    'Google\\Service\\AndroidProvisioningPartner\\DeviceClaim' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DeviceClaim.php',
    'Google\\Service\\AndroidProvisioningPartner\\DeviceIdentifier' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DeviceIdentifier.php',
    'Google\\Service\\AndroidProvisioningPartner\\DeviceMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DeviceMetadata.php',
    'Google\\Service\\AndroidProvisioningPartner\\DeviceReference' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DeviceReference.php',
    'Google\\Service\\AndroidProvisioningPartner\\DevicesLongRunningOperationMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DevicesLongRunningOperationMetadata.php',
    'Google\\Service\\AndroidProvisioningPartner\\DevicesLongRunningOperationResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/DevicesLongRunningOperationResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\Dpc' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Dpc.php',
    'Google\\Service\\AndroidProvisioningPartner\\FindDevicesByDeviceIdentifierRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/FindDevicesByDeviceIdentifierRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\FindDevicesByDeviceIdentifierResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/FindDevicesByDeviceIdentifierResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\FindDevicesByOwnerRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/FindDevicesByOwnerRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\FindDevicesByOwnerResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/FindDevicesByOwnerResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\GetDeviceSimLockStateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/GetDeviceSimLockStateRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\GetDeviceSimLockStateResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/GetDeviceSimLockStateResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\GoogleWorkspaceAccount' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/GoogleWorkspaceAccount.php',
    'Google\\Service\\AndroidProvisioningPartner\\ListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ListCustomersResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\ListVendorCustomersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ListVendorCustomersResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\ListVendorsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/ListVendorsResponse.php',
    'Google\\Service\\AndroidProvisioningPartner\\Operation' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Operation.php',
    'Google\\Service\\AndroidProvisioningPartner\\OperationPerDevice' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/OperationPerDevice.php',
    'Google\\Service\\AndroidProvisioningPartner\\PartnerClaim' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/PartnerClaim.php',
    'Google\\Service\\AndroidProvisioningPartner\\PartnerUnclaim' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/PartnerUnclaim.php',
    'Google\\Service\\AndroidProvisioningPartner\\PerDeviceStatusInBatch' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/PerDeviceStatusInBatch.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/Customers.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\CustomersConfigurations' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/CustomersConfigurations.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\CustomersDevices' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/CustomersDevices.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\CustomersDpcs' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/CustomersDpcs.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/Operations.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\Partners' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/Partners.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\PartnersCustomers' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/PartnersCustomers.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\PartnersDevices' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/PartnersDevices.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\PartnersVendors' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/PartnersVendors.php',
    'Google\\Service\\AndroidProvisioningPartner\\Resource\\PartnersVendorsCustomers' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Resource/PartnersVendorsCustomers.php',
    'Google\\Service\\AndroidProvisioningPartner\\Status' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/Status.php',
    'Google\\Service\\AndroidProvisioningPartner\\UnclaimDeviceRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/UnclaimDeviceRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\UnclaimDevicesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/UnclaimDevicesRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\UpdateDeviceMetadataInBatchRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/UpdateDeviceMetadataInBatchRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\UpdateDeviceMetadataRequest' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/UpdateDeviceMetadataRequest.php',
    'Google\\Service\\AndroidProvisioningPartner\\UpdateMetadataArguments' => $vendorDir . '/google/apiclient-services/src/AndroidProvisioningPartner/UpdateMetadataArguments.php',
    'Google\\Service\\AndroidPublisher' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher.php',
    'Google\\Service\\AndroidPublisher\\Abi' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Abi.php',
    'Google\\Service\\AndroidPublisher\\AbiTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AbiTargeting.php',
    'Google\\Service\\AndroidPublisher\\AcquisitionTargetingRule' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AcquisitionTargetingRule.php',
    'Google\\Service\\AndroidPublisher\\ActivateBasePlanRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ActivateBasePlanRequest.php',
    'Google\\Service\\AndroidPublisher\\ActivateSubscriptionOfferRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ActivateSubscriptionOfferRequest.php',
    'Google\\Service\\AndroidPublisher\\AddTargetingRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AddTargetingRequest.php',
    'Google\\Service\\AndroidPublisher\\AddTargetingResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AddTargetingResponse.php',
    'Google\\Service\\AndroidPublisher\\AllUsers' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AllUsers.php',
    'Google\\Service\\AndroidPublisher\\AndroidSdks' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AndroidSdks.php',
    'Google\\Service\\AndroidPublisher\\Apk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Apk.php',
    'Google\\Service\\AndroidPublisher\\ApkBinary' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApkBinary.php',
    'Google\\Service\\AndroidPublisher\\ApkDescription' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApkDescription.php',
    'Google\\Service\\AndroidPublisher\\ApkSet' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApkSet.php',
    'Google\\Service\\AndroidPublisher\\ApkTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApkTargeting.php',
    'Google\\Service\\AndroidPublisher\\ApksAddExternallyHostedRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApksAddExternallyHostedRequest.php',
    'Google\\Service\\AndroidPublisher\\ApksAddExternallyHostedResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApksAddExternallyHostedResponse.php',
    'Google\\Service\\AndroidPublisher\\ApksListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ApksListResponse.php',
    'Google\\Service\\AndroidPublisher\\AppDetails' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AppDetails.php',
    'Google\\Service\\AndroidPublisher\\AppEdit' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AppEdit.php',
    'Google\\Service\\AndroidPublisher\\AppRecoveryAction' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AppRecoveryAction.php',
    'Google\\Service\\AndroidPublisher\\AppVersionList' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AppVersionList.php',
    'Google\\Service\\AndroidPublisher\\AppVersionRange' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AppVersionRange.php',
    'Google\\Service\\AndroidPublisher\\ArchiveSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ArchiveSubscriptionRequest.php',
    'Google\\Service\\AndroidPublisher\\AssetModuleMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AssetModuleMetadata.php',
    'Google\\Service\\AndroidPublisher\\AssetSliceSet' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AssetSliceSet.php',
    'Google\\Service\\AndroidPublisher\\AutoRenewingBasePlanType' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AutoRenewingBasePlanType.php',
    'Google\\Service\\AndroidPublisher\\AutoRenewingPlan' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/AutoRenewingPlan.php',
    'Google\\Service\\AndroidPublisher\\BasePlan' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BasePlan.php',
    'Google\\Service\\AndroidPublisher\\BatchGetSubscriptionOffersRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchGetSubscriptionOffersRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchGetSubscriptionOffersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchGetSubscriptionOffersResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchGetSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchGetSubscriptionsResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchMigrateBasePlanPricesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchMigrateBasePlanPricesRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchMigrateBasePlanPricesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchMigrateBasePlanPricesResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateBasePlanStatesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateBasePlanStatesRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateBasePlanStatesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateBasePlanStatesResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionOfferStatesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionOfferStatesRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionOfferStatesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionOfferStatesResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionOffersRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionOffersRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionOffersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionOffersResponse.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionsRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionsRequest.php',
    'Google\\Service\\AndroidPublisher\\BatchUpdateSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BatchUpdateSubscriptionsResponse.php',
    'Google\\Service\\AndroidPublisher\\Bundle' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Bundle.php',
    'Google\\Service\\AndroidPublisher\\BundlesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/BundlesListResponse.php',
    'Google\\Service\\AndroidPublisher\\CancelAppRecoveryRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CancelAppRecoveryRequest.php',
    'Google\\Service\\AndroidPublisher\\CancelAppRecoveryResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CancelAppRecoveryResponse.php',
    'Google\\Service\\AndroidPublisher\\CancelSurveyResult' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CancelSurveyResult.php',
    'Google\\Service\\AndroidPublisher\\CanceledStateContext' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CanceledStateContext.php',
    'Google\\Service\\AndroidPublisher\\Comment' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Comment.php',
    'Google\\Service\\AndroidPublisher\\ConvertRegionPricesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ConvertRegionPricesRequest.php',
    'Google\\Service\\AndroidPublisher\\ConvertRegionPricesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ConvertRegionPricesResponse.php',
    'Google\\Service\\AndroidPublisher\\ConvertedOtherRegionsPrice' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ConvertedOtherRegionsPrice.php',
    'Google\\Service\\AndroidPublisher\\ConvertedRegionPrice' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ConvertedRegionPrice.php',
    'Google\\Service\\AndroidPublisher\\CountryTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CountryTargeting.php',
    'Google\\Service\\AndroidPublisher\\CreateDraftAppRecoveryRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/CreateDraftAppRecoveryRequest.php',
    'Google\\Service\\AndroidPublisher\\DeactivateBasePlanRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeactivateBasePlanRequest.php',
    'Google\\Service\\AndroidPublisher\\DeactivateSubscriptionOfferRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeactivateSubscriptionOfferRequest.php',
    'Google\\Service\\AndroidPublisher\\DeferredItemReplacement' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeferredItemReplacement.php',
    'Google\\Service\\AndroidPublisher\\DeobfuscationFile' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeobfuscationFile.php',
    'Google\\Service\\AndroidPublisher\\DeobfuscationFilesUploadResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeobfuscationFilesUploadResponse.php',
    'Google\\Service\\AndroidPublisher\\DeployAppRecoveryRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeployAppRecoveryRequest.php',
    'Google\\Service\\AndroidPublisher\\DeployAppRecoveryResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeployAppRecoveryResponse.php',
    'Google\\Service\\AndroidPublisher\\DeveloperComment' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeveloperComment.php',
    'Google\\Service\\AndroidPublisher\\DeveloperInitiatedCancellation' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeveloperInitiatedCancellation.php',
    'Google\\Service\\AndroidPublisher\\DeviceFeature' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceFeature.php',
    'Google\\Service\\AndroidPublisher\\DeviceFeatureTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceFeatureTargeting.php',
    'Google\\Service\\AndroidPublisher\\DeviceGroup' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceGroup.php',
    'Google\\Service\\AndroidPublisher\\DeviceId' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceId.php',
    'Google\\Service\\AndroidPublisher\\DeviceMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceMetadata.php',
    'Google\\Service\\AndroidPublisher\\DeviceRam' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceRam.php',
    'Google\\Service\\AndroidPublisher\\DeviceSelector' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceSelector.php',
    'Google\\Service\\AndroidPublisher\\DeviceSpec' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceSpec.php',
    'Google\\Service\\AndroidPublisher\\DeviceTier' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceTier.php',
    'Google\\Service\\AndroidPublisher\\DeviceTierConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceTierConfig.php',
    'Google\\Service\\AndroidPublisher\\DeviceTierSet' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/DeviceTierSet.php',
    'Google\\Service\\AndroidPublisher\\ExpansionFile' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExpansionFile.php',
    'Google\\Service\\AndroidPublisher\\ExpansionFilesUploadResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExpansionFilesUploadResponse.php',
    'Google\\Service\\AndroidPublisher\\ExternalAccountIdentifiers' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalAccountIdentifiers.php',
    'Google\\Service\\AndroidPublisher\\ExternalOfferInitialAcquisitionDetails' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalOfferInitialAcquisitionDetails.php',
    'Google\\Service\\AndroidPublisher\\ExternalSubscription' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalSubscription.php',
    'Google\\Service\\AndroidPublisher\\ExternalTransaction' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalTransaction.php',
    'Google\\Service\\AndroidPublisher\\ExternalTransactionAddress' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalTransactionAddress.php',
    'Google\\Service\\AndroidPublisher\\ExternalTransactionTestPurchase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternalTransactionTestPurchase.php',
    'Google\\Service\\AndroidPublisher\\ExternallyHostedApk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ExternallyHostedApk.php',
    'Google\\Service\\AndroidPublisher\\FullRefund' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/FullRefund.php',
    'Google\\Service\\AndroidPublisher\\GeneratedApksListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedApksListResponse.php',
    'Google\\Service\\AndroidPublisher\\GeneratedApksPerSigningKey' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedApksPerSigningKey.php',
    'Google\\Service\\AndroidPublisher\\GeneratedAssetPackSlice' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedAssetPackSlice.php',
    'Google\\Service\\AndroidPublisher\\GeneratedRecoveryApk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedRecoveryApk.php',
    'Google\\Service\\AndroidPublisher\\GeneratedSplitApk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedSplitApk.php',
    'Google\\Service\\AndroidPublisher\\GeneratedStandaloneApk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedStandaloneApk.php',
    'Google\\Service\\AndroidPublisher\\GeneratedUniversalApk' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GeneratedUniversalApk.php',
    'Google\\Service\\AndroidPublisher\\GetSubscriptionOfferRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/GetSubscriptionOfferRequest.php',
    'Google\\Service\\AndroidPublisher\\Grant' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Grant.php',
    'Google\\Service\\AndroidPublisher\\Image' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Image.php',
    'Google\\Service\\AndroidPublisher\\ImagesDeleteAllResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ImagesDeleteAllResponse.php',
    'Google\\Service\\AndroidPublisher\\ImagesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ImagesListResponse.php',
    'Google\\Service\\AndroidPublisher\\ImagesUploadResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ImagesUploadResponse.php',
    'Google\\Service\\AndroidPublisher\\InAppProduct' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InAppProduct.php',
    'Google\\Service\\AndroidPublisher\\InAppProductListing' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InAppProductListing.php',
    'Google\\Service\\AndroidPublisher\\InappproductsBatchDeleteRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsBatchDeleteRequest.php',
    'Google\\Service\\AndroidPublisher\\InappproductsBatchGetResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsBatchGetResponse.php',
    'Google\\Service\\AndroidPublisher\\InappproductsBatchUpdateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsBatchUpdateRequest.php',
    'Google\\Service\\AndroidPublisher\\InappproductsBatchUpdateResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsBatchUpdateResponse.php',
    'Google\\Service\\AndroidPublisher\\InappproductsDeleteRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsDeleteRequest.php',
    'Google\\Service\\AndroidPublisher\\InappproductsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsListResponse.php',
    'Google\\Service\\AndroidPublisher\\InappproductsUpdateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InappproductsUpdateRequest.php',
    'Google\\Service\\AndroidPublisher\\InstallmentPlan' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InstallmentPlan.php',
    'Google\\Service\\AndroidPublisher\\InstallmentsBasePlanType' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InstallmentsBasePlanType.php',
    'Google\\Service\\AndroidPublisher\\InternalAppSharingArtifact' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/InternalAppSharingArtifact.php',
    'Google\\Service\\AndroidPublisher\\IntroductoryPriceInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/IntroductoryPriceInfo.php',
    'Google\\Service\\AndroidPublisher\\LanguageTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/LanguageTargeting.php',
    'Google\\Service\\AndroidPublisher\\ListAppRecoveriesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListAppRecoveriesResponse.php',
    'Google\\Service\\AndroidPublisher\\ListDeviceTierConfigsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListDeviceTierConfigsResponse.php',
    'Google\\Service\\AndroidPublisher\\ListSubscriptionOffersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListSubscriptionOffersResponse.php',
    'Google\\Service\\AndroidPublisher\\ListSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListSubscriptionsResponse.php',
    'Google\\Service\\AndroidPublisher\\ListUsersResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListUsersResponse.php',
    'Google\\Service\\AndroidPublisher\\Listing' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Listing.php',
    'Google\\Service\\AndroidPublisher\\ListingsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ListingsListResponse.php',
    'Google\\Service\\AndroidPublisher\\LocalizedText' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/LocalizedText.php',
    'Google\\Service\\AndroidPublisher\\ManagedProductTaxAndComplianceSettings' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ManagedProductTaxAndComplianceSettings.php',
    'Google\\Service\\AndroidPublisher\\MigrateBasePlanPricesRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/MigrateBasePlanPricesRequest.php',
    'Google\\Service\\AndroidPublisher\\MigrateBasePlanPricesResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/MigrateBasePlanPricesResponse.php',
    'Google\\Service\\AndroidPublisher\\ModuleMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ModuleMetadata.php',
    'Google\\Service\\AndroidPublisher\\ModuleTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ModuleTargeting.php',
    'Google\\Service\\AndroidPublisher\\Money' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Money.php',
    'Google\\Service\\AndroidPublisher\\MultiAbi' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/MultiAbi.php',
    'Google\\Service\\AndroidPublisher\\MultiAbiTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/MultiAbiTargeting.php',
    'Google\\Service\\AndroidPublisher\\OfferDetails' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OfferDetails.php',
    'Google\\Service\\AndroidPublisher\\OfferTag' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OfferTag.php',
    'Google\\Service\\AndroidPublisher\\OneTimeExternalTransaction' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OneTimeExternalTransaction.php',
    'Google\\Service\\AndroidPublisher\\OtherRecurringProduct' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRecurringProduct.php',
    'Google\\Service\\AndroidPublisher\\OtherRegionsBasePlanConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRegionsBasePlanConfig.php',
    'Google\\Service\\AndroidPublisher\\OtherRegionsSubscriptionOfferConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRegionsSubscriptionOfferConfig.php',
    'Google\\Service\\AndroidPublisher\\OtherRegionsSubscriptionOfferPhaseConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRegionsSubscriptionOfferPhaseConfig.php',
    'Google\\Service\\AndroidPublisher\\OtherRegionsSubscriptionOfferPhaseFreePriceOverride' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRegionsSubscriptionOfferPhaseFreePriceOverride.php',
    'Google\\Service\\AndroidPublisher\\OtherRegionsSubscriptionOfferPhasePrices' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/OtherRegionsSubscriptionOfferPhasePrices.php',
    'Google\\Service\\AndroidPublisher\\PageInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PageInfo.php',
    'Google\\Service\\AndroidPublisher\\PartialRefund' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PartialRefund.php',
    'Google\\Service\\AndroidPublisher\\PausedStateContext' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PausedStateContext.php',
    'Google\\Service\\AndroidPublisher\\PendingCancellation' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PendingCancellation.php',
    'Google\\Service\\AndroidPublisher\\PrepaidBasePlanType' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PrepaidBasePlanType.php',
    'Google\\Service\\AndroidPublisher\\PrepaidPlan' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/PrepaidPlan.php',
    'Google\\Service\\AndroidPublisher\\Price' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Price.php',
    'Google\\Service\\AndroidPublisher\\ProductPurchase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ProductPurchase.php',
    'Google\\Service\\AndroidPublisher\\ProductPurchasesAcknowledgeRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ProductPurchasesAcknowledgeRequest.php',
    'Google\\Service\\AndroidPublisher\\RecurringExternalTransaction' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RecurringExternalTransaction.php',
    'Google\\Service\\AndroidPublisher\\RefundExternalTransactionRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RefundExternalTransactionRequest.php',
    'Google\\Service\\AndroidPublisher\\RegionalBasePlanConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalBasePlanConfig.php',
    'Google\\Service\\AndroidPublisher\\RegionalPriceMigrationConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalPriceMigrationConfig.php',
    'Google\\Service\\AndroidPublisher\\RegionalSubscriptionOfferConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalSubscriptionOfferConfig.php',
    'Google\\Service\\AndroidPublisher\\RegionalSubscriptionOfferPhaseConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalSubscriptionOfferPhaseConfig.php',
    'Google\\Service\\AndroidPublisher\\RegionalSubscriptionOfferPhaseFreePriceOverride' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalSubscriptionOfferPhaseFreePriceOverride.php',
    'Google\\Service\\AndroidPublisher\\RegionalTaxRateInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionalTaxRateInfo.php',
    'Google\\Service\\AndroidPublisher\\Regions' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Regions.php',
    'Google\\Service\\AndroidPublisher\\RegionsVersion' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RegionsVersion.php',
    'Google\\Service\\AndroidPublisher\\RemoteInAppUpdate' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RemoteInAppUpdate.php',
    'Google\\Service\\AndroidPublisher\\RemoteInAppUpdateData' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RemoteInAppUpdateData.php',
    'Google\\Service\\AndroidPublisher\\RemoteInAppUpdateDataPerBundle' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RemoteInAppUpdateDataPerBundle.php',
    'Google\\Service\\AndroidPublisher\\ReplacementCancellation' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ReplacementCancellation.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Applications' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Applications.php',
    'Google\\Service\\AndroidPublisher\\Resource\\ApplicationsDeviceTierConfigs' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/ApplicationsDeviceTierConfigs.php',
    'Google\\Service\\AndroidPublisher\\Resource\\ApplicationsPricing' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/ApplicationsPricing.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Apprecovery' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Apprecovery.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Edits' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Edits.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsApks' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsApks.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsBundles' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsBundles.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsCountryavailability' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsCountryavailability.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsDeobfuscationfiles' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsDeobfuscationfiles.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsDetails' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsDetails.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsExpansionfiles' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsExpansionfiles.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsImages' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsImages.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsListings' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsListings.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsTesters' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsTesters.php',
    'Google\\Service\\AndroidPublisher\\Resource\\EditsTracks' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/EditsTracks.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Externaltransactions' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Externaltransactions.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Generatedapks' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Generatedapks.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Grants' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Grants.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Inappproducts' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Inappproducts.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Internalappsharingartifacts' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Internalappsharingartifacts.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Monetization' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Monetization.php',
    'Google\\Service\\AndroidPublisher\\Resource\\MonetizationSubscriptions' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/MonetizationSubscriptions.php',
    'Google\\Service\\AndroidPublisher\\Resource\\MonetizationSubscriptionsBasePlans' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/MonetizationSubscriptionsBasePlans.php',
    'Google\\Service\\AndroidPublisher\\Resource\\MonetizationSubscriptionsBasePlansOffers' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/MonetizationSubscriptionsBasePlansOffers.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Orders' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Orders.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Purchases' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Purchases.php',
    'Google\\Service\\AndroidPublisher\\Resource\\PurchasesProducts' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/PurchasesProducts.php',
    'Google\\Service\\AndroidPublisher\\Resource\\PurchasesSubscriptions' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/PurchasesSubscriptions.php',
    'Google\\Service\\AndroidPublisher\\Resource\\PurchasesSubscriptionsv2' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/PurchasesSubscriptionsv2.php',
    'Google\\Service\\AndroidPublisher\\Resource\\PurchasesVoidedpurchases' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/PurchasesVoidedpurchases.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Reviews' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Reviews.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Systemapks' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Systemapks.php',
    'Google\\Service\\AndroidPublisher\\Resource\\SystemapksVariants' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/SystemapksVariants.php',
    'Google\\Service\\AndroidPublisher\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Resource/Users.php',
    'Google\\Service\\AndroidPublisher\\RestrictedPaymentCountries' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RestrictedPaymentCountries.php',
    'Google\\Service\\AndroidPublisher\\Review' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Review.php',
    'Google\\Service\\AndroidPublisher\\ReviewReplyResult' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ReviewReplyResult.php',
    'Google\\Service\\AndroidPublisher\\ReviewsListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ReviewsListResponse.php',
    'Google\\Service\\AndroidPublisher\\ReviewsReplyRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ReviewsReplyRequest.php',
    'Google\\Service\\AndroidPublisher\\ReviewsReplyResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ReviewsReplyResponse.php',
    'Google\\Service\\AndroidPublisher\\RevocationContext' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RevocationContext.php',
    'Google\\Service\\AndroidPublisher\\RevocationContextFullRefund' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RevocationContextFullRefund.php',
    'Google\\Service\\AndroidPublisher\\RevocationContextProratedRefund' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RevocationContextProratedRefund.php',
    'Google\\Service\\AndroidPublisher\\RevokeSubscriptionPurchaseRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RevokeSubscriptionPurchaseRequest.php',
    'Google\\Service\\AndroidPublisher\\RevokeSubscriptionPurchaseResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/RevokeSubscriptionPurchaseResponse.php',
    'Google\\Service\\AndroidPublisher\\SafetyLabelsUpdateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SafetyLabelsUpdateRequest.php',
    'Google\\Service\\AndroidPublisher\\SafetyLabelsUpdateResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SafetyLabelsUpdateResponse.php',
    'Google\\Service\\AndroidPublisher\\ScreenDensity' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ScreenDensity.php',
    'Google\\Service\\AndroidPublisher\\ScreenDensityTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/ScreenDensityTargeting.php',
    'Google\\Service\\AndroidPublisher\\SdkVersion' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SdkVersion.php',
    'Google\\Service\\AndroidPublisher\\SdkVersionTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SdkVersionTargeting.php',
    'Google\\Service\\AndroidPublisher\\SplitApkMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SplitApkMetadata.php',
    'Google\\Service\\AndroidPublisher\\SplitApkVariant' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SplitApkVariant.php',
    'Google\\Service\\AndroidPublisher\\StandaloneApkMetadata' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/StandaloneApkMetadata.php',
    'Google\\Service\\AndroidPublisher\\SubscribeWithGoogleInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscribeWithGoogleInfo.php',
    'Google\\Service\\AndroidPublisher\\Subscription' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Subscription.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionCancelSurveyResult' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionCancelSurveyResult.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionDeferralInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionDeferralInfo.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionItemPriceChangeDetails' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionItemPriceChangeDetails.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionListing' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionListing.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionOffer' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionOffer.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionOfferPhase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionOfferPhase.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionOfferTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionOfferTargeting.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPriceChange' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPriceChange.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchase.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchaseLineItem' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchaseLineItem.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchaseV2' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchaseV2.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchasesAcknowledgeRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchasesAcknowledgeRequest.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchasesDeferRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchasesDeferRequest.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionPurchasesDeferResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionPurchasesDeferResponse.php',
    'Google\\Service\\AndroidPublisher\\SubscriptionTaxAndComplianceSettings' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SubscriptionTaxAndComplianceSettings.php',
    'Google\\Service\\AndroidPublisher\\SystemApkOptions' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SystemApkOptions.php',
    'Google\\Service\\AndroidPublisher\\SystemApksListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SystemApksListResponse.php',
    'Google\\Service\\AndroidPublisher\\SystemFeature' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SystemFeature.php',
    'Google\\Service\\AndroidPublisher\\SystemInitiatedCancellation' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/SystemInitiatedCancellation.php',
    'Google\\Service\\AndroidPublisher\\Targeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Targeting.php',
    'Google\\Service\\AndroidPublisher\\TargetingInfo' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TargetingInfo.php',
    'Google\\Service\\AndroidPublisher\\TargetingRuleScope' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TargetingRuleScope.php',
    'Google\\Service\\AndroidPublisher\\TargetingRuleScopeAnySubscriptionInApp' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TargetingRuleScopeAnySubscriptionInApp.php',
    'Google\\Service\\AndroidPublisher\\TargetingRuleScopeThisSubscription' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TargetingRuleScopeThisSubscription.php',
    'Google\\Service\\AndroidPublisher\\TargetingUpdate' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TargetingUpdate.php',
    'Google\\Service\\AndroidPublisher\\TestPurchase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TestPurchase.php',
    'Google\\Service\\AndroidPublisher\\Testers' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Testers.php',
    'Google\\Service\\AndroidPublisher\\TextureCompressionFormat' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TextureCompressionFormat.php',
    'Google\\Service\\AndroidPublisher\\TextureCompressionFormatTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TextureCompressionFormatTargeting.php',
    'Google\\Service\\AndroidPublisher\\Timestamp' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Timestamp.php',
    'Google\\Service\\AndroidPublisher\\TokenPagination' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TokenPagination.php',
    'Google\\Service\\AndroidPublisher\\Track' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Track.php',
    'Google\\Service\\AndroidPublisher\\TrackConfig' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TrackConfig.php',
    'Google\\Service\\AndroidPublisher\\TrackCountryAvailability' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TrackCountryAvailability.php',
    'Google\\Service\\AndroidPublisher\\TrackRelease' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TrackRelease.php',
    'Google\\Service\\AndroidPublisher\\TrackTargetedCountry' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TrackTargetedCountry.php',
    'Google\\Service\\AndroidPublisher\\TracksListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/TracksListResponse.php',
    'Google\\Service\\AndroidPublisher\\UNDEFINEDPackageNameRevocationContextProratedRefund' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UNDEFINEDPackageNameRevocationContextProratedRefund.php',
    'Google\\Service\\AndroidPublisher\\UpdateBasePlanStateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UpdateBasePlanStateRequest.php',
    'Google\\Service\\AndroidPublisher\\UpdateSubscriptionOfferRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UpdateSubscriptionOfferRequest.php',
    'Google\\Service\\AndroidPublisher\\UpdateSubscriptionOfferStateRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UpdateSubscriptionOfferStateRequest.php',
    'Google\\Service\\AndroidPublisher\\UpdateSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UpdateSubscriptionRequest.php',
    'Google\\Service\\AndroidPublisher\\UpgradeTargetingRule' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UpgradeTargetingRule.php',
    'Google\\Service\\AndroidPublisher\\User' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/User.php',
    'Google\\Service\\AndroidPublisher\\UserComment' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UserComment.php',
    'Google\\Service\\AndroidPublisher\\UserCountriesTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UserCountriesTargeting.php',
    'Google\\Service\\AndroidPublisher\\UserCountrySet' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UserCountrySet.php',
    'Google\\Service\\AndroidPublisher\\UserInitiatedCancellation' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UserInitiatedCancellation.php',
    'Google\\Service\\AndroidPublisher\\UsesPermission' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/UsesPermission.php',
    'Google\\Service\\AndroidPublisher\\Variant' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/Variant.php',
    'Google\\Service\\AndroidPublisher\\VariantTargeting' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/VariantTargeting.php',
    'Google\\Service\\AndroidPublisher\\VoidedPurchase' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/VoidedPurchase.php',
    'Google\\Service\\AndroidPublisher\\VoidedPurchasesListResponse' => $vendorDir . '/google/apiclient-services/src/AndroidPublisher/VoidedPurchasesListResponse.php',
    'Google\\Service\\ApiKeysService' => $vendorDir . '/google/apiclient-services/src/ApiKeysService.php',
    'Google\\Service\\ApiKeysService\\Operation' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Operation.php',
    'Google\\Service\\ApiKeysService\\Resource\\Keys' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Resource/Keys.php',
    'Google\\Service\\ApiKeysService\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Resource/Operations.php',
    'Google\\Service\\ApiKeysService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Resource/Projects.php',
    'Google\\Service\\ApiKeysService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Resource/ProjectsLocations.php',
    'Google\\Service\\ApiKeysService\\Resource\\ProjectsLocationsKeys' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Resource/ProjectsLocationsKeys.php',
    'Google\\Service\\ApiKeysService\\Status' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/Status.php',
    'Google\\Service\\ApiKeysService\\V2AndroidApplication' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2AndroidApplication.php',
    'Google\\Service\\ApiKeysService\\V2AndroidKeyRestrictions' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2AndroidKeyRestrictions.php',
    'Google\\Service\\ApiKeysService\\V2ApiTarget' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2ApiTarget.php',
    'Google\\Service\\ApiKeysService\\V2BrowserKeyRestrictions' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2BrowserKeyRestrictions.php',
    'Google\\Service\\ApiKeysService\\V2CloneKeyRequest' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2CloneKeyRequest.php',
    'Google\\Service\\ApiKeysService\\V2GetKeyStringResponse' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2GetKeyStringResponse.php',
    'Google\\Service\\ApiKeysService\\V2IosKeyRestrictions' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2IosKeyRestrictions.php',
    'Google\\Service\\ApiKeysService\\V2Key' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2Key.php',
    'Google\\Service\\ApiKeysService\\V2ListKeysResponse' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2ListKeysResponse.php',
    'Google\\Service\\ApiKeysService\\V2LookupKeyResponse' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2LookupKeyResponse.php',
    'Google\\Service\\ApiKeysService\\V2Restrictions' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2Restrictions.php',
    'Google\\Service\\ApiKeysService\\V2ServerKeyRestrictions' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2ServerKeyRestrictions.php',
    'Google\\Service\\ApiKeysService\\V2UndeleteKeyRequest' => $vendorDir . '/google/apiclient-services/src/ApiKeysService/V2UndeleteKeyRequest.php',
    'Google\\Service\\Apigateway' => $vendorDir . '/google/apiclient-services/src/Apigateway.php',
    'Google\\Service\\Apigateway\\ApigatewayApi' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayApi.php',
    'Google\\Service\\Apigateway\\ApigatewayApiConfig' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayApiConfig.php',
    'Google\\Service\\Apigateway\\ApigatewayApiConfigFile' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayApiConfigFile.php',
    'Google\\Service\\Apigateway\\ApigatewayApiConfigGrpcServiceDefinition' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayApiConfigGrpcServiceDefinition.php',
    'Google\\Service\\Apigateway\\ApigatewayApiConfigOpenApiDocument' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayApiConfigOpenApiDocument.php',
    'Google\\Service\\Apigateway\\ApigatewayAuditConfig' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayAuditConfig.php',
    'Google\\Service\\Apigateway\\ApigatewayAuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayAuditLogConfig.php',
    'Google\\Service\\Apigateway\\ApigatewayBinding' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayBinding.php',
    'Google\\Service\\Apigateway\\ApigatewayCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayCancelOperationRequest.php',
    'Google\\Service\\Apigateway\\ApigatewayEmpty' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayEmpty.php',
    'Google\\Service\\Apigateway\\ApigatewayExpr' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayExpr.php',
    'Google\\Service\\Apigateway\\ApigatewayGateway' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayGateway.php',
    'Google\\Service\\Apigateway\\ApigatewayListApiConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayListApiConfigsResponse.php',
    'Google\\Service\\Apigateway\\ApigatewayListApisResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayListApisResponse.php',
    'Google\\Service\\Apigateway\\ApigatewayListGatewaysResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayListGatewaysResponse.php',
    'Google\\Service\\Apigateway\\ApigatewayListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayListLocationsResponse.php',
    'Google\\Service\\Apigateway\\ApigatewayListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayListOperationsResponse.php',
    'Google\\Service\\Apigateway\\ApigatewayLocation' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayLocation.php',
    'Google\\Service\\Apigateway\\ApigatewayOperation' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayOperation.php',
    'Google\\Service\\Apigateway\\ApigatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayOperationMetadata.php',
    'Google\\Service\\Apigateway\\ApigatewayOperationMetadataDiagnostic' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayOperationMetadataDiagnostic.php',
    'Google\\Service\\Apigateway\\ApigatewayPolicy' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayPolicy.php',
    'Google\\Service\\Apigateway\\ApigatewaySetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewaySetIamPolicyRequest.php',
    'Google\\Service\\Apigateway\\ApigatewayStatus' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayStatus.php',
    'Google\\Service\\Apigateway\\ApigatewayTestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayTestIamPermissionsRequest.php',
    'Google\\Service\\Apigateway\\ApigatewayTestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigateway/ApigatewayTestIamPermissionsResponse.php',
    'Google\\Service\\Apigateway\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/Projects.php',
    'Google\\Service\\Apigateway\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/ProjectsLocations.php',
    'Google\\Service\\Apigateway\\Resource\\ProjectsLocationsApis' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/ProjectsLocationsApis.php',
    'Google\\Service\\Apigateway\\Resource\\ProjectsLocationsApisConfigs' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/ProjectsLocationsApisConfigs.php',
    'Google\\Service\\Apigateway\\Resource\\ProjectsLocationsGateways' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/ProjectsLocationsGateways.php',
    'Google\\Service\\Apigateway\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Apigateway/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Apigee' => $vendorDir . '/google/apiclient-services/src/Apigee.php',
    'Google\\Service\\ApigeeRegistry' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry.php',
    'Google\\Service\\ApigeeRegistry\\Api' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Api.php',
    'Google\\Service\\ApigeeRegistry\\ApiDeployment' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ApiDeployment.php',
    'Google\\Service\\ApigeeRegistry\\ApiSpec' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ApiSpec.php',
    'Google\\Service\\ApigeeRegistry\\ApiVersion' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ApiVersion.php',
    'Google\\Service\\ApigeeRegistry\\ApigeeregistryEmpty' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ApigeeregistryEmpty.php',
    'Google\\Service\\ApigeeRegistry\\Artifact' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Artifact.php',
    'Google\\Service\\ApigeeRegistry\\Binding' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Binding.php',
    'Google\\Service\\ApigeeRegistry\\Build' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Build.php',
    'Google\\Service\\ApigeeRegistry\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/CancelOperationRequest.php',
    'Google\\Service\\ApigeeRegistry\\Config' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Config.php',
    'Google\\Service\\ApigeeRegistry\\Expr' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Expr.php',
    'Google\\Service\\ApigeeRegistry\\HttpBody' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/HttpBody.php',
    'Google\\Service\\ApigeeRegistry\\Instance' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Instance.php',
    'Google\\Service\\ApigeeRegistry\\ListApiDeploymentRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApiDeploymentRevisionsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListApiDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApiDeploymentsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListApiSpecRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApiSpecRevisionsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListApiSpecsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApiSpecsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListApiVersionsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApiVersionsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListApisResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListApisResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListArtifactsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListLocationsResponse.php',
    'Google\\Service\\ApigeeRegistry\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/ListOperationsResponse.php',
    'Google\\Service\\ApigeeRegistry\\Location' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Location.php',
    'Google\\Service\\ApigeeRegistry\\Operation' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Operation.php',
    'Google\\Service\\ApigeeRegistry\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/OperationMetadata.php',
    'Google\\Service\\ApigeeRegistry\\Policy' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Policy.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/Projects.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocations.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApis' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApis.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisArtifacts' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisArtifacts.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisDeployments' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisDeployments.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisDeploymentsArtifacts' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisDeploymentsArtifacts.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisVersions' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisVersions.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisVersionsArtifacts' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisVersionsArtifacts.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisVersionsSpecs' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisVersionsSpecs.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsApisVersionsSpecsArtifacts' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsApisVersionsSpecsArtifacts.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsArtifacts' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsArtifacts.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsDocuments' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsDocuments.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\ApigeeRegistry\\Resource\\ProjectsLocationsRuntime' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Resource/ProjectsLocationsRuntime.php',
    'Google\\Service\\ApigeeRegistry\\RollbackApiDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/RollbackApiDeploymentRequest.php',
    'Google\\Service\\ApigeeRegistry\\RollbackApiSpecRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/RollbackApiSpecRequest.php',
    'Google\\Service\\ApigeeRegistry\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/SetIamPolicyRequest.php',
    'Google\\Service\\ApigeeRegistry\\Status' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/Status.php',
    'Google\\Service\\ApigeeRegistry\\TagApiDeploymentRevisionRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/TagApiDeploymentRevisionRequest.php',
    'Google\\Service\\ApigeeRegistry\\TagApiSpecRevisionRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/TagApiSpecRevisionRequest.php',
    'Google\\Service\\ApigeeRegistry\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/TestIamPermissionsRequest.php',
    'Google\\Service\\ApigeeRegistry\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ApigeeRegistry/TestIamPermissionsResponse.php',
    'Google\\Service\\Apigee\\EdgeConfigstoreBundleBadBundle' => $vendorDir . '/google/apiclient-services/src/Apigee/EdgeConfigstoreBundleBadBundle.php',
    'Google\\Service\\Apigee\\EdgeConfigstoreBundleBadBundleViolation' => $vendorDir . '/google/apiclient-services/src/Apigee/EdgeConfigstoreBundleBadBundleViolation.php',
    'Google\\Service\\Apigee\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleApiHttpBody.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1APIProductAssociation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1APIProductAssociation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Access' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Access.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AccessGet' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AccessGet.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AccessLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AccessLoggingConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AccessRemove' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AccessRemove.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AccessSet' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AccessSet.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ActivateNatAddressRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ActivateNatAddressRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AddonsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AddonsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AdjustDeveloperBalanceRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AdjustDeveloperBalanceRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AdvancedApiOpsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AdvancedApiOpsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Alias' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Alias.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AliasRevisionConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AliasRevisionConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AnalyticsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AnalyticsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiCategory' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiCategory.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiCategoryData' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiCategoryData.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiCategoryResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiCategoryResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiDoc' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiDoc.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiDocDocumentation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiDocDocumentation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiDocDocumentationResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiDocDocumentationResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiDocResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiDocResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiProduct' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiProduct.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiProductRef' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiProductRef.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiProxy' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiProxy.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiProxyRevision' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiProxyRevision.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiResponseWrapper' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiResponseWrapper.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiSecurityConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiSecurityConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ApiSecurityRuntimeConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ApiSecurityRuntimeConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1App' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1App.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AppGroup' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AppGroup.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AppGroupApp' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AppGroupApp.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AppGroupAppKey' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AppGroupAppKey.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ArchiveDeployment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ArchiveDeployment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AsyncQuery' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AsyncQuery.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AsyncQueryResult' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AsyncQueryResult.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1AsyncQueryResultView' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1AsyncQueryResultView.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Attribute' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Attribute.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Attributes' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Attributes.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchUpdateSecurityIncidentsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchUpdateSecurityIncidentsRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1BatchUpdateSecurityIncidentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1BatchUpdateSecurityIncidentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CanaryEvaluation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CanaryEvaluation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CanaryEvaluationMetricLabels' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CanaryEvaluationMetricLabels.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CertInfo' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CertInfo.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Certificate' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Certificate.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CommonNameConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CommonNameConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ComputeEnvironmentScoresRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ComputeEnvironmentScoresRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ComputeEnvironmentScoresRequestFilter' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ComputeEnvironmentScoresRequestFilter.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ComputeEnvironmentScoresResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ComputeEnvironmentScoresResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ConfigVersion' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ConfigVersion.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ConnectorsPlatformConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ConnectorsPlatformConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Credential' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Credential.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CreditDeveloperBalanceRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CreditDeveloperBalanceRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CustomReport' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CustomReport.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1CustomReportMetric' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1CustomReportMetric.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DataCollector' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DataCollector.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DataCollectorConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DataCollectorConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Datastore' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Datastore.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DatastoreConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DatastoreConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DateRange' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DateRange.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DebugMask' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DebugMask.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DebugSession' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DebugSession.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DebugSessionTransaction' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DebugSessionTransaction.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeleteCustomReportResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeleteCustomReportResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeleteResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeleteResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Deployment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Deployment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentChangeReport' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentChangeReport.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentChangeReportRoutingChange' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentChangeReportRoutingChange.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeploymentGroupConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeploymentGroupConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Developer' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Developer.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperApp' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperApp.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperAppKey' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperAppKey.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperBalance' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperBalance.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperBalanceWallet' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperBalanceWallet.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperMonetizationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperMonetizationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DeveloperSubscription' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DeveloperSubscription.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DimensionMetric' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DimensionMetric.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DisableSecurityActionRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DisableSecurityActionRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1DocumentationFile' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1DocumentationFile.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EnableSecurityActionRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EnableSecurityActionRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EndpointAttachment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EndpointAttachment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EndpointChainingRule' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EndpointChainingRule.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EntityMetadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EntityMetadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Environment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Environment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EnvironmentConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EnvironmentGroup' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EnvironmentGroup.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EnvironmentGroupAttachment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EnvironmentGroupAttachment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1EnvironmentGroupConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1EnvironmentGroupConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ExpireDeveloperSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ExpireDeveloperSubscriptionRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Export' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Export.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ExportRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ExportRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1FlowHook' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1FlowHook.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1FlowHookConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1FlowHookConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GenerateDownloadUrlRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GenerateDownloadUrlRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GenerateDownloadUrlResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GenerateDownloadUrlResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GenerateUploadUrlRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GenerateUploadUrlRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GenerateUploadUrlResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GenerateUploadUrlResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GetAsyncQueryResultUrlResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GetAsyncQueryResultUrlResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GetAsyncQueryResultUrlResponseURLInfo' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GetAsyncQueryResultUrlResponseURLInfo.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GetSyncAuthorizationRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GetSyncAuthorizationRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GraphQLOperation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GraphQLOperation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GraphQLOperationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GraphQLOperationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GraphQLOperationGroup' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GraphQLOperationGroup.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GraphqlDocumentation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GraphqlDocumentation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GrpcOperationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GrpcOperationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1GrpcOperationGroup' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1GrpcOperationGroup.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1IngressConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1IngressConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Instance' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Instance.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1InstanceAttachment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1InstanceAttachment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1InstanceDeploymentStatus' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1InstanceDeploymentStatus.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRevision' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRevision.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRoute' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRoute.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1IntegrationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1IntegrationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1KeyAliasReference' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1KeyAliasReference.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1KeyValueEntry' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1KeyValueEntry.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1KeyValueMap' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1KeyValueMap.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Keystore' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Keystore.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1KeystoreConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1KeystoreConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListApiCategoriesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListApiCategoriesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListApiDocsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListApiDocsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListApiProductsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListApiProductsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListApiProxiesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListApiProxiesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListAppGroupAppsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListAppGroupAppsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListAppGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListAppGroupsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListAppsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListAppsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListArchiveDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListArchiveDeploymentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListAsyncQueriesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListAsyncQueriesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListCustomReportsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListCustomReportsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDataCollectorsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDataCollectorsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDatastoresResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDatastoresResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDebugSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDebugSessionsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDeploymentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDeveloperAppsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDeveloperAppsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListDeveloperSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListDeveloperSubscriptionsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListEndpointAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListEndpointAttachmentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListEnvironmentGroupAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListEnvironmentGroupAttachmentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListEnvironmentGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListEnvironmentGroupsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListEnvironmentResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListEnvironmentResourcesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListExportsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListExportsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListHybridIssuersResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListHybridIssuersResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListInstanceAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListInstanceAttachmentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListInstancesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListKeyValueEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListKeyValueEntriesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListNatAddressesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListNatAddressesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListOfDevelopersResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListOfDevelopersResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListOrganizationsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListOrganizationsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListRatePlansResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListRatePlansResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSecurityActionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSecurityActionsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSecurityIncidentsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSecurityIncidentsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSecurityProfileRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSecurityProfileRevisionsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSecurityProfilesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSecurityProfilesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSecurityReportsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSecurityReportsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListSharedFlowsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListSharedFlowsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ListTraceConfigOverridesResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ListTraceConfigOverridesResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Metadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Metadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Metric' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Metric.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1MetricAggregation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1MetricAggregation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1MonetizationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1MonetizationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1NatAddress' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1NatAddress.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1NodeConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1NodeConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OASDocumentation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OASDocumentation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Operation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Operation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OperationConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OperationConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OperationGroup' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OperationGroup.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OperationMetadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OperationMetadataProgress' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OperationMetadataProgress.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OptimizedStats' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OptimizedStats.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OptimizedStatsNode' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OptimizedStatsNode.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OptimizedStatsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OptimizedStatsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Organization' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Organization.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1OrganizationProjectMapping' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1OrganizationProjectMapping.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1PodStatus' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1PodStatus.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Point' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Point.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigAbuse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigAbuse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigAuthorization' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigAuthorization.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigCORS' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigCORS.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigCategory' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigCategory.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigMTLS' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigMTLS.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigMediation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigMediation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProfileConfigThreat' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProfileConfigThreat.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Properties' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Properties.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Property' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Property.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ProvisionOrganizationRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ProvisionOrganizationRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Query' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Query.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryMetadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryMetadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryMetric' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryMetric.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryTabularStatsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryTabularStatsRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryTabularStatsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryTabularStatsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryTimeSeriesStatsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryTimeSeriesStatsRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryTimeSeriesStatsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryTimeSeriesStatsResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Quota' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Quota.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RatePlan' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RatePlan.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RateRange' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RateRange.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Reference' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Reference.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ReferenceConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ReferenceConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ReportInstanceStatusRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ReportInstanceStatusRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ReportInstanceStatusResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ReportInstanceStatusResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ReportProperty' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ReportProperty.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ResourceConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ResourceConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ResourceFile' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ResourceFile.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ResourceFiles' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ResourceFiles.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ResourceStatus' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ResourceStatus.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Result' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Result.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RevenueShareRange' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RevenueShareRange.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RevisionStatus' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RevisionStatus.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RoutingRule' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RoutingRule.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeAddonsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeAddonsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeAnalyticsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeAnalyticsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeApiSecurityConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeApiSecurityConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeTraceConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeTraceConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeTraceConfigOverride' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeTraceConfigOverride.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1RuntimeTraceSamplingConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1RuntimeTraceSamplingConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Schema' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Schema.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SchemaSchemaElement' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SchemaSchemaElement.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SchemaSchemaProperty' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SchemaSchemaProperty.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Score' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Score.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ScoreComponent' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ScoreComponent.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ScoreComponentRecommendation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ScoreComponentRecommendation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ScoreComponentRecommendationAction' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ScoreComponentRecommendationAction.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ScoreComponentRecommendationActionActionContext' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ScoreComponentRecommendationActionActionContext.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAction' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAction.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionAllow' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionAllow.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionConditionConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionConditionConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionDeny' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionDeny.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionFlag' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionFlag.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionHttpHeader' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionHttpHeader.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityActionsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityActionsConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResult' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResult.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResultResource' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResultResource.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResultScoringResult' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResultScoringResult.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendationLink' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendationLink.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityIncident' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityIncident.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityProfile' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityProfile.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityProfileEnvironment' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityProfileEnvironment.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityProfileScoringConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityProfileScoringConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReport' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReport.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReportMetadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReportMetadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReportQuery' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReportQuery.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReportQueryMetric' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReportQueryMetric.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReportResultMetadata' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReportResultMetadata.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecurityReportResultView' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecurityReportResultView.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SecuritySettings' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SecuritySettings.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1ServiceIssuersMapping' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1ServiceIssuersMapping.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Session' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Session.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SetAddonEnablementRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SetAddonEnablementRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SetAddonsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SetAddonsRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SharedFlow' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SharedFlow.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SharedFlowRevision' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SharedFlowRevision.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Stats' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Stats.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1StatsEnvironmentStats' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1StatsEnvironmentStats.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1StatsHostStats' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1StatsHostStats.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1Subscription' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1Subscription.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1SyncAuthorization' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1SyncAuthorization.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TargetServer' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TargetServer.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TargetServerConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TargetServerConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TestDatastoreResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TestDatastoreResponse.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TlsInfo' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TlsInfo.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TlsInfoCommonName' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TlsInfoCommonName.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TlsInfoConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TlsInfoConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TraceConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TraceConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TraceConfigOverride' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TraceConfigOverride.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1TraceSamplingConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1TraceSamplingConfig.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1UpdateError' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1UpdateError.php',
    'Google\\Service\\Apigee\\GoogleCloudApigeeV1UpdateSecurityIncidentRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleCloudApigeeV1UpdateSecurityIncidentRequest.php',
    'Google\\Service\\Apigee\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1AuditConfig.php',
    'Google\\Service\\Apigee\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\Apigee\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1Binding.php',
    'Google\\Service\\Apigee\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1Policy.php',
    'Google\\Service\\Apigee\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\Apigee\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\Apigee\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\Apigee\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Apigee\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleLongrunningOperation.php',
    'Google\\Service\\Apigee\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleProtobufEmpty.php',
    'Google\\Service\\Apigee\\GoogleRpcPreconditionFailure' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleRpcPreconditionFailure.php',
    'Google\\Service\\Apigee\\GoogleRpcPreconditionFailureViolation' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleRpcPreconditionFailureViolation.php',
    'Google\\Service\\Apigee\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleRpcStatus.php',
    'Google\\Service\\Apigee\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleTypeExpr.php',
    'Google\\Service\\Apigee\\GoogleTypeInterval' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleTypeInterval.php',
    'Google\\Service\\Apigee\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Apigee/GoogleTypeMoney.php',
    'Google\\Service\\Apigee\\Resource\\Hybrid' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/Hybrid.php',
    'Google\\Service\\Apigee\\Resource\\HybridIssuers' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/HybridIssuers.php',
    'Google\\Service\\Apigee\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/Organizations.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAnalytics' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAnalytics.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAnalyticsDatastores' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAnalyticsDatastores.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApiproducts' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApiproducts.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApiproductsAttributes' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApiproductsAttributes.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApiproductsRateplans' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApiproductsRateplans.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApis' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApis.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApisDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApisDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApisKeyvaluemaps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApisKeyvaluemaps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApisKeyvaluemapsEntries' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApisKeyvaluemapsEntries.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApisRevisions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApisRevisions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApisRevisionsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApisRevisionsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAppgroups' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAppgroups.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAppgroupsApps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAppgroupsApps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAppgroupsAppsKeys' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAppgroupsAppsKeys.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsAppgroupsAppsKeysApiproducts' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsAppgroupsAppsKeysApiproducts.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsApps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsApps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDatacollectors' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDatacollectors.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopers' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopers.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersApps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersApps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersAppsAttributes' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersAppsAttributes.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersAppsKeys' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersAppsKeys.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersAppsKeysApiproducts' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersAppsKeysApiproducts.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersAppsKeysCreate' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersAppsKeysCreate.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersAttributes' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersAttributes.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersBalance' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersBalance.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsDevelopersSubscriptions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsDevelopersSubscriptions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEndpointAttachments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEndpointAttachments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvgroups' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvgroups.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvgroupsAttachments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvgroupsAttachments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsAddonsConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsAddonsConfig.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsAnalytics' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsAnalytics.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsAnalyticsAdmin' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsAnalyticsAdmin.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsAnalyticsExports' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsAnalyticsExports.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApis' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApis.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApisDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApisDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApisRevisions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApisRevisions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApisRevisionsDebugsessions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApisRevisionsDebugsessions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApisRevisionsDebugsessionsData' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApisRevisionsDebugsessionsData.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsApisRevisionsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsApisRevisionsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsArchiveDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsArchiveDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsCaches' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsCaches.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsFlowhooks' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsFlowhooks.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsKeystores' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsKeystores.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsKeystoresAliases' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsKeystoresAliases.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsKeyvaluemaps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsKeyvaluemaps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsKeyvaluemapsEntries' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsKeyvaluemapsEntries.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsOptimizedStats' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsOptimizedStats.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsQueries' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsQueries.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsReferences' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsReferences.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsResourcefiles' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsResourcefiles.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSecurityActions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSecurityActions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSecurityIncidents' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSecurityIncidents.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSecurityReports' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSecurityReports.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSecurityStats' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSecurityStats.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSharedflows' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSharedflows.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSharedflowsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSharedflowsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsSharedflowsRevisions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsSharedflowsRevisions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsStats' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsStats.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsTargetservers' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsTargetservers.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsTraceConfig' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsTraceConfig.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsEnvironmentsTraceConfigOverrides' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsEnvironmentsTraceConfigOverrides.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsHostQueries' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsHostQueries.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsHostSecurityReports' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsHostSecurityReports.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsHostStats' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsHostStats.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsInstances' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsInstances.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsInstancesAttachments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsInstancesAttachments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsInstancesCanaryevaluations' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsInstancesCanaryevaluations.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsInstancesNatAddresses' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsInstancesNatAddresses.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsKeyvaluemaps' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsKeyvaluemaps.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsKeyvaluemapsEntries' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsKeyvaluemapsEntries.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsOperations' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsOperations.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsOptimizedHostStats' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsOptimizedHostStats.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsReports' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsReports.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSecurityAssessmentResults' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSecurityAssessmentResults.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSecurityProfiles' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSecurityProfiles.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSecurityProfilesEnvironments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSecurityProfilesEnvironments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSharedflows' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSharedflows.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSharedflowsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSharedflowsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSharedflowsRevisions' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSharedflowsRevisions.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSharedflowsRevisionsDeployments' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSharedflowsRevisionsDeployments.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSites' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSites.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSitesApicategories' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSitesApicategories.php',
    'Google\\Service\\Apigee\\Resource\\OrganizationsSitesApidocs' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/OrganizationsSitesApidocs.php',
    'Google\\Service\\Apigee\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Apigee/Resource/Projects.php',
    'Google\\Service\\AppHub' => $vendorDir . '/google/apiclient-services/src/AppHub.php',
    'Google\\Service\\AppHub\\ApphubEmpty' => $vendorDir . '/google/apiclient-services/src/AppHub/ApphubEmpty.php',
    'Google\\Service\\AppHub\\Application' => $vendorDir . '/google/apiclient-services/src/AppHub/Application.php',
    'Google\\Service\\AppHub\\Attributes' => $vendorDir . '/google/apiclient-services/src/AppHub/Attributes.php',
    'Google\\Service\\AppHub\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/AppHub/AuditConfig.php',
    'Google\\Service\\AppHub\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/AppHub/AuditLogConfig.php',
    'Google\\Service\\AppHub\\Binding' => $vendorDir . '/google/apiclient-services/src/AppHub/Binding.php',
    'Google\\Service\\AppHub\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/AppHub/CancelOperationRequest.php',
    'Google\\Service\\AppHub\\Channel' => $vendorDir . '/google/apiclient-services/src/AppHub/Channel.php',
    'Google\\Service\\AppHub\\ContactInfo' => $vendorDir . '/google/apiclient-services/src/AppHub/ContactInfo.php',
    'Google\\Service\\AppHub\\Criticality' => $vendorDir . '/google/apiclient-services/src/AppHub/Criticality.php',
    'Google\\Service\\AppHub\\DetachServiceProjectAttachmentRequest' => $vendorDir . '/google/apiclient-services/src/AppHub/DetachServiceProjectAttachmentRequest.php',
    'Google\\Service\\AppHub\\DetachServiceProjectAttachmentResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/DetachServiceProjectAttachmentResponse.php',
    'Google\\Service\\AppHub\\DiscoveredService' => $vendorDir . '/google/apiclient-services/src/AppHub/DiscoveredService.php',
    'Google\\Service\\AppHub\\DiscoveredWorkload' => $vendorDir . '/google/apiclient-services/src/AppHub/DiscoveredWorkload.php',
    'Google\\Service\\AppHub\\Environment' => $vendorDir . '/google/apiclient-services/src/AppHub/Environment.php',
    'Google\\Service\\AppHub\\Expr' => $vendorDir . '/google/apiclient-services/src/AppHub/Expr.php',
    'Google\\Service\\AppHub\\FindUnregisteredServicesResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/FindUnregisteredServicesResponse.php',
    'Google\\Service\\AppHub\\FindUnregisteredWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/FindUnregisteredWorkloadsResponse.php',
    'Google\\Service\\AppHub\\ListApplicationsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListApplicationsResponse.php',
    'Google\\Service\\AppHub\\ListDiscoveredServicesResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListDiscoveredServicesResponse.php',
    'Google\\Service\\AppHub\\ListDiscoveredWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListDiscoveredWorkloadsResponse.php',
    'Google\\Service\\AppHub\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListLocationsResponse.php',
    'Google\\Service\\AppHub\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListOperationsResponse.php',
    'Google\\Service\\AppHub\\ListServiceProjectAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListServiceProjectAttachmentsResponse.php',
    'Google\\Service\\AppHub\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListServicesResponse.php',
    'Google\\Service\\AppHub\\ListWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/ListWorkloadsResponse.php',
    'Google\\Service\\AppHub\\Location' => $vendorDir . '/google/apiclient-services/src/AppHub/Location.php',
    'Google\\Service\\AppHub\\LookupDiscoveredServiceResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/LookupDiscoveredServiceResponse.php',
    'Google\\Service\\AppHub\\LookupDiscoveredWorkloadResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/LookupDiscoveredWorkloadResponse.php',
    'Google\\Service\\AppHub\\LookupServiceProjectAttachmentResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/LookupServiceProjectAttachmentResponse.php',
    'Google\\Service\\AppHub\\Operation' => $vendorDir . '/google/apiclient-services/src/AppHub/Operation.php',
    'Google\\Service\\AppHub\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/AppHub/OperationMetadata.php',
    'Google\\Service\\AppHub\\Policy' => $vendorDir . '/google/apiclient-services/src/AppHub/Policy.php',
    'Google\\Service\\AppHub\\ReconciliationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/AppHub/ReconciliationOperationMetadata.php',
    'Google\\Service\\AppHub\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/Projects.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocations.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsApplications' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsApplications.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsApplicationsServices' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsApplicationsServices.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsApplicationsWorkloads' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsApplicationsWorkloads.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsDiscoveredServices' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsDiscoveredServices.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsDiscoveredWorkloads' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsDiscoveredWorkloads.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\AppHub\\Resource\\ProjectsLocationsServiceProjectAttachments' => $vendorDir . '/google/apiclient-services/src/AppHub/Resource/ProjectsLocationsServiceProjectAttachments.php',
    'Google\\Service\\AppHub\\Scope' => $vendorDir . '/google/apiclient-services/src/AppHub/Scope.php',
    'Google\\Service\\AppHub\\Service' => $vendorDir . '/google/apiclient-services/src/AppHub/Service.php',
    'Google\\Service\\AppHub\\ServiceProjectAttachment' => $vendorDir . '/google/apiclient-services/src/AppHub/ServiceProjectAttachment.php',
    'Google\\Service\\AppHub\\ServiceProperties' => $vendorDir . '/google/apiclient-services/src/AppHub/ServiceProperties.php',
    'Google\\Service\\AppHub\\ServiceReference' => $vendorDir . '/google/apiclient-services/src/AppHub/ServiceReference.php',
    'Google\\Service\\AppHub\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/AppHub/SetIamPolicyRequest.php',
    'Google\\Service\\AppHub\\Status' => $vendorDir . '/google/apiclient-services/src/AppHub/Status.php',
    'Google\\Service\\AppHub\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/AppHub/TestIamPermissionsRequest.php',
    'Google\\Service\\AppHub\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/AppHub/TestIamPermissionsResponse.php',
    'Google\\Service\\AppHub\\Workload' => $vendorDir . '/google/apiclient-services/src/AppHub/Workload.php',
    'Google\\Service\\AppHub\\WorkloadProperties' => $vendorDir . '/google/apiclient-services/src/AppHub/WorkloadProperties.php',
    'Google\\Service\\AppHub\\WorkloadReference' => $vendorDir . '/google/apiclient-services/src/AppHub/WorkloadReference.php',
    'Google\\Service\\Appengine' => $vendorDir . '/google/apiclient-services/src/Appengine.php',
    'Google\\Service\\Appengine\\ApiConfigHandler' => $vendorDir . '/google/apiclient-services/src/Appengine/ApiConfigHandler.php',
    'Google\\Service\\Appengine\\ApiEndpointHandler' => $vendorDir . '/google/apiclient-services/src/Appengine/ApiEndpointHandler.php',
    'Google\\Service\\Appengine\\AppengineEmpty' => $vendorDir . '/google/apiclient-services/src/Appengine/AppengineEmpty.php',
    'Google\\Service\\Appengine\\Application' => $vendorDir . '/google/apiclient-services/src/Appengine/Application.php',
    'Google\\Service\\Appengine\\AuthorizedCertificate' => $vendorDir . '/google/apiclient-services/src/Appengine/AuthorizedCertificate.php',
    'Google\\Service\\Appengine\\AuthorizedDomain' => $vendorDir . '/google/apiclient-services/src/Appengine/AuthorizedDomain.php',
    'Google\\Service\\Appengine\\AutomaticScaling' => $vendorDir . '/google/apiclient-services/src/Appengine/AutomaticScaling.php',
    'Google\\Service\\Appengine\\BasicScaling' => $vendorDir . '/google/apiclient-services/src/Appengine/BasicScaling.php',
    'Google\\Service\\Appengine\\BatchUpdateIngressRulesRequest' => $vendorDir . '/google/apiclient-services/src/Appengine/BatchUpdateIngressRulesRequest.php',
    'Google\\Service\\Appengine\\BatchUpdateIngressRulesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/BatchUpdateIngressRulesResponse.php',
    'Google\\Service\\Appengine\\CertificateRawData' => $vendorDir . '/google/apiclient-services/src/Appengine/CertificateRawData.php',
    'Google\\Service\\Appengine\\CloudBuildOptions' => $vendorDir . '/google/apiclient-services/src/Appengine/CloudBuildOptions.php',
    'Google\\Service\\Appengine\\ContainerInfo' => $vendorDir . '/google/apiclient-services/src/Appengine/ContainerInfo.php',
    'Google\\Service\\Appengine\\ContainerState' => $vendorDir . '/google/apiclient-services/src/Appengine/ContainerState.php',
    'Google\\Service\\Appengine\\CpuUtilization' => $vendorDir . '/google/apiclient-services/src/Appengine/CpuUtilization.php',
    'Google\\Service\\Appengine\\CreateVersionMetadataV1' => $vendorDir . '/google/apiclient-services/src/Appengine/CreateVersionMetadataV1.php',
    'Google\\Service\\Appengine\\CreateVersionMetadataV1Alpha' => $vendorDir . '/google/apiclient-services/src/Appengine/CreateVersionMetadataV1Alpha.php',
    'Google\\Service\\Appengine\\CreateVersionMetadataV1Beta' => $vendorDir . '/google/apiclient-services/src/Appengine/CreateVersionMetadataV1Beta.php',
    'Google\\Service\\Appengine\\Date' => $vendorDir . '/google/apiclient-services/src/Appengine/Date.php',
    'Google\\Service\\Appengine\\DebugInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Appengine/DebugInstanceRequest.php',
    'Google\\Service\\Appengine\\Deployment' => $vendorDir . '/google/apiclient-services/src/Appengine/Deployment.php',
    'Google\\Service\\Appengine\\DiskUtilization' => $vendorDir . '/google/apiclient-services/src/Appengine/DiskUtilization.php',
    'Google\\Service\\Appengine\\DomainMapping' => $vendorDir . '/google/apiclient-services/src/Appengine/DomainMapping.php',
    'Google\\Service\\Appengine\\EndpointsApiService' => $vendorDir . '/google/apiclient-services/src/Appengine/EndpointsApiService.php',
    'Google\\Service\\Appengine\\Entrypoint' => $vendorDir . '/google/apiclient-services/src/Appengine/Entrypoint.php',
    'Google\\Service\\Appengine\\ErrorHandler' => $vendorDir . '/google/apiclient-services/src/Appengine/ErrorHandler.php',
    'Google\\Service\\Appengine\\FeatureSettings' => $vendorDir . '/google/apiclient-services/src/Appengine/FeatureSettings.php',
    'Google\\Service\\Appengine\\FileInfo' => $vendorDir . '/google/apiclient-services/src/Appengine/FileInfo.php',
    'Google\\Service\\Appengine\\FirewallRule' => $vendorDir . '/google/apiclient-services/src/Appengine/FirewallRule.php',
    'Google\\Service\\Appengine\\FlexibleRuntimeSettings' => $vendorDir . '/google/apiclient-services/src/Appengine/FlexibleRuntimeSettings.php',
    'Google\\Service\\Appengine\\GoogleAppengineV1betaLocationMetadata' => $vendorDir . '/google/apiclient-services/src/Appengine/GoogleAppengineV1betaLocationMetadata.php',
    'Google\\Service\\Appengine\\GoogleAppengineV2OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Appengine/GoogleAppengineV2OperationMetadata.php',
    'Google\\Service\\Appengine\\GoogleAppengineV2mainOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Appengine/GoogleAppengineV2mainOperationMetadata.php',
    'Google\\Service\\Appengine\\HealthCheck' => $vendorDir . '/google/apiclient-services/src/Appengine/HealthCheck.php',
    'Google\\Service\\Appengine\\IdentityAwareProxy' => $vendorDir . '/google/apiclient-services/src/Appengine/IdentityAwareProxy.php',
    'Google\\Service\\Appengine\\Instance' => $vendorDir . '/google/apiclient-services/src/Appengine/Instance.php',
    'Google\\Service\\Appengine\\Library' => $vendorDir . '/google/apiclient-services/src/Appengine/Library.php',
    'Google\\Service\\Appengine\\ListAuthorizedCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListAuthorizedCertificatesResponse.php',
    'Google\\Service\\Appengine\\ListAuthorizedDomainsResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListAuthorizedDomainsResponse.php',
    'Google\\Service\\Appengine\\ListDomainMappingsResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListDomainMappingsResponse.php',
    'Google\\Service\\Appengine\\ListIngressRulesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListIngressRulesResponse.php',
    'Google\\Service\\Appengine\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListInstancesResponse.php',
    'Google\\Service\\Appengine\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListLocationsResponse.php',
    'Google\\Service\\Appengine\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListOperationsResponse.php',
    'Google\\Service\\Appengine\\ListRuntimesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListRuntimesResponse.php',
    'Google\\Service\\Appengine\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListServicesResponse.php',
    'Google\\Service\\Appengine\\ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Appengine/ListVersionsResponse.php',
    'Google\\Service\\Appengine\\LivenessCheck' => $vendorDir . '/google/apiclient-services/src/Appengine/LivenessCheck.php',
    'Google\\Service\\Appengine\\Location' => $vendorDir . '/google/apiclient-services/src/Appengine/Location.php',
    'Google\\Service\\Appengine\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/Appengine/LocationMetadata.php',
    'Google\\Service\\Appengine\\ManagedCertificate' => $vendorDir . '/google/apiclient-services/src/Appengine/ManagedCertificate.php',
    'Google\\Service\\Appengine\\ManualScaling' => $vendorDir . '/google/apiclient-services/src/Appengine/ManualScaling.php',
    'Google\\Service\\Appengine\\Network' => $vendorDir . '/google/apiclient-services/src/Appengine/Network.php',
    'Google\\Service\\Appengine\\NetworkSettings' => $vendorDir . '/google/apiclient-services/src/Appengine/NetworkSettings.php',
    'Google\\Service\\Appengine\\NetworkUtilization' => $vendorDir . '/google/apiclient-services/src/Appengine/NetworkUtilization.php',
    'Google\\Service\\Appengine\\Operation' => $vendorDir . '/google/apiclient-services/src/Appengine/Operation.php',
    'Google\\Service\\Appengine\\OperationMetadataV1' => $vendorDir . '/google/apiclient-services/src/Appengine/OperationMetadataV1.php',
    'Google\\Service\\Appengine\\OperationMetadataV1Alpha' => $vendorDir . '/google/apiclient-services/src/Appengine/OperationMetadataV1Alpha.php',
    'Google\\Service\\Appengine\\OperationMetadataV1Beta' => $vendorDir . '/google/apiclient-services/src/Appengine/OperationMetadataV1Beta.php',
    'Google\\Service\\Appengine\\ProjectEvent' => $vendorDir . '/google/apiclient-services/src/Appengine/ProjectEvent.php',
    'Google\\Service\\Appengine\\ProjectState' => $vendorDir . '/google/apiclient-services/src/Appengine/ProjectState.php',
    'Google\\Service\\Appengine\\ProjectsMetadata' => $vendorDir . '/google/apiclient-services/src/Appengine/ProjectsMetadata.php',
    'Google\\Service\\Appengine\\ReadinessCheck' => $vendorDir . '/google/apiclient-services/src/Appengine/ReadinessCheck.php',
    'Google\\Service\\Appengine\\Reasons' => $vendorDir . '/google/apiclient-services/src/Appengine/Reasons.php',
    'Google\\Service\\Appengine\\RepairApplicationRequest' => $vendorDir . '/google/apiclient-services/src/Appengine/RepairApplicationRequest.php',
    'Google\\Service\\Appengine\\RequestUtilization' => $vendorDir . '/google/apiclient-services/src/Appengine/RequestUtilization.php',
    'Google\\Service\\Appengine\\ResourceRecord' => $vendorDir . '/google/apiclient-services/src/Appengine/ResourceRecord.php',
    'Google\\Service\\Appengine\\Resource\\Apps' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/Apps.php',
    'Google\\Service\\Appengine\\Resource\\AppsAuthorizedCertificates' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsAuthorizedCertificates.php',
    'Google\\Service\\Appengine\\Resource\\AppsAuthorizedDomains' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsAuthorizedDomains.php',
    'Google\\Service\\Appengine\\Resource\\AppsDomainMappings' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsDomainMappings.php',
    'Google\\Service\\Appengine\\Resource\\AppsFirewall' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsFirewall.php',
    'Google\\Service\\Appengine\\Resource\\AppsFirewallIngressRules' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsFirewallIngressRules.php',
    'Google\\Service\\Appengine\\Resource\\AppsLocations' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsLocations.php',
    'Google\\Service\\Appengine\\Resource\\AppsOperations' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsOperations.php',
    'Google\\Service\\Appengine\\Resource\\AppsServices' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsServices.php',
    'Google\\Service\\Appengine\\Resource\\AppsServicesVersions' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsServicesVersions.php',
    'Google\\Service\\Appengine\\Resource\\AppsServicesVersionsInstances' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/AppsServicesVersionsInstances.php',
    'Google\\Service\\Appengine\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/Projects.php',
    'Google\\Service\\Appengine\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/ProjectsLocations.php',
    'Google\\Service\\Appengine\\Resource\\ProjectsLocationsApplications' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/ProjectsLocationsApplications.php',
    'Google\\Service\\Appengine\\Resource\\ProjectsLocationsApplicationsAuthorizedDomains' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/ProjectsLocationsApplicationsAuthorizedDomains.php',
    'Google\\Service\\Appengine\\Resource\\ProjectsLocationsApplicationsServices' => $vendorDir . '/google/apiclient-services/src/Appengine/Resource/ProjectsLocationsApplicationsServices.php',
    'Google\\Service\\Appengine\\Resources' => $vendorDir . '/google/apiclient-services/src/Appengine/Resources.php',
    'Google\\Service\\Appengine\\Runtime' => $vendorDir . '/google/apiclient-services/src/Appengine/Runtime.php',
    'Google\\Service\\Appengine\\ScriptHandler' => $vendorDir . '/google/apiclient-services/src/Appengine/ScriptHandler.php',
    'Google\\Service\\Appengine\\Service' => $vendorDir . '/google/apiclient-services/src/Appengine/Service.php',
    'Google\\Service\\Appengine\\SslSettings' => $vendorDir . '/google/apiclient-services/src/Appengine/SslSettings.php',
    'Google\\Service\\Appengine\\StandardSchedulerSettings' => $vendorDir . '/google/apiclient-services/src/Appengine/StandardSchedulerSettings.php',
    'Google\\Service\\Appengine\\StaticFilesHandler' => $vendorDir . '/google/apiclient-services/src/Appengine/StaticFilesHandler.php',
    'Google\\Service\\Appengine\\Status' => $vendorDir . '/google/apiclient-services/src/Appengine/Status.php',
    'Google\\Service\\Appengine\\TrafficSplit' => $vendorDir . '/google/apiclient-services/src/Appengine/TrafficSplit.php',
    'Google\\Service\\Appengine\\UrlDispatchRule' => $vendorDir . '/google/apiclient-services/src/Appengine/UrlDispatchRule.php',
    'Google\\Service\\Appengine\\UrlMap' => $vendorDir . '/google/apiclient-services/src/Appengine/UrlMap.php',
    'Google\\Service\\Appengine\\Version' => $vendorDir . '/google/apiclient-services/src/Appengine/Version.php',
    'Google\\Service\\Appengine\\Volume' => $vendorDir . '/google/apiclient-services/src/Appengine/Volume.php',
    'Google\\Service\\Appengine\\VpcAccessConnector' => $vendorDir . '/google/apiclient-services/src/Appengine/VpcAccessConnector.php',
    'Google\\Service\\Appengine\\ZipInfo' => $vendorDir . '/google/apiclient-services/src/Appengine/ZipInfo.php',
    'Google\\Service\\Area120Tables' => $vendorDir . '/google/apiclient-services/src/Area120Tables.php',
    'Google\\Service\\Area120Tables\\Area120tablesEmpty' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Area120tablesEmpty.php',
    'Google\\Service\\Area120Tables\\BatchCreateRowsRequest' => $vendorDir . '/google/apiclient-services/src/Area120Tables/BatchCreateRowsRequest.php',
    'Google\\Service\\Area120Tables\\BatchCreateRowsResponse' => $vendorDir . '/google/apiclient-services/src/Area120Tables/BatchCreateRowsResponse.php',
    'Google\\Service\\Area120Tables\\BatchDeleteRowsRequest' => $vendorDir . '/google/apiclient-services/src/Area120Tables/BatchDeleteRowsRequest.php',
    'Google\\Service\\Area120Tables\\BatchUpdateRowsRequest' => $vendorDir . '/google/apiclient-services/src/Area120Tables/BatchUpdateRowsRequest.php',
    'Google\\Service\\Area120Tables\\BatchUpdateRowsResponse' => $vendorDir . '/google/apiclient-services/src/Area120Tables/BatchUpdateRowsResponse.php',
    'Google\\Service\\Area120Tables\\ColumnDescription' => $vendorDir . '/google/apiclient-services/src/Area120Tables/ColumnDescription.php',
    'Google\\Service\\Area120Tables\\CreateRowRequest' => $vendorDir . '/google/apiclient-services/src/Area120Tables/CreateRowRequest.php',
    'Google\\Service\\Area120Tables\\DateDetails' => $vendorDir . '/google/apiclient-services/src/Area120Tables/DateDetails.php',
    'Google\\Service\\Area120Tables\\LabeledItem' => $vendorDir . '/google/apiclient-services/src/Area120Tables/LabeledItem.php',
    'Google\\Service\\Area120Tables\\ListRowsResponse' => $vendorDir . '/google/apiclient-services/src/Area120Tables/ListRowsResponse.php',
    'Google\\Service\\Area120Tables\\ListTablesResponse' => $vendorDir . '/google/apiclient-services/src/Area120Tables/ListTablesResponse.php',
    'Google\\Service\\Area120Tables\\ListWorkspacesResponse' => $vendorDir . '/google/apiclient-services/src/Area120Tables/ListWorkspacesResponse.php',
    'Google\\Service\\Area120Tables\\LookupDetails' => $vendorDir . '/google/apiclient-services/src/Area120Tables/LookupDetails.php',
    'Google\\Service\\Area120Tables\\RelationshipDetails' => $vendorDir . '/google/apiclient-services/src/Area120Tables/RelationshipDetails.php',
    'Google\\Service\\Area120Tables\\Resource\\Tables' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Resource/Tables.php',
    'Google\\Service\\Area120Tables\\Resource\\TablesRows' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Resource/TablesRows.php',
    'Google\\Service\\Area120Tables\\Resource\\Workspaces' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Resource/Workspaces.php',
    'Google\\Service\\Area120Tables\\Row' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Row.php',
    'Google\\Service\\Area120Tables\\SavedView' => $vendorDir . '/google/apiclient-services/src/Area120Tables/SavedView.php',
    'Google\\Service\\Area120Tables\\Table' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Table.php',
    'Google\\Service\\Area120Tables\\UpdateRowRequest' => $vendorDir . '/google/apiclient-services/src/Area120Tables/UpdateRowRequest.php',
    'Google\\Service\\Area120Tables\\Workspace' => $vendorDir . '/google/apiclient-services/src/Area120Tables/Workspace.php',
    'Google\\Service\\ArtifactRegistry' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry.php',
    'Google\\Service\\ArtifactRegistry\\AptArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/AptArtifact.php',
    'Google\\Service\\ArtifactRegistry\\AptRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/AptRepository.php',
    'Google\\Service\\ArtifactRegistry\\ArtifactregistryEmpty' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ArtifactregistryEmpty.php',
    'Google\\Service\\ArtifactRegistry\\BatchDeleteVersionsMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/BatchDeleteVersionsMetadata.php',
    'Google\\Service\\ArtifactRegistry\\BatchDeleteVersionsRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/BatchDeleteVersionsRequest.php',
    'Google\\Service\\ArtifactRegistry\\Binding' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Binding.php',
    'Google\\Service\\ArtifactRegistry\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/CancelOperationRequest.php',
    'Google\\Service\\ArtifactRegistry\\CleanupPolicy' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/CleanupPolicy.php',
    'Google\\Service\\ArtifactRegistry\\CleanupPolicyCondition' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/CleanupPolicyCondition.php',
    'Google\\Service\\ArtifactRegistry\\CleanupPolicyMostRecentVersions' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/CleanupPolicyMostRecentVersions.php',
    'Google\\Service\\ArtifactRegistry\\CommonRemoteRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/CommonRemoteRepository.php',
    'Google\\Service\\ArtifactRegistry\\DockerImage' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/DockerImage.php',
    'Google\\Service\\ArtifactRegistry\\DockerRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/DockerRepository.php',
    'Google\\Service\\ArtifactRegistry\\DockerRepositoryConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/DockerRepositoryConfig.php',
    'Google\\Service\\ArtifactRegistry\\DownloadFileResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/DownloadFileResponse.php',
    'Google\\Service\\ArtifactRegistry\\Expr' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Expr.php',
    'Google\\Service\\ArtifactRegistry\\GenericArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GenericArtifact.php',
    'Google\\Service\\ArtifactRegistry\\GoModule' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoModule.php',
    'Google\\Service\\ArtifactRegistry\\GoogetArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogetArtifact.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1File' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1File.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryPublicRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigAptRepositoryPublicRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigDockerRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigDockerRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigMavenRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigMavenRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryCustomRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryCustomRepository.php',
    'Google\\Service\\ArtifactRegistry\\GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryPublicRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryPublicRepository.php',
    'Google\\Service\\ArtifactRegistry\\Hash' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Hash.php',
    'Google\\Service\\ArtifactRegistry\\ImportAptArtifactsErrorInfo' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportAptArtifactsErrorInfo.php',
    'Google\\Service\\ArtifactRegistry\\ImportAptArtifactsGcsSource' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportAptArtifactsGcsSource.php',
    'Google\\Service\\ArtifactRegistry\\ImportAptArtifactsMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportAptArtifactsMetadata.php',
    'Google\\Service\\ArtifactRegistry\\ImportAptArtifactsRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportAptArtifactsRequest.php',
    'Google\\Service\\ArtifactRegistry\\ImportAptArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportAptArtifactsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ImportGoogetArtifactsErrorInfo' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportGoogetArtifactsErrorInfo.php',
    'Google\\Service\\ArtifactRegistry\\ImportGoogetArtifactsGcsSource' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportGoogetArtifactsGcsSource.php',
    'Google\\Service\\ArtifactRegistry\\ImportGoogetArtifactsMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportGoogetArtifactsMetadata.php',
    'Google\\Service\\ArtifactRegistry\\ImportGoogetArtifactsRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportGoogetArtifactsRequest.php',
    'Google\\Service\\ArtifactRegistry\\ImportGoogetArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportGoogetArtifactsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ImportYumArtifactsErrorInfo' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportYumArtifactsErrorInfo.php',
    'Google\\Service\\ArtifactRegistry\\ImportYumArtifactsGcsSource' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportYumArtifactsGcsSource.php',
    'Google\\Service\\ArtifactRegistry\\ImportYumArtifactsMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportYumArtifactsMetadata.php',
    'Google\\Service\\ArtifactRegistry\\ImportYumArtifactsRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportYumArtifactsRequest.php',
    'Google\\Service\\ArtifactRegistry\\ImportYumArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ImportYumArtifactsResponse.php',
    'Google\\Service\\ArtifactRegistry\\KfpArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/KfpArtifact.php',
    'Google\\Service\\ArtifactRegistry\\ListDockerImagesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListDockerImagesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListFilesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListFilesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListLocationsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListMavenArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListMavenArtifactsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListNpmPackagesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListNpmPackagesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListOperationsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListPackagesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListPackagesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListPythonPackagesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListPythonPackagesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListRepositoriesResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListTagsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListTagsResponse.php',
    'Google\\Service\\ArtifactRegistry\\ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ListVersionsResponse.php',
    'Google\\Service\\ArtifactRegistry\\Location' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Location.php',
    'Google\\Service\\ArtifactRegistry\\MavenArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/MavenArtifact.php',
    'Google\\Service\\ArtifactRegistry\\MavenRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/MavenRepository.php',
    'Google\\Service\\ArtifactRegistry\\MavenRepositoryConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/MavenRepositoryConfig.php',
    'Google\\Service\\ArtifactRegistry\\NpmPackage' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/NpmPackage.php',
    'Google\\Service\\ArtifactRegistry\\NpmRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/NpmRepository.php',
    'Google\\Service\\ArtifactRegistry\\Operation' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Operation.php',
    'Google\\Service\\ArtifactRegistry\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/OperationMetadata.php',
    'Google\\Service\\ArtifactRegistry\\Package' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Package.php',
    'Google\\Service\\ArtifactRegistry\\Policy' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Policy.php',
    'Google\\Service\\ArtifactRegistry\\ProjectSettings' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/ProjectSettings.php',
    'Google\\Service\\ArtifactRegistry\\PromoteArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/PromoteArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\PythonPackage' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/PythonPackage.php',
    'Google\\Service\\ArtifactRegistry\\PythonRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/PythonRepository.php',
    'Google\\Service\\ArtifactRegistry\\RemoteRepositoryConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/RemoteRepositoryConfig.php',
    'Google\\Service\\ArtifactRegistry\\Repository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Repository.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/Media.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/Operations.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/Projects.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocations.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositories' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositories.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesAptArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesAptArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesDockerImages' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesDockerImages.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesFiles' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesFiles.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesGenericArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesGenericArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesGoModules' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesGoModules.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesGoogetArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesGoogetArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesKfpArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesKfpArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesMavenArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesMavenArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesNpmPackages' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesNpmPackages.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesPackages' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesPackages.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesPackagesTags' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesPackagesTags.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesPackagesVersions' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesPackagesVersions.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesPythonPackages' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesPythonPackages.php',
    'Google\\Service\\ArtifactRegistry\\Resource\\ProjectsLocationsRepositoriesYumArtifacts' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Resource/ProjectsLocationsRepositoriesYumArtifacts.php',
    'Google\\Service\\ArtifactRegistry\\SbomConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/SbomConfig.php',
    'Google\\Service\\ArtifactRegistry\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/SetIamPolicyRequest.php',
    'Google\\Service\\ArtifactRegistry\\Status' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Status.php',
    'Google\\Service\\ArtifactRegistry\\Tag' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Tag.php',
    'Google\\Service\\ArtifactRegistry\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/TestIamPermissionsRequest.php',
    'Google\\Service\\ArtifactRegistry\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/TestIamPermissionsResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadAptArtifactMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadAptArtifactMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadAptArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadAptArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadAptArtifactRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadAptArtifactRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadAptArtifactResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadAptArtifactResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadGenericArtifactMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGenericArtifactMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadGenericArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGenericArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadGenericArtifactRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGenericArtifactRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoModuleMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoModuleMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoModuleMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoModuleMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoModuleRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoModuleRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoogetArtifactMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoogetArtifactMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoogetArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoogetArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoogetArtifactRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoogetArtifactRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadGoogetArtifactResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadGoogetArtifactResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadKfpArtifactMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadKfpArtifactMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadKfpArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadKfpArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadKfpArtifactRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadKfpArtifactRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadYumArtifactMediaResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadYumArtifactMediaResponse.php',
    'Google\\Service\\ArtifactRegistry\\UploadYumArtifactMetadata' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadYumArtifactMetadata.php',
    'Google\\Service\\ArtifactRegistry\\UploadYumArtifactRequest' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadYumArtifactRequest.php',
    'Google\\Service\\ArtifactRegistry\\UploadYumArtifactResponse' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UploadYumArtifactResponse.php',
    'Google\\Service\\ArtifactRegistry\\UpstreamCredentials' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UpstreamCredentials.php',
    'Google\\Service\\ArtifactRegistry\\UpstreamPolicy' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UpstreamPolicy.php',
    'Google\\Service\\ArtifactRegistry\\UsernamePasswordCredentials' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/UsernamePasswordCredentials.php',
    'Google\\Service\\ArtifactRegistry\\VPCSCConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/VPCSCConfig.php',
    'Google\\Service\\ArtifactRegistry\\Version' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/Version.php',
    'Google\\Service\\ArtifactRegistry\\VirtualRepositoryConfig' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/VirtualRepositoryConfig.php',
    'Google\\Service\\ArtifactRegistry\\YumArtifact' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/YumArtifact.php',
    'Google\\Service\\ArtifactRegistry\\YumRepository' => $vendorDir . '/google/apiclient-services/src/ArtifactRegistry/YumRepository.php',
    'Google\\Service\\Assuredworkloads' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1AssetMoveAnalysis' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1AssetMoveAnalysis.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ListViolationsResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ListViolationsResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ListWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ListWorkloadsResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1MoveAnalysisGroup' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1MoveAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1MoveAnalysisResult.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1MoveImpact' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1MoveImpact.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1Violation' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1Violation.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ViolationExceptionContext' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ViolationExceptionContext.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ViolationRemediation' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ViolationRemediation.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1Workload' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1Workload.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadKMSSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadKMSSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadResourceInfo' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadResourceInfo.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadResourceSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadResourceSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1CreateWorkloadOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1CreateWorkloadOperationMetadata.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1Workload' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1Workload.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadCJISSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadCJISSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampHighSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampHighSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampModerateSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadFedrampModerateSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadIL4Settings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadIL4Settings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadKMSSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadKMSSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadResourceInfo' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadResourceInfo.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadResourceSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadResourceSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsV1beta1WorkloadSaaEnrollmentResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsV1beta1WorkloadSaaEnrollmentResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainCreateWorkloadOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainCreateWorkloadOperationMetadata.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkload' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkload.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadCJISSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadCJISSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadComplianceStatus' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadComplianceStatus.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadFedrampHighSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadFedrampHighSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadFedrampModerateSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadFedrampModerateSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadIL4Settings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadIL4Settings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadKMSSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadKMSSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadResourceInfo' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadResourceInfo.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadResourceSettings' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadResourceSettings.php',
    'Google\\Service\\Assuredworkloads\\GoogleCloudAssuredworkloadsVersioningV1mainWorkloadSaaEnrollmentResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleCloudAssuredworkloadsVersioningV1mainWorkloadSaaEnrollmentResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Assuredworkloads\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleLongrunningOperation.php',
    'Google\\Service\\Assuredworkloads\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleProtobufEmpty.php',
    'Google\\Service\\Assuredworkloads\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/GoogleRpcStatus.php',
    'Google\\Service\\Assuredworkloads\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/Resource/Organizations.php',
    'Google\\Service\\Assuredworkloads\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/Resource/OrganizationsLocations.php',
    'Google\\Service\\Assuredworkloads\\Resource\\OrganizationsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/Resource/OrganizationsLocationsOperations.php',
    'Google\\Service\\Assuredworkloads\\Resource\\OrganizationsLocationsWorkloads' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/Resource/OrganizationsLocationsWorkloads.php',
    'Google\\Service\\Assuredworkloads\\Resource\\OrganizationsLocationsWorkloadsViolations' => $vendorDir . '/google/apiclient-services/src/Assuredworkloads/Resource/OrganizationsLocationsWorkloadsViolations.php',
    'Google\\Service\\AuthorizedBuyersMarketplace' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AcceptProposalRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AcceptProposalRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ActivateClientRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ActivateClientRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ActivateClientUserRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ActivateClientUserRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AdSize' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AdSize.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AddCreativeRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AddCreativeRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AddNoteRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AddNoteRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AuctionPackage' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AuctionPackage.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\AuthorizedbuyersmarketplaceEmpty' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/AuthorizedbuyersmarketplaceEmpty.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\BatchUpdateDealsRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/BatchUpdateDealsRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\BatchUpdateDealsResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/BatchUpdateDealsResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\CancelNegotiationRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/CancelNegotiationRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Client' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Client.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ClientUser' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ClientUser.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Contact' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Contact.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\CreativeRequirements' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/CreativeRequirements.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\CriteriaTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/CriteriaTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DayPart' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DayPart.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DayPartTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DayPartTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DeactivateClientRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DeactivateClientRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DeactivateClientUserRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DeactivateClientUserRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Deal' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Deal.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DealPausingInfo' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DealPausingInfo.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\DeliveryControl' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/DeliveryControl.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\FinalizedDeal' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/FinalizedDeal.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\FirstPartyMobileApplicationTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/FirstPartyMobileApplicationTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\FrequencyCap' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/FrequencyCap.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\InventorySizeTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/InventorySizeTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\InventoryTypeTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/InventoryTypeTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListAuctionPackagesResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListAuctionPackagesResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListClientUsersResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListClientUsersResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListClientsResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListClientsResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListDealsResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListDealsResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListFinalizedDealsResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListFinalizedDealsResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListProposalsResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListProposalsResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ListPublisherProfilesResponse' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ListPublisherProfilesResponse.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\MarketplaceTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/MarketplaceTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\MediaPlanner' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/MediaPlanner.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\MobileApplicationTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/MobileApplicationTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Money' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Money.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Note' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Note.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\OperatingSystemTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/OperatingSystemTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PauseFinalizedDealRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PauseFinalizedDealRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PlacementTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PlacementTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PreferredDealTerms' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PreferredDealTerms.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Price' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Price.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PrivateAuctionTerms' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PrivateAuctionTerms.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PrivateData' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PrivateData.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ProgrammaticGuaranteedTerms' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ProgrammaticGuaranteedTerms.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Proposal' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Proposal.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PublisherProfile' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PublisherProfile.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\PublisherProfileMobileApplication' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/PublisherProfileMobileApplication.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\Bidders' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/Bidders.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BiddersAuctionPackages' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BiddersAuctionPackages.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BiddersFinalizedDeals' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BiddersFinalizedDeals.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\Buyers' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/Buyers.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersAuctionPackages' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersAuctionPackages.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersClients' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersClients.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersClientsUsers' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersClientsUsers.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersFinalizedDeals' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersFinalizedDeals.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersProposals' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersProposals.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersProposalsDeals' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersProposalsDeals.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\Resource\\BuyersPublisherProfiles' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/Resource/BuyersPublisherProfiles.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\ResumeFinalizedDealRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/ResumeFinalizedDealRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\RtbMetrics' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/RtbMetrics.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\SendRfpRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/SendRfpRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\SetReadyToServeRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/SetReadyToServeRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\SubscribeAuctionPackageRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/SubscribeAuctionPackageRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\SubscribeClientsRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/SubscribeClientsRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\TechnologyTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/TechnologyTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/TimeOfDay.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\TimeZone' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/TimeZone.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\UnsubscribeAuctionPackageRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/UnsubscribeAuctionPackageRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\UnsubscribeClientsRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/UnsubscribeClientsRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\UpdateDealRequest' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/UpdateDealRequest.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\UriTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/UriTargeting.php',
    'Google\\Service\\AuthorizedBuyersMarketplace\\VideoTargeting' => $vendorDir . '/google/apiclient-services/src/AuthorizedBuyersMarketplace/VideoTargeting.php',
    'Google\\Service\\Backupdr' => $vendorDir . '/google/apiclient-services/src/Backupdr.php',
    'Google\\Service\\Backupdr\\AbandonBackupRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/AbandonBackupRequest.php',
    'Google\\Service\\Backupdr\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/AcceleratorConfig.php',
    'Google\\Service\\Backupdr\\AccessConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/AccessConfig.php',
    'Google\\Service\\Backupdr\\AdvancedMachineFeatures' => $vendorDir . '/google/apiclient-services/src/Backupdr/AdvancedMachineFeatures.php',
    'Google\\Service\\Backupdr\\AliasIpRange' => $vendorDir . '/google/apiclient-services/src/Backupdr/AliasIpRange.php',
    'Google\\Service\\Backupdr\\AllocationAffinity' => $vendorDir . '/google/apiclient-services/src/Backupdr/AllocationAffinity.php',
    'Google\\Service\\Backupdr\\AssetLocation' => $vendorDir . '/google/apiclient-services/src/Backupdr/AssetLocation.php',
    'Google\\Service\\Backupdr\\AttachedDisk' => $vendorDir . '/google/apiclient-services/src/Backupdr/AttachedDisk.php',
    'Google\\Service\\Backupdr\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/AuditConfig.php',
    'Google\\Service\\Backupdr\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/AuditLogConfig.php',
    'Google\\Service\\Backupdr\\Backup' => $vendorDir . '/google/apiclient-services/src/Backupdr/Backup.php',
    'Google\\Service\\Backupdr\\BackupApplianceBackupConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupApplianceBackupConfig.php',
    'Google\\Service\\Backupdr\\BackupApplianceBackupProperties' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupApplianceBackupProperties.php',
    'Google\\Service\\Backupdr\\BackupApplianceLockInfo' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupApplianceLockInfo.php',
    'Google\\Service\\Backupdr\\BackupConfigInfo' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupConfigInfo.php',
    'Google\\Service\\Backupdr\\BackupLock' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupLock.php',
    'Google\\Service\\Backupdr\\BackupPlan' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupPlan.php',
    'Google\\Service\\Backupdr\\BackupPlanAssociation' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupPlanAssociation.php',
    'Google\\Service\\Backupdr\\BackupRule' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupRule.php',
    'Google\\Service\\Backupdr\\BackupVault' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupVault.php',
    'Google\\Service\\Backupdr\\BackupWindow' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupWindow.php',
    'Google\\Service\\Backupdr\\BackupdrEmpty' => $vendorDir . '/google/apiclient-services/src/Backupdr/BackupdrEmpty.php',
    'Google\\Service\\Backupdr\\Binding' => $vendorDir . '/google/apiclient-services/src/Backupdr/Binding.php',
    'Google\\Service\\Backupdr\\BlobstoreLocation' => $vendorDir . '/google/apiclient-services/src/Backupdr/BlobstoreLocation.php',
    'Google\\Service\\Backupdr\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/CancelOperationRequest.php',
    'Google\\Service\\Backupdr\\CloudAsset' => $vendorDir . '/google/apiclient-services/src/Backupdr/CloudAsset.php',
    'Google\\Service\\Backupdr\\CloudAssetComposition' => $vendorDir . '/google/apiclient-services/src/Backupdr/CloudAssetComposition.php',
    'Google\\Service\\Backupdr\\ComputeInstanceBackupProperties' => $vendorDir . '/google/apiclient-services/src/Backupdr/ComputeInstanceBackupProperties.php',
    'Google\\Service\\Backupdr\\ComputeInstanceDataSourceProperties' => $vendorDir . '/google/apiclient-services/src/Backupdr/ComputeInstanceDataSourceProperties.php',
    'Google\\Service\\Backupdr\\ComputeInstanceRestoreProperties' => $vendorDir . '/google/apiclient-services/src/Backupdr/ComputeInstanceRestoreProperties.php',
    'Google\\Service\\Backupdr\\ComputeInstanceTargetEnvironment' => $vendorDir . '/google/apiclient-services/src/Backupdr/ComputeInstanceTargetEnvironment.php',
    'Google\\Service\\Backupdr\\ConfidentialInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/ConfidentialInstanceConfig.php',
    'Google\\Service\\Backupdr\\CustomerEncryptionKey' => $vendorDir . '/google/apiclient-services/src/Backupdr/CustomerEncryptionKey.php',
    'Google\\Service\\Backupdr\\DataSource' => $vendorDir . '/google/apiclient-services/src/Backupdr/DataSource.php',
    'Google\\Service\\Backupdr\\DataSourceBackupApplianceApplication' => $vendorDir . '/google/apiclient-services/src/Backupdr/DataSourceBackupApplianceApplication.php',
    'Google\\Service\\Backupdr\\DataSourceGcpResource' => $vendorDir . '/google/apiclient-services/src/Backupdr/DataSourceGcpResource.php',
    'Google\\Service\\Backupdr\\DirectLocationAssignment' => $vendorDir . '/google/apiclient-services/src/Backupdr/DirectLocationAssignment.php',
    'Google\\Service\\Backupdr\\DisplayDevice' => $vendorDir . '/google/apiclient-services/src/Backupdr/DisplayDevice.php',
    'Google\\Service\\Backupdr\\Entry' => $vendorDir . '/google/apiclient-services/src/Backupdr/Entry.php',
    'Google\\Service\\Backupdr\\Expr' => $vendorDir . '/google/apiclient-services/src/Backupdr/Expr.php',
    'Google\\Service\\Backupdr\\ExtraParameter' => $vendorDir . '/google/apiclient-services/src/Backupdr/ExtraParameter.php',
    'Google\\Service\\Backupdr\\FetchAccessTokenRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/FetchAccessTokenRequest.php',
    'Google\\Service\\Backupdr\\FetchAccessTokenResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/FetchAccessTokenResponse.php',
    'Google\\Service\\Backupdr\\FetchUsableBackupVaultsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/FetchUsableBackupVaultsResponse.php',
    'Google\\Service\\Backupdr\\FinalizeBackupRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/FinalizeBackupRequest.php',
    'Google\\Service\\Backupdr\\GCPBackupPlanInfo' => $vendorDir . '/google/apiclient-services/src/Backupdr/GCPBackupPlanInfo.php',
    'Google\\Service\\Backupdr\\GcpBackupConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/GcpBackupConfig.php',
    'Google\\Service\\Backupdr\\GuestOsFeature' => $vendorDir . '/google/apiclient-services/src/Backupdr/GuestOsFeature.php',
    'Google\\Service\\Backupdr\\InitializeParams' => $vendorDir . '/google/apiclient-services/src/Backupdr/InitializeParams.php',
    'Google\\Service\\Backupdr\\InitiateBackupRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/InitiateBackupRequest.php',
    'Google\\Service\\Backupdr\\InitiateBackupResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/InitiateBackupResponse.php',
    'Google\\Service\\Backupdr\\InstanceParams' => $vendorDir . '/google/apiclient-services/src/Backupdr/InstanceParams.php',
    'Google\\Service\\Backupdr\\IsolationExpectations' => $vendorDir . '/google/apiclient-services/src/Backupdr/IsolationExpectations.php',
    'Google\\Service\\Backupdr\\ListBackupPlanAssociationsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListBackupPlanAssociationsResponse.php',
    'Google\\Service\\Backupdr\\ListBackupPlansResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListBackupPlansResponse.php',
    'Google\\Service\\Backupdr\\ListBackupVaultsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListBackupVaultsResponse.php',
    'Google\\Service\\Backupdr\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListBackupsResponse.php',
    'Google\\Service\\Backupdr\\ListDataSourcesResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListDataSourcesResponse.php',
    'Google\\Service\\Backupdr\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListLocationsResponse.php',
    'Google\\Service\\Backupdr\\ListManagementServersResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListManagementServersResponse.php',
    'Google\\Service\\Backupdr\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/ListOperationsResponse.php',
    'Google\\Service\\Backupdr\\Location' => $vendorDir . '/google/apiclient-services/src/Backupdr/Location.php',
    'Google\\Service\\Backupdr\\LocationAssignment' => $vendorDir . '/google/apiclient-services/src/Backupdr/LocationAssignment.php',
    'Google\\Service\\Backupdr\\LocationData' => $vendorDir . '/google/apiclient-services/src/Backupdr/LocationData.php',
    'Google\\Service\\Backupdr\\ManagementServer' => $vendorDir . '/google/apiclient-services/src/Backupdr/ManagementServer.php',
    'Google\\Service\\Backupdr\\ManagementURI' => $vendorDir . '/google/apiclient-services/src/Backupdr/ManagementURI.php',
    'Google\\Service\\Backupdr\\Metadata' => $vendorDir . '/google/apiclient-services/src/Backupdr/Metadata.php',
    'Google\\Service\\Backupdr\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/NetworkConfig.php',
    'Google\\Service\\Backupdr\\NetworkInterface' => $vendorDir . '/google/apiclient-services/src/Backupdr/NetworkInterface.php',
    'Google\\Service\\Backupdr\\NetworkPerformanceConfig' => $vendorDir . '/google/apiclient-services/src/Backupdr/NetworkPerformanceConfig.php',
    'Google\\Service\\Backupdr\\NodeAffinity' => $vendorDir . '/google/apiclient-services/src/Backupdr/NodeAffinity.php',
    'Google\\Service\\Backupdr\\Operation' => $vendorDir . '/google/apiclient-services/src/Backupdr/Operation.php',
    'Google\\Service\\Backupdr\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Backupdr/OperationMetadata.php',
    'Google\\Service\\Backupdr\\PlacerLocation' => $vendorDir . '/google/apiclient-services/src/Backupdr/PlacerLocation.php',
    'Google\\Service\\Backupdr\\Policy' => $vendorDir . '/google/apiclient-services/src/Backupdr/Policy.php',
    'Google\\Service\\Backupdr\\RegionalMigDistributionPolicy' => $vendorDir . '/google/apiclient-services/src/Backupdr/RegionalMigDistributionPolicy.php',
    'Google\\Service\\Backupdr\\RemoveDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/RemoveDataSourceRequest.php',
    'Google\\Service\\Backupdr\\RequirementOverride' => $vendorDir . '/google/apiclient-services/src/Backupdr/RequirementOverride.php',
    'Google\\Service\\Backupdr\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/Projects.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocations.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsBackupPlanAssociations' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsBackupPlanAssociations.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsBackupPlans' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsBackupPlans.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsBackupVaults' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsBackupVaults.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsBackupVaultsDataSources' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsBackupVaultsDataSources.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsBackupVaultsDataSourcesBackups' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsBackupVaultsDataSourcesBackups.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsManagementServers' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsManagementServers.php',
    'Google\\Service\\Backupdr\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Backupdr/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Backupdr\\RestoreBackupRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/RestoreBackupRequest.php',
    'Google\\Service\\Backupdr\\RuleConfigInfo' => $vendorDir . '/google/apiclient-services/src/Backupdr/RuleConfigInfo.php',
    'Google\\Service\\Backupdr\\Scheduling' => $vendorDir . '/google/apiclient-services/src/Backupdr/Scheduling.php',
    'Google\\Service\\Backupdr\\SchedulingDuration' => $vendorDir . '/google/apiclient-services/src/Backupdr/SchedulingDuration.php',
    'Google\\Service\\Backupdr\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Backupdr/ServiceAccount.php',
    'Google\\Service\\Backupdr\\ServiceLockInfo' => $vendorDir . '/google/apiclient-services/src/Backupdr/ServiceLockInfo.php',
    'Google\\Service\\Backupdr\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/SetIamPolicyRequest.php',
    'Google\\Service\\Backupdr\\SetInternalStatusRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/SetInternalStatusRequest.php',
    'Google\\Service\\Backupdr\\SpannerLocation' => $vendorDir . '/google/apiclient-services/src/Backupdr/SpannerLocation.php',
    'Google\\Service\\Backupdr\\StandardSchedule' => $vendorDir . '/google/apiclient-services/src/Backupdr/StandardSchedule.php',
    'Google\\Service\\Backupdr\\Status' => $vendorDir . '/google/apiclient-services/src/Backupdr/Status.php',
    'Google\\Service\\Backupdr\\Tags' => $vendorDir . '/google/apiclient-services/src/Backupdr/Tags.php',
    'Google\\Service\\Backupdr\\TenantProjectProxy' => $vendorDir . '/google/apiclient-services/src/Backupdr/TenantProjectProxy.php',
    'Google\\Service\\Backupdr\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/TestIamPermissionsRequest.php',
    'Google\\Service\\Backupdr\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Backupdr/TestIamPermissionsResponse.php',
    'Google\\Service\\Backupdr\\TriggerBackupRequest' => $vendorDir . '/google/apiclient-services/src/Backupdr/TriggerBackupRequest.php',
    'Google\\Service\\Backupdr\\WeekDayOfMonth' => $vendorDir . '/google/apiclient-services/src/Backupdr/WeekDayOfMonth.php',
    'Google\\Service\\Backupdr\\WorkforceIdentityBasedManagementURI' => $vendorDir . '/google/apiclient-services/src/Backupdr/WorkforceIdentityBasedManagementURI.php',
    'Google\\Service\\Backupdr\\WorkforceIdentityBasedOAuth2ClientID' => $vendorDir . '/google/apiclient-services/src/Backupdr/WorkforceIdentityBasedOAuth2ClientID.php',
    'Google\\Service\\Backupdr\\ZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/Backupdr/ZoneConfiguration.php',
    'Google\\Service\\BackupforGKE' => $vendorDir . '/google/apiclient-services/src/BackupforGKE.php',
    'Google\\Service\\BackupforGKE\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/AuditConfig.php',
    'Google\\Service\\BackupforGKE\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/AuditLogConfig.php',
    'Google\\Service\\BackupforGKE\\Backup' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Backup.php',
    'Google\\Service\\BackupforGKE\\BackupConfig' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/BackupConfig.php',
    'Google\\Service\\BackupforGKE\\BackupPlan' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/BackupPlan.php',
    'Google\\Service\\BackupforGKE\\Binding' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Binding.php',
    'Google\\Service\\BackupforGKE\\ClusterMetadata' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ClusterMetadata.php',
    'Google\\Service\\BackupforGKE\\ClusterResourceRestoreScope' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ClusterResourceRestoreScope.php',
    'Google\\Service\\BackupforGKE\\Date' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Date.php',
    'Google\\Service\\BackupforGKE\\DayOfWeekList' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/DayOfWeekList.php',
    'Google\\Service\\BackupforGKE\\EncryptionKey' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/EncryptionKey.php',
    'Google\\Service\\BackupforGKE\\ExclusionWindow' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ExclusionWindow.php',
    'Google\\Service\\BackupforGKE\\Expr' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Expr.php',
    'Google\\Service\\BackupforGKE\\Filter' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Filter.php',
    'Google\\Service\\BackupforGKE\\GetBackupIndexDownloadUrlResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GetBackupIndexDownloadUrlResponse.php',
    'Google\\Service\\BackupforGKE\\GkebackupEmpty' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GkebackupEmpty.php',
    'Google\\Service\\BackupforGKE\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\BackupforGKE\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\BackupforGKE\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GoogleLongrunningOperation.php',
    'Google\\Service\\BackupforGKE\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GoogleRpcStatus.php',
    'Google\\Service\\BackupforGKE\\GroupKind' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GroupKind.php',
    'Google\\Service\\BackupforGKE\\GroupKindDependency' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/GroupKindDependency.php',
    'Google\\Service\\BackupforGKE\\ListBackupPlansResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListBackupPlansResponse.php',
    'Google\\Service\\BackupforGKE\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListBackupsResponse.php',
    'Google\\Service\\BackupforGKE\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListLocationsResponse.php',
    'Google\\Service\\BackupforGKE\\ListRestorePlansResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListRestorePlansResponse.php',
    'Google\\Service\\BackupforGKE\\ListRestoresResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListRestoresResponse.php',
    'Google\\Service\\BackupforGKE\\ListVolumeBackupsResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListVolumeBackupsResponse.php',
    'Google\\Service\\BackupforGKE\\ListVolumeRestoresResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ListVolumeRestoresResponse.php',
    'Google\\Service\\BackupforGKE\\Location' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Location.php',
    'Google\\Service\\BackupforGKE\\NamespacedName' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/NamespacedName.php',
    'Google\\Service\\BackupforGKE\\NamespacedNames' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/NamespacedNames.php',
    'Google\\Service\\BackupforGKE\\Namespaces' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Namespaces.php',
    'Google\\Service\\BackupforGKE\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/OperationMetadata.php',
    'Google\\Service\\BackupforGKE\\Policy' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Policy.php',
    'Google\\Service\\BackupforGKE\\ResourceFilter' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ResourceFilter.php',
    'Google\\Service\\BackupforGKE\\ResourceSelector' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/ResourceSelector.php',
    'Google\\Service\\BackupforGKE\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/Projects.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocations.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsBackupPlans' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsBackupPlans.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsBackupPlansBackups' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsBackupPlansBackups.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsBackupPlansBackupsVolumeBackups' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsBackupPlansBackupsVolumeBackups.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsRestorePlans' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsRestorePlans.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsRestorePlansRestores' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsRestorePlansRestores.php',
    'Google\\Service\\BackupforGKE\\Resource\\ProjectsLocationsRestorePlansRestoresVolumeRestores' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Resource/ProjectsLocationsRestorePlansRestoresVolumeRestores.php',
    'Google\\Service\\BackupforGKE\\Restore' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Restore.php',
    'Google\\Service\\BackupforGKE\\RestoreConfig' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/RestoreConfig.php',
    'Google\\Service\\BackupforGKE\\RestoreOrder' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/RestoreOrder.php',
    'Google\\Service\\BackupforGKE\\RestorePlan' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/RestorePlan.php',
    'Google\\Service\\BackupforGKE\\RetentionPolicy' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/RetentionPolicy.php',
    'Google\\Service\\BackupforGKE\\RpoConfig' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/RpoConfig.php',
    'Google\\Service\\BackupforGKE\\Schedule' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/Schedule.php',
    'Google\\Service\\BackupforGKE\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/SetIamPolicyRequest.php',
    'Google\\Service\\BackupforGKE\\SubstitutionRule' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/SubstitutionRule.php',
    'Google\\Service\\BackupforGKE\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/TestIamPermissionsRequest.php',
    'Google\\Service\\BackupforGKE\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/TestIamPermissionsResponse.php',
    'Google\\Service\\BackupforGKE\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/TimeOfDay.php',
    'Google\\Service\\BackupforGKE\\TransformationRule' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/TransformationRule.php',
    'Google\\Service\\BackupforGKE\\TransformationRuleAction' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/TransformationRuleAction.php',
    'Google\\Service\\BackupforGKE\\VolumeBackup' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/VolumeBackup.php',
    'Google\\Service\\BackupforGKE\\VolumeDataRestorePolicyBinding' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/VolumeDataRestorePolicyBinding.php',
    'Google\\Service\\BackupforGKE\\VolumeDataRestorePolicyOverride' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/VolumeDataRestorePolicyOverride.php',
    'Google\\Service\\BackupforGKE\\VolumeRestore' => $vendorDir . '/google/apiclient-services/src/BackupforGKE/VolumeRestore.php',
    'Google\\Service\\Baremetalsolution' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution.php',
    'Google\\Service\\Baremetalsolution\\AllowedClient' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/AllowedClient.php',
    'Google\\Service\\Baremetalsolution\\BaremetalsolutionEmpty' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/BaremetalsolutionEmpty.php',
    'Google\\Service\\Baremetalsolution\\Binding' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Binding.php',
    'Google\\Service\\Baremetalsolution\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/CancelOperationRequest.php',
    'Google\\Service\\Baremetalsolution\\DetachLunRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/DetachLunRequest.php',
    'Google\\Service\\Baremetalsolution\\DisableHyperthreadingRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/DisableHyperthreadingRequest.php',
    'Google\\Service\\Baremetalsolution\\DisableInteractiveSerialConsoleRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/DisableInteractiveSerialConsoleRequest.php',
    'Google\\Service\\Baremetalsolution\\DisableInteractiveSerialConsoleResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/DisableInteractiveSerialConsoleResponse.php',
    'Google\\Service\\Baremetalsolution\\EnableHyperthreadingRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/EnableHyperthreadingRequest.php',
    'Google\\Service\\Baremetalsolution\\EnableInteractiveSerialConsoleRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/EnableInteractiveSerialConsoleRequest.php',
    'Google\\Service\\Baremetalsolution\\EnableInteractiveSerialConsoleResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/EnableInteractiveSerialConsoleResponse.php',
    'Google\\Service\\Baremetalsolution\\EvictLunRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/EvictLunRequest.php',
    'Google\\Service\\Baremetalsolution\\EvictVolumeRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/EvictVolumeRequest.php',
    'Google\\Service\\Baremetalsolution\\Expr' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Expr.php',
    'Google\\Service\\Baremetalsolution\\FetchInstanceProvisioningSettingsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/FetchInstanceProvisioningSettingsResponse.php',
    'Google\\Service\\Baremetalsolution\\GoogleCloudBaremetalsolutionV2LogicalInterface' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/GoogleCloudBaremetalsolutionV2LogicalInterface.php',
    'Google\\Service\\Baremetalsolution\\GoogleCloudBaremetalsolutionV2ServerNetworkTemplateLogicalInterface' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/GoogleCloudBaremetalsolutionV2ServerNetworkTemplateLogicalInterface.php',
    'Google\\Service\\Baremetalsolution\\Instance' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Instance.php',
    'Google\\Service\\Baremetalsolution\\InstanceConfig' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/InstanceConfig.php',
    'Google\\Service\\Baremetalsolution\\InstanceQuota' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/InstanceQuota.php',
    'Google\\Service\\Baremetalsolution\\IntakeVlanAttachment' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/IntakeVlanAttachment.php',
    'Google\\Service\\Baremetalsolution\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListInstancesResponse.php',
    'Google\\Service\\Baremetalsolution\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListLocationsResponse.php',
    'Google\\Service\\Baremetalsolution\\ListLunsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListLunsResponse.php',
    'Google\\Service\\Baremetalsolution\\ListNetworkUsageResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListNetworkUsageResponse.php',
    'Google\\Service\\Baremetalsolution\\ListNetworksResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListNetworksResponse.php',
    'Google\\Service\\Baremetalsolution\\ListNfsSharesResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListNfsSharesResponse.php',
    'Google\\Service\\Baremetalsolution\\ListOSImagesResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListOSImagesResponse.php',
    'Google\\Service\\Baremetalsolution\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListOperationsResponse.php',
    'Google\\Service\\Baremetalsolution\\ListProvisioningQuotasResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListProvisioningQuotasResponse.php',
    'Google\\Service\\Baremetalsolution\\ListSSHKeysResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListSSHKeysResponse.php',
    'Google\\Service\\Baremetalsolution\\ListSnapshotSchedulePoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListSnapshotSchedulePoliciesResponse.php',
    'Google\\Service\\Baremetalsolution\\ListVolumeSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListVolumeSnapshotsResponse.php',
    'Google\\Service\\Baremetalsolution\\ListVolumesResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ListVolumesResponse.php',
    'Google\\Service\\Baremetalsolution\\LoadInstanceAuthInfoResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/LoadInstanceAuthInfoResponse.php',
    'Google\\Service\\Baremetalsolution\\Location' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Location.php',
    'Google\\Service\\Baremetalsolution\\LogicalInterface' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/LogicalInterface.php',
    'Google\\Service\\Baremetalsolution\\LogicalNetworkInterface' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/LogicalNetworkInterface.php',
    'Google\\Service\\Baremetalsolution\\Lun' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Lun.php',
    'Google\\Service\\Baremetalsolution\\LunRange' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/LunRange.php',
    'Google\\Service\\Baremetalsolution\\Network' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Network.php',
    'Google\\Service\\Baremetalsolution\\NetworkAddress' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NetworkAddress.php',
    'Google\\Service\\Baremetalsolution\\NetworkAddressReservation' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NetworkAddressReservation.php',
    'Google\\Service\\Baremetalsolution\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NetworkConfig.php',
    'Google\\Service\\Baremetalsolution\\NetworkMountPoint' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NetworkMountPoint.php',
    'Google\\Service\\Baremetalsolution\\NetworkUsage' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NetworkUsage.php',
    'Google\\Service\\Baremetalsolution\\NfsExport' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NfsExport.php',
    'Google\\Service\\Baremetalsolution\\NfsShare' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/NfsShare.php',
    'Google\\Service\\Baremetalsolution\\OSImage' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/OSImage.php',
    'Google\\Service\\Baremetalsolution\\Operation' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Operation.php',
    'Google\\Service\\Baremetalsolution\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/OperationMetadata.php',
    'Google\\Service\\Baremetalsolution\\Policy' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Policy.php',
    'Google\\Service\\Baremetalsolution\\ProvisioningConfig' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ProvisioningConfig.php',
    'Google\\Service\\Baremetalsolution\\ProvisioningQuota' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ProvisioningQuota.php',
    'Google\\Service\\Baremetalsolution\\QosPolicy' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/QosPolicy.php',
    'Google\\Service\\Baremetalsolution\\ReimageInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ReimageInstanceRequest.php',
    'Google\\Service\\Baremetalsolution\\RenameInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/RenameInstanceRequest.php',
    'Google\\Service\\Baremetalsolution\\RenameNetworkRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/RenameNetworkRequest.php',
    'Google\\Service\\Baremetalsolution\\RenameNfsShareRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/RenameNfsShareRequest.php',
    'Google\\Service\\Baremetalsolution\\RenameVolumeRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/RenameVolumeRequest.php',
    'Google\\Service\\Baremetalsolution\\ResetInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ResetInstanceRequest.php',
    'Google\\Service\\Baremetalsolution\\ResetInstanceResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ResetInstanceResponse.php',
    'Google\\Service\\Baremetalsolution\\ResizeVolumeRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ResizeVolumeRequest.php',
    'Google\\Service\\Baremetalsolution\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/Operations.php',
    'Google\\Service\\Baremetalsolution\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/Projects.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocations.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsInstanceProvisioningSettings' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsInstanceProvisioningSettings.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsNetworks' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsNetworks.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsNfsShares' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsNfsShares.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsOsImages' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsOsImages.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsProvisioningConfigs' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsProvisioningConfigs.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsProvisioningQuotas' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsProvisioningQuotas.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsSnapshotSchedulePolicies' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsSnapshotSchedulePolicies.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsSshKeys' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsSshKeys.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsVolumes' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsVolumes.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsVolumesLuns' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsVolumesLuns.php',
    'Google\\Service\\Baremetalsolution\\Resource\\ProjectsLocationsVolumesSnapshots' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Resource/ProjectsLocationsVolumesSnapshots.php',
    'Google\\Service\\Baremetalsolution\\RestoreVolumeSnapshotRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/RestoreVolumeSnapshotRequest.php',
    'Google\\Service\\Baremetalsolution\\SSHKey' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SSHKey.php',
    'Google\\Service\\Baremetalsolution\\Schedule' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Schedule.php',
    'Google\\Service\\Baremetalsolution\\ServerNetworkTemplate' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/ServerNetworkTemplate.php',
    'Google\\Service\\Baremetalsolution\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SetIamPolicyRequest.php',
    'Google\\Service\\Baremetalsolution\\SnapshotReservationDetail' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SnapshotReservationDetail.php',
    'Google\\Service\\Baremetalsolution\\SnapshotSchedulePolicy' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SnapshotSchedulePolicy.php',
    'Google\\Service\\Baremetalsolution\\StartInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/StartInstanceRequest.php',
    'Google\\Service\\Baremetalsolution\\StartInstanceResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/StartInstanceResponse.php',
    'Google\\Service\\Baremetalsolution\\Status' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Status.php',
    'Google\\Service\\Baremetalsolution\\StopInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/StopInstanceRequest.php',
    'Google\\Service\\Baremetalsolution\\StopInstanceResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/StopInstanceResponse.php',
    'Google\\Service\\Baremetalsolution\\SubmitProvisioningConfigRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SubmitProvisioningConfigRequest.php',
    'Google\\Service\\Baremetalsolution\\SubmitProvisioningConfigResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/SubmitProvisioningConfigResponse.php',
    'Google\\Service\\Baremetalsolution\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/TestIamPermissionsRequest.php',
    'Google\\Service\\Baremetalsolution\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/TestIamPermissionsResponse.php',
    'Google\\Service\\Baremetalsolution\\UserAccount' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/UserAccount.php',
    'Google\\Service\\Baremetalsolution\\VRF' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/VRF.php',
    'Google\\Service\\Baremetalsolution\\VlanAttachment' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/VlanAttachment.php',
    'Google\\Service\\Baremetalsolution\\Volume' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/Volume.php',
    'Google\\Service\\Baremetalsolution\\VolumeConfig' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/VolumeConfig.php',
    'Google\\Service\\Baremetalsolution\\VolumeSnapshot' => $vendorDir . '/google/apiclient-services/src/Baremetalsolution/VolumeSnapshot.php',
    'Google\\Service\\Batch' => $vendorDir . '/google/apiclient-services/src/Batch.php',
    'Google\\Service\\Batch\\Accelerator' => $vendorDir . '/google/apiclient-services/src/Batch/Accelerator.php',
    'Google\\Service\\Batch\\ActionCondition' => $vendorDir . '/google/apiclient-services/src/Batch/ActionCondition.php',
    'Google\\Service\\Batch\\AgentContainer' => $vendorDir . '/google/apiclient-services/src/Batch/AgentContainer.php',
    'Google\\Service\\Batch\\AgentEnvironment' => $vendorDir . '/google/apiclient-services/src/Batch/AgentEnvironment.php',
    'Google\\Service\\Batch\\AgentInfo' => $vendorDir . '/google/apiclient-services/src/Batch/AgentInfo.php',
    'Google\\Service\\Batch\\AgentKMSEnvMap' => $vendorDir . '/google/apiclient-services/src/Batch/AgentKMSEnvMap.php',
    'Google\\Service\\Batch\\AgentMetadata' => $vendorDir . '/google/apiclient-services/src/Batch/AgentMetadata.php',
    'Google\\Service\\Batch\\AgentScript' => $vendorDir . '/google/apiclient-services/src/Batch/AgentScript.php',
    'Google\\Service\\Batch\\AgentTask' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTask.php',
    'Google\\Service\\Batch\\AgentTaskInfo' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTaskInfo.php',
    'Google\\Service\\Batch\\AgentTaskLoggingOption' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTaskLoggingOption.php',
    'Google\\Service\\Batch\\AgentTaskRunnable' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTaskRunnable.php',
    'Google\\Service\\Batch\\AgentTaskSpec' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTaskSpec.php',
    'Google\\Service\\Batch\\AgentTaskUserAccount' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTaskUserAccount.php',
    'Google\\Service\\Batch\\AgentTimingInfo' => $vendorDir . '/google/apiclient-services/src/Batch/AgentTimingInfo.php',
    'Google\\Service\\Batch\\AllocationPolicy' => $vendorDir . '/google/apiclient-services/src/Batch/AllocationPolicy.php',
    'Google\\Service\\Batch\\AttachedDisk' => $vendorDir . '/google/apiclient-services/src/Batch/AttachedDisk.php',
    'Google\\Service\\Batch\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Batch/AuditConfig.php',
    'Google\\Service\\Batch\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Batch/AuditLogConfig.php',
    'Google\\Service\\Batch\\Barrier' => $vendorDir . '/google/apiclient-services/src/Batch/Barrier.php',
    'Google\\Service\\Batch\\BatchEmpty' => $vendorDir . '/google/apiclient-services/src/Batch/BatchEmpty.php',
    'Google\\Service\\Batch\\Binding' => $vendorDir . '/google/apiclient-services/src/Batch/Binding.php',
    'Google\\Service\\Batch\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Batch/CancelOperationRequest.php',
    'Google\\Service\\Batch\\CloudLoggingOption' => $vendorDir . '/google/apiclient-services/src/Batch/CloudLoggingOption.php',
    'Google\\Service\\Batch\\ComputeResource' => $vendorDir . '/google/apiclient-services/src/Batch/ComputeResource.php',
    'Google\\Service\\Batch\\Container' => $vendorDir . '/google/apiclient-services/src/Batch/Container.php',
    'Google\\Service\\Batch\\Disk' => $vendorDir . '/google/apiclient-services/src/Batch/Disk.php',
    'Google\\Service\\Batch\\Environment' => $vendorDir . '/google/apiclient-services/src/Batch/Environment.php',
    'Google\\Service\\Batch\\Expr' => $vendorDir . '/google/apiclient-services/src/Batch/Expr.php',
    'Google\\Service\\Batch\\GCS' => $vendorDir . '/google/apiclient-services/src/Batch/GCS.php',
    'Google\\Service\\Batch\\InstancePolicy' => $vendorDir . '/google/apiclient-services/src/Batch/InstancePolicy.php',
    'Google\\Service\\Batch\\InstancePolicyOrTemplate' => $vendorDir . '/google/apiclient-services/src/Batch/InstancePolicyOrTemplate.php',
    'Google\\Service\\Batch\\InstanceStatus' => $vendorDir . '/google/apiclient-services/src/Batch/InstanceStatus.php',
    'Google\\Service\\Batch\\Job' => $vendorDir . '/google/apiclient-services/src/Batch/Job.php',
    'Google\\Service\\Batch\\JobNotification' => $vendorDir . '/google/apiclient-services/src/Batch/JobNotification.php',
    'Google\\Service\\Batch\\JobStatus' => $vendorDir . '/google/apiclient-services/src/Batch/JobStatus.php',
    'Google\\Service\\Batch\\KMSEnvMap' => $vendorDir . '/google/apiclient-services/src/Batch/KMSEnvMap.php',
    'Google\\Service\\Batch\\LifecyclePolicy' => $vendorDir . '/google/apiclient-services/src/Batch/LifecyclePolicy.php',
    'Google\\Service\\Batch\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/Batch/ListJobsResponse.php',
    'Google\\Service\\Batch\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Batch/ListLocationsResponse.php',
    'Google\\Service\\Batch\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Batch/ListOperationsResponse.php',
    'Google\\Service\\Batch\\ListTasksResponse' => $vendorDir . '/google/apiclient-services/src/Batch/ListTasksResponse.php',
    'Google\\Service\\Batch\\Location' => $vendorDir . '/google/apiclient-services/src/Batch/Location.php',
    'Google\\Service\\Batch\\LocationPolicy' => $vendorDir . '/google/apiclient-services/src/Batch/LocationPolicy.php',
    'Google\\Service\\Batch\\LogsPolicy' => $vendorDir . '/google/apiclient-services/src/Batch/LogsPolicy.php',
    'Google\\Service\\Batch\\Message' => $vendorDir . '/google/apiclient-services/src/Batch/Message.php',
    'Google\\Service\\Batch\\NFS' => $vendorDir . '/google/apiclient-services/src/Batch/NFS.php',
    'Google\\Service\\Batch\\NetworkInterface' => $vendorDir . '/google/apiclient-services/src/Batch/NetworkInterface.php',
    'Google\\Service\\Batch\\NetworkPolicy' => $vendorDir . '/google/apiclient-services/src/Batch/NetworkPolicy.php',
    'Google\\Service\\Batch\\Operation' => $vendorDir . '/google/apiclient-services/src/Batch/Operation.php',
    'Google\\Service\\Batch\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Batch/OperationMetadata.php',
    'Google\\Service\\Batch\\PlacementPolicy' => $vendorDir . '/google/apiclient-services/src/Batch/PlacementPolicy.php',
    'Google\\Service\\Batch\\Policy' => $vendorDir . '/google/apiclient-services/src/Batch/Policy.php',
    'Google\\Service\\Batch\\ReportAgentStateRequest' => $vendorDir . '/google/apiclient-services/src/Batch/ReportAgentStateRequest.php',
    'Google\\Service\\Batch\\ReportAgentStateResponse' => $vendorDir . '/google/apiclient-services/src/Batch/ReportAgentStateResponse.php',
    'Google\\Service\\Batch\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/Projects.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocations.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsJobs' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsJobs.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsJobsTaskGroups' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsJobsTaskGroups.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsJobsTaskGroupsTasks' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsJobsTaskGroupsTasks.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsNodes' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsNodes.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsState' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsState.php',
    'Google\\Service\\Batch\\Resource\\ProjectsLocationsTasks' => $vendorDir . '/google/apiclient-services/src/Batch/Resource/ProjectsLocationsTasks.php',
    'Google\\Service\\Batch\\Runnable' => $vendorDir . '/google/apiclient-services/src/Batch/Runnable.php',
    'Google\\Service\\Batch\\Script' => $vendorDir . '/google/apiclient-services/src/Batch/Script.php',
    'Google\\Service\\Batch\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Batch/ServiceAccount.php',
    'Google\\Service\\Batch\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Batch/SetIamPolicyRequest.php',
    'Google\\Service\\Batch\\Status' => $vendorDir . '/google/apiclient-services/src/Batch/Status.php',
    'Google\\Service\\Batch\\StatusEvent' => $vendorDir . '/google/apiclient-services/src/Batch/StatusEvent.php',
    'Google\\Service\\Batch\\Task' => $vendorDir . '/google/apiclient-services/src/Batch/Task.php',
    'Google\\Service\\Batch\\TaskExecution' => $vendorDir . '/google/apiclient-services/src/Batch/TaskExecution.php',
    'Google\\Service\\Batch\\TaskGroup' => $vendorDir . '/google/apiclient-services/src/Batch/TaskGroup.php',
    'Google\\Service\\Batch\\TaskGroupStatus' => $vendorDir . '/google/apiclient-services/src/Batch/TaskGroupStatus.php',
    'Google\\Service\\Batch\\TaskSpec' => $vendorDir . '/google/apiclient-services/src/Batch/TaskSpec.php',
    'Google\\Service\\Batch\\TaskStatus' => $vendorDir . '/google/apiclient-services/src/Batch/TaskStatus.php',
    'Google\\Service\\Batch\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Batch/TestIamPermissionsRequest.php',
    'Google\\Service\\Batch\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Batch/TestIamPermissionsResponse.php',
    'Google\\Service\\Batch\\Volume' => $vendorDir . '/google/apiclient-services/src/Batch/Volume.php',
    'Google\\Service\\BeyondCorp' => $vendorDir . '/google/apiclient-services/src/BeyondCorp.php',
    'Google\\Service\\BeyondCorp\\AllocatedConnection' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/AllocatedConnection.php',
    'Google\\Service\\BeyondCorp\\AppGateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/AppGateway.php',
    'Google\\Service\\BeyondCorp\\AppGatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/AppGatewayOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\ApplicationEndpoint' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ApplicationEndpoint.php',
    'Google\\Service\\BeyondCorp\\BeyondcorpEmpty' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/BeyondcorpEmpty.php',
    'Google\\Service\\BeyondCorp\\ClientConnectorService' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ClientConnectorService.php',
    'Google\\Service\\BeyondCorp\\ClientConnectorServiceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ClientConnectorServiceOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\ClientGateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ClientGateway.php',
    'Google\\Service\\BeyondCorp\\ClientGatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ClientGatewayOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\CloudPubSubNotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/CloudPubSubNotificationConfig.php',
    'Google\\Service\\BeyondCorp\\CloudSecurityZerotrustApplinkAppConnectorProtoConnectionConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/CloudSecurityZerotrustApplinkAppConnectorProtoConnectionConfig.php',
    'Google\\Service\\BeyondCorp\\CloudSecurityZerotrustApplinkAppConnectorProtoConnectorDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/CloudSecurityZerotrustApplinkAppConnectorProtoConnectorDetails.php',
    'Google\\Service\\BeyondCorp\\CloudSecurityZerotrustApplinkAppConnectorProtoGateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/CloudSecurityZerotrustApplinkAppConnectorProtoGateway.php',
    'Google\\Service\\BeyondCorp\\CloudSecurityZerotrustApplinkLogagentProtoLogAgentDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/CloudSecurityZerotrustApplinkLogagentProtoLogAgentDetails.php',
    'Google\\Service\\BeyondCorp\\Config' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Config.php',
    'Google\\Service\\BeyondCorp\\Connection' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Connection.php',
    'Google\\Service\\BeyondCorp\\ConnectionDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ConnectionDetails.php',
    'Google\\Service\\BeyondCorp\\ConnectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ConnectionOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\Connector' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Connector.php',
    'Google\\Service\\BeyondCorp\\ConnectorInstanceConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ConnectorInstanceConfig.php',
    'Google\\Service\\BeyondCorp\\ConnectorOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ConnectorOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\ContainerHealthDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ContainerHealthDetails.php',
    'Google\\Service\\BeyondCorp\\DestinationRoute' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/DestinationRoute.php',
    'Google\\Service\\BeyondCorp\\Egress' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Egress.php',
    'Google\\Service\\BeyondCorp\\Gateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Gateway.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1AppConnection' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1AppConnection.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1AppConnectionApplicationEndpoint' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1AppConnectionApplicationEndpoint.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1AppConnectionGateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1AppConnectionGateway.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1AppConnectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1AppConnectionOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1ListAppConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1ListAppConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1ResolveAppConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1ResolveAppConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1ResolveAppConnectionsResponseAppConnectionDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1ResolveAppConnectionsResponseAppConnectionDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionApplicationEndpoint' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionApplicationEndpoint.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionGateway' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionGateway.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseAppConnectionDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseAppConnectionDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1AppConnector' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1AppConnector.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1AppConnectorInstanceConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1AppConnectorInstanceConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1AppConnectorOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1AppConnectorOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1AppConnectorPrincipalInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1AppConnectorPrincipalInfo.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1AppConnectorPrincipalInfoServiceAccount' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1AppConnectorPrincipalInfoServiceAccount.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ContainerHealthDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ContainerHealthDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ImageConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ImageConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ListAppConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ListAppConnectorsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1NotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1NotificationConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1NotificationConfigCloudPubSubNotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1NotificationConfigCloudPubSubNotificationConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1RemoteAgentDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1RemoteAgentDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ReportStatusRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ReportStatusRequest.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ResolveInstanceConfigResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ResolveInstanceConfigResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorInstanceConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorInstanceConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfo.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfoServiceAccount' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfoServiceAccount.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaContainerHealthDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaContainerHealthDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaImageConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaImageConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfigCloudPubSubNotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfigCloudPubSubNotificationConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaRemoteAgentDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaRemoteAgentDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaReportStatusRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaReportStatusRequest.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpAppgatewaysV1alphaAppGatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpAppgatewaysV1alphaAppGatewayOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpApplicationsV1alphaApplicationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpApplicationsV1alphaApplicationOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpClientconnectorservicesV1alphaClientConnectorServiceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpClientconnectorservicesV1alphaClientConnectorServiceOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpClientgatewaysV1alphaClientGatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpClientgatewaysV1alphaClientGatewayOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpConnectionsV1alphaConnectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpConnectionsV1alphaConnectionOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpConnectorsV1alphaConnectorOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpConnectorsV1alphaConnectorOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpConnectorsV1alphaContainerHealthDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpConnectorsV1alphaContainerHealthDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpConnectorsV1alphaRemoteAgentDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpConnectorsV1alphaRemoteAgentDetails.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnectionOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpPartnerservicesV1alphaPartnerServiceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpPartnerservicesV1alphaPartnerServiceOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpPartnerservicesV1mainPartnerServiceOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpPartnerservicesV1mainPartnerServiceOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleCloudLocationLocation.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1AuditConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1Binding.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1Policy.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\BeyondCorp\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\BeyondCorp\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\BeyondCorp\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleLongrunningOperation.php',
    'Google\\Service\\BeyondCorp\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleRpcStatus.php',
    'Google\\Service\\BeyondCorp\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/GoogleTypeExpr.php',
    'Google\\Service\\BeyondCorp\\ImageConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ImageConfig.php',
    'Google\\Service\\BeyondCorp\\Ingress' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Ingress.php',
    'Google\\Service\\BeyondCorp\\ListAppGatewaysResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ListAppGatewaysResponse.php',
    'Google\\Service\\BeyondCorp\\ListClientConnectorServicesResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ListClientConnectorServicesResponse.php',
    'Google\\Service\\BeyondCorp\\ListClientGatewaysResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ListClientGatewaysResponse.php',
    'Google\\Service\\BeyondCorp\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ListConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\ListConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ListConnectorsResponse.php',
    'Google\\Service\\BeyondCorp\\NotificationConfig' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/NotificationConfig.php',
    'Google\\Service\\BeyondCorp\\PeeredVpc' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/PeeredVpc.php',
    'Google\\Service\\BeyondCorp\\PrincipalInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/PrincipalInfo.php',
    'Google\\Service\\BeyondCorp\\RemoteAgentDetails' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/RemoteAgentDetails.php',
    'Google\\Service\\BeyondCorp\\ReportStatusRequest' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ReportStatusRequest.php',
    'Google\\Service\\BeyondCorp\\ResolveConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ResolveConnectionsResponse.php',
    'Google\\Service\\BeyondCorp\\ResolveInstanceConfigResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ResolveInstanceConfigResponse.php',
    'Google\\Service\\BeyondCorp\\ResourceInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ResourceInfo.php',
    'Google\\Service\\BeyondCorp\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/Organizations.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocations.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobal' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobal.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobalPartnerTenants' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobalPartnerTenants.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobalPartnerTenantsBrowserDlpRules' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobalPartnerTenantsBrowserDlpRules.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobalPartnerTenantsProxyConfigs' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobalPartnerTenantsProxyConfigs.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobalTenants' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobalTenants.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsBeyondcorpGlobalTenantsProxyConfigs' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsBeyondcorpGlobalTenantsProxyConfigs.php',
    'Google\\Service\\BeyondCorp\\Resource\\OrganizationsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/OrganizationsLocationsOperations.php',
    'Google\\Service\\BeyondCorp\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/Projects.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocations.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsAppConnections' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsAppConnections.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsAppConnectors' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsAppConnectors.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsAppGateways' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsAppGateways.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsClientConnectorServices' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsClientConnectorServices.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsClientGateways' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsClientGateways.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsConnectors' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsConnectors.php',
    'Google\\Service\\BeyondCorp\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\BeyondCorp\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ServiceAccount.php',
    'Google\\Service\\BeyondCorp\\ShouldThrottleResponse' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/ShouldThrottleResponse.php',
    'Google\\Service\\BeyondCorp\\Tunnelv1ProtoTunnelerError' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Tunnelv1ProtoTunnelerError.php',
    'Google\\Service\\BeyondCorp\\Tunnelv1ProtoTunnelerInfo' => $vendorDir . '/google/apiclient-services/src/BeyondCorp/Tunnelv1ProtoTunnelerInfo.php',
    'Google\\Service\\BigLakeService' => $vendorDir . '/google/apiclient-services/src/BigLakeService.php',
    'Google\\Service\\BigLakeService\\Catalog' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Catalog.php',
    'Google\\Service\\BigLakeService\\Database' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Database.php',
    'Google\\Service\\BigLakeService\\HiveDatabaseOptions' => $vendorDir . '/google/apiclient-services/src/BigLakeService/HiveDatabaseOptions.php',
    'Google\\Service\\BigLakeService\\HiveTableOptions' => $vendorDir . '/google/apiclient-services/src/BigLakeService/HiveTableOptions.php',
    'Google\\Service\\BigLakeService\\ListCatalogsResponse' => $vendorDir . '/google/apiclient-services/src/BigLakeService/ListCatalogsResponse.php',
    'Google\\Service\\BigLakeService\\ListDatabasesResponse' => $vendorDir . '/google/apiclient-services/src/BigLakeService/ListDatabasesResponse.php',
    'Google\\Service\\BigLakeService\\ListTablesResponse' => $vendorDir . '/google/apiclient-services/src/BigLakeService/ListTablesResponse.php',
    'Google\\Service\\BigLakeService\\RenameTableRequest' => $vendorDir . '/google/apiclient-services/src/BigLakeService/RenameTableRequest.php',
    'Google\\Service\\BigLakeService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Resource/Projects.php',
    'Google\\Service\\BigLakeService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Resource/ProjectsLocations.php',
    'Google\\Service\\BigLakeService\\Resource\\ProjectsLocationsCatalogs' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Resource/ProjectsLocationsCatalogs.php',
    'Google\\Service\\BigLakeService\\Resource\\ProjectsLocationsCatalogsDatabases' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Resource/ProjectsLocationsCatalogsDatabases.php',
    'Google\\Service\\BigLakeService\\Resource\\ProjectsLocationsCatalogsDatabasesTables' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Resource/ProjectsLocationsCatalogsDatabasesTables.php',
    'Google\\Service\\BigLakeService\\SerDeInfo' => $vendorDir . '/google/apiclient-services/src/BigLakeService/SerDeInfo.php',
    'Google\\Service\\BigLakeService\\StorageDescriptor' => $vendorDir . '/google/apiclient-services/src/BigLakeService/StorageDescriptor.php',
    'Google\\Service\\BigLakeService\\Table' => $vendorDir . '/google/apiclient-services/src/BigLakeService/Table.php',
    'Google\\Service\\BigQueryConnectionService' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService.php',
    'Google\\Service\\BigQueryConnectionService\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/AuditConfig.php',
    'Google\\Service\\BigQueryConnectionService\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/AuditLogConfig.php',
    'Google\\Service\\BigQueryConnectionService\\AwsAccessRole' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/AwsAccessRole.php',
    'Google\\Service\\BigQueryConnectionService\\AwsProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/AwsProperties.php',
    'Google\\Service\\BigQueryConnectionService\\AzureProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/AzureProperties.php',
    'Google\\Service\\BigQueryConnectionService\\BigqueryconnectionEmpty' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/BigqueryconnectionEmpty.php',
    'Google\\Service\\BigQueryConnectionService\\Binding' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Binding.php',
    'Google\\Service\\BigQueryConnectionService\\CloudResourceProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/CloudResourceProperties.php',
    'Google\\Service\\BigQueryConnectionService\\CloudSpannerProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/CloudSpannerProperties.php',
    'Google\\Service\\BigQueryConnectionService\\CloudSqlCredential' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/CloudSqlCredential.php',
    'Google\\Service\\BigQueryConnectionService\\CloudSqlProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/CloudSqlProperties.php',
    'Google\\Service\\BigQueryConnectionService\\Connection' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Connection.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectionCredential' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectionCredential.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfiguration' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfiguration.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationAsset' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationAsset.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationAuthentication' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationAuthentication.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationEndpoint' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationEndpoint.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationNetwork' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationNetwork.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationPrivateServiceConnect' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationPrivateServiceConnect.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationSecret' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationSecret.php',
    'Google\\Service\\BigQueryConnectionService\\ConnectorConfigurationUsernamePassword' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ConnectorConfigurationUsernamePassword.php',
    'Google\\Service\\BigQueryConnectionService\\Expr' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Expr.php',
    'Google\\Service\\BigQueryConnectionService\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/GetIamPolicyRequest.php',
    'Google\\Service\\BigQueryConnectionService\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/GetPolicyOptions.php',
    'Google\\Service\\BigQueryConnectionService\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/ListConnectionsResponse.php',
    'Google\\Service\\BigQueryConnectionService\\MetastoreServiceConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/MetastoreServiceConfig.php',
    'Google\\Service\\BigQueryConnectionService\\Policy' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Policy.php',
    'Google\\Service\\BigQueryConnectionService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Resource/Projects.php',
    'Google\\Service\\BigQueryConnectionService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Resource/ProjectsLocations.php',
    'Google\\Service\\BigQueryConnectionService\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\BigQueryConnectionService\\SalesforceDataCloudProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/SalesforceDataCloudProperties.php',
    'Google\\Service\\BigQueryConnectionService\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/SetIamPolicyRequest.php',
    'Google\\Service\\BigQueryConnectionService\\SparkHistoryServerConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/SparkHistoryServerConfig.php',
    'Google\\Service\\BigQueryConnectionService\\SparkProperties' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/SparkProperties.php',
    'Google\\Service\\BigQueryConnectionService\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/TestIamPermissionsRequest.php',
    'Google\\Service\\BigQueryConnectionService\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryConnectionService/TestIamPermissionsResponse.php',
    'Google\\Service\\BigQueryDataPolicyService' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService.php',
    'Google\\Service\\BigQueryDataPolicyService\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/AuditConfig.php',
    'Google\\Service\\BigQueryDataPolicyService\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/AuditLogConfig.php',
    'Google\\Service\\BigQueryDataPolicyService\\BigquerydatapolicyEmpty' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/BigquerydatapolicyEmpty.php',
    'Google\\Service\\BigQueryDataPolicyService\\Binding' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Binding.php',
    'Google\\Service\\BigQueryDataPolicyService\\DataMaskingPolicy' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/DataMaskingPolicy.php',
    'Google\\Service\\BigQueryDataPolicyService\\DataPolicy' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/DataPolicy.php',
    'Google\\Service\\BigQueryDataPolicyService\\Expr' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Expr.php',
    'Google\\Service\\BigQueryDataPolicyService\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/GetIamPolicyRequest.php',
    'Google\\Service\\BigQueryDataPolicyService\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/GetPolicyOptions.php',
    'Google\\Service\\BigQueryDataPolicyService\\ListDataPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/ListDataPoliciesResponse.php',
    'Google\\Service\\BigQueryDataPolicyService\\Policy' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Policy.php',
    'Google\\Service\\BigQueryDataPolicyService\\RenameDataPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/RenameDataPolicyRequest.php',
    'Google\\Service\\BigQueryDataPolicyService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Resource/Projects.php',
    'Google\\Service\\BigQueryDataPolicyService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Resource/ProjectsLocations.php',
    'Google\\Service\\BigQueryDataPolicyService\\Resource\\ProjectsLocationsDataPolicies' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/Resource/ProjectsLocationsDataPolicies.php',
    'Google\\Service\\BigQueryDataPolicyService\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/SetIamPolicyRequest.php',
    'Google\\Service\\BigQueryDataPolicyService\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/TestIamPermissionsRequest.php',
    'Google\\Service\\BigQueryDataPolicyService\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataPolicyService/TestIamPermissionsResponse.php',
    'Google\\Service\\BigQueryDataTransfer' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer.php',
    'Google\\Service\\BigQueryDataTransfer\\BigquerydatatransferEmpty' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/BigquerydatatransferEmpty.php',
    'Google\\Service\\BigQueryDataTransfer\\CheckValidCredsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/CheckValidCredsRequest.php',
    'Google\\Service\\BigQueryDataTransfer\\CheckValidCredsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/CheckValidCredsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\DataSource' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/DataSource.php',
    'Google\\Service\\BigQueryDataTransfer\\DataSourceParameter' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/DataSourceParameter.php',
    'Google\\Service\\BigQueryDataTransfer\\EmailPreferences' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/EmailPreferences.php',
    'Google\\Service\\BigQueryDataTransfer\\EncryptionConfiguration' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/EncryptionConfiguration.php',
    'Google\\Service\\BigQueryDataTransfer\\EnrollDataSourcesRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/EnrollDataSourcesRequest.php',
    'Google\\Service\\BigQueryDataTransfer\\ListDataSourcesResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ListDataSourcesResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ListLocationsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\ListTransferConfigsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ListTransferConfigsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\ListTransferLogsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ListTransferLogsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\ListTransferRunsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ListTransferRunsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\Location' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Location.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/Projects.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsDataSources' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsDataSources.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsLocations.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsLocationsDataSources' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsLocationsDataSources.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsLocationsTransferConfigs' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsLocationsTransferConfigs.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsLocationsTransferConfigsRuns' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsLocationsTransferConfigsRuns.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsLocationsTransferConfigsRunsTransferLogs' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsLocationsTransferConfigsRunsTransferLogs.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsTransferConfigs' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsTransferConfigs.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsTransferConfigsRuns' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsTransferConfigsRuns.php',
    'Google\\Service\\BigQueryDataTransfer\\Resource\\ProjectsTransferConfigsRunsTransferLogs' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Resource/ProjectsTransferConfigsRunsTransferLogs.php',
    'Google\\Service\\BigQueryDataTransfer\\ScheduleOptions' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ScheduleOptions.php',
    'Google\\Service\\BigQueryDataTransfer\\ScheduleTransferRunsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ScheduleTransferRunsRequest.php',
    'Google\\Service\\BigQueryDataTransfer\\ScheduleTransferRunsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/ScheduleTransferRunsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\StartManualTransferRunsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/StartManualTransferRunsRequest.php',
    'Google\\Service\\BigQueryDataTransfer\\StartManualTransferRunsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/StartManualTransferRunsResponse.php',
    'Google\\Service\\BigQueryDataTransfer\\Status' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/Status.php',
    'Google\\Service\\BigQueryDataTransfer\\TimeRange' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/TimeRange.php',
    'Google\\Service\\BigQueryDataTransfer\\TransferConfig' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/TransferConfig.php',
    'Google\\Service\\BigQueryDataTransfer\\TransferMessage' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/TransferMessage.php',
    'Google\\Service\\BigQueryDataTransfer\\TransferRun' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/TransferRun.php',
    'Google\\Service\\BigQueryDataTransfer\\UnenrollDataSourcesRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/UnenrollDataSourcesRequest.php',
    'Google\\Service\\BigQueryDataTransfer\\UserInfo' => $vendorDir . '/google/apiclient-services/src/BigQueryDataTransfer/UserInfo.php',
    'Google\\Service\\BigQueryReservation' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation.php',
    'Google\\Service\\BigQueryReservation\\Assignment' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Assignment.php',
    'Google\\Service\\BigQueryReservation\\Autoscale' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Autoscale.php',
    'Google\\Service\\BigQueryReservation\\BiReservation' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/BiReservation.php',
    'Google\\Service\\BigQueryReservation\\BigqueryreservationEmpty' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/BigqueryreservationEmpty.php',
    'Google\\Service\\BigQueryReservation\\CapacityCommitment' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/CapacityCommitment.php',
    'Google\\Service\\BigQueryReservation\\FailoverReservationRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/FailoverReservationRequest.php',
    'Google\\Service\\BigQueryReservation\\ListAssignmentsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/ListAssignmentsResponse.php',
    'Google\\Service\\BigQueryReservation\\ListCapacityCommitmentsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/ListCapacityCommitmentsResponse.php',
    'Google\\Service\\BigQueryReservation\\ListReservationsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/ListReservationsResponse.php',
    'Google\\Service\\BigQueryReservation\\MergeCapacityCommitmentsRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/MergeCapacityCommitmentsRequest.php',
    'Google\\Service\\BigQueryReservation\\MoveAssignmentRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/MoveAssignmentRequest.php',
    'Google\\Service\\BigQueryReservation\\Reservation' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Reservation.php',
    'Google\\Service\\BigQueryReservation\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Resource/Projects.php',
    'Google\\Service\\BigQueryReservation\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Resource/ProjectsLocations.php',
    'Google\\Service\\BigQueryReservation\\Resource\\ProjectsLocationsCapacityCommitments' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Resource/ProjectsLocationsCapacityCommitments.php',
    'Google\\Service\\BigQueryReservation\\Resource\\ProjectsLocationsReservations' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Resource/ProjectsLocationsReservations.php',
    'Google\\Service\\BigQueryReservation\\Resource\\ProjectsLocationsReservationsAssignments' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Resource/ProjectsLocationsReservationsAssignments.php',
    'Google\\Service\\BigQueryReservation\\SearchAllAssignmentsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/SearchAllAssignmentsResponse.php',
    'Google\\Service\\BigQueryReservation\\SearchAssignmentsResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/SearchAssignmentsResponse.php',
    'Google\\Service\\BigQueryReservation\\SplitCapacityCommitmentRequest' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/SplitCapacityCommitmentRequest.php',
    'Google\\Service\\BigQueryReservation\\SplitCapacityCommitmentResponse' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/SplitCapacityCommitmentResponse.php',
    'Google\\Service\\BigQueryReservation\\Status' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/Status.php',
    'Google\\Service\\BigQueryReservation\\TableReference' => $vendorDir . '/google/apiclient-services/src/BigQueryReservation/TableReference.php',
    'Google\\Service\\Bigquery' => $vendorDir . '/google/apiclient-services/src/Bigquery.php',
    'Google\\Service\\Bigquery\\AggregateClassificationMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/AggregateClassificationMetrics.php',
    'Google\\Service\\Bigquery\\AggregationThresholdPolicy' => $vendorDir . '/google/apiclient-services/src/Bigquery/AggregationThresholdPolicy.php',
    'Google\\Service\\Bigquery\\Argument' => $vendorDir . '/google/apiclient-services/src/Bigquery/Argument.php',
    'Google\\Service\\Bigquery\\ArimaCoefficients' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaCoefficients.php',
    'Google\\Service\\Bigquery\\ArimaFittingMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaFittingMetrics.php',
    'Google\\Service\\Bigquery\\ArimaForecastingMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaForecastingMetrics.php',
    'Google\\Service\\Bigquery\\ArimaModelInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaModelInfo.php',
    'Google\\Service\\Bigquery\\ArimaOrder' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaOrder.php',
    'Google\\Service\\Bigquery\\ArimaResult' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaResult.php',
    'Google\\Service\\Bigquery\\ArimaSingleModelForecastingMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ArimaSingleModelForecastingMetrics.php',
    'Google\\Service\\Bigquery\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Bigquery/AuditConfig.php',
    'Google\\Service\\Bigquery\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Bigquery/AuditLogConfig.php',
    'Google\\Service\\Bigquery\\AvroOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/AvroOptions.php',
    'Google\\Service\\Bigquery\\BiEngineReason' => $vendorDir . '/google/apiclient-services/src/Bigquery/BiEngineReason.php',
    'Google\\Service\\Bigquery\\BiEngineStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/BiEngineStatistics.php',
    'Google\\Service\\Bigquery\\BigLakeConfiguration' => $vendorDir . '/google/apiclient-services/src/Bigquery/BigLakeConfiguration.php',
    'Google\\Service\\Bigquery\\BigQueryModelTraining' => $vendorDir . '/google/apiclient-services/src/Bigquery/BigQueryModelTraining.php',
    'Google\\Service\\Bigquery\\BigtableColumn' => $vendorDir . '/google/apiclient-services/src/Bigquery/BigtableColumn.php',
    'Google\\Service\\Bigquery\\BigtableColumnFamily' => $vendorDir . '/google/apiclient-services/src/Bigquery/BigtableColumnFamily.php',
    'Google\\Service\\Bigquery\\BigtableOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/BigtableOptions.php',
    'Google\\Service\\Bigquery\\BinaryClassificationMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/BinaryClassificationMetrics.php',
    'Google\\Service\\Bigquery\\BinaryConfusionMatrix' => $vendorDir . '/google/apiclient-services/src/Bigquery/BinaryConfusionMatrix.php',
    'Google\\Service\\Bigquery\\Binding' => $vendorDir . '/google/apiclient-services/src/Bigquery/Binding.php',
    'Google\\Service\\Bigquery\\BqmlIterationResult' => $vendorDir . '/google/apiclient-services/src/Bigquery/BqmlIterationResult.php',
    'Google\\Service\\Bigquery\\BqmlTrainingRun' => $vendorDir . '/google/apiclient-services/src/Bigquery/BqmlTrainingRun.php',
    'Google\\Service\\Bigquery\\BqmlTrainingRunTrainingOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/BqmlTrainingRunTrainingOptions.php',
    'Google\\Service\\Bigquery\\CategoricalValue' => $vendorDir . '/google/apiclient-services/src/Bigquery/CategoricalValue.php',
    'Google\\Service\\Bigquery\\CategoryCount' => $vendorDir . '/google/apiclient-services/src/Bigquery/CategoryCount.php',
    'Google\\Service\\Bigquery\\CloneDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/CloneDefinition.php',
    'Google\\Service\\Bigquery\\Cluster' => $vendorDir . '/google/apiclient-services/src/Bigquery/Cluster.php',
    'Google\\Service\\Bigquery\\ClusterInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/ClusterInfo.php',
    'Google\\Service\\Bigquery\\Clustering' => $vendorDir . '/google/apiclient-services/src/Bigquery/Clustering.php',
    'Google\\Service\\Bigquery\\ClusteringMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ClusteringMetrics.php',
    'Google\\Service\\Bigquery\\ConfusionMatrix' => $vendorDir . '/google/apiclient-services/src/Bigquery/ConfusionMatrix.php',
    'Google\\Service\\Bigquery\\ConnectionProperty' => $vendorDir . '/google/apiclient-services/src/Bigquery/ConnectionProperty.php',
    'Google\\Service\\Bigquery\\CsvOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/CsvOptions.php',
    'Google\\Service\\Bigquery\\DataFormatOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/DataFormatOptions.php',
    'Google\\Service\\Bigquery\\DataMaskingStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/DataMaskingStatistics.php',
    'Google\\Service\\Bigquery\\DataPolicyOption' => $vendorDir . '/google/apiclient-services/src/Bigquery/DataPolicyOption.php',
    'Google\\Service\\Bigquery\\DataSplitResult' => $vendorDir . '/google/apiclient-services/src/Bigquery/DataSplitResult.php',
    'Google\\Service\\Bigquery\\Dataset' => $vendorDir . '/google/apiclient-services/src/Bigquery/Dataset.php',
    'Google\\Service\\Bigquery\\DatasetAccess' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetAccess.php',
    'Google\\Service\\Bigquery\\DatasetAccessEntry' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetAccessEntry.php',
    'Google\\Service\\Bigquery\\DatasetAccessEntryTargetTypes' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetAccessEntryTargetTypes.php',
    'Google\\Service\\Bigquery\\DatasetList' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetList.php',
    'Google\\Service\\Bigquery\\DatasetListDatasets' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetListDatasets.php',
    'Google\\Service\\Bigquery\\DatasetReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetReference.php',
    'Google\\Service\\Bigquery\\DatasetTags' => $vendorDir . '/google/apiclient-services/src/Bigquery/DatasetTags.php',
    'Google\\Service\\Bigquery\\DestinationTableProperties' => $vendorDir . '/google/apiclient-services/src/Bigquery/DestinationTableProperties.php',
    'Google\\Service\\Bigquery\\DifferentialPrivacyPolicy' => $vendorDir . '/google/apiclient-services/src/Bigquery/DifferentialPrivacyPolicy.php',
    'Google\\Service\\Bigquery\\DimensionalityReductionMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/DimensionalityReductionMetrics.php',
    'Google\\Service\\Bigquery\\DmlStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/DmlStatistics.php',
    'Google\\Service\\Bigquery\\DoubleCandidates' => $vendorDir . '/google/apiclient-services/src/Bigquery/DoubleCandidates.php',
    'Google\\Service\\Bigquery\\DoubleHparamSearchSpace' => $vendorDir . '/google/apiclient-services/src/Bigquery/DoubleHparamSearchSpace.php',
    'Google\\Service\\Bigquery\\DoubleRange' => $vendorDir . '/google/apiclient-services/src/Bigquery/DoubleRange.php',
    'Google\\Service\\Bigquery\\EncryptionConfiguration' => $vendorDir . '/google/apiclient-services/src/Bigquery/EncryptionConfiguration.php',
    'Google\\Service\\Bigquery\\Entry' => $vendorDir . '/google/apiclient-services/src/Bigquery/Entry.php',
    'Google\\Service\\Bigquery\\ErrorProto' => $vendorDir . '/google/apiclient-services/src/Bigquery/ErrorProto.php',
    'Google\\Service\\Bigquery\\EvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/EvaluationMetrics.php',
    'Google\\Service\\Bigquery\\ExplainQueryStage' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExplainQueryStage.php',
    'Google\\Service\\Bigquery\\ExplainQueryStep' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExplainQueryStep.php',
    'Google\\Service\\Bigquery\\Explanation' => $vendorDir . '/google/apiclient-services/src/Bigquery/Explanation.php',
    'Google\\Service\\Bigquery\\ExportDataStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExportDataStatistics.php',
    'Google\\Service\\Bigquery\\Expr' => $vendorDir . '/google/apiclient-services/src/Bigquery/Expr.php',
    'Google\\Service\\Bigquery\\ExternalCatalogDatasetOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExternalCatalogDatasetOptions.php',
    'Google\\Service\\Bigquery\\ExternalCatalogTableOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExternalCatalogTableOptions.php',
    'Google\\Service\\Bigquery\\ExternalDataConfiguration' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExternalDataConfiguration.php',
    'Google\\Service\\Bigquery\\ExternalDatasetReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExternalDatasetReference.php',
    'Google\\Service\\Bigquery\\ExternalServiceCost' => $vendorDir . '/google/apiclient-services/src/Bigquery/ExternalServiceCost.php',
    'Google\\Service\\Bigquery\\FeatureValue' => $vendorDir . '/google/apiclient-services/src/Bigquery/FeatureValue.php',
    'Google\\Service\\Bigquery\\ForeignTypeInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/ForeignTypeInfo.php',
    'Google\\Service\\Bigquery\\ForeignViewDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/ForeignViewDefinition.php',
    'Google\\Service\\Bigquery\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/GetIamPolicyRequest.php',
    'Google\\Service\\Bigquery\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/GetPolicyOptions.php',
    'Google\\Service\\Bigquery\\GetQueryResultsResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/GetQueryResultsResponse.php',
    'Google\\Service\\Bigquery\\GetServiceAccountResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/GetServiceAccountResponse.php',
    'Google\\Service\\Bigquery\\GlobalExplanation' => $vendorDir . '/google/apiclient-services/src/Bigquery/GlobalExplanation.php',
    'Google\\Service\\Bigquery\\GoogleSheetsOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/GoogleSheetsOptions.php',
    'Google\\Service\\Bigquery\\HighCardinalityJoin' => $vendorDir . '/google/apiclient-services/src/Bigquery/HighCardinalityJoin.php',
    'Google\\Service\\Bigquery\\HivePartitioningOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/HivePartitioningOptions.php',
    'Google\\Service\\Bigquery\\HparamSearchSpaces' => $vendorDir . '/google/apiclient-services/src/Bigquery/HparamSearchSpaces.php',
    'Google\\Service\\Bigquery\\HparamTuningTrial' => $vendorDir . '/google/apiclient-services/src/Bigquery/HparamTuningTrial.php',
    'Google\\Service\\Bigquery\\IdentityColumnInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/IdentityColumnInfo.php',
    'Google\\Service\\Bigquery\\IndexUnusedReason' => $vendorDir . '/google/apiclient-services/src/Bigquery/IndexUnusedReason.php',
    'Google\\Service\\Bigquery\\InputDataChange' => $vendorDir . '/google/apiclient-services/src/Bigquery/InputDataChange.php',
    'Google\\Service\\Bigquery\\IntArray' => $vendorDir . '/google/apiclient-services/src/Bigquery/IntArray.php',
    'Google\\Service\\Bigquery\\IntArrayHparamSearchSpace' => $vendorDir . '/google/apiclient-services/src/Bigquery/IntArrayHparamSearchSpace.php',
    'Google\\Service\\Bigquery\\IntCandidates' => $vendorDir . '/google/apiclient-services/src/Bigquery/IntCandidates.php',
    'Google\\Service\\Bigquery\\IntHparamSearchSpace' => $vendorDir . '/google/apiclient-services/src/Bigquery/IntHparamSearchSpace.php',
    'Google\\Service\\Bigquery\\IntRange' => $vendorDir . '/google/apiclient-services/src/Bigquery/IntRange.php',
    'Google\\Service\\Bigquery\\IterationResult' => $vendorDir . '/google/apiclient-services/src/Bigquery/IterationResult.php',
    'Google\\Service\\Bigquery\\Job' => $vendorDir . '/google/apiclient-services/src/Bigquery/Job.php',
    'Google\\Service\\Bigquery\\JobCancelResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobCancelResponse.php',
    'Google\\Service\\Bigquery\\JobConfiguration' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobConfiguration.php',
    'Google\\Service\\Bigquery\\JobConfigurationExtract' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobConfigurationExtract.php',
    'Google\\Service\\Bigquery\\JobConfigurationLoad' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobConfigurationLoad.php',
    'Google\\Service\\Bigquery\\JobConfigurationQuery' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobConfigurationQuery.php',
    'Google\\Service\\Bigquery\\JobConfigurationTableCopy' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobConfigurationTableCopy.php',
    'Google\\Service\\Bigquery\\JobCreationReason' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobCreationReason.php',
    'Google\\Service\\Bigquery\\JobList' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobList.php',
    'Google\\Service\\Bigquery\\JobListJobs' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobListJobs.php',
    'Google\\Service\\Bigquery\\JobReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobReference.php',
    'Google\\Service\\Bigquery\\JobStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics.php',
    'Google\\Service\\Bigquery\\JobStatistics2' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics2.php',
    'Google\\Service\\Bigquery\\JobStatistics2ReservationUsage' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics2ReservationUsage.php',
    'Google\\Service\\Bigquery\\JobStatistics3' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics3.php',
    'Google\\Service\\Bigquery\\JobStatistics4' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics4.php',
    'Google\\Service\\Bigquery\\JobStatistics5' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatistics5.php',
    'Google\\Service\\Bigquery\\JobStatisticsReservationUsage' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatisticsReservationUsage.php',
    'Google\\Service\\Bigquery\\JobStatus' => $vendorDir . '/google/apiclient-services/src/Bigquery/JobStatus.php',
    'Google\\Service\\Bigquery\\JoinRestrictionPolicy' => $vendorDir . '/google/apiclient-services/src/Bigquery/JoinRestrictionPolicy.php',
    'Google\\Service\\Bigquery\\JsonOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/JsonOptions.php',
    'Google\\Service\\Bigquery\\LinkedDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Bigquery/LinkedDatasetMetadata.php',
    'Google\\Service\\Bigquery\\LinkedDatasetSource' => $vendorDir . '/google/apiclient-services/src/Bigquery/LinkedDatasetSource.php',
    'Google\\Service\\Bigquery\\ListModelsResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/ListModelsResponse.php',
    'Google\\Service\\Bigquery\\ListRoutinesResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/ListRoutinesResponse.php',
    'Google\\Service\\Bigquery\\ListRowAccessPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/ListRowAccessPoliciesResponse.php',
    'Google\\Service\\Bigquery\\LoadQueryStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/LoadQueryStatistics.php',
    'Google\\Service\\Bigquery\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/Bigquery/LocationMetadata.php',
    'Google\\Service\\Bigquery\\MaterializedView' => $vendorDir . '/google/apiclient-services/src/Bigquery/MaterializedView.php',
    'Google\\Service\\Bigquery\\MaterializedViewDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/MaterializedViewDefinition.php',
    'Google\\Service\\Bigquery\\MaterializedViewStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/MaterializedViewStatistics.php',
    'Google\\Service\\Bigquery\\MaterializedViewStatus' => $vendorDir . '/google/apiclient-services/src/Bigquery/MaterializedViewStatus.php',
    'Google\\Service\\Bigquery\\MetadataCacheStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/MetadataCacheStatistics.php',
    'Google\\Service\\Bigquery\\MlStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/MlStatistics.php',
    'Google\\Service\\Bigquery\\Model' => $vendorDir . '/google/apiclient-services/src/Bigquery/Model.php',
    'Google\\Service\\Bigquery\\ModelDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/ModelDefinition.php',
    'Google\\Service\\Bigquery\\ModelDefinitionModelOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ModelDefinitionModelOptions.php',
    'Google\\Service\\Bigquery\\ModelExtractOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ModelExtractOptions.php',
    'Google\\Service\\Bigquery\\ModelReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/ModelReference.php',
    'Google\\Service\\Bigquery\\MultiClassClassificationMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/MultiClassClassificationMetrics.php',
    'Google\\Service\\Bigquery\\ParquetOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ParquetOptions.php',
    'Google\\Service\\Bigquery\\PartitionSkew' => $vendorDir . '/google/apiclient-services/src/Bigquery/PartitionSkew.php',
    'Google\\Service\\Bigquery\\PartitionedColumn' => $vendorDir . '/google/apiclient-services/src/Bigquery/PartitionedColumn.php',
    'Google\\Service\\Bigquery\\PartitioningDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/PartitioningDefinition.php',
    'Google\\Service\\Bigquery\\PerformanceInsights' => $vendorDir . '/google/apiclient-services/src/Bigquery/PerformanceInsights.php',
    'Google\\Service\\Bigquery\\Policy' => $vendorDir . '/google/apiclient-services/src/Bigquery/Policy.php',
    'Google\\Service\\Bigquery\\PrincipalComponentInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/PrincipalComponentInfo.php',
    'Google\\Service\\Bigquery\\PrivacyPolicy' => $vendorDir . '/google/apiclient-services/src/Bigquery/PrivacyPolicy.php',
    'Google\\Service\\Bigquery\\ProjectList' => $vendorDir . '/google/apiclient-services/src/Bigquery/ProjectList.php',
    'Google\\Service\\Bigquery\\ProjectListProjects' => $vendorDir . '/google/apiclient-services/src/Bigquery/ProjectListProjects.php',
    'Google\\Service\\Bigquery\\ProjectReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/ProjectReference.php',
    'Google\\Service\\Bigquery\\QueryInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryInfo.php',
    'Google\\Service\\Bigquery\\QueryParameter' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryParameter.php',
    'Google\\Service\\Bigquery\\QueryParameterType' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryParameterType.php',
    'Google\\Service\\Bigquery\\QueryParameterTypeStructTypes' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryParameterTypeStructTypes.php',
    'Google\\Service\\Bigquery\\QueryParameterValue' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryParameterValue.php',
    'Google\\Service\\Bigquery\\QueryParameterValueRangeValue' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryParameterValueRangeValue.php',
    'Google\\Service\\Bigquery\\QueryRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryRequest.php',
    'Google\\Service\\Bigquery\\QueryResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryResponse.php',
    'Google\\Service\\Bigquery\\QueryTimelineSample' => $vendorDir . '/google/apiclient-services/src/Bigquery/QueryTimelineSample.php',
    'Google\\Service\\Bigquery\\RangePartitioning' => $vendorDir . '/google/apiclient-services/src/Bigquery/RangePartitioning.php',
    'Google\\Service\\Bigquery\\RangePartitioningRange' => $vendorDir . '/google/apiclient-services/src/Bigquery/RangePartitioningRange.php',
    'Google\\Service\\Bigquery\\RangeValue' => $vendorDir . '/google/apiclient-services/src/Bigquery/RangeValue.php',
    'Google\\Service\\Bigquery\\RankingMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/RankingMetrics.php',
    'Google\\Service\\Bigquery\\RegressionMetrics' => $vendorDir . '/google/apiclient-services/src/Bigquery/RegressionMetrics.php',
    'Google\\Service\\Bigquery\\RemoteFunctionOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/RemoteFunctionOptions.php',
    'Google\\Service\\Bigquery\\RemoteModelInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/RemoteModelInfo.php',
    'Google\\Service\\Bigquery\\Resource\\Datasets' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Datasets.php',
    'Google\\Service\\Bigquery\\Resource\\Jobs' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Jobs.php',
    'Google\\Service\\Bigquery\\Resource\\Models' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Models.php',
    'Google\\Service\\Bigquery\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Projects.php',
    'Google\\Service\\Bigquery\\Resource\\Routines' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Routines.php',
    'Google\\Service\\Bigquery\\Resource\\RowAccessPolicies' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/RowAccessPolicies.php',
    'Google\\Service\\Bigquery\\Resource\\Tabledata' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Tabledata.php',
    'Google\\Service\\Bigquery\\Resource\\Tables' => $vendorDir . '/google/apiclient-services/src/Bigquery/Resource/Tables.php',
    'Google\\Service\\Bigquery\\RestrictionConfig' => $vendorDir . '/google/apiclient-services/src/Bigquery/RestrictionConfig.php',
    'Google\\Service\\Bigquery\\Routine' => $vendorDir . '/google/apiclient-services/src/Bigquery/Routine.php',
    'Google\\Service\\Bigquery\\RoutineReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/RoutineReference.php',
    'Google\\Service\\Bigquery\\Row' => $vendorDir . '/google/apiclient-services/src/Bigquery/Row.php',
    'Google\\Service\\Bigquery\\RowAccessPolicy' => $vendorDir . '/google/apiclient-services/src/Bigquery/RowAccessPolicy.php',
    'Google\\Service\\Bigquery\\RowAccessPolicyReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/RowAccessPolicyReference.php',
    'Google\\Service\\Bigquery\\RowLevelSecurityStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/RowLevelSecurityStatistics.php',
    'Google\\Service\\Bigquery\\ScriptOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/ScriptOptions.php',
    'Google\\Service\\Bigquery\\ScriptStackFrame' => $vendorDir . '/google/apiclient-services/src/Bigquery/ScriptStackFrame.php',
    'Google\\Service\\Bigquery\\ScriptStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/ScriptStatistics.php',
    'Google\\Service\\Bigquery\\SearchStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/SearchStatistics.php',
    'Google\\Service\\Bigquery\\SerDeInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/SerDeInfo.php',
    'Google\\Service\\Bigquery\\SessionInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/SessionInfo.php',
    'Google\\Service\\Bigquery\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/SetIamPolicyRequest.php',
    'Google\\Service\\Bigquery\\SkewSource' => $vendorDir . '/google/apiclient-services/src/Bigquery/SkewSource.php',
    'Google\\Service\\Bigquery\\SnapshotDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/SnapshotDefinition.php',
    'Google\\Service\\Bigquery\\SparkLoggingInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/SparkLoggingInfo.php',
    'Google\\Service\\Bigquery\\SparkOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/SparkOptions.php',
    'Google\\Service\\Bigquery\\SparkStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/SparkStatistics.php',
    'Google\\Service\\Bigquery\\StagePerformanceChangeInsight' => $vendorDir . '/google/apiclient-services/src/Bigquery/StagePerformanceChangeInsight.php',
    'Google\\Service\\Bigquery\\StagePerformanceStandaloneInsight' => $vendorDir . '/google/apiclient-services/src/Bigquery/StagePerformanceStandaloneInsight.php',
    'Google\\Service\\Bigquery\\StandardSqlDataType' => $vendorDir . '/google/apiclient-services/src/Bigquery/StandardSqlDataType.php',
    'Google\\Service\\Bigquery\\StandardSqlField' => $vendorDir . '/google/apiclient-services/src/Bigquery/StandardSqlField.php',
    'Google\\Service\\Bigquery\\StandardSqlStructType' => $vendorDir . '/google/apiclient-services/src/Bigquery/StandardSqlStructType.php',
    'Google\\Service\\Bigquery\\StandardSqlTableType' => $vendorDir . '/google/apiclient-services/src/Bigquery/StandardSqlTableType.php',
    'Google\\Service\\Bigquery\\StorageDescriptor' => $vendorDir . '/google/apiclient-services/src/Bigquery/StorageDescriptor.php',
    'Google\\Service\\Bigquery\\Streamingbuffer' => $vendorDir . '/google/apiclient-services/src/Bigquery/Streamingbuffer.php',
    'Google\\Service\\Bigquery\\StringHparamSearchSpace' => $vendorDir . '/google/apiclient-services/src/Bigquery/StringHparamSearchSpace.php',
    'Google\\Service\\Bigquery\\SystemVariables' => $vendorDir . '/google/apiclient-services/src/Bigquery/SystemVariables.php',
    'Google\\Service\\Bigquery\\Table' => $vendorDir . '/google/apiclient-services/src/Bigquery/Table.php',
    'Google\\Service\\Bigquery\\TableCell' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableCell.php',
    'Google\\Service\\Bigquery\\TableConstraints' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableConstraints.php',
    'Google\\Service\\Bigquery\\TableConstraintsForeignKeys' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableConstraintsForeignKeys.php',
    'Google\\Service\\Bigquery\\TableConstraintsForeignKeysColumnReferences' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableConstraintsForeignKeysColumnReferences.php',
    'Google\\Service\\Bigquery\\TableConstraintsForeignKeysReferencedTable' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableConstraintsForeignKeysReferencedTable.php',
    'Google\\Service\\Bigquery\\TableConstraintsPrimaryKey' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableConstraintsPrimaryKey.php',
    'Google\\Service\\Bigquery\\TableDataInsertAllRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableDataInsertAllRequest.php',
    'Google\\Service\\Bigquery\\TableDataInsertAllRequestRows' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableDataInsertAllRequestRows.php',
    'Google\\Service\\Bigquery\\TableDataInsertAllResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableDataInsertAllResponse.php',
    'Google\\Service\\Bigquery\\TableDataInsertAllResponseInsertErrors' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableDataInsertAllResponseInsertErrors.php',
    'Google\\Service\\Bigquery\\TableDataList' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableDataList.php',
    'Google\\Service\\Bigquery\\TableFieldSchema' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableFieldSchema.php',
    'Google\\Service\\Bigquery\\TableFieldSchemaCategories' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableFieldSchemaCategories.php',
    'Google\\Service\\Bigquery\\TableFieldSchemaPolicyTags' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableFieldSchemaPolicyTags.php',
    'Google\\Service\\Bigquery\\TableFieldSchemaRangeElementType' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableFieldSchemaRangeElementType.php',
    'Google\\Service\\Bigquery\\TableList' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableList.php',
    'Google\\Service\\Bigquery\\TableListTables' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableListTables.php',
    'Google\\Service\\Bigquery\\TableListTablesView' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableListTablesView.php',
    'Google\\Service\\Bigquery\\TableMetadataCacheUsage' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableMetadataCacheUsage.php',
    'Google\\Service\\Bigquery\\TableReference' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableReference.php',
    'Google\\Service\\Bigquery\\TableReplicationInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableReplicationInfo.php',
    'Google\\Service\\Bigquery\\TableRow' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableRow.php',
    'Google\\Service\\Bigquery\\TableSchema' => $vendorDir . '/google/apiclient-services/src/Bigquery/TableSchema.php',
    'Google\\Service\\Bigquery\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/TestIamPermissionsRequest.php',
    'Google\\Service\\Bigquery\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Bigquery/TestIamPermissionsResponse.php',
    'Google\\Service\\Bigquery\\TimePartitioning' => $vendorDir . '/google/apiclient-services/src/Bigquery/TimePartitioning.php',
    'Google\\Service\\Bigquery\\TrainingOptions' => $vendorDir . '/google/apiclient-services/src/Bigquery/TrainingOptions.php',
    'Google\\Service\\Bigquery\\TrainingRun' => $vendorDir . '/google/apiclient-services/src/Bigquery/TrainingRun.php',
    'Google\\Service\\Bigquery\\TransactionInfo' => $vendorDir . '/google/apiclient-services/src/Bigquery/TransactionInfo.php',
    'Google\\Service\\Bigquery\\TransformColumn' => $vendorDir . '/google/apiclient-services/src/Bigquery/TransformColumn.php',
    'Google\\Service\\Bigquery\\UndeleteDatasetRequest' => $vendorDir . '/google/apiclient-services/src/Bigquery/UndeleteDatasetRequest.php',
    'Google\\Service\\Bigquery\\UserDefinedFunctionResource' => $vendorDir . '/google/apiclient-services/src/Bigquery/UserDefinedFunctionResource.php',
    'Google\\Service\\Bigquery\\VectorSearchStatistics' => $vendorDir . '/google/apiclient-services/src/Bigquery/VectorSearchStatistics.php',
    'Google\\Service\\Bigquery\\ViewDefinition' => $vendorDir . '/google/apiclient-services/src/Bigquery/ViewDefinition.php',
    'Google\\Service\\BigtableAdmin' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin.php',
    'Google\\Service\\BigtableAdmin\\AppProfile' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AppProfile.php',
    'Google\\Service\\BigtableAdmin\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AuditConfig.php',
    'Google\\Service\\BigtableAdmin\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AuditLogConfig.php',
    'Google\\Service\\BigtableAdmin\\AuthorizedView' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AuthorizedView.php',
    'Google\\Service\\BigtableAdmin\\AutomatedBackupPolicy' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AutomatedBackupPolicy.php',
    'Google\\Service\\BigtableAdmin\\AutoscalingLimits' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AutoscalingLimits.php',
    'Google\\Service\\BigtableAdmin\\AutoscalingTargets' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/AutoscalingTargets.php',
    'Google\\Service\\BigtableAdmin\\Backup' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Backup.php',
    'Google\\Service\\BigtableAdmin\\BackupInfo' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/BackupInfo.php',
    'Google\\Service\\BigtableAdmin\\BigtableadminEmpty' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/BigtableadminEmpty.php',
    'Google\\Service\\BigtableAdmin\\Binding' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Binding.php',
    'Google\\Service\\BigtableAdmin\\ChangeStreamConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ChangeStreamConfig.php',
    'Google\\Service\\BigtableAdmin\\CheckConsistencyRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CheckConsistencyRequest.php',
    'Google\\Service\\BigtableAdmin\\CheckConsistencyResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CheckConsistencyResponse.php',
    'Google\\Service\\BigtableAdmin\\Cluster' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Cluster.php',
    'Google\\Service\\BigtableAdmin\\ClusterAutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ClusterAutoscalingConfig.php',
    'Google\\Service\\BigtableAdmin\\ClusterConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ClusterConfig.php',
    'Google\\Service\\BigtableAdmin\\ClusterState' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ClusterState.php',
    'Google\\Service\\BigtableAdmin\\ColumnFamily' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ColumnFamily.php',
    'Google\\Service\\BigtableAdmin\\ColumnFamilyStats' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ColumnFamilyStats.php',
    'Google\\Service\\BigtableAdmin\\CopyBackupMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CopyBackupMetadata.php',
    'Google\\Service\\BigtableAdmin\\CopyBackupRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CopyBackupRequest.php',
    'Google\\Service\\BigtableAdmin\\CreateAuthorizedViewMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateAuthorizedViewMetadata.php',
    'Google\\Service\\BigtableAdmin\\CreateAuthorizedViewRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateAuthorizedViewRequest.php',
    'Google\\Service\\BigtableAdmin\\CreateBackupMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateBackupMetadata.php',
    'Google\\Service\\BigtableAdmin\\CreateClusterMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateClusterMetadata.php',
    'Google\\Service\\BigtableAdmin\\CreateClusterRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateClusterRequest.php',
    'Google\\Service\\BigtableAdmin\\CreateInstanceMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateInstanceMetadata.php',
    'Google\\Service\\BigtableAdmin\\CreateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateInstanceRequest.php',
    'Google\\Service\\BigtableAdmin\\CreateTableRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/CreateTableRequest.php',
    'Google\\Service\\BigtableAdmin\\DataBoostIsolationReadOnly' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/DataBoostIsolationReadOnly.php',
    'Google\\Service\\BigtableAdmin\\DataBoostReadLocalWrites' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/DataBoostReadLocalWrites.php',
    'Google\\Service\\BigtableAdmin\\DropRowRangeRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/DropRowRangeRequest.php',
    'Google\\Service\\BigtableAdmin\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/EncryptionConfig.php',
    'Google\\Service\\BigtableAdmin\\EncryptionInfo' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/EncryptionInfo.php',
    'Google\\Service\\BigtableAdmin\\Expr' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Expr.php',
    'Google\\Service\\BigtableAdmin\\FailureTrace' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/FailureTrace.php',
    'Google\\Service\\BigtableAdmin\\Frame' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Frame.php',
    'Google\\Service\\BigtableAdmin\\GcRule' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GcRule.php',
    'Google\\Service\\BigtableAdmin\\GenerateConsistencyTokenRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GenerateConsistencyTokenRequest.php',
    'Google\\Service\\BigtableAdmin\\GenerateConsistencyTokenResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GenerateConsistencyTokenResponse.php',
    'Google\\Service\\BigtableAdmin\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GetIamPolicyRequest.php',
    'Google\\Service\\BigtableAdmin\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GetPolicyOptions.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2AuthorizedViewFamilySubsets' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2AuthorizedViewFamilySubsets.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2AuthorizedViewSubsetView' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2AuthorizedViewSubsetView.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeAggregate' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeAggregate.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeAggregateHyperLogLogPlusPlusUniqueCount' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeAggregateHyperLogLogPlusPlusUniqueCount.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeAggregateMax' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeAggregateMax.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeAggregateMin' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeAggregateMin.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeAggregateSum' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeAggregateSum.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeArray' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeArray.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeBool' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeBool.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeBytes' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeBytes.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeBytesEncoding' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeBytesEncoding.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeBytesEncodingRaw' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeBytesEncodingRaw.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeDate' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeDate.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeFloat32' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeFloat32.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeFloat64' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeFloat64.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeInt64' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeInt64.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeInt64Encoding' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeInt64Encoding.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeInt64EncodingBigEndianBytes' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeInt64EncodingBigEndianBytes.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeMap' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeMap.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeString' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeString.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeStringEncoding' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeStringEncoding.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeStringEncodingUtf8Raw' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeStringEncodingUtf8Raw.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeStruct' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeStruct.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeStructField' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeStructField.php',
    'Google\\Service\\BigtableAdmin\\GoogleBigtableAdminV2TypeTimestamp' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/GoogleBigtableAdminV2TypeTimestamp.php',
    'Google\\Service\\BigtableAdmin\\HotTablet' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/HotTablet.php',
    'Google\\Service\\BigtableAdmin\\Instance' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Instance.php',
    'Google\\Service\\BigtableAdmin\\Intersection' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Intersection.php',
    'Google\\Service\\BigtableAdmin\\ListAppProfilesResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListAppProfilesResponse.php',
    'Google\\Service\\BigtableAdmin\\ListAuthorizedViewsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListAuthorizedViewsResponse.php',
    'Google\\Service\\BigtableAdmin\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListBackupsResponse.php',
    'Google\\Service\\BigtableAdmin\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListClustersResponse.php',
    'Google\\Service\\BigtableAdmin\\ListHotTabletsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListHotTabletsResponse.php',
    'Google\\Service\\BigtableAdmin\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListInstancesResponse.php',
    'Google\\Service\\BigtableAdmin\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListLocationsResponse.php',
    'Google\\Service\\BigtableAdmin\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListOperationsResponse.php',
    'Google\\Service\\BigtableAdmin\\ListTablesResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ListTablesResponse.php',
    'Google\\Service\\BigtableAdmin\\Location' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Location.php',
    'Google\\Service\\BigtableAdmin\\Modification' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Modification.php',
    'Google\\Service\\BigtableAdmin\\ModifyColumnFamiliesRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/ModifyColumnFamiliesRequest.php',
    'Google\\Service\\BigtableAdmin\\MultiClusterRoutingUseAny' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/MultiClusterRoutingUseAny.php',
    'Google\\Service\\BigtableAdmin\\Operation' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Operation.php',
    'Google\\Service\\BigtableAdmin\\OperationProgress' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/OperationProgress.php',
    'Google\\Service\\BigtableAdmin\\OptimizeRestoredTableMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/OptimizeRestoredTableMetadata.php',
    'Google\\Service\\BigtableAdmin\\PartialUpdateClusterMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/PartialUpdateClusterMetadata.php',
    'Google\\Service\\BigtableAdmin\\PartialUpdateClusterRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/PartialUpdateClusterRequest.php',
    'Google\\Service\\BigtableAdmin\\PartialUpdateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/PartialUpdateInstanceRequest.php',
    'Google\\Service\\BigtableAdmin\\Policy' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Policy.php',
    'Google\\Service\\BigtableAdmin\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/Operations.php',
    'Google\\Service\\BigtableAdmin\\Resource\\OperationsProjects' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/OperationsProjects.php',
    'Google\\Service\\BigtableAdmin\\Resource\\OperationsProjectsOperations' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/OperationsProjectsOperations.php',
    'Google\\Service\\BigtableAdmin\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/Projects.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstances' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstances.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesAppProfiles' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesAppProfiles.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesClusters' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesClusters.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesClustersBackups' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesClustersBackups.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesClustersHotTablets' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesClustersHotTablets.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesTables' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesTables.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesTablesAuthorizedViews' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesTablesAuthorizedViews.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsInstancesTablesViews' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsInstancesTablesViews.php',
    'Google\\Service\\BigtableAdmin\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Resource/ProjectsLocations.php',
    'Google\\Service\\BigtableAdmin\\RestoreInfo' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/RestoreInfo.php',
    'Google\\Service\\BigtableAdmin\\RestoreTableMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/RestoreTableMetadata.php',
    'Google\\Service\\BigtableAdmin\\RestoreTableRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/RestoreTableRequest.php',
    'Google\\Service\\BigtableAdmin\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/SetIamPolicyRequest.php',
    'Google\\Service\\BigtableAdmin\\SingleClusterRouting' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/SingleClusterRouting.php',
    'Google\\Service\\BigtableAdmin\\Split' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Split.php',
    'Google\\Service\\BigtableAdmin\\StandardIsolation' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/StandardIsolation.php',
    'Google\\Service\\BigtableAdmin\\StandardReadRemoteWrites' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/StandardReadRemoteWrites.php',
    'Google\\Service\\BigtableAdmin\\Status' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Status.php',
    'Google\\Service\\BigtableAdmin\\Table' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Table.php',
    'Google\\Service\\BigtableAdmin\\TableProgress' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/TableProgress.php',
    'Google\\Service\\BigtableAdmin\\TableStats' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/TableStats.php',
    'Google\\Service\\BigtableAdmin\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/TestIamPermissionsRequest.php',
    'Google\\Service\\BigtableAdmin\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/TestIamPermissionsResponse.php',
    'Google\\Service\\BigtableAdmin\\Type' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Type.php',
    'Google\\Service\\BigtableAdmin\\UndeleteTableMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UndeleteTableMetadata.php',
    'Google\\Service\\BigtableAdmin\\UndeleteTableRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UndeleteTableRequest.php',
    'Google\\Service\\BigtableAdmin\\Union' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/Union.php',
    'Google\\Service\\BigtableAdmin\\UpdateAppProfileMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateAppProfileMetadata.php',
    'Google\\Service\\BigtableAdmin\\UpdateAuthorizedViewMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateAuthorizedViewMetadata.php',
    'Google\\Service\\BigtableAdmin\\UpdateAuthorizedViewRequest' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateAuthorizedViewRequest.php',
    'Google\\Service\\BigtableAdmin\\UpdateClusterMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateClusterMetadata.php',
    'Google\\Service\\BigtableAdmin\\UpdateInstanceMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateInstanceMetadata.php',
    'Google\\Service\\BigtableAdmin\\UpdateTableMetadata' => $vendorDir . '/google/apiclient-services/src/BigtableAdmin/UpdateTableMetadata.php',
    'Google\\Service\\BinaryAuthorization' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization.php',
    'Google\\Service\\BinaryAuthorization\\AdmissionRule' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AdmissionRule.php',
    'Google\\Service\\BinaryAuthorization\\AdmissionWhitelistPattern' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AdmissionWhitelistPattern.php',
    'Google\\Service\\BinaryAuthorization\\AllowlistResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AllowlistResult.php',
    'Google\\Service\\BinaryAuthorization\\AttestationAuthenticator' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AttestationAuthenticator.php',
    'Google\\Service\\BinaryAuthorization\\AttestationOccurrence' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AttestationOccurrence.php',
    'Google\\Service\\BinaryAuthorization\\AttestationSource' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AttestationSource.php',
    'Google\\Service\\BinaryAuthorization\\Attestor' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Attestor.php',
    'Google\\Service\\BinaryAuthorization\\AttestorPublicKey' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/AttestorPublicKey.php',
    'Google\\Service\\BinaryAuthorization\\BinaryauthorizationEmpty' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/BinaryauthorizationEmpty.php',
    'Google\\Service\\BinaryAuthorization\\Binding' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Binding.php',
    'Google\\Service\\BinaryAuthorization\\Check' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Check.php',
    'Google\\Service\\BinaryAuthorization\\CheckResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/CheckResult.php',
    'Google\\Service\\BinaryAuthorization\\CheckResults' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/CheckResults.php',
    'Google\\Service\\BinaryAuthorization\\CheckSet' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/CheckSet.php',
    'Google\\Service\\BinaryAuthorization\\CheckSetResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/CheckSetResult.php',
    'Google\\Service\\BinaryAuthorization\\EvaluateGkePolicyRequest' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/EvaluateGkePolicyRequest.php',
    'Google\\Service\\BinaryAuthorization\\EvaluateGkePolicyResponse' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/EvaluateGkePolicyResponse.php',
    'Google\\Service\\BinaryAuthorization\\EvaluationResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/EvaluationResult.php',
    'Google\\Service\\BinaryAuthorization\\Expr' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Expr.php',
    'Google\\Service\\BinaryAuthorization\\GkePolicy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/GkePolicy.php',
    'Google\\Service\\BinaryAuthorization\\IamPolicy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/IamPolicy.php',
    'Google\\Service\\BinaryAuthorization\\ImageAllowlist' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ImageAllowlist.php',
    'Google\\Service\\BinaryAuthorization\\ImageFreshnessCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ImageFreshnessCheck.php',
    'Google\\Service\\BinaryAuthorization\\ImageResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ImageResult.php',
    'Google\\Service\\BinaryAuthorization\\Jwt' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Jwt.php',
    'Google\\Service\\BinaryAuthorization\\ListAttestorsResponse' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ListAttestorsResponse.php',
    'Google\\Service\\BinaryAuthorization\\ListPlatformPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ListPlatformPoliciesResponse.php',
    'Google\\Service\\BinaryAuthorization\\PkixPublicKey' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/PkixPublicKey.php',
    'Google\\Service\\BinaryAuthorization\\PkixPublicKeySet' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/PkixPublicKeySet.php',
    'Google\\Service\\BinaryAuthorization\\PlatformPolicy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/PlatformPolicy.php',
    'Google\\Service\\BinaryAuthorization\\PodResult' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/PodResult.php',
    'Google\\Service\\BinaryAuthorization\\Policy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Policy.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/Projects.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsAttestors' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsAttestors.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsPlatforms' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsPlatforms.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsPlatformsGke' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsPlatformsGke.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsPlatformsGkePolicies' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsPlatformsGkePolicies.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsPlatformsPolicies' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsPlatformsPolicies.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\ProjectsPolicy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/ProjectsPolicy.php',
    'Google\\Service\\BinaryAuthorization\\Resource\\Systempolicy' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Resource/Systempolicy.php',
    'Google\\Service\\BinaryAuthorization\\Scope' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Scope.php',
    'Google\\Service\\BinaryAuthorization\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SetIamPolicyRequest.php',
    'Google\\Service\\BinaryAuthorization\\Signature' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/Signature.php',
    'Google\\Service\\BinaryAuthorization\\SigstoreAuthority' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SigstoreAuthority.php',
    'Google\\Service\\BinaryAuthorization\\SigstorePublicKey' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SigstorePublicKey.php',
    'Google\\Service\\BinaryAuthorization\\SigstorePublicKeySet' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SigstorePublicKeySet.php',
    'Google\\Service\\BinaryAuthorization\\SigstoreSignatureCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SigstoreSignatureCheck.php',
    'Google\\Service\\BinaryAuthorization\\SimpleSigningAttestationCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SimpleSigningAttestationCheck.php',
    'Google\\Service\\BinaryAuthorization\\SlsaCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/SlsaCheck.php',
    'Google\\Service\\BinaryAuthorization\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/TestIamPermissionsRequest.php',
    'Google\\Service\\BinaryAuthorization\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/TestIamPermissionsResponse.php',
    'Google\\Service\\BinaryAuthorization\\TrustedDirectoryCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/TrustedDirectoryCheck.php',
    'Google\\Service\\BinaryAuthorization\\UserOwnedGrafeasNote' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/UserOwnedGrafeasNote.php',
    'Google\\Service\\BinaryAuthorization\\ValidateAttestationOccurrenceRequest' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ValidateAttestationOccurrenceRequest.php',
    'Google\\Service\\BinaryAuthorization\\ValidateAttestationOccurrenceResponse' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/ValidateAttestationOccurrenceResponse.php',
    'Google\\Service\\BinaryAuthorization\\VerificationRule' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/VerificationRule.php',
    'Google\\Service\\BinaryAuthorization\\VulnerabilityCheck' => $vendorDir . '/google/apiclient-services/src/BinaryAuthorization/VulnerabilityCheck.php',
    'Google\\Service\\BlockchainNodeEngine' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine.php',
    'Google\\Service\\BlockchainNodeEngine\\BlockchainNode' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/BlockchainNode.php',
    'Google\\Service\\BlockchainNodeEngine\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/CancelOperationRequest.php',
    'Google\\Service\\BlockchainNodeEngine\\ConnectionInfo' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/ConnectionInfo.php',
    'Google\\Service\\BlockchainNodeEngine\\EndpointInfo' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/EndpointInfo.php',
    'Google\\Service\\BlockchainNodeEngine\\EthereumDetails' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/EthereumDetails.php',
    'Google\\Service\\BlockchainNodeEngine\\EthereumEndpoints' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/EthereumEndpoints.php',
    'Google\\Service\\BlockchainNodeEngine\\GethDetails' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/GethDetails.php',
    'Google\\Service\\BlockchainNodeEngine\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/GoogleProtobufEmpty.php',
    'Google\\Service\\BlockchainNodeEngine\\ListBlockchainNodesResponse' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/ListBlockchainNodesResponse.php',
    'Google\\Service\\BlockchainNodeEngine\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/ListLocationsResponse.php',
    'Google\\Service\\BlockchainNodeEngine\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/ListOperationsResponse.php',
    'Google\\Service\\BlockchainNodeEngine\\Location' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Location.php',
    'Google\\Service\\BlockchainNodeEngine\\Operation' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Operation.php',
    'Google\\Service\\BlockchainNodeEngine\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/OperationMetadata.php',
    'Google\\Service\\BlockchainNodeEngine\\PolygonDetails' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/PolygonDetails.php',
    'Google\\Service\\BlockchainNodeEngine\\PolygonEndpoints' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/PolygonEndpoints.php',
    'Google\\Service\\BlockchainNodeEngine\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Resource/Projects.php',
    'Google\\Service\\BlockchainNodeEngine\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Resource/ProjectsLocations.php',
    'Google\\Service\\BlockchainNodeEngine\\Resource\\ProjectsLocationsBlockchainNodes' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Resource/ProjectsLocationsBlockchainNodes.php',
    'Google\\Service\\BlockchainNodeEngine\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\BlockchainNodeEngine\\Status' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/Status.php',
    'Google\\Service\\BlockchainNodeEngine\\ValidatorConfig' => $vendorDir . '/google/apiclient-services/src/BlockchainNodeEngine/ValidatorConfig.php',
    'Google\\Service\\Blogger' => $vendorDir . '/google/apiclient-services/src/Blogger.php',
    'Google\\Service\\Blogger\\Blog' => $vendorDir . '/google/apiclient-services/src/Blogger/Blog.php',
    'Google\\Service\\Blogger\\BlogList' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogList.php',
    'Google\\Service\\Blogger\\BlogLocale' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogLocale.php',
    'Google\\Service\\Blogger\\BlogPages' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogPages.php',
    'Google\\Service\\Blogger\\BlogPerUserInfo' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogPerUserInfo.php',
    'Google\\Service\\Blogger\\BlogPosts' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogPosts.php',
    'Google\\Service\\Blogger\\BlogUserInfo' => $vendorDir . '/google/apiclient-services/src/Blogger/BlogUserInfo.php',
    'Google\\Service\\Blogger\\Comment' => $vendorDir . '/google/apiclient-services/src/Blogger/Comment.php',
    'Google\\Service\\Blogger\\CommentAuthor' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentAuthor.php',
    'Google\\Service\\Blogger\\CommentAuthorImage' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentAuthorImage.php',
    'Google\\Service\\Blogger\\CommentBlog' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentBlog.php',
    'Google\\Service\\Blogger\\CommentInReplyTo' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentInReplyTo.php',
    'Google\\Service\\Blogger\\CommentList' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentList.php',
    'Google\\Service\\Blogger\\CommentPost' => $vendorDir . '/google/apiclient-services/src/Blogger/CommentPost.php',
    'Google\\Service\\Blogger\\Page' => $vendorDir . '/google/apiclient-services/src/Blogger/Page.php',
    'Google\\Service\\Blogger\\PageAuthor' => $vendorDir . '/google/apiclient-services/src/Blogger/PageAuthor.php',
    'Google\\Service\\Blogger\\PageAuthorImage' => $vendorDir . '/google/apiclient-services/src/Blogger/PageAuthorImage.php',
    'Google\\Service\\Blogger\\PageBlog' => $vendorDir . '/google/apiclient-services/src/Blogger/PageBlog.php',
    'Google\\Service\\Blogger\\PageList' => $vendorDir . '/google/apiclient-services/src/Blogger/PageList.php',
    'Google\\Service\\Blogger\\Pageviews' => $vendorDir . '/google/apiclient-services/src/Blogger/Pageviews.php',
    'Google\\Service\\Blogger\\PageviewsCounts' => $vendorDir . '/google/apiclient-services/src/Blogger/PageviewsCounts.php',
    'Google\\Service\\Blogger\\Post' => $vendorDir . '/google/apiclient-services/src/Blogger/Post.php',
    'Google\\Service\\Blogger\\PostAuthor' => $vendorDir . '/google/apiclient-services/src/Blogger/PostAuthor.php',
    'Google\\Service\\Blogger\\PostAuthorImage' => $vendorDir . '/google/apiclient-services/src/Blogger/PostAuthorImage.php',
    'Google\\Service\\Blogger\\PostBlog' => $vendorDir . '/google/apiclient-services/src/Blogger/PostBlog.php',
    'Google\\Service\\Blogger\\PostImages' => $vendorDir . '/google/apiclient-services/src/Blogger/PostImages.php',
    'Google\\Service\\Blogger\\PostList' => $vendorDir . '/google/apiclient-services/src/Blogger/PostList.php',
    'Google\\Service\\Blogger\\PostLocation' => $vendorDir . '/google/apiclient-services/src/Blogger/PostLocation.php',
    'Google\\Service\\Blogger\\PostPerUserInfo' => $vendorDir . '/google/apiclient-services/src/Blogger/PostPerUserInfo.php',
    'Google\\Service\\Blogger\\PostReplies' => $vendorDir . '/google/apiclient-services/src/Blogger/PostReplies.php',
    'Google\\Service\\Blogger\\PostUserInfo' => $vendorDir . '/google/apiclient-services/src/Blogger/PostUserInfo.php',
    'Google\\Service\\Blogger\\PostUserInfosList' => $vendorDir . '/google/apiclient-services/src/Blogger/PostUserInfosList.php',
    'Google\\Service\\Blogger\\Resource\\BlogUserInfos' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/BlogUserInfos.php',
    'Google\\Service\\Blogger\\Resource\\Blogs' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/Blogs.php',
    'Google\\Service\\Blogger\\Resource\\Comments' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/Comments.php',
    'Google\\Service\\Blogger\\Resource\\PageViews' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/PageViews.php',
    'Google\\Service\\Blogger\\Resource\\Pages' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/Pages.php',
    'Google\\Service\\Blogger\\Resource\\PostUserInfos' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/PostUserInfos.php',
    'Google\\Service\\Blogger\\Resource\\Posts' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/Posts.php',
    'Google\\Service\\Blogger\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/Blogger/Resource/Users.php',
    'Google\\Service\\Blogger\\User' => $vendorDir . '/google/apiclient-services/src/Blogger/User.php',
    'Google\\Service\\Blogger\\UserBlogs' => $vendorDir . '/google/apiclient-services/src/Blogger/UserBlogs.php',
    'Google\\Service\\Blogger\\UserLocale' => $vendorDir . '/google/apiclient-services/src/Blogger/UserLocale.php',
    'Google\\Service\\Books' => $vendorDir . '/google/apiclient-services/src/Books.php',
    'Google\\Service\\Books\\Annotation' => $vendorDir . '/google/apiclient-services/src/Books/Annotation.php',
    'Google\\Service\\Books\\AnnotationClientVersionRanges' => $vendorDir . '/google/apiclient-services/src/Books/AnnotationClientVersionRanges.php',
    'Google\\Service\\Books\\AnnotationCurrentVersionRanges' => $vendorDir . '/google/apiclient-services/src/Books/AnnotationCurrentVersionRanges.php',
    'Google\\Service\\Books\\AnnotationLayerSummary' => $vendorDir . '/google/apiclient-services/src/Books/AnnotationLayerSummary.php',
    'Google\\Service\\Books\\Annotations' => $vendorDir . '/google/apiclient-services/src/Books/Annotations.php',
    'Google\\Service\\Books\\AnnotationsSummary' => $vendorDir . '/google/apiclient-services/src/Books/AnnotationsSummary.php',
    'Google\\Service\\Books\\AnnotationsSummaryLayers' => $vendorDir . '/google/apiclient-services/src/Books/AnnotationsSummaryLayers.php',
    'Google\\Service\\Books\\Annotationsdata' => $vendorDir . '/google/apiclient-services/src/Books/Annotationsdata.php',
    'Google\\Service\\Books\\BooksAnnotationsRange' => $vendorDir . '/google/apiclient-services/src/Books/BooksAnnotationsRange.php',
    'Google\\Service\\Books\\BooksCloudloadingResource' => $vendorDir . '/google/apiclient-services/src/Books/BooksCloudloadingResource.php',
    'Google\\Service\\Books\\BooksEmpty' => $vendorDir . '/google/apiclient-services/src/Books/BooksEmpty.php',
    'Google\\Service\\Books\\BooksVolumesRecommendedRateResponse' => $vendorDir . '/google/apiclient-services/src/Books/BooksVolumesRecommendedRateResponse.php',
    'Google\\Service\\Books\\Bookshelf' => $vendorDir . '/google/apiclient-services/src/Books/Bookshelf.php',
    'Google\\Service\\Books\\Bookshelves' => $vendorDir . '/google/apiclient-services/src/Books/Bookshelves.php',
    'Google\\Service\\Books\\Category' => $vendorDir . '/google/apiclient-services/src/Books/Category.php',
    'Google\\Service\\Books\\CategoryItems' => $vendorDir . '/google/apiclient-services/src/Books/CategoryItems.php',
    'Google\\Service\\Books\\ConcurrentAccessRestriction' => $vendorDir . '/google/apiclient-services/src/Books/ConcurrentAccessRestriction.php',
    'Google\\Service\\Books\\DictionaryAnnotationdata' => $vendorDir . '/google/apiclient-services/src/Books/DictionaryAnnotationdata.php',
    'Google\\Service\\Books\\Dictlayerdata' => $vendorDir . '/google/apiclient-services/src/Books/Dictlayerdata.php',
    'Google\\Service\\Books\\DictlayerdataCommon' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataCommon.php',
    'Google\\Service\\Books\\DictlayerdataDict' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDict.php',
    'Google\\Service\\Books\\DictlayerdataDictSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWords' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWords.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsDerivatives' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsDerivatives.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsDerivativesSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsDerivativesSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsExamples' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsExamples.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsExamplesSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsExamplesSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSenses' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSenses.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesConjugations' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesConjugations.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesDefinitions' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesDefinitions.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesDefinitionsExamples' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesDefinitionsExamples.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesDefinitionsExamplesSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesDefinitionsExamplesSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesSynonyms' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesSynonyms.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSensesSynonymsSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSensesSynonymsSource.php',
    'Google\\Service\\Books\\DictlayerdataDictWordsSource' => $vendorDir . '/google/apiclient-services/src/Books/DictlayerdataDictWordsSource.php',
    'Google\\Service\\Books\\Discoveryclusters' => $vendorDir . '/google/apiclient-services/src/Books/Discoveryclusters.php',
    'Google\\Service\\Books\\DiscoveryclustersClusters' => $vendorDir . '/google/apiclient-services/src/Books/DiscoveryclustersClusters.php',
    'Google\\Service\\Books\\DiscoveryclustersClustersBannerWithContentContainer' => $vendorDir . '/google/apiclient-services/src/Books/DiscoveryclustersClustersBannerWithContentContainer.php',
    'Google\\Service\\Books\\DownloadAccessRestriction' => $vendorDir . '/google/apiclient-services/src/Books/DownloadAccessRestriction.php',
    'Google\\Service\\Books\\DownloadAccesses' => $vendorDir . '/google/apiclient-services/src/Books/DownloadAccesses.php',
    'Google\\Service\\Books\\FamilyInfo' => $vendorDir . '/google/apiclient-services/src/Books/FamilyInfo.php',
    'Google\\Service\\Books\\FamilyInfoMembership' => $vendorDir . '/google/apiclient-services/src/Books/FamilyInfoMembership.php',
    'Google\\Service\\Books\\GeoAnnotationdata' => $vendorDir . '/google/apiclient-services/src/Books/GeoAnnotationdata.php',
    'Google\\Service\\Books\\Geolayerdata' => $vendorDir . '/google/apiclient-services/src/Books/Geolayerdata.php',
    'Google\\Service\\Books\\GeolayerdataCommon' => $vendorDir . '/google/apiclient-services/src/Books/GeolayerdataCommon.php',
    'Google\\Service\\Books\\GeolayerdataGeo' => $vendorDir . '/google/apiclient-services/src/Books/GeolayerdataGeo.php',
    'Google\\Service\\Books\\GeolayerdataGeoViewport' => $vendorDir . '/google/apiclient-services/src/Books/GeolayerdataGeoViewport.php',
    'Google\\Service\\Books\\GeolayerdataGeoViewportHi' => $vendorDir . '/google/apiclient-services/src/Books/GeolayerdataGeoViewportHi.php',
    'Google\\Service\\Books\\GeolayerdataGeoViewportLo' => $vendorDir . '/google/apiclient-services/src/Books/GeolayerdataGeoViewportLo.php',
    'Google\\Service\\Books\\Layersummaries' => $vendorDir . '/google/apiclient-services/src/Books/Layersummaries.php',
    'Google\\Service\\Books\\Layersummary' => $vendorDir . '/google/apiclient-services/src/Books/Layersummary.php',
    'Google\\Service\\Books\\Metadata' => $vendorDir . '/google/apiclient-services/src/Books/Metadata.php',
    'Google\\Service\\Books\\MetadataItems' => $vendorDir . '/google/apiclient-services/src/Books/MetadataItems.php',
    'Google\\Service\\Books\\Notification' => $vendorDir . '/google/apiclient-services/src/Books/Notification.php',
    'Google\\Service\\Books\\Offers' => $vendorDir . '/google/apiclient-services/src/Books/Offers.php',
    'Google\\Service\\Books\\OffersItems' => $vendorDir . '/google/apiclient-services/src/Books/OffersItems.php',
    'Google\\Service\\Books\\OffersItemsItems' => $vendorDir . '/google/apiclient-services/src/Books/OffersItemsItems.php',
    'Google\\Service\\Books\\ReadingPosition' => $vendorDir . '/google/apiclient-services/src/Books/ReadingPosition.php',
    'Google\\Service\\Books\\RequestAccessData' => $vendorDir . '/google/apiclient-services/src/Books/RequestAccessData.php',
    'Google\\Service\\Books\\Resource\\Bookshelves' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Bookshelves.php',
    'Google\\Service\\Books\\Resource\\BookshelvesVolumes' => $vendorDir . '/google/apiclient-services/src/Books/Resource/BookshelvesVolumes.php',
    'Google\\Service\\Books\\Resource\\Cloudloading' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Cloudloading.php',
    'Google\\Service\\Books\\Resource\\Dictionary' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Dictionary.php',
    'Google\\Service\\Books\\Resource\\Familysharing' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Familysharing.php',
    'Google\\Service\\Books\\Resource\\Layers' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Layers.php',
    'Google\\Service\\Books\\Resource\\LayersAnnotationData' => $vendorDir . '/google/apiclient-services/src/Books/Resource/LayersAnnotationData.php',
    'Google\\Service\\Books\\Resource\\LayersVolumeAnnotations' => $vendorDir . '/google/apiclient-services/src/Books/Resource/LayersVolumeAnnotations.php',
    'Google\\Service\\Books\\Resource\\Myconfig' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Myconfig.php',
    'Google\\Service\\Books\\Resource\\Mylibrary' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Mylibrary.php',
    'Google\\Service\\Books\\Resource\\MylibraryAnnotations' => $vendorDir . '/google/apiclient-services/src/Books/Resource/MylibraryAnnotations.php',
    'Google\\Service\\Books\\Resource\\MylibraryBookshelves' => $vendorDir . '/google/apiclient-services/src/Books/Resource/MylibraryBookshelves.php',
    'Google\\Service\\Books\\Resource\\MylibraryBookshelvesVolumes' => $vendorDir . '/google/apiclient-services/src/Books/Resource/MylibraryBookshelvesVolumes.php',
    'Google\\Service\\Books\\Resource\\MylibraryReadingpositions' => $vendorDir . '/google/apiclient-services/src/Books/Resource/MylibraryReadingpositions.php',
    'Google\\Service\\Books\\Resource\\Notification' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Notification.php',
    'Google\\Service\\Books\\Resource\\Onboarding' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Onboarding.php',
    'Google\\Service\\Books\\Resource\\Personalizedstream' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Personalizedstream.php',
    'Google\\Service\\Books\\Resource\\Promooffer' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Promooffer.php',
    'Google\\Service\\Books\\Resource\\Series' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Series.php',
    'Google\\Service\\Books\\Resource\\SeriesMembership' => $vendorDir . '/google/apiclient-services/src/Books/Resource/SeriesMembership.php',
    'Google\\Service\\Books\\Resource\\Volumes' => $vendorDir . '/google/apiclient-services/src/Books/Resource/Volumes.php',
    'Google\\Service\\Books\\Resource\\VolumesAssociated' => $vendorDir . '/google/apiclient-services/src/Books/Resource/VolumesAssociated.php',
    'Google\\Service\\Books\\Resource\\VolumesMybooks' => $vendorDir . '/google/apiclient-services/src/Books/Resource/VolumesMybooks.php',
    'Google\\Service\\Books\\Resource\\VolumesRecommended' => $vendorDir . '/google/apiclient-services/src/Books/Resource/VolumesRecommended.php',
    'Google\\Service\\Books\\Resource\\VolumesUseruploaded' => $vendorDir . '/google/apiclient-services/src/Books/Resource/VolumesUseruploaded.php',
    'Google\\Service\\Books\\Review' => $vendorDir . '/google/apiclient-services/src/Books/Review.php',
    'Google\\Service\\Books\\ReviewAuthor' => $vendorDir . '/google/apiclient-services/src/Books/ReviewAuthor.php',
    'Google\\Service\\Books\\ReviewSource' => $vendorDir . '/google/apiclient-services/src/Books/ReviewSource.php',
    'Google\\Service\\Books\\Series' => $vendorDir . '/google/apiclient-services/src/Books/Series.php',
    'Google\\Service\\Books\\SeriesSeries' => $vendorDir . '/google/apiclient-services/src/Books/SeriesSeries.php',
    'Google\\Service\\Books\\SeriesSeriesSeriesSubscriptionReleaseInfo' => $vendorDir . '/google/apiclient-services/src/Books/SeriesSeriesSeriesSubscriptionReleaseInfo.php',
    'Google\\Service\\Books\\SeriesSeriesSeriesSubscriptionReleaseInfoCurrentReleaseInfo' => $vendorDir . '/google/apiclient-services/src/Books/SeriesSeriesSeriesSubscriptionReleaseInfoCurrentReleaseInfo.php',
    'Google\\Service\\Books\\SeriesSeriesSeriesSubscriptionReleaseInfoNextReleaseInfo' => $vendorDir . '/google/apiclient-services/src/Books/SeriesSeriesSeriesSubscriptionReleaseInfoNextReleaseInfo.php',
    'Google\\Service\\Books\\Seriesmembership' => $vendorDir . '/google/apiclient-services/src/Books/Seriesmembership.php',
    'Google\\Service\\Books\\Usersettings' => $vendorDir . '/google/apiclient-services/src/Books/Usersettings.php',
    'Google\\Service\\Books\\UsersettingsNotesExport' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotesExport.php',
    'Google\\Service\\Books\\UsersettingsNotification' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotification.php',
    'Google\\Service\\Books\\UsersettingsNotificationMatchMyInterests' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotificationMatchMyInterests.php',
    'Google\\Service\\Books\\UsersettingsNotificationMoreFromAuthors' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotificationMoreFromAuthors.php',
    'Google\\Service\\Books\\UsersettingsNotificationMoreFromSeries' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotificationMoreFromSeries.php',
    'Google\\Service\\Books\\UsersettingsNotificationPriceDrop' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotificationPriceDrop.php',
    'Google\\Service\\Books\\UsersettingsNotificationRewardExpirations' => $vendorDir . '/google/apiclient-services/src/Books/UsersettingsNotificationRewardExpirations.php',
    'Google\\Service\\Books\\Volume' => $vendorDir . '/google/apiclient-services/src/Books/Volume.php',
    'Google\\Service\\Books\\Volume2' => $vendorDir . '/google/apiclient-services/src/Books/Volume2.php',
    'Google\\Service\\Books\\VolumeAccessInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeAccessInfo.php',
    'Google\\Service\\Books\\VolumeAccessInfoEpub' => $vendorDir . '/google/apiclient-services/src/Books/VolumeAccessInfoEpub.php',
    'Google\\Service\\Books\\VolumeAccessInfoPdf' => $vendorDir . '/google/apiclient-services/src/Books/VolumeAccessInfoPdf.php',
    'Google\\Service\\Books\\VolumeLayerInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeLayerInfo.php',
    'Google\\Service\\Books\\VolumeLayerInfoLayers' => $vendorDir . '/google/apiclient-services/src/Books/VolumeLayerInfoLayers.php',
    'Google\\Service\\Books\\VolumeRecommendedInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeRecommendedInfo.php',
    'Google\\Service\\Books\\VolumeSaleInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfo.php',
    'Google\\Service\\Books\\VolumeSaleInfoListPrice' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoListPrice.php',
    'Google\\Service\\Books\\VolumeSaleInfoOffers' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoOffers.php',
    'Google\\Service\\Books\\VolumeSaleInfoOffersListPrice' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoOffersListPrice.php',
    'Google\\Service\\Books\\VolumeSaleInfoOffersRentalDuration' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoOffersRentalDuration.php',
    'Google\\Service\\Books\\VolumeSaleInfoOffersRetailPrice' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoOffersRetailPrice.php',
    'Google\\Service\\Books\\VolumeSaleInfoRetailPrice' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSaleInfoRetailPrice.php',
    'Google\\Service\\Books\\VolumeSearchInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeSearchInfo.php',
    'Google\\Service\\Books\\VolumeUserInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeUserInfo.php',
    'Google\\Service\\Books\\VolumeUserInfoCopy' => $vendorDir . '/google/apiclient-services/src/Books/VolumeUserInfoCopy.php',
    'Google\\Service\\Books\\VolumeUserInfoFamilySharing' => $vendorDir . '/google/apiclient-services/src/Books/VolumeUserInfoFamilySharing.php',
    'Google\\Service\\Books\\VolumeUserInfoRentalPeriod' => $vendorDir . '/google/apiclient-services/src/Books/VolumeUserInfoRentalPeriod.php',
    'Google\\Service\\Books\\VolumeUserInfoUserUploadedVolumeInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeUserInfoUserUploadedVolumeInfo.php',
    'Google\\Service\\Books\\VolumeVolumeInfo' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfo.php',
    'Google\\Service\\Books\\VolumeVolumeInfoDimensions' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfoDimensions.php',
    'Google\\Service\\Books\\VolumeVolumeInfoImageLinks' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfoImageLinks.php',
    'Google\\Service\\Books\\VolumeVolumeInfoIndustryIdentifiers' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfoIndustryIdentifiers.php',
    'Google\\Service\\Books\\VolumeVolumeInfoPanelizationSummary' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfoPanelizationSummary.php',
    'Google\\Service\\Books\\VolumeVolumeInfoReadingModes' => $vendorDir . '/google/apiclient-services/src/Books/VolumeVolumeInfoReadingModes.php',
    'Google\\Service\\Books\\Volumeannotation' => $vendorDir . '/google/apiclient-services/src/Books/Volumeannotation.php',
    'Google\\Service\\Books\\VolumeannotationContentRanges' => $vendorDir . '/google/apiclient-services/src/Books/VolumeannotationContentRanges.php',
    'Google\\Service\\Books\\Volumeannotations' => $vendorDir . '/google/apiclient-services/src/Books/Volumeannotations.php',
    'Google\\Service\\Books\\Volumes' => $vendorDir . '/google/apiclient-services/src/Books/Volumes.php',
    'Google\\Service\\Books\\Volumeseriesinfo' => $vendorDir . '/google/apiclient-services/src/Books/Volumeseriesinfo.php',
    'Google\\Service\\Books\\VolumeseriesinfoVolumeSeries' => $vendorDir . '/google/apiclient-services/src/Books/VolumeseriesinfoVolumeSeries.php',
    'Google\\Service\\Books\\VolumeseriesinfoVolumeSeriesIssue' => $vendorDir . '/google/apiclient-services/src/Books/VolumeseriesinfoVolumeSeriesIssue.php',
    'Google\\Service\\BusinessProfilePerformance' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance.php',
    'Google\\Service\\BusinessProfilePerformance\\DailyMetricTimeSeries' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/DailyMetricTimeSeries.php',
    'Google\\Service\\BusinessProfilePerformance\\DailySubEntityType' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/DailySubEntityType.php',
    'Google\\Service\\BusinessProfilePerformance\\Date' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/Date.php',
    'Google\\Service\\BusinessProfilePerformance\\DatedValue' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/DatedValue.php',
    'Google\\Service\\BusinessProfilePerformance\\FetchMultiDailyMetricsTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/FetchMultiDailyMetricsTimeSeriesResponse.php',
    'Google\\Service\\BusinessProfilePerformance\\GetDailyMetricsTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/GetDailyMetricsTimeSeriesResponse.php',
    'Google\\Service\\BusinessProfilePerformance\\InsightsValue' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/InsightsValue.php',
    'Google\\Service\\BusinessProfilePerformance\\ListSearchKeywordImpressionsMonthlyResponse' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/ListSearchKeywordImpressionsMonthlyResponse.php',
    'Google\\Service\\BusinessProfilePerformance\\MultiDailyMetricTimeSeries' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/MultiDailyMetricTimeSeries.php',
    'Google\\Service\\BusinessProfilePerformance\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/Resource/Locations.php',
    'Google\\Service\\BusinessProfilePerformance\\Resource\\LocationsSearchkeywords' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/Resource/LocationsSearchkeywords.php',
    'Google\\Service\\BusinessProfilePerformance\\Resource\\LocationsSearchkeywordsImpressions' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/Resource/LocationsSearchkeywordsImpressions.php',
    'Google\\Service\\BusinessProfilePerformance\\Resource\\LocationsSearchkeywordsImpressionsMonthly' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/Resource/LocationsSearchkeywordsImpressionsMonthly.php',
    'Google\\Service\\BusinessProfilePerformance\\SearchKeywordCount' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/SearchKeywordCount.php',
    'Google\\Service\\BusinessProfilePerformance\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/TimeOfDay.php',
    'Google\\Service\\BusinessProfilePerformance\\TimeSeries' => $vendorDir . '/google/apiclient-services/src/BusinessProfilePerformance/TimeSeries.php',
    'Google\\Service\\CCAIPlatform' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform.php',
    'Google\\Service\\CCAIPlatform\\AdminUser' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/AdminUser.php',
    'Google\\Service\\CCAIPlatform\\AuthenticationConfig' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/AuthenticationConfig.php',
    'Google\\Service\\CCAIPlatform\\BasicAuthConfig' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/BasicAuthConfig.php',
    'Google\\Service\\CCAIPlatform\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/CancelOperationRequest.php',
    'Google\\Service\\CCAIPlatform\\Component' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Component.php',
    'Google\\Service\\CCAIPlatform\\ContactCenter' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ContactCenter.php',
    'Google\\Service\\CCAIPlatform\\ContactCenterQuota' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ContactCenterQuota.php',
    'Google\\Service\\CCAIPlatform\\ContactcenteraiplatformEmpty' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ContactcenteraiplatformEmpty.php',
    'Google\\Service\\CCAIPlatform\\Critical' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Critical.php',
    'Google\\Service\\CCAIPlatform\\Early' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Early.php',
    'Google\\Service\\CCAIPlatform\\GoogleCloudCommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/GoogleCloudCommonOperationMetadata.php',
    'Google\\Service\\CCAIPlatform\\InstanceConfig' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/InstanceConfig.php',
    'Google\\Service\\CCAIPlatform\\ListContactCentersResponse' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ListContactCentersResponse.php',
    'Google\\Service\\CCAIPlatform\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ListLocationsResponse.php',
    'Google\\Service\\CCAIPlatform\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ListOperationsResponse.php',
    'Google\\Service\\CCAIPlatform\\Location' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Location.php',
    'Google\\Service\\CCAIPlatform\\Normal' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Normal.php',
    'Google\\Service\\CCAIPlatform\\Operation' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Operation.php',
    'Google\\Service\\CCAIPlatform\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/OperationMetadata.php',
    'Google\\Service\\CCAIPlatform\\PrivateAccess' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/PrivateAccess.php',
    'Google\\Service\\CCAIPlatform\\PscSetting' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/PscSetting.php',
    'Google\\Service\\CCAIPlatform\\Quota' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Quota.php',
    'Google\\Service\\CCAIPlatform\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Resource/Projects.php',
    'Google\\Service\\CCAIPlatform\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Resource/ProjectsLocations.php',
    'Google\\Service\\CCAIPlatform\\Resource\\ProjectsLocationsContactCenters' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Resource/ProjectsLocationsContactCenters.php',
    'Google\\Service\\CCAIPlatform\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CCAIPlatform\\SAMLParams' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/SAMLParams.php',
    'Google\\Service\\CCAIPlatform\\SamlConfig' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/SamlConfig.php',
    'Google\\Service\\CCAIPlatform\\ServiceAttachment' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/ServiceAttachment.php',
    'Google\\Service\\CCAIPlatform\\Status' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/Status.php',
    'Google\\Service\\CCAIPlatform\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/TimeOfDay.php',
    'Google\\Service\\CCAIPlatform\\URIs' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/URIs.php',
    'Google\\Service\\CCAIPlatform\\WeeklySchedule' => $vendorDir . '/google/apiclient-services/src/CCAIPlatform/WeeklySchedule.php',
    'Google\\Service\\Calendar' => $vendorDir . '/google/apiclient-services/src/Calendar.php',
    'Google\\Service\\Calendar\\Acl' => $vendorDir . '/google/apiclient-services/src/Calendar/Acl.php',
    'Google\\Service\\Calendar\\AclRule' => $vendorDir . '/google/apiclient-services/src/Calendar/AclRule.php',
    'Google\\Service\\Calendar\\AclRuleScope' => $vendorDir . '/google/apiclient-services/src/Calendar/AclRuleScope.php',
    'Google\\Service\\Calendar\\Calendar' => $vendorDir . '/google/apiclient-services/src/Calendar/Calendar.php',
    'Google\\Service\\Calendar\\CalendarList' => $vendorDir . '/google/apiclient-services/src/Calendar/CalendarList.php',
    'Google\\Service\\Calendar\\CalendarListEntry' => $vendorDir . '/google/apiclient-services/src/Calendar/CalendarListEntry.php',
    'Google\\Service\\Calendar\\CalendarListEntryNotificationSettings' => $vendorDir . '/google/apiclient-services/src/Calendar/CalendarListEntryNotificationSettings.php',
    'Google\\Service\\Calendar\\CalendarNotification' => $vendorDir . '/google/apiclient-services/src/Calendar/CalendarNotification.php',
    'Google\\Service\\Calendar\\Channel' => $vendorDir . '/google/apiclient-services/src/Calendar/Channel.php',
    'Google\\Service\\Calendar\\ColorDefinition' => $vendorDir . '/google/apiclient-services/src/Calendar/ColorDefinition.php',
    'Google\\Service\\Calendar\\Colors' => $vendorDir . '/google/apiclient-services/src/Calendar/Colors.php',
    'Google\\Service\\Calendar\\ConferenceData' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceData.php',
    'Google\\Service\\Calendar\\ConferenceParameters' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceParameters.php',
    'Google\\Service\\Calendar\\ConferenceParametersAddOnParameters' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceParametersAddOnParameters.php',
    'Google\\Service\\Calendar\\ConferenceProperties' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceProperties.php',
    'Google\\Service\\Calendar\\ConferenceRequestStatus' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceRequestStatus.php',
    'Google\\Service\\Calendar\\ConferenceSolution' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceSolution.php',
    'Google\\Service\\Calendar\\ConferenceSolutionKey' => $vendorDir . '/google/apiclient-services/src/Calendar/ConferenceSolutionKey.php',
    'Google\\Service\\Calendar\\CreateConferenceRequest' => $vendorDir . '/google/apiclient-services/src/Calendar/CreateConferenceRequest.php',
    'Google\\Service\\Calendar\\EntryPoint' => $vendorDir . '/google/apiclient-services/src/Calendar/EntryPoint.php',
    'Google\\Service\\Calendar\\Error' => $vendorDir . '/google/apiclient-services/src/Calendar/Error.php',
    'Google\\Service\\Calendar\\Event' => $vendorDir . '/google/apiclient-services/src/Calendar/Event.php',
    'Google\\Service\\Calendar\\EventAttachment' => $vendorDir . '/google/apiclient-services/src/Calendar/EventAttachment.php',
    'Google\\Service\\Calendar\\EventAttendee' => $vendorDir . '/google/apiclient-services/src/Calendar/EventAttendee.php',
    'Google\\Service\\Calendar\\EventCreator' => $vendorDir . '/google/apiclient-services/src/Calendar/EventCreator.php',
    'Google\\Service\\Calendar\\EventDateTime' => $vendorDir . '/google/apiclient-services/src/Calendar/EventDateTime.php',
    'Google\\Service\\Calendar\\EventExtendedProperties' => $vendorDir . '/google/apiclient-services/src/Calendar/EventExtendedProperties.php',
    'Google\\Service\\Calendar\\EventFocusTimeProperties' => $vendorDir . '/google/apiclient-services/src/Calendar/EventFocusTimeProperties.php',
    'Google\\Service\\Calendar\\EventGadget' => $vendorDir . '/google/apiclient-services/src/Calendar/EventGadget.php',
    'Google\\Service\\Calendar\\EventOrganizer' => $vendorDir . '/google/apiclient-services/src/Calendar/EventOrganizer.php',
    'Google\\Service\\Calendar\\EventOutOfOfficeProperties' => $vendorDir . '/google/apiclient-services/src/Calendar/EventOutOfOfficeProperties.php',
    'Google\\Service\\Calendar\\EventReminder' => $vendorDir . '/google/apiclient-services/src/Calendar/EventReminder.php',
    'Google\\Service\\Calendar\\EventReminders' => $vendorDir . '/google/apiclient-services/src/Calendar/EventReminders.php',
    'Google\\Service\\Calendar\\EventSource' => $vendorDir . '/google/apiclient-services/src/Calendar/EventSource.php',
    'Google\\Service\\Calendar\\EventWorkingLocationProperties' => $vendorDir . '/google/apiclient-services/src/Calendar/EventWorkingLocationProperties.php',
    'Google\\Service\\Calendar\\EventWorkingLocationPropertiesCustomLocation' => $vendorDir . '/google/apiclient-services/src/Calendar/EventWorkingLocationPropertiesCustomLocation.php',
    'Google\\Service\\Calendar\\EventWorkingLocationPropertiesOfficeLocation' => $vendorDir . '/google/apiclient-services/src/Calendar/EventWorkingLocationPropertiesOfficeLocation.php',
    'Google\\Service\\Calendar\\Events' => $vendorDir . '/google/apiclient-services/src/Calendar/Events.php',
    'Google\\Service\\Calendar\\FreeBusyCalendar' => $vendorDir . '/google/apiclient-services/src/Calendar/FreeBusyCalendar.php',
    'Google\\Service\\Calendar\\FreeBusyGroup' => $vendorDir . '/google/apiclient-services/src/Calendar/FreeBusyGroup.php',
    'Google\\Service\\Calendar\\FreeBusyRequest' => $vendorDir . '/google/apiclient-services/src/Calendar/FreeBusyRequest.php',
    'Google\\Service\\Calendar\\FreeBusyRequestItem' => $vendorDir . '/google/apiclient-services/src/Calendar/FreeBusyRequestItem.php',
    'Google\\Service\\Calendar\\FreeBusyResponse' => $vendorDir . '/google/apiclient-services/src/Calendar/FreeBusyResponse.php',
    'Google\\Service\\Calendar\\Resource\\Acl' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Acl.php',
    'Google\\Service\\Calendar\\Resource\\CalendarList' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/CalendarList.php',
    'Google\\Service\\Calendar\\Resource\\Calendars' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Calendars.php',
    'Google\\Service\\Calendar\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Channels.php',
    'Google\\Service\\Calendar\\Resource\\Colors' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Colors.php',
    'Google\\Service\\Calendar\\Resource\\Events' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Events.php',
    'Google\\Service\\Calendar\\Resource\\Freebusy' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Freebusy.php',
    'Google\\Service\\Calendar\\Resource\\Settings' => $vendorDir . '/google/apiclient-services/src/Calendar/Resource/Settings.php',
    'Google\\Service\\Calendar\\Setting' => $vendorDir . '/google/apiclient-services/src/Calendar/Setting.php',
    'Google\\Service\\Calendar\\Settings' => $vendorDir . '/google/apiclient-services/src/Calendar/Settings.php',
    'Google\\Service\\Calendar\\TimePeriod' => $vendorDir . '/google/apiclient-services/src/Calendar/TimePeriod.php',
    'Google\\Service\\CertificateAuthorityService' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService.php',
    'Google\\Service\\CertificateAuthorityService\\AccessUrls' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/AccessUrls.php',
    'Google\\Service\\CertificateAuthorityService\\ActivateCertificateAuthorityRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ActivateCertificateAuthorityRequest.php',
    'Google\\Service\\CertificateAuthorityService\\AllowedKeyType' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/AllowedKeyType.php',
    'Google\\Service\\CertificateAuthorityService\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/AuditConfig.php',
    'Google\\Service\\CertificateAuthorityService\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/AuditLogConfig.php',
    'Google\\Service\\CertificateAuthorityService\\Binding' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Binding.php',
    'Google\\Service\\CertificateAuthorityService\\CaOptions' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CaOptions.php',
    'Google\\Service\\CertificateAuthorityService\\CaPool' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CaPool.php',
    'Google\\Service\\CertificateAuthorityService\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CancelOperationRequest.php',
    'Google\\Service\\CertificateAuthorityService\\CertChain' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertChain.php',
    'Google\\Service\\CertificateAuthorityService\\Certificate' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Certificate.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateAuthority' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateAuthority.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateConfig' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateConfig.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateConfigKeyId' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateConfigKeyId.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateDescription' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateDescription.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateExtensionConstraints' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateExtensionConstraints.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateFingerprint' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateFingerprint.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateIdentityConstraints' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateIdentityConstraints.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateRevocationList' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateRevocationList.php',
    'Google\\Service\\CertificateAuthorityService\\CertificateTemplate' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/CertificateTemplate.php',
    'Google\\Service\\CertificateAuthorityService\\DisableCertificateAuthorityRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/DisableCertificateAuthorityRequest.php',
    'Google\\Service\\CertificateAuthorityService\\EcKeyType' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/EcKeyType.php',
    'Google\\Service\\CertificateAuthorityService\\EnableCertificateAuthorityRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/EnableCertificateAuthorityRequest.php',
    'Google\\Service\\CertificateAuthorityService\\Expr' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Expr.php',
    'Google\\Service\\CertificateAuthorityService\\ExtendedKeyUsageOptions' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ExtendedKeyUsageOptions.php',
    'Google\\Service\\CertificateAuthorityService\\FetchCaCertsRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/FetchCaCertsRequest.php',
    'Google\\Service\\CertificateAuthorityService\\FetchCaCertsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/FetchCaCertsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\FetchCertificateAuthorityCsrResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/FetchCertificateAuthorityCsrResponse.php',
    'Google\\Service\\CertificateAuthorityService\\IssuanceModes' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/IssuanceModes.php',
    'Google\\Service\\CertificateAuthorityService\\IssuancePolicy' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/IssuancePolicy.php',
    'Google\\Service\\CertificateAuthorityService\\KeyId' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/KeyId.php',
    'Google\\Service\\CertificateAuthorityService\\KeyUsage' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/KeyUsage.php',
    'Google\\Service\\CertificateAuthorityService\\KeyUsageOptions' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/KeyUsageOptions.php',
    'Google\\Service\\CertificateAuthorityService\\KeyVersionSpec' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/KeyVersionSpec.php',
    'Google\\Service\\CertificateAuthorityService\\ListCaPoolsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListCaPoolsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListCertificateAuthoritiesResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListCertificateAuthoritiesResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListCertificateRevocationListsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListCertificateRevocationListsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListCertificateTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListCertificateTemplatesResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListCertificatesResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListLocationsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ListOperationsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\Location' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Location.php',
    'Google\\Service\\CertificateAuthorityService\\NameConstraints' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/NameConstraints.php',
    'Google\\Service\\CertificateAuthorityService\\ObjectId' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ObjectId.php',
    'Google\\Service\\CertificateAuthorityService\\Operation' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Operation.php',
    'Google\\Service\\CertificateAuthorityService\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/OperationMetadata.php',
    'Google\\Service\\CertificateAuthorityService\\Policy' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Policy.php',
    'Google\\Service\\CertificateAuthorityService\\PrivatecaEmpty' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/PrivatecaEmpty.php',
    'Google\\Service\\CertificateAuthorityService\\PublicKey' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/PublicKey.php',
    'Google\\Service\\CertificateAuthorityService\\PublishingOptions' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/PublishingOptions.php',
    'Google\\Service\\CertificateAuthorityService\\ReconciliationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/ReconciliationOperationMetadata.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/Projects.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocations.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsCaPools' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsCaPools.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsCaPoolsCertificateAuthorities' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsCaPoolsCertificateAuthorities.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsCaPoolsCertificateAuthoritiesCertificateRevocationLists' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsCaPoolsCertificateAuthoritiesCertificateRevocationLists.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsCaPoolsCertificates' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsCaPoolsCertificates.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsCertificateTemplates' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsCertificateTemplates.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsManagedPkis' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsManagedPkis.php',
    'Google\\Service\\CertificateAuthorityService\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CertificateAuthorityService\\RevocationDetails' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/RevocationDetails.php',
    'Google\\Service\\CertificateAuthorityService\\RevokeCertificateRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/RevokeCertificateRequest.php',
    'Google\\Service\\CertificateAuthorityService\\RevokedCertificate' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/RevokedCertificate.php',
    'Google\\Service\\CertificateAuthorityService\\RsaKeyType' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/RsaKeyType.php',
    'Google\\Service\\CertificateAuthorityService\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SetIamPolicyRequest.php',
    'Google\\Service\\CertificateAuthorityService\\Status' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Status.php',
    'Google\\Service\\CertificateAuthorityService\\Subject' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/Subject.php',
    'Google\\Service\\CertificateAuthorityService\\SubjectAltNames' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SubjectAltNames.php',
    'Google\\Service\\CertificateAuthorityService\\SubjectConfig' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SubjectConfig.php',
    'Google\\Service\\CertificateAuthorityService\\SubjectDescription' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SubjectDescription.php',
    'Google\\Service\\CertificateAuthorityService\\SubordinateConfig' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SubordinateConfig.php',
    'Google\\Service\\CertificateAuthorityService\\SubordinateConfigChain' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/SubordinateConfigChain.php',
    'Google\\Service\\CertificateAuthorityService\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/TestIamPermissionsRequest.php',
    'Google\\Service\\CertificateAuthorityService\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/TestIamPermissionsResponse.php',
    'Google\\Service\\CertificateAuthorityService\\UndeleteCertificateAuthorityRequest' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/UndeleteCertificateAuthorityRequest.php',
    'Google\\Service\\CertificateAuthorityService\\X509Extension' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/X509Extension.php',
    'Google\\Service\\CertificateAuthorityService\\X509Parameters' => $vendorDir . '/google/apiclient-services/src/CertificateAuthorityService/X509Parameters.php',
    'Google\\Service\\CertificateManager' => $vendorDir . '/google/apiclient-services/src/CertificateManager.php',
    'Google\\Service\\CertificateManager\\AllowlistedCertificate' => $vendorDir . '/google/apiclient-services/src/CertificateManager/AllowlistedCertificate.php',
    'Google\\Service\\CertificateManager\\AuthorizationAttemptInfo' => $vendorDir . '/google/apiclient-services/src/CertificateManager/AuthorizationAttemptInfo.php',
    'Google\\Service\\CertificateManager\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CancelOperationRequest.php',
    'Google\\Service\\CertificateManager\\Certificate' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Certificate.php',
    'Google\\Service\\CertificateManager\\CertificateAuthorityConfig' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificateAuthorityConfig.php',
    'Google\\Service\\CertificateManager\\CertificateAuthorityServiceConfig' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificateAuthorityServiceConfig.php',
    'Google\\Service\\CertificateManager\\CertificateIssuanceConfig' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificateIssuanceConfig.php',
    'Google\\Service\\CertificateManager\\CertificateMap' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificateMap.php',
    'Google\\Service\\CertificateManager\\CertificateMapEntry' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificateMapEntry.php',
    'Google\\Service\\CertificateManager\\CertificatemanagerEmpty' => $vendorDir . '/google/apiclient-services/src/CertificateManager/CertificatemanagerEmpty.php',
    'Google\\Service\\CertificateManager\\DnsAuthorization' => $vendorDir . '/google/apiclient-services/src/CertificateManager/DnsAuthorization.php',
    'Google\\Service\\CertificateManager\\DnsResourceRecord' => $vendorDir . '/google/apiclient-services/src/CertificateManager/DnsResourceRecord.php',
    'Google\\Service\\CertificateManager\\GclbTarget' => $vendorDir . '/google/apiclient-services/src/CertificateManager/GclbTarget.php',
    'Google\\Service\\CertificateManager\\IntermediateCA' => $vendorDir . '/google/apiclient-services/src/CertificateManager/IntermediateCA.php',
    'Google\\Service\\CertificateManager\\IpConfig' => $vendorDir . '/google/apiclient-services/src/CertificateManager/IpConfig.php',
    'Google\\Service\\CertificateManager\\ListCertificateIssuanceConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListCertificateIssuanceConfigsResponse.php',
    'Google\\Service\\CertificateManager\\ListCertificateMapEntriesResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListCertificateMapEntriesResponse.php',
    'Google\\Service\\CertificateManager\\ListCertificateMapsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListCertificateMapsResponse.php',
    'Google\\Service\\CertificateManager\\ListCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListCertificatesResponse.php',
    'Google\\Service\\CertificateManager\\ListDnsAuthorizationsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListDnsAuthorizationsResponse.php',
    'Google\\Service\\CertificateManager\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListLocationsResponse.php',
    'Google\\Service\\CertificateManager\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListOperationsResponse.php',
    'Google\\Service\\CertificateManager\\ListTrustConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ListTrustConfigsResponse.php',
    'Google\\Service\\CertificateManager\\Location' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Location.php',
    'Google\\Service\\CertificateManager\\ManagedCertificate' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ManagedCertificate.php',
    'Google\\Service\\CertificateManager\\Operation' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Operation.php',
    'Google\\Service\\CertificateManager\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CertificateManager/OperationMetadata.php',
    'Google\\Service\\CertificateManager\\ProvisioningIssue' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ProvisioningIssue.php',
    'Google\\Service\\CertificateManager\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/Projects.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocations.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsCertificateIssuanceConfigs' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsCertificateIssuanceConfigs.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsCertificateMaps' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsCertificateMaps.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsCertificateMapsCertificateMapEntries' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsCertificateMapsCertificateMapEntries.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsCertificates' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsCertificates.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsDnsAuthorizations' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsDnsAuthorizations.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CertificateManager\\Resource\\ProjectsLocationsTrustConfigs' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Resource/ProjectsLocationsTrustConfigs.php',
    'Google\\Service\\CertificateManager\\ResourcesCount' => $vendorDir . '/google/apiclient-services/src/CertificateManager/ResourcesCount.php',
    'Google\\Service\\CertificateManager\\SelfManagedCertificate' => $vendorDir . '/google/apiclient-services/src/CertificateManager/SelfManagedCertificate.php',
    'Google\\Service\\CertificateManager\\Status' => $vendorDir . '/google/apiclient-services/src/CertificateManager/Status.php',
    'Google\\Service\\CertificateManager\\TrustAnchor' => $vendorDir . '/google/apiclient-services/src/CertificateManager/TrustAnchor.php',
    'Google\\Service\\CertificateManager\\TrustConfig' => $vendorDir . '/google/apiclient-services/src/CertificateManager/TrustConfig.php',
    'Google\\Service\\CertificateManager\\TrustStore' => $vendorDir . '/google/apiclient-services/src/CertificateManager/TrustStore.php',
    'Google\\Service\\ChecksService' => $vendorDir . '/google/apiclient-services/src/ChecksService.php',
    'Google\\Service\\ChecksService\\AnalyzePrivacyPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChecksService/AnalyzePrivacyPolicyRequest.php',
    'Google\\Service\\ChecksService\\AnalyzePrivacyPolicyResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/AnalyzePrivacyPolicyResponse.php',
    'Google\\Service\\ChecksService\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ChecksService/CancelOperationRequest.php',
    'Google\\Service\\ChecksService\\ChecksEmpty' => $vendorDir . '/google/apiclient-services/src/ChecksService/ChecksEmpty.php',
    'Google\\Service\\ChecksService\\Date' => $vendorDir . '/google/apiclient-services/src/ChecksService/Date.php',
    'Google\\Service\\ChecksService\\FindPrivacyPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChecksService/FindPrivacyPolicyRequest.php',
    'Google\\Service\\ChecksService\\FindPrivacyPolicyResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/FindPrivacyPolicyResponse.php',
    'Google\\Service\\ChecksService\\GoogleChecksAccountV1alphaApp' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksAccountV1alphaApp.php',
    'Google\\Service\\ChecksService\\GoogleChecksAccountV1alphaListAppsResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksAccountV1alphaListAppsResponse.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaAnalyzeUploadRequest' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaAnalyzeUploadRequest.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaAppBundle' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaAppBundle.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheck' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheck.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckCitation' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckCitation.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckDataSecurityEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckDataSecurityEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckDataSecurityEvidenceDataInTransitInfo' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckDataSecurityEvidenceDataInTransitInfo.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckDataTypeEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckDataTypeEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckEndpointEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckEndpointEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckEndpointRestrictionViolationEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckEndpointRestrictionViolationEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckEndpointRestrictionViolationEvidenceEndpointDetails' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckEndpointRestrictionViolationEvidenceEndpointDetails.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckPermissionEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckPermissionEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckPermissionRestrictionViolationEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckPermissionRestrictionViolationEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckPermissionRestrictionViolationEvidencePermissionDetails' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckPermissionRestrictionViolationEvidencePermissionDetails.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckPrivacyPolicyTextEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckPrivacyPolicyTextEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckSdkEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckSdkEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckSdkIssueEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckSdkIssueEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckSdkRestrictionViolationEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckSdkRestrictionViolationEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckSdkRestrictionViolationEvidenceSdkDetails' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckSdkRestrictionViolationEvidenceSdkDetails.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaCheckStateMetadata' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaCheckStateMetadata.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoring' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoring.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoringDataTypeResult' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoringDataTypeResult.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoringEndpointResult' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoringEndpointResult.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoringPermissionResult' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoringPermissionResult.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoringResultMetadata' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoringResultMetadata.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataMonitoringSdkResult' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataMonitoringSdkResult.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypeEndpointEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypeEndpointEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypeEndpointEvidenceAttributedSdk' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypeEndpointEvidenceAttributedSdk.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypeEndpointEvidenceEndpointDetails' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypeEndpointEvidenceEndpointDetails.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypeEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypeEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypePermissionEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypePermissionEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaDataTypePrivacyPolicyTextEvidence' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaDataTypePrivacyPolicyTextEvidence.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaEndpoint' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaEndpoint.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaListReportsResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaListReportsResponse.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaPermission' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaPermission.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaPolicyFragment' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaPolicyFragment.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaReport' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaReport.php',
    'Google\\Service\\ChecksService\\GoogleChecksReportV1alphaSdk' => $vendorDir . '/google/apiclient-services/src/ChecksService/GoogleChecksReportV1alphaSdk.php',
    'Google\\Service\\ChecksService\\LastUpdatedDate' => $vendorDir . '/google/apiclient-services/src/ChecksService/LastUpdatedDate.php',
    'Google\\Service\\ChecksService\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/ListOperationsResponse.php',
    'Google\\Service\\ChecksService\\ListPrivacyPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/ChecksService/ListPrivacyPoliciesResponse.php',
    'Google\\Service\\ChecksService\\Operation' => $vendorDir . '/google/apiclient-services/src/ChecksService/Operation.php',
    'Google\\Service\\ChecksService\\PolicyDataTypeAnnotation' => $vendorDir . '/google/apiclient-services/src/ChecksService/PolicyDataTypeAnnotation.php',
    'Google\\Service\\ChecksService\\PolicyPurposeOfUseAnnotation' => $vendorDir . '/google/apiclient-services/src/ChecksService/PolicyPurposeOfUseAnnotation.php',
    'Google\\Service\\ChecksService\\PolicySectionAnnotation' => $vendorDir . '/google/apiclient-services/src/ChecksService/PolicySectionAnnotation.php',
    'Google\\Service\\ChecksService\\PrivacyPolicy' => $vendorDir . '/google/apiclient-services/src/ChecksService/PrivacyPolicy.php',
    'Google\\Service\\ChecksService\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/Accounts.php',
    'Google\\Service\\ChecksService\\Resource\\AccountsApps' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/AccountsApps.php',
    'Google\\Service\\ChecksService\\Resource\\AccountsAppsOperations' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/AccountsAppsOperations.php',
    'Google\\Service\\ChecksService\\Resource\\AccountsAppsReports' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/AccountsAppsReports.php',
    'Google\\Service\\ChecksService\\Resource\\AccountsRepos' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/AccountsRepos.php',
    'Google\\Service\\ChecksService\\Resource\\AccountsReposOperations' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/AccountsReposOperations.php',
    'Google\\Service\\ChecksService\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/Media.php',
    'Google\\Service\\ChecksService\\Resource\\Privacypolicy' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/Privacypolicy.php',
    'Google\\Service\\ChecksService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/Projects.php',
    'Google\\Service\\ChecksService\\Resource\\ProjectsPrivacyPolicies' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/ProjectsPrivacyPolicies.php',
    'Google\\Service\\ChecksService\\Resource\\ProjectsPrivacypolicy' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/ProjectsPrivacypolicy.php',
    'Google\\Service\\ChecksService\\Resource\\ProjectsPrivacypolicyOperations' => $vendorDir . '/google/apiclient-services/src/ChecksService/Resource/ProjectsPrivacypolicyOperations.php',
    'Google\\Service\\ChecksService\\Status' => $vendorDir . '/google/apiclient-services/src/ChecksService/Status.php',
    'Google\\Service\\ChecksService\\WaitOperationRequest' => $vendorDir . '/google/apiclient-services/src/ChecksService/WaitOperationRequest.php',
    'Google\\Service\\ChromeManagement' => $vendorDir . '/google/apiclient-services/src/ChromeManagement.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AndroidAppInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AndroidAppInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AndroidAppPermission' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AndroidAppPermission.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AppDetails' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AppDetails.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AppReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AppReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AppUsageData' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AppUsageData.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1AudioStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1AudioStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1BatteryInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1BatteryInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1BatterySampleReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1BatterySampleReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1BatteryStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1BatteryStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1BootPerformanceReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1BootPerformanceReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1BrowserVersion' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1BrowserVersion.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ChromeAppInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ChromeAppInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ChromeAppPermission' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ChromeAppPermission.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ChromeAppRequest' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ChromeAppRequest.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ChromeAppSiteAccess' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ChromeAppSiteAccess.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeAppRequestsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeAppRequestsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeBrowsersNeedingAttentionResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeBrowsersNeedingAttentionResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeCrashEventsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeCrashEventsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeCrashEventsResponseCrashEventCount' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeCrashEventsResponseCrashEventCount.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeDevicesReachingAutoExpirationDateResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeDevicesReachingAutoExpirationDateResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountChromeVersionsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountChromeVersionsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountInstalledAppsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountInstalledAppsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountPrintJobsByPrinterResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountPrintJobsByPrinterResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CountPrintJobsByUserResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CountPrintJobsByUserResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CpuInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CpuInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CpuStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CpuStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1CpuTemperatureInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1CpuTemperatureInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1Device' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1Device.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DeviceActivityReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DeviceActivityReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DeviceAueCountReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DeviceAueCountReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DeviceHardwareCountReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DeviceHardwareCountReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DeviceRequestingExtensionDetails' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DeviceRequestingExtensionDetails.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DiskInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DiskInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DisplayDevice' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DisplayDevice.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1DisplayInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1DisplayInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1EnumeratePrintJobsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1EnumeratePrintJobsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1FetchUsersRequestingExtensionResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1FetchUsersRequestingExtensionResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1FindInstalledAppDevicesResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1FindInstalledAppDevicesResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1GraphicsAdapterInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1GraphicsAdapterInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1GraphicsInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1GraphicsInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1GraphicsStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1GraphicsStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1HeartbeatStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1HeartbeatStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1HttpsLatencyRoutineData' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1HttpsLatencyRoutineData.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1InstalledApp' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1InstalledApp.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1KioskAppStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1KioskAppStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ListTelemetryDevicesResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ListTelemetryDevicesResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ListTelemetryEventsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ListTelemetryEventsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ListTelemetryNotificationConfigsResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ListTelemetryNotificationConfigsResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ListTelemetryUsersResponse' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ListTelemetryUsersResponse.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1MemoryInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1MemoryInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1MemoryStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1MemoryStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1NetworkBandwidthReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1NetworkBandwidthReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1NetworkDevice' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1NetworkDevice.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1NetworkDiagnosticsReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1NetworkDiagnosticsReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1NetworkInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1NetworkInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1NetworkStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1NetworkStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1OsUpdateStatus' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1OsUpdateStatus.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1PeripheralsReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1PeripheralsReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1PrintJob' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1PrintJob.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1PrinterReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1PrinterReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1RuntimeCountersReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1RuntimeCountersReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1StorageInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1StorageInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1StorageInfoDiskVolume' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1StorageInfoDiskVolume.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1StorageStatusReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1StorageStatusReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryAppInstallEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryAppInstallEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryAppLaunchEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryAppLaunchEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryAppUninstallEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryAppUninstallEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryAudioSevereUnderrunEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryAudioSevereUnderrunEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryDevice' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryDevice.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryDeviceInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryDeviceInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryEventNotificationFilter' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryEventNotificationFilter.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryHttpsLatencyChangeEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryHttpsLatencyChangeEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryNetworkConnectionStateChangeEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryNetworkConnectionStateChangeEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryNetworkSignalStrengthEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryNetworkSignalStrengthEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryNotificationConfig' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryNotificationConfig.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryNotificationFilter' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryNotificationFilter.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryUsbPeripheralsEvent' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryUsbPeripheralsEvent.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryUser' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryUser.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryUserDevice' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryUserDevice.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TelemetryUserInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TelemetryUserInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1ThunderboltInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1ThunderboltInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TotalMemoryEncryptionInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TotalMemoryEncryptionInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TouchScreenDevice' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TouchScreenDevice.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1TouchScreenInfo' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1TouchScreenInfo.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1UsbPeripheralReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1UsbPeripheralReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1UserPrintReport' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1UserPrintReport.php',
    'Google\\Service\\ChromeManagement\\GoogleChromeManagementV1UserRequestingExtensionDetails' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleChromeManagementV1UserRequestingExtensionDetails.php',
    'Google\\Service\\ChromeManagement\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleProtobufEmpty.php',
    'Google\\Service\\ChromeManagement\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleRpcStatus.php',
    'Google\\Service\\ChromeManagement\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/GoogleTypeDate.php',
    'Google\\Service\\ChromeManagement\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/Customers.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersApps' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersApps.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersAppsAndroid' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersAppsAndroid.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersAppsChrome' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersAppsChrome.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersAppsWeb' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersAppsWeb.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersReports' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersReports.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersTelemetry' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersTelemetry.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersTelemetryDevices' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersTelemetryDevices.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersTelemetryEvents' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersTelemetryEvents.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersTelemetryNotificationConfigs' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersTelemetryNotificationConfigs.php',
    'Google\\Service\\ChromeManagement\\Resource\\CustomersTelemetryUsers' => $vendorDir . '/google/apiclient-services/src/ChromeManagement/Resource/CustomersTelemetryUsers.php',
    'Google\\Service\\ChromePolicy' => $vendorDir . '/google/apiclient-services/src/ChromePolicy.php',
    'Google\\Service\\ChromePolicy\\ChromeCrosDpanelAutosettingsProtoPolicyApiLifecycle' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/ChromeCrosDpanelAutosettingsProtoPolicyApiLifecycle.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1AdditionalTargetKeyName' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1AdditionalTargetKeyName.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1BatchDeleteGroupPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1BatchDeleteGroupPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1BatchInheritOrgUnitPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1BatchInheritOrgUnitPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1BatchModifyGroupPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1BatchModifyGroupPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1BatchModifyOrgUnitPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1BatchModifyOrgUnitPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1DefineCertificateRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1DefineCertificateRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1DefineCertificateResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1DefineCertificateResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1DefineNetworkRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1DefineNetworkRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1DefineNetworkResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1DefineNetworkResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1DeleteGroupPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1DeleteGroupPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1InheritOrgUnitPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1InheritOrgUnitPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ListGroupPriorityOrderingRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ListGroupPriorityOrderingRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ListGroupPriorityOrderingResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ListGroupPriorityOrderingResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ListPolicySchemasResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ListPolicySchemasResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ModifyGroupPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ModifyGroupPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ModifyOrgUnitPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ModifyOrgUnitPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1NetworkSetting' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1NetworkSetting.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicyModificationFieldError' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicyModificationFieldError.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchema' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchema.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchemaFieldDependencies' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchemaFieldDependencies.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchemaFieldDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchemaFieldDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchemaFieldKnownValueDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchemaFieldKnownValueDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchemaNoticeDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchemaNoticeDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicySchemaRequiredItems' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicySchemaRequiredItems.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicyTargetKey' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicyTargetKey.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1PolicyValue' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1PolicyValue.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1RemoveCertificateRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1RemoveCertificateRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1RemoveCertificateResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1RemoveCertificateResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1RemoveNetworkRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1RemoveNetworkRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1RemoveNetworkResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1RemoveNetworkResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ResolveRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ResolveRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ResolveResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ResolveResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1ResolvedPolicy' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1ResolvedPolicy.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1UpdateGroupPriorityOrderingRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1UpdateGroupPriorityOrderingRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1UploadPolicyFileRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1UploadPolicyFileRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyV1UploadPolicyFileResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyV1UploadPolicyFileResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1AdditionalTargetKeyName' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1AdditionalTargetKeyName.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1BatchDeleteGroupPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1BatchDeleteGroupPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1BatchInheritOrgUnitPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1BatchInheritOrgUnitPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1BatchModifyGroupPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1BatchModifyGroupPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1BatchModifyOrgUnitPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1BatchModifyOrgUnitPoliciesRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1CertificateReference' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1CertificateReference.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1DefineCertificateRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1DefineCertificateRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1DefineCertificateResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1DefineCertificateResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1DefineNetworkRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1DefineNetworkRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1DefineNetworkResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1DefineNetworkResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1DeleteGroupPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1DeleteGroupPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1FieldConstraints' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1FieldConstraints.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1InheritOrgUnitPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1InheritOrgUnitPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ListGroupPriorityOrderingRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ListGroupPriorityOrderingRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ListGroupPriorityOrderingResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ListGroupPriorityOrderingResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ListPolicySchemasResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ListPolicySchemasResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ModifyGroupPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ModifyGroupPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ModifyOrgUnitPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ModifyOrgUnitPolicyRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1NetworkSetting' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1NetworkSetting.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1NumericRangeConstraint' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1NumericRangeConstraint.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyApiLifecycle' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyApiLifecycle.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyModificationError' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyModificationError.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyModificationErrorDetails' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyModificationErrorDetails.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyModificationFieldError' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyModificationFieldError.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchema' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchema.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchemaFieldDependencies' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchemaFieldDependencies.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchemaFieldDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchemaFieldDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchemaFieldKnownValueDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchemaFieldKnownValueDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicySchemaRequiredItems' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicySchemaRequiredItems.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyTargetKey' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyTargetKey.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1PolicyValue' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1PolicyValue.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1RemoveCertificateErrorDetails' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1RemoveCertificateErrorDetails.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1RemoveCertificateRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1RemoveCertificateRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1RemoveCertificateResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1RemoveCertificateResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1RemoveNetworkRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1RemoveNetworkRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1RemoveNetworkResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1RemoveNetworkResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ResolveRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ResolveRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ResolveResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ResolveResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1ResolvedPolicy' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1ResolvedPolicy.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1UpdateGroupPriorityOrderingRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1UpdateGroupPriorityOrderingRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1UploadPolicyFileRequest' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1UploadPolicyFileRequest.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1UploadPolicyFileResponse' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1UploadPolicyFileResponse.php',
    'Google\\Service\\ChromePolicy\\GoogleChromePolicyVersionsV1UploadedFileConstraints' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleChromePolicyVersionsV1UploadedFileConstraints.php',
    'Google\\Service\\ChromePolicy\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleProtobufEmpty.php',
    'Google\\Service\\ChromePolicy\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/GoogleTypeDate.php',
    'Google\\Service\\ChromePolicy\\Proto2DescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2DescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Proto2EnumDescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2EnumDescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Proto2EnumValueDescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2EnumValueDescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Proto2FieldDescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2FieldDescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Proto2FileDescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2FileDescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Proto2OneofDescriptorProto' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Proto2OneofDescriptorProto.php',
    'Google\\Service\\ChromePolicy\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/Customers.php',
    'Google\\Service\\ChromePolicy\\Resource\\CustomersPolicies' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/CustomersPolicies.php',
    'Google\\Service\\ChromePolicy\\Resource\\CustomersPoliciesGroups' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/CustomersPoliciesGroups.php',
    'Google\\Service\\ChromePolicy\\Resource\\CustomersPoliciesNetworks' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/CustomersPoliciesNetworks.php',
    'Google\\Service\\ChromePolicy\\Resource\\CustomersPoliciesOrgunits' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/CustomersPoliciesOrgunits.php',
    'Google\\Service\\ChromePolicy\\Resource\\CustomersPolicySchemas' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/CustomersPolicySchemas.php',
    'Google\\Service\\ChromePolicy\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/ChromePolicy/Resource/Media.php',
    'Google\\Service\\ChromeUXReport' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport.php',
    'Google\\Service\\ChromeUXReport\\Bin' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Bin.php',
    'Google\\Service\\ChromeUXReport\\CollectionPeriod' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/CollectionPeriod.php',
    'Google\\Service\\ChromeUXReport\\Date' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Date.php',
    'Google\\Service\\ChromeUXReport\\FractionTimeseries' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/FractionTimeseries.php',
    'Google\\Service\\ChromeUXReport\\HistoryKey' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/HistoryKey.php',
    'Google\\Service\\ChromeUXReport\\HistoryRecord' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/HistoryRecord.php',
    'Google\\Service\\ChromeUXReport\\Key' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Key.php',
    'Google\\Service\\ChromeUXReport\\Metric' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Metric.php',
    'Google\\Service\\ChromeUXReport\\MetricTimeseries' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/MetricTimeseries.php',
    'Google\\Service\\ChromeUXReport\\Percentiles' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Percentiles.php',
    'Google\\Service\\ChromeUXReport\\QueryHistoryRequest' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/QueryHistoryRequest.php',
    'Google\\Service\\ChromeUXReport\\QueryHistoryResponse' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/QueryHistoryResponse.php',
    'Google\\Service\\ChromeUXReport\\QueryRequest' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/QueryRequest.php',
    'Google\\Service\\ChromeUXReport\\QueryResponse' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/QueryResponse.php',
    'Google\\Service\\ChromeUXReport\\Record' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Record.php',
    'Google\\Service\\ChromeUXReport\\Resource\\Records' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/Resource/Records.php',
    'Google\\Service\\ChromeUXReport\\TimeseriesBin' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/TimeseriesBin.php',
    'Google\\Service\\ChromeUXReport\\TimeseriesPercentiles' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/TimeseriesPercentiles.php',
    'Google\\Service\\ChromeUXReport\\UrlNormalization' => $vendorDir . '/google/apiclient-services/src/ChromeUXReport/UrlNormalization.php',
    'Google\\Service\\CivicInfo' => $vendorDir . '/google/apiclient-services/src/CivicInfo.php',
    'Google\\Service\\CivicInfo\\AdministrationRegion' => $vendorDir . '/google/apiclient-services/src/CivicInfo/AdministrationRegion.php',
    'Google\\Service\\CivicInfo\\AdministrativeBody' => $vendorDir . '/google/apiclient-services/src/CivicInfo/AdministrativeBody.php',
    'Google\\Service\\CivicInfo\\Candidate' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Candidate.php',
    'Google\\Service\\CivicInfo\\Channel' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Channel.php',
    'Google\\Service\\CivicInfo\\Contest' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Contest.php',
    'Google\\Service\\CivicInfo\\DivisionSearchResponse' => $vendorDir . '/google/apiclient-services/src/CivicInfo/DivisionSearchResponse.php',
    'Google\\Service\\CivicInfo\\DivisionSearchResult' => $vendorDir . '/google/apiclient-services/src/CivicInfo/DivisionSearchResult.php',
    'Google\\Service\\CivicInfo\\Election' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Election.php',
    'Google\\Service\\CivicInfo\\ElectionOfficial' => $vendorDir . '/google/apiclient-services/src/CivicInfo/ElectionOfficial.php',
    'Google\\Service\\CivicInfo\\ElectionsQueryResponse' => $vendorDir . '/google/apiclient-services/src/CivicInfo/ElectionsQueryResponse.php',
    'Google\\Service\\CivicInfo\\ElectoralDistrict' => $vendorDir . '/google/apiclient-services/src/CivicInfo/ElectoralDistrict.php',
    'Google\\Service\\CivicInfo\\FeatureIdProto' => $vendorDir . '/google/apiclient-services/src/CivicInfo/FeatureIdProto.php',
    'Google\\Service\\CivicInfo\\GeocodingSummary' => $vendorDir . '/google/apiclient-services/src/CivicInfo/GeocodingSummary.php',
    'Google\\Service\\CivicInfo\\GeographicDivision' => $vendorDir . '/google/apiclient-services/src/CivicInfo/GeographicDivision.php',
    'Google\\Service\\CivicInfo\\MessageSet' => $vendorDir . '/google/apiclient-services/src/CivicInfo/MessageSet.php',
    'Google\\Service\\CivicInfo\\Office' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Office.php',
    'Google\\Service\\CivicInfo\\Official' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Official.php',
    'Google\\Service\\CivicInfo\\PollingLocation' => $vendorDir . '/google/apiclient-services/src/CivicInfo/PollingLocation.php',
    'Google\\Service\\CivicInfo\\Precinct' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Precinct.php',
    'Google\\Service\\CivicInfo\\RepresentativeInfoData' => $vendorDir . '/google/apiclient-services/src/CivicInfo/RepresentativeInfoData.php',
    'Google\\Service\\CivicInfo\\RepresentativeInfoResponse' => $vendorDir . '/google/apiclient-services/src/CivicInfo/RepresentativeInfoResponse.php',
    'Google\\Service\\CivicInfo\\Resource\\Divisions' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Resource/Divisions.php',
    'Google\\Service\\CivicInfo\\Resource\\Elections' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Resource/Elections.php',
    'Google\\Service\\CivicInfo\\Resource\\Representatives' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Resource/Representatives.php',
    'Google\\Service\\CivicInfo\\SimpleAddressType' => $vendorDir . '/google/apiclient-services/src/CivicInfo/SimpleAddressType.php',
    'Google\\Service\\CivicInfo\\Source' => $vendorDir . '/google/apiclient-services/src/CivicInfo/Source.php',
    'Google\\Service\\CivicInfo\\VoterInfoResponse' => $vendorDir . '/google/apiclient-services/src/CivicInfo/VoterInfoResponse.php',
    'Google\\Service\\Classroom' => $vendorDir . '/google/apiclient-services/src/Classroom.php',
    'Google\\Service\\Classroom\\AddOnAttachment' => $vendorDir . '/google/apiclient-services/src/Classroom/AddOnAttachment.php',
    'Google\\Service\\Classroom\\AddOnAttachmentStudentSubmission' => $vendorDir . '/google/apiclient-services/src/Classroom/AddOnAttachmentStudentSubmission.php',
    'Google\\Service\\Classroom\\AddOnContext' => $vendorDir . '/google/apiclient-services/src/Classroom/AddOnContext.php',
    'Google\\Service\\Classroom\\Announcement' => $vendorDir . '/google/apiclient-services/src/Classroom/Announcement.php',
    'Google\\Service\\Classroom\\Assignment' => $vendorDir . '/google/apiclient-services/src/Classroom/Assignment.php',
    'Google\\Service\\Classroom\\AssignmentSubmission' => $vendorDir . '/google/apiclient-services/src/Classroom/AssignmentSubmission.php',
    'Google\\Service\\Classroom\\Attachment' => $vendorDir . '/google/apiclient-services/src/Classroom/Attachment.php',
    'Google\\Service\\Classroom\\ClassroomEmpty' => $vendorDir . '/google/apiclient-services/src/Classroom/ClassroomEmpty.php',
    'Google\\Service\\Classroom\\CloudPubsubTopic' => $vendorDir . '/google/apiclient-services/src/Classroom/CloudPubsubTopic.php',
    'Google\\Service\\Classroom\\CopyHistory' => $vendorDir . '/google/apiclient-services/src/Classroom/CopyHistory.php',
    'Google\\Service\\Classroom\\Course' => $vendorDir . '/google/apiclient-services/src/Classroom/Course.php',
    'Google\\Service\\Classroom\\CourseAlias' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseAlias.php',
    'Google\\Service\\Classroom\\CourseMaterial' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseMaterial.php',
    'Google\\Service\\Classroom\\CourseMaterialSet' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseMaterialSet.php',
    'Google\\Service\\Classroom\\CourseRosterChangesInfo' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseRosterChangesInfo.php',
    'Google\\Service\\Classroom\\CourseWork' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseWork.php',
    'Google\\Service\\Classroom\\CourseWorkChangesInfo' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseWorkChangesInfo.php',
    'Google\\Service\\Classroom\\CourseWorkMaterial' => $vendorDir . '/google/apiclient-services/src/Classroom/CourseWorkMaterial.php',
    'Google\\Service\\Classroom\\Date' => $vendorDir . '/google/apiclient-services/src/Classroom/Date.php',
    'Google\\Service\\Classroom\\DriveFile' => $vendorDir . '/google/apiclient-services/src/Classroom/DriveFile.php',
    'Google\\Service\\Classroom\\DriveFolder' => $vendorDir . '/google/apiclient-services/src/Classroom/DriveFolder.php',
    'Google\\Service\\Classroom\\EmbedUri' => $vendorDir . '/google/apiclient-services/src/Classroom/EmbedUri.php',
    'Google\\Service\\Classroom\\Feed' => $vendorDir . '/google/apiclient-services/src/Classroom/Feed.php',
    'Google\\Service\\Classroom\\Form' => $vendorDir . '/google/apiclient-services/src/Classroom/Form.php',
    'Google\\Service\\Classroom\\GlobalPermission' => $vendorDir . '/google/apiclient-services/src/Classroom/GlobalPermission.php',
    'Google\\Service\\Classroom\\GradeCategory' => $vendorDir . '/google/apiclient-services/src/Classroom/GradeCategory.php',
    'Google\\Service\\Classroom\\GradeHistory' => $vendorDir . '/google/apiclient-services/src/Classroom/GradeHistory.php',
    'Google\\Service\\Classroom\\GradebookSettings' => $vendorDir . '/google/apiclient-services/src/Classroom/GradebookSettings.php',
    'Google\\Service\\Classroom\\Guardian' => $vendorDir . '/google/apiclient-services/src/Classroom/Guardian.php',
    'Google\\Service\\Classroom\\GuardianInvitation' => $vendorDir . '/google/apiclient-services/src/Classroom/GuardianInvitation.php',
    'Google\\Service\\Classroom\\IndividualStudentsOptions' => $vendorDir . '/google/apiclient-services/src/Classroom/IndividualStudentsOptions.php',
    'Google\\Service\\Classroom\\Invitation' => $vendorDir . '/google/apiclient-services/src/Classroom/Invitation.php',
    'Google\\Service\\Classroom\\Link' => $vendorDir . '/google/apiclient-services/src/Classroom/Link.php',
    'Google\\Service\\Classroom\\ListAddOnAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListAddOnAttachmentsResponse.php',
    'Google\\Service\\Classroom\\ListAnnouncementsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListAnnouncementsResponse.php',
    'Google\\Service\\Classroom\\ListCourseAliasesResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListCourseAliasesResponse.php',
    'Google\\Service\\Classroom\\ListCourseWorkMaterialResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListCourseWorkMaterialResponse.php',
    'Google\\Service\\Classroom\\ListCourseWorkResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListCourseWorkResponse.php',
    'Google\\Service\\Classroom\\ListCoursesResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListCoursesResponse.php',
    'Google\\Service\\Classroom\\ListGuardianInvitationsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListGuardianInvitationsResponse.php',
    'Google\\Service\\Classroom\\ListGuardiansResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListGuardiansResponse.php',
    'Google\\Service\\Classroom\\ListInvitationsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListInvitationsResponse.php',
    'Google\\Service\\Classroom\\ListStudentSubmissionsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListStudentSubmissionsResponse.php',
    'Google\\Service\\Classroom\\ListStudentsResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListStudentsResponse.php',
    'Google\\Service\\Classroom\\ListTeachersResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListTeachersResponse.php',
    'Google\\Service\\Classroom\\ListTopicResponse' => $vendorDir . '/google/apiclient-services/src/Classroom/ListTopicResponse.php',
    'Google\\Service\\Classroom\\Material' => $vendorDir . '/google/apiclient-services/src/Classroom/Material.php',
    'Google\\Service\\Classroom\\ModifyAnnouncementAssigneesRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/ModifyAnnouncementAssigneesRequest.php',
    'Google\\Service\\Classroom\\ModifyAttachmentsRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/ModifyAttachmentsRequest.php',
    'Google\\Service\\Classroom\\ModifyCourseWorkAssigneesRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/ModifyCourseWorkAssigneesRequest.php',
    'Google\\Service\\Classroom\\ModifyIndividualStudentsOptions' => $vendorDir . '/google/apiclient-services/src/Classroom/ModifyIndividualStudentsOptions.php',
    'Google\\Service\\Classroom\\MultipleChoiceQuestion' => $vendorDir . '/google/apiclient-services/src/Classroom/MultipleChoiceQuestion.php',
    'Google\\Service\\Classroom\\MultipleChoiceSubmission' => $vendorDir . '/google/apiclient-services/src/Classroom/MultipleChoiceSubmission.php',
    'Google\\Service\\Classroom\\Name' => $vendorDir . '/google/apiclient-services/src/Classroom/Name.php',
    'Google\\Service\\Classroom\\ReclaimStudentSubmissionRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/ReclaimStudentSubmissionRequest.php',
    'Google\\Service\\Classroom\\Registration' => $vendorDir . '/google/apiclient-services/src/Classroom/Registration.php',
    'Google\\Service\\Classroom\\Resource\\Courses' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/Courses.php',
    'Google\\Service\\Classroom\\Resource\\CoursesAliases' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesAliases.php',
    'Google\\Service\\Classroom\\Resource\\CoursesAnnouncements' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesAnnouncements.php',
    'Google\\Service\\Classroom\\Resource\\CoursesAnnouncementsAddOnAttachments' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesAnnouncementsAddOnAttachments.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWork' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWork.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWorkAddOnAttachments' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWorkAddOnAttachments.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWorkAddOnAttachmentsStudentSubmissions' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWorkAddOnAttachmentsStudentSubmissions.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWorkMaterials' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWorkMaterials.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWorkMaterialsAddOnAttachments' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWorkMaterialsAddOnAttachments.php',
    'Google\\Service\\Classroom\\Resource\\CoursesCourseWorkStudentSubmissions' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesCourseWorkStudentSubmissions.php',
    'Google\\Service\\Classroom\\Resource\\CoursesPosts' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesPosts.php',
    'Google\\Service\\Classroom\\Resource\\CoursesPostsAddOnAttachments' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesPostsAddOnAttachments.php',
    'Google\\Service\\Classroom\\Resource\\CoursesPostsAddOnAttachmentsStudentSubmissions' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesPostsAddOnAttachmentsStudentSubmissions.php',
    'Google\\Service\\Classroom\\Resource\\CoursesStudents' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesStudents.php',
    'Google\\Service\\Classroom\\Resource\\CoursesTeachers' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesTeachers.php',
    'Google\\Service\\Classroom\\Resource\\CoursesTopics' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/CoursesTopics.php',
    'Google\\Service\\Classroom\\Resource\\Invitations' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/Invitations.php',
    'Google\\Service\\Classroom\\Resource\\Registrations' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/Registrations.php',
    'Google\\Service\\Classroom\\Resource\\UserProfiles' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/UserProfiles.php',
    'Google\\Service\\Classroom\\Resource\\UserProfilesGuardianInvitations' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/UserProfilesGuardianInvitations.php',
    'Google\\Service\\Classroom\\Resource\\UserProfilesGuardians' => $vendorDir . '/google/apiclient-services/src/Classroom/Resource/UserProfilesGuardians.php',
    'Google\\Service\\Classroom\\ReturnStudentSubmissionRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/ReturnStudentSubmissionRequest.php',
    'Google\\Service\\Classroom\\SharedDriveFile' => $vendorDir . '/google/apiclient-services/src/Classroom/SharedDriveFile.php',
    'Google\\Service\\Classroom\\ShortAnswerSubmission' => $vendorDir . '/google/apiclient-services/src/Classroom/ShortAnswerSubmission.php',
    'Google\\Service\\Classroom\\StateHistory' => $vendorDir . '/google/apiclient-services/src/Classroom/StateHistory.php',
    'Google\\Service\\Classroom\\Student' => $vendorDir . '/google/apiclient-services/src/Classroom/Student.php',
    'Google\\Service\\Classroom\\StudentContext' => $vendorDir . '/google/apiclient-services/src/Classroom/StudentContext.php',
    'Google\\Service\\Classroom\\StudentSubmission' => $vendorDir . '/google/apiclient-services/src/Classroom/StudentSubmission.php',
    'Google\\Service\\Classroom\\SubmissionHistory' => $vendorDir . '/google/apiclient-services/src/Classroom/SubmissionHistory.php',
    'Google\\Service\\Classroom\\Teacher' => $vendorDir . '/google/apiclient-services/src/Classroom/Teacher.php',
    'Google\\Service\\Classroom\\TeacherContext' => $vendorDir . '/google/apiclient-services/src/Classroom/TeacherContext.php',
    'Google\\Service\\Classroom\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Classroom/TimeOfDay.php',
    'Google\\Service\\Classroom\\Topic' => $vendorDir . '/google/apiclient-services/src/Classroom/Topic.php',
    'Google\\Service\\Classroom\\TurnInStudentSubmissionRequest' => $vendorDir . '/google/apiclient-services/src/Classroom/TurnInStudentSubmissionRequest.php',
    'Google\\Service\\Classroom\\UserProfile' => $vendorDir . '/google/apiclient-services/src/Classroom/UserProfile.php',
    'Google\\Service\\Classroom\\YouTubeVideo' => $vendorDir . '/google/apiclient-services/src/Classroom/YouTubeVideo.php',
    'Google\\Service\\CloudAlloyDBAdmin' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin.php',
    'Google\\Service\\CloudAlloyDBAdmin\\AlloydbEmpty' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/AlloydbEmpty.php',
    'Google\\Service\\CloudAlloyDBAdmin\\AuthorizedNetwork' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/AuthorizedNetwork.php',
    'Google\\Service\\CloudAlloyDBAdmin\\AutomatedBackupPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/AutomatedBackupPolicy.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Backup' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Backup.php',
    'Google\\Service\\CloudAlloyDBAdmin\\BackupSource' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/BackupSource.php',
    'Google\\Service\\CloudAlloyDBAdmin\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/CancelOperationRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ClientConnectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ClientConnectionConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\CloudControl2SharedOperationsReconciliationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/CloudControl2SharedOperationsReconciliationOperationMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Cluster' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Cluster.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ClusterUpgradeDetails' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ClusterUpgradeDetails.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ConnectionInfo' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ConnectionInfo.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ContinuousBackupConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ContinuousBackupConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ContinuousBackupInfo' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ContinuousBackupInfo.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ContinuousBackupSource' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ContinuousBackupSource.php',
    'Google\\Service\\CloudAlloyDBAdmin\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/EncryptionConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\EncryptionInfo' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/EncryptionInfo.php',
    'Google\\Service\\CloudAlloyDBAdmin\\FailoverInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/FailoverInstanceRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\GenerateClientCertificateRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/GenerateClientCertificateRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\GenerateClientCertificateResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/GenerateClientCertificateResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/GoogleCloudLocationLocation.php',
    'Google\\Service\\CloudAlloyDBAdmin\\GoogleTypeTimeOfDay' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/GoogleTypeTimeOfDay.php',
    'Google\\Service\\CloudAlloyDBAdmin\\InjectFaultRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/InjectFaultRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Instance' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Instance.php',
    'Google\\Service\\CloudAlloyDBAdmin\\InstanceNetworkConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/InstanceNetworkConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\InstanceUpgradeDetails' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/InstanceUpgradeDetails.php',
    'Google\\Service\\CloudAlloyDBAdmin\\IntegerRestrictions' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/IntegerRestrictions.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListBackupsResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListClustersResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListInstancesResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListOperationsResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListSupportedDatabaseFlagsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListSupportedDatabaseFlagsResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ListUsersResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ListUsersResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\MachineConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/MachineConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/MaintenanceSchedule.php',
    'Google\\Service\\CloudAlloyDBAdmin\\MaintenanceUpdatePolicy' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/MaintenanceUpdatePolicy.php',
    'Google\\Service\\CloudAlloyDBAdmin\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/MaintenanceWindow.php',
    'Google\\Service\\CloudAlloyDBAdmin\\MigrationSource' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/MigrationSource.php',
    'Google\\Service\\CloudAlloyDBAdmin\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/NetworkConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Node' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Node.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Operation.php',
    'Google\\Service\\CloudAlloyDBAdmin\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/OperationMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\PrimaryConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/PrimaryConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\PromoteClusterRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/PromoteClusterRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\PscConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/PscConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\PscInstanceConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/PscInstanceConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\QuantityBasedExpiry' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/QuantityBasedExpiry.php',
    'Google\\Service\\CloudAlloyDBAdmin\\QuantityBasedRetention' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/QuantityBasedRetention.php',
    'Google\\Service\\CloudAlloyDBAdmin\\QueryInsightsInstanceConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/QueryInsightsInstanceConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\ReadPoolConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/ReadPoolConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/Projects.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsBackups' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsBackups.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsClusters' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsClusters.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsClustersInstances' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsClustersInstances.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsClustersUsers' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsClustersUsers.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Resource\\ProjectsLocationsSupportedDatabaseFlags' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Resource/ProjectsLocationsSupportedDatabaseFlags.php',
    'Google\\Service\\CloudAlloyDBAdmin\\RestartInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/RestartInstanceRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\RestoreClusterRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/RestoreClusterRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\SecondaryConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/SecondaryConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\SslConfig' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/SslConfig.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StageInfo' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StageInfo.php',
    'Google\\Service\\CloudAlloyDBAdmin\\Status' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/Status.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainBackupConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainBackupConfiguration.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainBackupRun' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainBackupRun.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainCompliance' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainCompliance.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainCustomMetadataData' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainCustomMetadataData.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseResourceId' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseResourceId.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainDatabaseResourceRecommendationSignalData' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainDatabaseResourceRecommendationSignalData.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainEntitlement' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainEntitlement.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainMachineConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainMachineConfiguration.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainObservabilityMetricData' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainObservabilityMetricData.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainOperationError' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainOperationError.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainRetentionSettings' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainRetentionSettings.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterPartnerapiV1mainUserLabels' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterPartnerapiV1mainUserLabels.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterProtoCommonProduct' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterProtoCommonProduct.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StorageDatabasecenterProtoCommonTypedValue' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StorageDatabasecenterProtoCommonTypedValue.php',
    'Google\\Service\\CloudAlloyDBAdmin\\StringRestrictions' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/StringRestrictions.php',
    'Google\\Service\\CloudAlloyDBAdmin\\SupportedDatabaseFlag' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/SupportedDatabaseFlag.php',
    'Google\\Service\\CloudAlloyDBAdmin\\SwitchoverClusterRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/SwitchoverClusterRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\TimeBasedRetention' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/TimeBasedRetention.php',
    'Google\\Service\\CloudAlloyDBAdmin\\TrialMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/TrialMetadata.php',
    'Google\\Service\\CloudAlloyDBAdmin\\UpgradeClusterRequest' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/UpgradeClusterRequest.php',
    'Google\\Service\\CloudAlloyDBAdmin\\UpgradeClusterResponse' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/UpgradeClusterResponse.php',
    'Google\\Service\\CloudAlloyDBAdmin\\User' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/User.php',
    'Google\\Service\\CloudAlloyDBAdmin\\UserPassword' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/UserPassword.php',
    'Google\\Service\\CloudAlloyDBAdmin\\WeeklySchedule' => $vendorDir . '/google/apiclient-services/src/CloudAlloyDBAdmin/WeeklySchedule.php',
    'Google\\Service\\CloudAsset' => $vendorDir . '/google/apiclient-services/src/CloudAsset.php',
    'Google\\Service\\CloudAsset\\AccessSelector' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AccessSelector.php',
    'Google\\Service\\CloudAsset\\AnalyzeIamPolicyLongrunningMetadata' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeIamPolicyLongrunningMetadata.php',
    'Google\\Service\\CloudAsset\\AnalyzeIamPolicyLongrunningRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeIamPolicyLongrunningRequest.php',
    'Google\\Service\\CloudAsset\\AnalyzeIamPolicyLongrunningResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeIamPolicyLongrunningResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzeIamPolicyResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeIamPolicyResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzeMoveResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeMoveResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzeOrgPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeOrgPoliciesResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzeOrgPolicyGovernedAssetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeOrgPolicyGovernedAssetsResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzeOrgPolicyGovernedContainersResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzeOrgPolicyGovernedContainersResponse.php',
    'Google\\Service\\CloudAsset\\AnalyzerOrgPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzerOrgPolicy.php',
    'Google\\Service\\CloudAsset\\AnalyzerOrgPolicyConstraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AnalyzerOrgPolicyConstraint.php',
    'Google\\Service\\CloudAsset\\Asset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Asset.php',
    'Google\\Service\\CloudAsset\\AssetEnrichment' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AssetEnrichment.php',
    'Google\\Service\\CloudAsset\\AttachedResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AttachedResource.php',
    'Google\\Service\\CloudAsset\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AuditConfig.php',
    'Google\\Service\\CloudAsset\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/AuditLogConfig.php',
    'Google\\Service\\CloudAsset\\BatchGetAssetsHistoryResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/BatchGetAssetsHistoryResponse.php',
    'Google\\Service\\CloudAsset\\BatchGetEffectiveIamPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/BatchGetEffectiveIamPoliciesResponse.php',
    'Google\\Service\\CloudAsset\\BigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/BigQueryDestination.php',
    'Google\\Service\\CloudAsset\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Binding.php',
    'Google\\Service\\CloudAsset\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/CancelOperationRequest.php',
    'Google\\Service\\CloudAsset\\CloudassetEmpty' => $vendorDir . '/google/apiclient-services/src/CloudAsset/CloudassetEmpty.php',
    'Google\\Service\\CloudAsset\\CloudassetResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/CloudassetResource.php',
    'Google\\Service\\CloudAsset\\ConditionContext' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ConditionContext.php',
    'Google\\Service\\CloudAsset\\ConditionEvaluation' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ConditionEvaluation.php',
    'Google\\Service\\CloudAsset\\CreateFeedRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/CreateFeedRequest.php',
    'Google\\Service\\CloudAsset\\Date' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Date.php',
    'Google\\Service\\CloudAsset\\DeniedAccess' => $vendorDir . '/google/apiclient-services/src/CloudAsset/DeniedAccess.php',
    'Google\\Service\\CloudAsset\\EffectiveIamPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/EffectiveIamPolicy.php',
    'Google\\Service\\CloudAsset\\EffectiveTagDetails' => $vendorDir . '/google/apiclient-services/src/CloudAsset/EffectiveTagDetails.php',
    'Google\\Service\\CloudAsset\\Explanation' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Explanation.php',
    'Google\\Service\\CloudAsset\\ExportAssetsRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ExportAssetsRequest.php',
    'Google\\Service\\CloudAsset\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Expr.php',
    'Google\\Service\\CloudAsset\\Feed' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Feed.php',
    'Google\\Service\\CloudAsset\\FeedOutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/FeedOutputConfig.php',
    'Google\\Service\\CloudAsset\\GcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GcsDestination.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Access' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Access.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1AccessControlList' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1AccessControlList.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedAsset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedAsset.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedIamPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedIamPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedResource.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1BigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1BigQueryDestination.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1BooleanConstraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1BooleanConstraint.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Constraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Constraint.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1CustomConstraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1CustomConstraint.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1DeniedAccessAccess' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1DeniedAccessAccess.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1DeniedAccessAccessTuple' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1DeniedAccessAccessTuple.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1DeniedAccessDenyDetail' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1DeniedAccessDenyDetail.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1DeniedAccessIdentity' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1DeniedAccessIdentity.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1DeniedAccessResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1DeniedAccessResource.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Edge' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Edge.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1GcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1GcsDestination.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1GovernedContainer' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1GovernedContainer.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Identity' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Identity.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1IdentityList' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1IdentityList.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1ListConstraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1ListConstraint.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1QueryAssetsOutputConfigBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1QueryAssetsOutputConfigBigQueryDestination.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Resource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Resource.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1Rule' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1Rule.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1StringValues' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1StringValues.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1p7beta1Asset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1p7beta1Asset.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1p7beta1RelatedAsset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1p7beta1RelatedAsset.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1p7beta1RelatedAssets' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1p7beta1RelatedAssets.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1p7beta1RelationshipAttributes' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1p7beta1RelationshipAttributes.php',
    'Google\\Service\\CloudAsset\\GoogleCloudAssetV1p7beta1Resource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudAssetV1p7beta1Resource.php',
    'Google\\Service\\CloudAsset\\GoogleCloudOrgpolicyV1BooleanPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudOrgpolicyV1BooleanPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleCloudOrgpolicyV1ListPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudOrgpolicyV1ListPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleCloudOrgpolicyV1Policy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudOrgpolicyV1Policy.php',
    'Google\\Service\\CloudAsset\\GoogleCloudOrgpolicyV1RestoreDefault' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleCloudOrgpolicyV1RestoreDefault.php',
    'Google\\Service\\CloudAsset\\GoogleIamV2DenyRule' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIamV2DenyRule.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1AccessLevel' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1AccessLevel.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1AccessPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1AccessPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1ApiOperation' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1ApiOperation.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1BasicLevel' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1BasicLevel.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1Condition' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1Condition.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1CustomLevel' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1CustomLevel.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1DevicePolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1DevicePolicy.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1EgressFrom' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1EgressFrom.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1EgressPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1EgressPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1EgressSource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1EgressSource.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1EgressTo' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1EgressTo.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1IngressFrom' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1IngressFrom.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1IngressPolicy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1IngressPolicy.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1IngressSource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1IngressSource.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1IngressTo' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1IngressTo.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1MethodSelector' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1MethodSelector.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1OsConstraint' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1OsConstraint.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1ServicePerimeter' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1ServicePerimeter.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1ServicePerimeterConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1ServicePerimeterConfig.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1VpcNetworkSource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1VpcNetworkSource.php',
    'Google\\Service\\CloudAsset\\GoogleIdentityAccesscontextmanagerV1VpcSubNetwork' => $vendorDir . '/google/apiclient-services/src/CloudAsset/GoogleIdentityAccesscontextmanagerV1VpcSubNetwork.php',
    'Google\\Service\\CloudAsset\\IamPolicyAnalysis' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicyAnalysis.php',
    'Google\\Service\\CloudAsset\\IamPolicyAnalysisOutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicyAnalysisOutputConfig.php',
    'Google\\Service\\CloudAsset\\IamPolicyAnalysisQuery' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicyAnalysisQuery.php',
    'Google\\Service\\CloudAsset\\IamPolicyAnalysisResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicyAnalysisResult.php',
    'Google\\Service\\CloudAsset\\IamPolicyAnalysisState' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicyAnalysisState.php',
    'Google\\Service\\CloudAsset\\IamPolicySearchResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IamPolicySearchResult.php',
    'Google\\Service\\CloudAsset\\IdentitySelector' => $vendorDir . '/google/apiclient-services/src/CloudAsset/IdentitySelector.php',
    'Google\\Service\\CloudAsset\\Inventory' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Inventory.php',
    'Google\\Service\\CloudAsset\\Item' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Item.php',
    'Google\\Service\\CloudAsset\\ListAssetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ListAssetsResponse.php',
    'Google\\Service\\CloudAsset\\ListFeedsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ListFeedsResponse.php',
    'Google\\Service\\CloudAsset\\ListSavedQueriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ListSavedQueriesResponse.php',
    'Google\\Service\\CloudAsset\\MoveAnalysis' => $vendorDir . '/google/apiclient-services/src/CloudAsset/MoveAnalysis.php',
    'Google\\Service\\CloudAsset\\MoveAnalysisResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/MoveAnalysisResult.php',
    'Google\\Service\\CloudAsset\\MoveImpact' => $vendorDir . '/google/apiclient-services/src/CloudAsset/MoveImpact.php',
    'Google\\Service\\CloudAsset\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Operation.php',
    'Google\\Service\\CloudAsset\\Options' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Options.php',
    'Google\\Service\\CloudAsset\\OrgPolicyResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/OrgPolicyResult.php',
    'Google\\Service\\CloudAsset\\OsInfo' => $vendorDir . '/google/apiclient-services/src/CloudAsset/OsInfo.php',
    'Google\\Service\\CloudAsset\\OutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/OutputConfig.php',
    'Google\\Service\\CloudAsset\\PartitionSpec' => $vendorDir . '/google/apiclient-services/src/CloudAsset/PartitionSpec.php',
    'Google\\Service\\CloudAsset\\Permissions' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Permissions.php',
    'Google\\Service\\CloudAsset\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Policy.php',
    'Google\\Service\\CloudAsset\\PolicyInfo' => $vendorDir . '/google/apiclient-services/src/CloudAsset/PolicyInfo.php',
    'Google\\Service\\CloudAsset\\PubsubDestination' => $vendorDir . '/google/apiclient-services/src/CloudAsset/PubsubDestination.php',
    'Google\\Service\\CloudAsset\\QueryAssetsOutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudAsset/QueryAssetsOutputConfig.php',
    'Google\\Service\\CloudAsset\\QueryAssetsRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/QueryAssetsRequest.php',
    'Google\\Service\\CloudAsset\\QueryAssetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/QueryAssetsResponse.php',
    'Google\\Service\\CloudAsset\\QueryContent' => $vendorDir . '/google/apiclient-services/src/CloudAsset/QueryContent.php',
    'Google\\Service\\CloudAsset\\QueryResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/QueryResult.php',
    'Google\\Service\\CloudAsset\\RelatedAsset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/RelatedAsset.php',
    'Google\\Service\\CloudAsset\\RelatedAssets' => $vendorDir . '/google/apiclient-services/src/CloudAsset/RelatedAssets.php',
    'Google\\Service\\CloudAsset\\RelatedResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/RelatedResource.php',
    'Google\\Service\\CloudAsset\\RelatedResources' => $vendorDir . '/google/apiclient-services/src/CloudAsset/RelatedResources.php',
    'Google\\Service\\CloudAsset\\RelationshipAttributes' => $vendorDir . '/google/apiclient-services/src/CloudAsset/RelationshipAttributes.php',
    'Google\\Service\\CloudAsset\\ResourceOwners' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ResourceOwners.php',
    'Google\\Service\\CloudAsset\\ResourceSearchResult' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ResourceSearchResult.php',
    'Google\\Service\\CloudAsset\\ResourceSelector' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ResourceSelector.php',
    'Google\\Service\\CloudAsset\\Resource\\Assets' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/Assets.php',
    'Google\\Service\\CloudAsset\\Resource\\EffectiveIamPolicies' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/EffectiveIamPolicies.php',
    'Google\\Service\\CloudAsset\\Resource\\Feeds' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/Feeds.php',
    'Google\\Service\\CloudAsset\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/Operations.php',
    'Google\\Service\\CloudAsset\\Resource\\SavedQueries' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/SavedQueries.php',
    'Google\\Service\\CloudAsset\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Resource/V1.php',
    'Google\\Service\\CloudAsset\\SavedQuery' => $vendorDir . '/google/apiclient-services/src/CloudAsset/SavedQuery.php',
    'Google\\Service\\CloudAsset\\SearchAllIamPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/SearchAllIamPoliciesResponse.php',
    'Google\\Service\\CloudAsset\\SearchAllResourcesResponse' => $vendorDir . '/google/apiclient-services/src/CloudAsset/SearchAllResourcesResponse.php',
    'Google\\Service\\CloudAsset\\SoftwarePackage' => $vendorDir . '/google/apiclient-services/src/CloudAsset/SoftwarePackage.php',
    'Google\\Service\\CloudAsset\\Status' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Status.php',
    'Google\\Service\\CloudAsset\\TableFieldSchema' => $vendorDir . '/google/apiclient-services/src/CloudAsset/TableFieldSchema.php',
    'Google\\Service\\CloudAsset\\TableSchema' => $vendorDir . '/google/apiclient-services/src/CloudAsset/TableSchema.php',
    'Google\\Service\\CloudAsset\\Tag' => $vendorDir . '/google/apiclient-services/src/CloudAsset/Tag.php',
    'Google\\Service\\CloudAsset\\TemporalAsset' => $vendorDir . '/google/apiclient-services/src/CloudAsset/TemporalAsset.php',
    'Google\\Service\\CloudAsset\\TimeWindow' => $vendorDir . '/google/apiclient-services/src/CloudAsset/TimeWindow.php',
    'Google\\Service\\CloudAsset\\UpdateFeedRequest' => $vendorDir . '/google/apiclient-services/src/CloudAsset/UpdateFeedRequest.php',
    'Google\\Service\\CloudAsset\\VersionedPackage' => $vendorDir . '/google/apiclient-services/src/CloudAsset/VersionedPackage.php',
    'Google\\Service\\CloudAsset\\VersionedResource' => $vendorDir . '/google/apiclient-services/src/CloudAsset/VersionedResource.php',
    'Google\\Service\\CloudAsset\\WindowsApplication' => $vendorDir . '/google/apiclient-services/src/CloudAsset/WindowsApplication.php',
    'Google\\Service\\CloudAsset\\WindowsQuickFixEngineeringPackage' => $vendorDir . '/google/apiclient-services/src/CloudAsset/WindowsQuickFixEngineeringPackage.php',
    'Google\\Service\\CloudAsset\\WindowsUpdateCategory' => $vendorDir . '/google/apiclient-services/src/CloudAsset/WindowsUpdateCategory.php',
    'Google\\Service\\CloudAsset\\WindowsUpdatePackage' => $vendorDir . '/google/apiclient-services/src/CloudAsset/WindowsUpdatePackage.php',
    'Google\\Service\\CloudAsset\\ZypperPatch' => $vendorDir . '/google/apiclient-services/src/CloudAsset/ZypperPatch.php',
    'Google\\Service\\CloudBillingBudget' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1Budget' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1Budget.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1BudgetAmount' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1BudgetAmount.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1CustomPeriod' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1CustomPeriod.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1Filter' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1Filter.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1LastPeriodAmount' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1LastPeriodAmount.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1ListBudgetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1ListBudgetsResponse.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1NotificationsRule' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1NotificationsRule.php',
    'Google\\Service\\CloudBillingBudget\\GoogleCloudBillingBudgetsV1ThresholdRule' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleCloudBillingBudgetsV1ThresholdRule.php',
    'Google\\Service\\CloudBillingBudget\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudBillingBudget\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleTypeDate.php',
    'Google\\Service\\CloudBillingBudget\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/GoogleTypeMoney.php',
    'Google\\Service\\CloudBillingBudget\\Resource\\BillingAccounts' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/Resource/BillingAccounts.php',
    'Google\\Service\\CloudBillingBudget\\Resource\\BillingAccountsBudgets' => $vendorDir . '/google/apiclient-services/src/CloudBillingBudget/Resource/BillingAccountsBudgets.php',
    'Google\\Service\\CloudBuild' => $vendorDir . '/google/apiclient-services/src/CloudBuild.php',
    'Google\\Service\\CloudBuild\\AddBitbucketServerConnectedRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/AddBitbucketServerConnectedRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\AddBitbucketServerConnectedRepositoryResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/AddBitbucketServerConnectedRepositoryResponse.php',
    'Google\\Service\\CloudBuild\\ApprovalConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ApprovalConfig.php',
    'Google\\Service\\CloudBuild\\ApprovalResult' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ApprovalResult.php',
    'Google\\Service\\CloudBuild\\ApproveBuildRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ApproveBuildRequest.php',
    'Google\\Service\\CloudBuild\\ArtifactObjects' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ArtifactObjects.php',
    'Google\\Service\\CloudBuild\\ArtifactResult' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ArtifactResult.php',
    'Google\\Service\\CloudBuild\\Artifacts' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Artifacts.php',
    'Google\\Service\\CloudBuild\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/AuditConfig.php',
    'Google\\Service\\CloudBuild\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/AuditLogConfig.php',
    'Google\\Service\\CloudBuild\\BatchCreateBitbucketServerConnectedRepositoriesRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateBitbucketServerConnectedRepositoriesRequest.php',
    'Google\\Service\\CloudBuild\\BatchCreateBitbucketServerConnectedRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateBitbucketServerConnectedRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\BatchCreateBitbucketServerConnectedRepositoriesResponseMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateBitbucketServerConnectedRepositoriesResponseMetadata.php',
    'Google\\Service\\CloudBuild\\BatchCreateGitLabConnectedRepositoriesRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateGitLabConnectedRepositoriesRequest.php',
    'Google\\Service\\CloudBuild\\BatchCreateGitLabConnectedRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateGitLabConnectedRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\BatchCreateGitLabConnectedRepositoriesResponseMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateGitLabConnectedRepositoriesResponseMetadata.php',
    'Google\\Service\\CloudBuild\\BatchCreateRepositoriesRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateRepositoriesRequest.php',
    'Google\\Service\\CloudBuild\\BatchCreateRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BatchCreateRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Binding.php',
    'Google\\Service\\CloudBuild\\BitbucketCloudConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketCloudConfig.php',
    'Google\\Service\\CloudBuild\\BitbucketDataCenterConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketDataCenterConfig.php',
    'Google\\Service\\CloudBuild\\BitbucketServerConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerConfig.php',
    'Google\\Service\\CloudBuild\\BitbucketServerConnectedRepository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerConnectedRepository.php',
    'Google\\Service\\CloudBuild\\BitbucketServerRepository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerRepository.php',
    'Google\\Service\\CloudBuild\\BitbucketServerRepositoryId' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerRepositoryId.php',
    'Google\\Service\\CloudBuild\\BitbucketServerSecrets' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerSecrets.php',
    'Google\\Service\\CloudBuild\\BitbucketServerTriggerConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BitbucketServerTriggerConfig.php',
    'Google\\Service\\CloudBuild\\Build' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Build.php',
    'Google\\Service\\CloudBuild\\BuildApproval' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuildApproval.php',
    'Google\\Service\\CloudBuild\\BuildOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuildOperationMetadata.php',
    'Google\\Service\\CloudBuild\\BuildOptions' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuildOptions.php',
    'Google\\Service\\CloudBuild\\BuildStep' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuildStep.php',
    'Google\\Service\\CloudBuild\\BuildTrigger' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuildTrigger.php',
    'Google\\Service\\CloudBuild\\BuiltImage' => $vendorDir . '/google/apiclient-services/src/CloudBuild/BuiltImage.php',
    'Google\\Service\\CloudBuild\\CancelBuildRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CancelBuildRequest.php',
    'Google\\Service\\CloudBuild\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CancelOperationRequest.php',
    'Google\\Service\\CloudBuild\\Capabilities' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Capabilities.php',
    'Google\\Service\\CloudBuild\\ChildStatusReference' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ChildStatusReference.php',
    'Google\\Service\\CloudBuild\\CloudbuildEmpty' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CloudbuildEmpty.php',
    'Google\\Service\\CloudBuild\\ConnectedRepository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ConnectedRepository.php',
    'Google\\Service\\CloudBuild\\Connection' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Connection.php',
    'Google\\Service\\CloudBuild\\CreateBitbucketServerConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateBitbucketServerConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\CreateBitbucketServerConnectedRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateBitbucketServerConnectedRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\CreateGitHubEnterpriseConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateGitHubEnterpriseConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\CreateGitLabConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateGitLabConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\CreateGitLabConnectedRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateGitLabConnectedRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\CreateRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\CreateWorkerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/CreateWorkerPoolOperationMetadata.php',
    'Google\\Service\\CloudBuild\\DeleteBitbucketServerConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/DeleteBitbucketServerConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\DeleteGitHubEnterpriseConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/DeleteGitHubEnterpriseConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\DeleteGitLabConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/DeleteGitLabConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\DeleteWorkerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/DeleteWorkerPoolOperationMetadata.php',
    'Google\\Service\\CloudBuild\\EmbeddedTask' => $vendorDir . '/google/apiclient-services/src/CloudBuild/EmbeddedTask.php',
    'Google\\Service\\CloudBuild\\EmptyDirVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/EmptyDirVolumeSource.php',
    'Google\\Service\\CloudBuild\\EnvVar' => $vendorDir . '/google/apiclient-services/src/CloudBuild/EnvVar.php',
    'Google\\Service\\CloudBuild\\ExecAction' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ExecAction.php',
    'Google\\Service\\CloudBuild\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Expr.php',
    'Google\\Service\\CloudBuild\\FailureInfo' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FailureInfo.php',
    'Google\\Service\\CloudBuild\\FetchGitRefsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchGitRefsResponse.php',
    'Google\\Service\\CloudBuild\\FetchLinkableRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchLinkableRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\FetchReadTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchReadTokenRequest.php',
    'Google\\Service\\CloudBuild\\FetchReadTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchReadTokenResponse.php',
    'Google\\Service\\CloudBuild\\FetchReadWriteTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchReadWriteTokenRequest.php',
    'Google\\Service\\CloudBuild\\FetchReadWriteTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FetchReadWriteTokenResponse.php',
    'Google\\Service\\CloudBuild\\FileHashes' => $vendorDir . '/google/apiclient-services/src/CloudBuild/FileHashes.php',
    'Google\\Service\\CloudBuild\\GitFileSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitFileSource.php',
    'Google\\Service\\CloudBuild\\GitHubConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitHubConfig.php',
    'Google\\Service\\CloudBuild\\GitHubEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitHubEnterpriseConfig.php',
    'Google\\Service\\CloudBuild\\GitHubEnterpriseSecrets' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitHubEnterpriseSecrets.php',
    'Google\\Service\\CloudBuild\\GitHubEventsConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitHubEventsConfig.php',
    'Google\\Service\\CloudBuild\\GitLabConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabConfig.php',
    'Google\\Service\\CloudBuild\\GitLabConnectedRepository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabConnectedRepository.php',
    'Google\\Service\\CloudBuild\\GitLabEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabEnterpriseConfig.php',
    'Google\\Service\\CloudBuild\\GitLabEventsConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabEventsConfig.php',
    'Google\\Service\\CloudBuild\\GitLabRepository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabRepository.php',
    'Google\\Service\\CloudBuild\\GitLabRepositoryId' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabRepositoryId.php',
    'Google\\Service\\CloudBuild\\GitLabSecrets' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitLabSecrets.php',
    'Google\\Service\\CloudBuild\\GitRepoSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitRepoSource.php',
    'Google\\Service\\CloudBuild\\GitSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GitSource.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV1BuildOptionsPoolOptionWorkerConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV1BuildOptionsPoolOptionWorkerConfig.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV2Condition' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV2Condition.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV2GitLabConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV2GitLabConfig.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV2OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV2OperationMetadata.php',
    'Google\\Service\\CloudBuild\\GoogleDevtoolsCloudbuildV2ServiceDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/GoogleDevtoolsCloudbuildV2ServiceDirectoryConfig.php',
    'Google\\Service\\CloudBuild\\HTTPDelivery' => $vendorDir . '/google/apiclient-services/src/CloudBuild/HTTPDelivery.php',
    'Google\\Service\\CloudBuild\\Hash' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Hash.php',
    'Google\\Service\\CloudBuild\\HttpBody' => $vendorDir . '/google/apiclient-services/src/CloudBuild/HttpBody.php',
    'Google\\Service\\CloudBuild\\HybridPoolConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/HybridPoolConfig.php',
    'Google\\Service\\CloudBuild\\HybridWorkerConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/HybridWorkerConfig.php',
    'Google\\Service\\CloudBuild\\InlineSecret' => $vendorDir . '/google/apiclient-services/src/CloudBuild/InlineSecret.php',
    'Google\\Service\\CloudBuild\\InstallationState' => $vendorDir . '/google/apiclient-services/src/CloudBuild/InstallationState.php',
    'Google\\Service\\CloudBuild\\ListBitbucketServerConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListBitbucketServerConfigsResponse.php',
    'Google\\Service\\CloudBuild\\ListBitbucketServerRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListBitbucketServerRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\ListBuildTriggersResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListBuildTriggersResponse.php',
    'Google\\Service\\CloudBuild\\ListBuildsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListBuildsResponse.php',
    'Google\\Service\\CloudBuild\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListConnectionsResponse.php',
    'Google\\Service\\CloudBuild\\ListGitLabConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListGitLabConfigsResponse.php',
    'Google\\Service\\CloudBuild\\ListGitLabRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListGitLabRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\ListGithubEnterpriseConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListGithubEnterpriseConfigsResponse.php',
    'Google\\Service\\CloudBuild\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListLocationsResponse.php',
    'Google\\Service\\CloudBuild\\ListRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListRepositoriesResponse.php',
    'Google\\Service\\CloudBuild\\ListWorkerPoolsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ListWorkerPoolsResponse.php',
    'Google\\Service\\CloudBuild\\Location' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Location.php',
    'Google\\Service\\CloudBuild\\MavenArtifact' => $vendorDir . '/google/apiclient-services/src/CloudBuild/MavenArtifact.php',
    'Google\\Service\\CloudBuild\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NetworkConfig.php',
    'Google\\Service\\CloudBuild\\Notification' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Notification.php',
    'Google\\Service\\CloudBuild\\NotifierConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NotifierConfig.php',
    'Google\\Service\\CloudBuild\\NotifierMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NotifierMetadata.php',
    'Google\\Service\\CloudBuild\\NotifierSecret' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NotifierSecret.php',
    'Google\\Service\\CloudBuild\\NotifierSecretRef' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NotifierSecretRef.php',
    'Google\\Service\\CloudBuild\\NotifierSpec' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NotifierSpec.php',
    'Google\\Service\\CloudBuild\\NpmPackage' => $vendorDir . '/google/apiclient-services/src/CloudBuild/NpmPackage.php',
    'Google\\Service\\CloudBuild\\OAuthCredential' => $vendorDir . '/google/apiclient-services/src/CloudBuild/OAuthCredential.php',
    'Google\\Service\\CloudBuild\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Operation.php',
    'Google\\Service\\CloudBuild\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/OperationMetadata.php',
    'Google\\Service\\CloudBuild\\Param' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Param.php',
    'Google\\Service\\CloudBuild\\ParamSpec' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ParamSpec.php',
    'Google\\Service\\CloudBuild\\ParamValue' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ParamValue.php',
    'Google\\Service\\CloudBuild\\PipelineRef' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineRef.php',
    'Google\\Service\\CloudBuild\\PipelineResult' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineResult.php',
    'Google\\Service\\CloudBuild\\PipelineRun' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineRun.php',
    'Google\\Service\\CloudBuild\\PipelineRunResult' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineRunResult.php',
    'Google\\Service\\CloudBuild\\PipelineSpec' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineSpec.php',
    'Google\\Service\\CloudBuild\\PipelineTask' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineTask.php',
    'Google\\Service\\CloudBuild\\PipelineWorkspaceDeclaration' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PipelineWorkspaceDeclaration.php',
    'Google\\Service\\CloudBuild\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Policy.php',
    'Google\\Service\\CloudBuild\\PoolOption' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PoolOption.php',
    'Google\\Service\\CloudBuild\\PrivatePoolV1Config' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PrivatePoolV1Config.php',
    'Google\\Service\\CloudBuild\\Probe' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Probe.php',
    'Google\\Service\\CloudBuild\\ProcessAppManifestCallbackOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ProcessAppManifestCallbackOperationMetadata.php',
    'Google\\Service\\CloudBuild\\PropertySpec' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PropertySpec.php',
    'Google\\Service\\CloudBuild\\Provenance' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Provenance.php',
    'Google\\Service\\CloudBuild\\PubsubConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PubsubConfig.php',
    'Google\\Service\\CloudBuild\\PullRequestFilter' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PullRequestFilter.php',
    'Google\\Service\\CloudBuild\\PushFilter' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PushFilter.php',
    'Google\\Service\\CloudBuild\\PythonPackage' => $vendorDir . '/google/apiclient-services/src/CloudBuild/PythonPackage.php',
    'Google\\Service\\CloudBuild\\ReceiveTriggerWebhookResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ReceiveTriggerWebhookResponse.php',
    'Google\\Service\\CloudBuild\\RemoveBitbucketServerConnectedRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RemoveBitbucketServerConnectedRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\RemoveGitLabConnectedRepositoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RemoveGitLabConnectedRepositoryRequest.php',
    'Google\\Service\\CloudBuild\\RepoSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RepoSource.php',
    'Google\\Service\\CloudBuild\\Repository' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Repository.php',
    'Google\\Service\\CloudBuild\\RepositoryEventConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RepositoryEventConfig.php',
    'Google\\Service\\CloudBuild\\Resource\\GithubDotComWebhook' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/GithubDotComWebhook.php',
    'Google\\Service\\CloudBuild\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/Locations.php',
    'Google\\Service\\CloudBuild\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/Operations.php',
    'Google\\Service\\CloudBuild\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/Projects.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsBuilds' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsBuilds.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsGithubEnterpriseConfigs' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsGithubEnterpriseConfigs.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsBitbucketServerConfigs' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsBitbucketServerConfigs.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsBitbucketServerConfigsConnectedRepositories' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsBitbucketServerConfigsConnectedRepositories.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsBitbucketServerConfigsRepos' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsBitbucketServerConfigsRepos.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsBuilds' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsBuilds.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsConnectionsRepositories' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsConnectionsRepositories.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsGitLabConfigs' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsGitLabConfigs.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsGitLabConfigsConnectedRepositories' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsGitLabConfigsConnectedRepositories.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsGitLabConfigsRepos' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsGitLabConfigsRepos.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsGithubEnterpriseConfigs' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsGithubEnterpriseConfigs.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsTriggers' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsTriggers.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsLocationsWorkerPools' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsLocationsWorkerPools.php',
    'Google\\Service\\CloudBuild\\Resource\\ProjectsTriggers' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/ProjectsTriggers.php',
    'Google\\Service\\CloudBuild\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Resource/V1.php',
    'Google\\Service\\CloudBuild\\ResultValue' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ResultValue.php',
    'Google\\Service\\CloudBuild\\Results' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Results.php',
    'Google\\Service\\CloudBuild\\RetryBuildRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RetryBuildRequest.php',
    'Google\\Service\\CloudBuild\\RunBuildTriggerRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RunBuildTriggerRequest.php',
    'Google\\Service\\CloudBuild\\RunWorkflowCustomOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/RunWorkflowCustomOperationMetadata.php',
    'Google\\Service\\CloudBuild\\SMTPDelivery' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SMTPDelivery.php',
    'Google\\Service\\CloudBuild\\Secret' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Secret.php',
    'Google\\Service\\CloudBuild\\SecretManagerSecret' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SecretManagerSecret.php',
    'Google\\Service\\CloudBuild\\SecretVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SecretVolumeSource.php',
    'Google\\Service\\CloudBuild\\Secrets' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Secrets.php',
    'Google\\Service\\CloudBuild\\Security' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Security.php',
    'Google\\Service\\CloudBuild\\SecurityContext' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SecurityContext.php',
    'Google\\Service\\CloudBuild\\ServiceDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/ServiceDirectoryConfig.php',
    'Google\\Service\\CloudBuild\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SetIamPolicyRequest.php',
    'Google\\Service\\CloudBuild\\Sidecar' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Sidecar.php',
    'Google\\Service\\CloudBuild\\SkippedTask' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SkippedTask.php',
    'Google\\Service\\CloudBuild\\SlackDelivery' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SlackDelivery.php',
    'Google\\Service\\CloudBuild\\Source' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Source.php',
    'Google\\Service\\CloudBuild\\SourceProvenance' => $vendorDir . '/google/apiclient-services/src/CloudBuild/SourceProvenance.php',
    'Google\\Service\\CloudBuild\\Status' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Status.php',
    'Google\\Service\\CloudBuild\\Step' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Step.php',
    'Google\\Service\\CloudBuild\\StepRef' => $vendorDir . '/google/apiclient-services/src/CloudBuild/StepRef.php',
    'Google\\Service\\CloudBuild\\StepTemplate' => $vendorDir . '/google/apiclient-services/src/CloudBuild/StepTemplate.php',
    'Google\\Service\\CloudBuild\\StorageSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/StorageSource.php',
    'Google\\Service\\CloudBuild\\StorageSourceManifest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/StorageSourceManifest.php',
    'Google\\Service\\CloudBuild\\TaskRef' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TaskRef.php',
    'Google\\Service\\CloudBuild\\TaskResult' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TaskResult.php',
    'Google\\Service\\CloudBuild\\TaskSpec' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TaskSpec.php',
    'Google\\Service\\CloudBuild\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudBuild\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudBuild\\TimeSpan' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TimeSpan.php',
    'Google\\Service\\CloudBuild\\TimeoutFields' => $vendorDir . '/google/apiclient-services/src/CloudBuild/TimeoutFields.php',
    'Google\\Service\\CloudBuild\\UpdateBitbucketServerConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UpdateBitbucketServerConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\UpdateGitHubEnterpriseConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UpdateGitHubEnterpriseConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\UpdateGitLabConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UpdateGitLabConfigOperationMetadata.php',
    'Google\\Service\\CloudBuild\\UpdateWorkerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UpdateWorkerPoolOperationMetadata.php',
    'Google\\Service\\CloudBuild\\UploadedMavenArtifact' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UploadedMavenArtifact.php',
    'Google\\Service\\CloudBuild\\UploadedNpmPackage' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UploadedNpmPackage.php',
    'Google\\Service\\CloudBuild\\UploadedPythonPackage' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UploadedPythonPackage.php',
    'Google\\Service\\CloudBuild\\UserCredential' => $vendorDir . '/google/apiclient-services/src/CloudBuild/UserCredential.php',
    'Google\\Service\\CloudBuild\\Volume' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Volume.php',
    'Google\\Service\\CloudBuild\\VolumeClaim' => $vendorDir . '/google/apiclient-services/src/CloudBuild/VolumeClaim.php',
    'Google\\Service\\CloudBuild\\VolumeMount' => $vendorDir . '/google/apiclient-services/src/CloudBuild/VolumeMount.php',
    'Google\\Service\\CloudBuild\\VolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudBuild/VolumeSource.php',
    'Google\\Service\\CloudBuild\\Warning' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Warning.php',
    'Google\\Service\\CloudBuild\\WebhookConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WebhookConfig.php',
    'Google\\Service\\CloudBuild\\WhenExpression' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WhenExpression.php',
    'Google\\Service\\CloudBuild\\Worker' => $vendorDir . '/google/apiclient-services/src/CloudBuild/Worker.php',
    'Google\\Service\\CloudBuild\\WorkerConfig' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WorkerConfig.php',
    'Google\\Service\\CloudBuild\\WorkerPool' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WorkerPool.php',
    'Google\\Service\\CloudBuild\\WorkspaceBinding' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WorkspaceBinding.php',
    'Google\\Service\\CloudBuild\\WorkspaceDeclaration' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WorkspaceDeclaration.php',
    'Google\\Service\\CloudBuild\\WorkspacePipelineTaskBinding' => $vendorDir . '/google/apiclient-services/src/CloudBuild/WorkspacePipelineTaskBinding.php',
    'Google\\Service\\CloudCommercePartnerProcurementService' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Account' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Account.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Approval' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Approval.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ApproveAccountRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ApproveAccountRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ApproveEntitlementPlanChangeRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ApproveEntitlementPlanChangeRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ApproveEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ApproveEntitlementRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\CloudcommerceprocurementEmpty' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/CloudcommerceprocurementEmpty.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Consumer' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Consumer.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Entitlement' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Entitlement.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ListAccountsResponse.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ListEntitlementsResponse' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ListEntitlementsResponse.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\RejectAccountRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/RejectAccountRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\RejectEntitlementPlanChangeRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/RejectEntitlementPlanChangeRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\RejectEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/RejectEntitlementRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\ResetAccountRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/ResetAccountRequest.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Resource\\Providers' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Resource/Providers.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Resource\\ProvidersAccounts' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Resource/ProvidersAccounts.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\Resource\\ProvidersEntitlements' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/Resource/ProvidersEntitlements.php',
    'Google\\Service\\CloudCommercePartnerProcurementService\\SuspendEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/CloudCommercePartnerProcurementService/SuspendEntitlementRequest.php',
    'Google\\Service\\CloudComposer' => $vendorDir . '/google/apiclient-services/src/CloudComposer.php',
    'Google\\Service\\CloudComposer\\AirflowMetadataRetentionPolicyConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/AirflowMetadataRetentionPolicyConfig.php',
    'Google\\Service\\CloudComposer\\AllowedIpRange' => $vendorDir . '/google/apiclient-services/src/CloudComposer/AllowedIpRange.php',
    'Google\\Service\\CloudComposer\\CheckUpgradeRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/CheckUpgradeRequest.php',
    'Google\\Service\\CloudComposer\\CheckUpgradeResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/CheckUpgradeResponse.php',
    'Google\\Service\\CloudComposer\\CidrBlock' => $vendorDir . '/google/apiclient-services/src/CloudComposer/CidrBlock.php',
    'Google\\Service\\CloudComposer\\CloudDataLineageIntegration' => $vendorDir . '/google/apiclient-services/src/CloudComposer/CloudDataLineageIntegration.php',
    'Google\\Service\\CloudComposer\\ComposerEmpty' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ComposerEmpty.php',
    'Google\\Service\\CloudComposer\\ComposerWorkload' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ComposerWorkload.php',
    'Google\\Service\\CloudComposer\\ComposerWorkloadStatus' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ComposerWorkloadStatus.php',
    'Google\\Service\\CloudComposer\\DagProcessorResource' => $vendorDir . '/google/apiclient-services/src/CloudComposer/DagProcessorResource.php',
    'Google\\Service\\CloudComposer\\DataRetentionConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/DataRetentionConfig.php',
    'Google\\Service\\CloudComposer\\DatabaseConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/DatabaseConfig.php',
    'Google\\Service\\CloudComposer\\DatabaseFailoverRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/DatabaseFailoverRequest.php',
    'Google\\Service\\CloudComposer\\DatabaseFailoverResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/DatabaseFailoverResponse.php',
    'Google\\Service\\CloudComposer\\Date' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Date.php',
    'Google\\Service\\CloudComposer\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/EncryptionConfig.php',
    'Google\\Service\\CloudComposer\\Environment' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Environment.php',
    'Google\\Service\\CloudComposer\\EnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/EnvironmentConfig.php',
    'Google\\Service\\CloudComposer\\ExecuteAirflowCommandRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ExecuteAirflowCommandRequest.php',
    'Google\\Service\\CloudComposer\\ExecuteAirflowCommandResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ExecuteAirflowCommandResponse.php',
    'Google\\Service\\CloudComposer\\ExitInfo' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ExitInfo.php',
    'Google\\Service\\CloudComposer\\FetchDatabasePropertiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/FetchDatabasePropertiesResponse.php',
    'Google\\Service\\CloudComposer\\IPAllocationPolicy' => $vendorDir . '/google/apiclient-services/src/CloudComposer/IPAllocationPolicy.php',
    'Google\\Service\\CloudComposer\\ImageVersion' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ImageVersion.php',
    'Google\\Service\\CloudComposer\\Line' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Line.php',
    'Google\\Service\\CloudComposer\\ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListEnvironmentsResponse.php',
    'Google\\Service\\CloudComposer\\ListImageVersionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListImageVersionsResponse.php',
    'Google\\Service\\CloudComposer\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListOperationsResponse.php',
    'Google\\Service\\CloudComposer\\ListUserWorkloadsConfigMapsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListUserWorkloadsConfigMapsResponse.php',
    'Google\\Service\\CloudComposer\\ListUserWorkloadsSecretsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListUserWorkloadsSecretsResponse.php',
    'Google\\Service\\CloudComposer\\ListWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ListWorkloadsResponse.php',
    'Google\\Service\\CloudComposer\\LoadSnapshotRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/LoadSnapshotRequest.php',
    'Google\\Service\\CloudComposer\\LoadSnapshotResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/LoadSnapshotResponse.php',
    'Google\\Service\\CloudComposer\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudComposer/MaintenanceWindow.php',
    'Google\\Service\\CloudComposer\\MasterAuthorizedNetworksConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/MasterAuthorizedNetworksConfig.php',
    'Google\\Service\\CloudComposer\\NetworkingConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/NetworkingConfig.php',
    'Google\\Service\\CloudComposer\\NodeConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/NodeConfig.php',
    'Google\\Service\\CloudComposer\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Operation.php',
    'Google\\Service\\CloudComposer\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudComposer/OperationMetadata.php',
    'Google\\Service\\CloudComposer\\PollAirflowCommandRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/PollAirflowCommandRequest.php',
    'Google\\Service\\CloudComposer\\PollAirflowCommandResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/PollAirflowCommandResponse.php',
    'Google\\Service\\CloudComposer\\PrivateClusterConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/PrivateClusterConfig.php',
    'Google\\Service\\CloudComposer\\PrivateEnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/PrivateEnvironmentConfig.php',
    'Google\\Service\\CloudComposer\\RecoveryConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/RecoveryConfig.php',
    'Google\\Service\\CloudComposer\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/Projects.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsEnvironments' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsEnvironments.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsEnvironmentsUserWorkloadsConfigMaps' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsEnvironmentsUserWorkloadsConfigMaps.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsEnvironmentsUserWorkloadsSecrets' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsEnvironmentsUserWorkloadsSecrets.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsEnvironmentsWorkloads' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsEnvironmentsWorkloads.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsImageVersions' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsImageVersions.php',
    'Google\\Service\\CloudComposer\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudComposer\\SaveSnapshotRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/SaveSnapshotRequest.php',
    'Google\\Service\\CloudComposer\\SaveSnapshotResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/SaveSnapshotResponse.php',
    'Google\\Service\\CloudComposer\\ScheduledSnapshotsConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/ScheduledSnapshotsConfig.php',
    'Google\\Service\\CloudComposer\\SchedulerResource' => $vendorDir . '/google/apiclient-services/src/CloudComposer/SchedulerResource.php',
    'Google\\Service\\CloudComposer\\SoftwareConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/SoftwareConfig.php',
    'Google\\Service\\CloudComposer\\Status' => $vendorDir . '/google/apiclient-services/src/CloudComposer/Status.php',
    'Google\\Service\\CloudComposer\\StopAirflowCommandRequest' => $vendorDir . '/google/apiclient-services/src/CloudComposer/StopAirflowCommandRequest.php',
    'Google\\Service\\CloudComposer\\StopAirflowCommandResponse' => $vendorDir . '/google/apiclient-services/src/CloudComposer/StopAirflowCommandResponse.php',
    'Google\\Service\\CloudComposer\\StorageConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/StorageConfig.php',
    'Google\\Service\\CloudComposer\\TaskLogsRetentionConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/TaskLogsRetentionConfig.php',
    'Google\\Service\\CloudComposer\\TriggererResource' => $vendorDir . '/google/apiclient-services/src/CloudComposer/TriggererResource.php',
    'Google\\Service\\CloudComposer\\UserWorkloadsConfigMap' => $vendorDir . '/google/apiclient-services/src/CloudComposer/UserWorkloadsConfigMap.php',
    'Google\\Service\\CloudComposer\\UserWorkloadsSecret' => $vendorDir . '/google/apiclient-services/src/CloudComposer/UserWorkloadsSecret.php',
    'Google\\Service\\CloudComposer\\WebServerConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/WebServerConfig.php',
    'Google\\Service\\CloudComposer\\WebServerNetworkAccessControl' => $vendorDir . '/google/apiclient-services/src/CloudComposer/WebServerNetworkAccessControl.php',
    'Google\\Service\\CloudComposer\\WebServerResource' => $vendorDir . '/google/apiclient-services/src/CloudComposer/WebServerResource.php',
    'Google\\Service\\CloudComposer\\WorkerResource' => $vendorDir . '/google/apiclient-services/src/CloudComposer/WorkerResource.php',
    'Google\\Service\\CloudComposer\\WorkloadsConfig' => $vendorDir . '/google/apiclient-services/src/CloudComposer/WorkloadsConfig.php',
    'Google\\Service\\CloudControlsPartnerService' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService.php',
    'Google\\Service\\CloudControlsPartnerService\\AccessApprovalRequest' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/AccessApprovalRequest.php',
    'Google\\Service\\CloudControlsPartnerService\\AccessReason' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/AccessReason.php',
    'Google\\Service\\CloudControlsPartnerService\\ConnectionError' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/ConnectionError.php',
    'Google\\Service\\CloudControlsPartnerService\\Console' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Console.php',
    'Google\\Service\\CloudControlsPartnerService\\Customer' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Customer.php',
    'Google\\Service\\CloudControlsPartnerService\\CustomerOnboardingState' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/CustomerOnboardingState.php',
    'Google\\Service\\CloudControlsPartnerService\\CustomerOnboardingStep' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/CustomerOnboardingStep.php',
    'Google\\Service\\CloudControlsPartnerService\\EkmConnection' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/EkmConnection.php',
    'Google\\Service\\CloudControlsPartnerService\\EkmConnections' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/EkmConnections.php',
    'Google\\Service\\CloudControlsPartnerService\\EkmMetadata' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/EkmMetadata.php',
    'Google\\Service\\CloudControlsPartnerService\\Gcloud' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Gcloud.php',
    'Google\\Service\\CloudControlsPartnerService\\Instructions' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Instructions.php',
    'Google\\Service\\CloudControlsPartnerService\\ListAccessApprovalRequestsResponse' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/ListAccessApprovalRequestsResponse.php',
    'Google\\Service\\CloudControlsPartnerService\\ListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/ListCustomersResponse.php',
    'Google\\Service\\CloudControlsPartnerService\\ListViolationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/ListViolationsResponse.php',
    'Google\\Service\\CloudControlsPartnerService\\ListWorkloadsResponse' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/ListWorkloadsResponse.php',
    'Google\\Service\\CloudControlsPartnerService\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/OperationMetadata.php',
    'Google\\Service\\CloudControlsPartnerService\\Partner' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Partner.php',
    'Google\\Service\\CloudControlsPartnerService\\PartnerPermissions' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/PartnerPermissions.php',
    'Google\\Service\\CloudControlsPartnerService\\Remediation' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Remediation.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/Organizations.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/OrganizationsLocations.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\OrganizationsLocationsCustomers' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/OrganizationsLocationsCustomers.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\OrganizationsLocationsCustomersWorkloads' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/OrganizationsLocationsCustomersWorkloads.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\OrganizationsLocationsCustomersWorkloadsAccessApprovalRequests' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/OrganizationsLocationsCustomersWorkloadsAccessApprovalRequests.php',
    'Google\\Service\\CloudControlsPartnerService\\Resource\\OrganizationsLocationsCustomersWorkloadsViolations' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Resource/OrganizationsLocationsCustomersWorkloadsViolations.php',
    'Google\\Service\\CloudControlsPartnerService\\Sku' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Sku.php',
    'Google\\Service\\CloudControlsPartnerService\\Violation' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Violation.php',
    'Google\\Service\\CloudControlsPartnerService\\Workload' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/Workload.php',
    'Google\\Service\\CloudControlsPartnerService\\WorkloadOnboardingState' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/WorkloadOnboardingState.php',
    'Google\\Service\\CloudControlsPartnerService\\WorkloadOnboardingStep' => $vendorDir . '/google/apiclient-services/src/CloudControlsPartnerService/WorkloadOnboardingStep.php',
    'Google\\Service\\CloudDataplex' => $vendorDir . '/google/apiclient-services/src/CloudDataplex.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosAssetLocation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosAssetLocation.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosAssetLocationIsolationExpectations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosAssetLocationIsolationExpectations.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosAssetLocationIsolationExpectationsRequirementOverride' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosAssetLocationIsolationExpectationsRequirementOverride.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosBlobstoreLocation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosBlobstoreLocation.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosCloudAsset' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosCloudAsset.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosCloudAssetComposition' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosCloudAssetComposition.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosDirectLocationAssignment' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosDirectLocationAssignment.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosExtraParameter' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosExtraParameter.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosLocationAssignment' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosLocationAssignment.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosLocationData' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosLocationData.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosPlacerLocation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosPlacerLocation.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosRegionalMigDistributionPolicy' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosRegionalMigDistributionPolicy.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosSpannerLocation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosSpannerLocation.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosTenantProjectProxy' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosTenantProjectProxy.php',
    'Google\\Service\\CloudDataplex\\CloudReliabilityZicyWs3DataplaneProtosZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/CloudReliabilityZicyWs3DataplaneProtosZoneConfiguration.php',
    'Google\\Service\\CloudDataplex\\DataplexEmpty' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/DataplexEmpty.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Action' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Action.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionFailedSecurityPolicyApply' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionFailedSecurityPolicyApply.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionIncompatibleDataSchema' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionIncompatibleDataSchema.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionInvalidDataFormat' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionInvalidDataFormat.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionInvalidDataOrganization' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionInvalidDataOrganization.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionInvalidDataPartition' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionInvalidDataPartition.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionMissingData' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionMissingData.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionMissingResource' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionMissingResource.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ActionUnauthorizedResource' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ActionUnauthorizedResource.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Aspect' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Aspect.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectSource' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectSource.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectType' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectType.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectTypeAuthorization' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectTypeAuthorization.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectTypeMetadataTemplate' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectTypeMetadataTemplate.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectTypeMetadataTemplateAnnotations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectTypeMetadataTemplateAnnotations.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectTypeMetadataTemplateConstraints' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectTypeMetadataTemplateConstraints.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AspectTypeMetadataTemplateEnumValue' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AspectTypeMetadataTemplateEnumValue.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Asset' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Asset.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetDiscoverySpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetDiscoverySpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetDiscoveryStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetDiscoveryStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetDiscoveryStatusStats' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetDiscoveryStatusStats.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetResourceSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetResourceSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetResourceStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetResourceStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetSecurityStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetSecurityStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1AssetStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1AssetStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1CancelJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1CancelJobRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1CancelMetadataJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1CancelMetadataJobRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Content' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Content.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ContentNotebook' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ContentNotebook.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ContentSqlScript' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ContentSqlScript.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataAccessSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataAccessSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataAttribute' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataAttribute.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataAttributeBinding' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataAttributeBinding.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataAttributeBindingPath' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataAttributeBindingPath.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataDocumentationResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataDocumentationResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataDocumentationResultQuery' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataDocumentationResultQuery.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataDocumentationSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataDocumentationSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultPostScanActionsResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultPostScanActionsResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultPostScanActionsResultBigQueryExportResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultPostScanActionsResultBigQueryExportResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfile' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfile.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileField' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileField.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoStringFieldInfo' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoStringFieldInfo.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileSpecPostScanActions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileSpecPostScanActions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileSpecPostScanActionsBigQueryExport' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileSpecPostScanActionsBigQueryExport.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataProfileSpecSelectedFields' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataProfileSpecSelectedFields.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityColumnResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityColumnResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityDimension' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityDimension.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityDimensionResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityDimensionResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityResultPostScanActionsResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityResultPostScanActionsResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityResultPostScanActionsResultBigQueryExportResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityResultPostScanActionsResultBigQueryExportResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRule' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRule.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleNonNullExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleNonNullExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleRangeExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleRangeExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleRegexExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleRegexExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleRowConditionExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleRowConditionExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleSetExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleSetExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleSqlAssertion' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleSqlAssertion.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleStatisticRangeExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleStatisticRangeExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleTableConditionExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleTableConditionExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityRuleUniquenessExpectation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityRuleUniquenessExpectation.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualityScanRuleResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualityScanRuleResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsBigQueryExport' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsBigQueryExport.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScan' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScan.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventDataProfileResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventDataProfileResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventDataQualityResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventDataQualityResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventPostScanActionsResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventPostScanActionsResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanEventPostScanActionsResultBigQueryExportResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanEventPostScanActionsResultBigQueryExportResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanExecutionSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanExecutionSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanExecutionStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanExecutionStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataScanJob' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataScanJob.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataSource' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataSource.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DataTaxonomy' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DataTaxonomy.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DiscoveryEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DiscoveryEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DiscoveryEventActionDetails' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DiscoveryEventActionDetails.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DiscoveryEventConfigDetails' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DiscoveryEventConfigDetails.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DiscoveryEventEntityDetails' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DiscoveryEventEntityDetails.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1DiscoveryEventPartitionDetails' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1DiscoveryEventPartitionDetails.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Entity' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Entity.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntityCompatibilityStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntityCompatibilityStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntityCompatibilityStatusCompatibility' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntityCompatibilityStatusCompatibility.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Entry' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Entry.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntryGroup' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntryGroup.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntrySource' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntrySource.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntrySourceAncestor' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntrySourceAncestor.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntryType' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntryType.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntryTypeAspectInfo' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntryTypeAspectInfo.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EntryTypeAuthorization' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EntryTypeAuthorization.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Environment' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Environment.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentEndpoints' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentEndpoints.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentInfrastructureSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentInfrastructureSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentInfrastructureSpecComputeResources' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentInfrastructureSpecComputeResources.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentInfrastructureSpecOsImageRuntime' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentInfrastructureSpecOsImageRuntime.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentSessionSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentSessionSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1EnvironmentSessionStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1EnvironmentSessionStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1GenerateDataQualityRulesRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1GenerateDataQualityRulesRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1GenerateDataQualityRulesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1GenerateDataQualityRulesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1GovernanceEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1GovernanceEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1GovernanceEventEntity' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1GovernanceEventEntity.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ImportItem' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ImportItem.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Job' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Job.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1JobEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1JobEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Lake' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Lake.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1LakeMetastore' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1LakeMetastore.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1LakeMetastoreStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1LakeMetastoreStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListActionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListActionsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListAspectTypesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListAspectTypesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListAssetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListAssetsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListContentResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListContentResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListDataAttributeBindingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListDataAttributeBindingsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListDataAttributesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListDataAttributesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListDataScanJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListDataScanJobsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListDataScansResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListDataScansResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListDataTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListDataTaxonomiesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListEntitiesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListEntriesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListEntryGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListEntryGroupsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListEntryTypesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListEntryTypesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListEnvironmentsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListJobsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListLakesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListLakesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListMetadataJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListMetadataJobsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListPartitionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListPartitionsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListSessionsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListTasksResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListTasksResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ListZonesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ListZonesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJob' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJob.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobEventImportResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobEventImportResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobImportJobResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobImportJobResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobImportJobSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobImportJobSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1MetadataJobStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1MetadataJobStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1OperationMetadata.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Partition' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Partition.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ResourceAccessSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ResourceAccessSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1RunDataScanRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1RunDataScanRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1RunDataScanResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1RunDataScanResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1RunTaskRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1RunTaskRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1RunTaskResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1RunTaskResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ScannedData' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ScannedData.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ScannedDataIncrementalField' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ScannedDataIncrementalField.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Schema' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Schema.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SchemaPartitionField' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SchemaPartitionField.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SchemaSchemaField' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SchemaSchemaField.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SearchEntriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SearchEntriesResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SearchEntriesResult' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SearchEntriesResult.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SearchEntriesResultSnippets' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SearchEntriesResultSnippets.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Session' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Session.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SessionEvent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SessionEvent.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1SessionEventQueryDetail' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1SessionEventQueryDetail.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1StorageAccess' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1StorageAccess.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1StorageFormat' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1StorageFormat.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1StorageFormatCsvOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1StorageFormatCsvOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1StorageFormatIcebergOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1StorageFormatIcebergOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1StorageFormatJsonOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1StorageFormatJsonOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Task' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Task.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskExecutionSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskExecutionSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskExecutionStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskExecutionStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskInfrastructureSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskInfrastructureSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskInfrastructureSpecBatchComputeResources' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskInfrastructureSpecBatchComputeResources.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskInfrastructureSpecContainerImageRuntime' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskInfrastructureSpecContainerImageRuntime.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskNotebookTaskConfig' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskNotebookTaskConfig.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskSparkTaskConfig' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskSparkTaskConfig.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TaskTriggerSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TaskTriggerSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Trigger' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Trigger.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TriggerOnDemand' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TriggerOnDemand.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1TriggerSchedule' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1TriggerSchedule.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1Zone' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1Zone.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ZoneDiscoverySpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ZoneDiscoverySpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudDataplexV1ZoneResourceSpec' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudDataplexV1ZoneResourceSpec.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleCloudLocationLocation.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1AuditConfig.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1Binding.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1Policy.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\CloudDataplex\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\CloudDataplex\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleLongrunningOperation.php',
    'Google\\Service\\CloudDataplex\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleRpcStatus.php',
    'Google\\Service\\CloudDataplex\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/GoogleTypeExpr.php',
    'Google\\Service\\CloudDataplex\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/Organizations.php',
    'Google\\Service\\CloudDataplex\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/OrganizationsLocations.php',
    'Google\\Service\\CloudDataplex\\Resource\\OrganizationsLocationsEncryptionConfigs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/OrganizationsLocationsEncryptionConfigs.php',
    'Google\\Service\\CloudDataplex\\Resource\\OrganizationsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/OrganizationsLocationsOperations.php',
    'Google\\Service\\CloudDataplex\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/Projects.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsAspectTypes' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsAspectTypes.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsDataAttributeBindings' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsDataAttributeBindings.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsDataScans' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsDataScans.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsDataScansJobs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsDataScansJobs.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsDataTaxonomies' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsDataTaxonomies.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsDataTaxonomiesAttributes' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsDataTaxonomiesAttributes.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsEntryGroups' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsEntryGroups.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsEntryGroupsEntries' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsEntryGroupsEntries.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsEntryLinkTypes' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsEntryLinkTypes.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsEntryTypes' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsEntryTypes.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsGlossaries' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsGlossaries.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsGlossariesCategories' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsGlossariesCategories.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsGlossariesTerms' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsGlossariesTerms.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsGovernanceRules' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsGovernanceRules.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakes' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakes.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesActions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesActions.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesContent' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesContent.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesContentitems' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesContentitems.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesEnvironments' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesEnvironments.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesEnvironmentsSessions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesEnvironmentsSessions.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesTasks' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesTasks.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesTasksJobs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesTasksJobs.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZones' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZones.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZonesActions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZonesActions.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZonesAssets' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZonesAssets.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZonesAssetsActions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZonesAssetsActions.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZonesEntities' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZonesEntities.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsLakesZonesEntitiesPartitions' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsLakesZonesEntitiesPartitions.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsMetadataJobs' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsMetadataJobs.php',
    'Google\\Service\\CloudDataplex\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudDataplex/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudDebugger' => $vendorDir . '/google/apiclient-services/src/CloudDebugger.php',
    'Google\\Service\\CloudDebugger\\AliasContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/AliasContext.php',
    'Google\\Service\\CloudDebugger\\Breakpoint' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Breakpoint.php',
    'Google\\Service\\CloudDebugger\\CloudRepoSourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/CloudRepoSourceContext.php',
    'Google\\Service\\CloudDebugger\\CloudWorkspaceId' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/CloudWorkspaceId.php',
    'Google\\Service\\CloudDebugger\\CloudWorkspaceSourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/CloudWorkspaceSourceContext.php',
    'Google\\Service\\CloudDebugger\\ClouddebuggerEmpty' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ClouddebuggerEmpty.php',
    'Google\\Service\\CloudDebugger\\Debuggee' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Debuggee.php',
    'Google\\Service\\CloudDebugger\\ExtendedSourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ExtendedSourceContext.php',
    'Google\\Service\\CloudDebugger\\FormatMessage' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/FormatMessage.php',
    'Google\\Service\\CloudDebugger\\GerritSourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/GerritSourceContext.php',
    'Google\\Service\\CloudDebugger\\GetBreakpointResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/GetBreakpointResponse.php',
    'Google\\Service\\CloudDebugger\\GitSourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/GitSourceContext.php',
    'Google\\Service\\CloudDebugger\\ListActiveBreakpointsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ListActiveBreakpointsResponse.php',
    'Google\\Service\\CloudDebugger\\ListBreakpointsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ListBreakpointsResponse.php',
    'Google\\Service\\CloudDebugger\\ListDebuggeesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ListDebuggeesResponse.php',
    'Google\\Service\\CloudDebugger\\ProjectRepoId' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/ProjectRepoId.php',
    'Google\\Service\\CloudDebugger\\RegisterDebuggeeRequest' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/RegisterDebuggeeRequest.php',
    'Google\\Service\\CloudDebugger\\RegisterDebuggeeResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/RegisterDebuggeeResponse.php',
    'Google\\Service\\CloudDebugger\\RepoId' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/RepoId.php',
    'Google\\Service\\CloudDebugger\\Resource\\Controller' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/Controller.php',
    'Google\\Service\\CloudDebugger\\Resource\\ControllerDebuggees' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/ControllerDebuggees.php',
    'Google\\Service\\CloudDebugger\\Resource\\ControllerDebuggeesBreakpoints' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/ControllerDebuggeesBreakpoints.php',
    'Google\\Service\\CloudDebugger\\Resource\\Debugger' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/Debugger.php',
    'Google\\Service\\CloudDebugger\\Resource\\DebuggerDebuggees' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/DebuggerDebuggees.php',
    'Google\\Service\\CloudDebugger\\Resource\\DebuggerDebuggeesBreakpoints' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Resource/DebuggerDebuggeesBreakpoints.php',
    'Google\\Service\\CloudDebugger\\SetBreakpointResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/SetBreakpointResponse.php',
    'Google\\Service\\CloudDebugger\\SourceContext' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/SourceContext.php',
    'Google\\Service\\CloudDebugger\\SourceLocation' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/SourceLocation.php',
    'Google\\Service\\CloudDebugger\\StackFrame' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/StackFrame.php',
    'Google\\Service\\CloudDebugger\\StatusMessage' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/StatusMessage.php',
    'Google\\Service\\CloudDebugger\\UpdateActiveBreakpointRequest' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/UpdateActiveBreakpointRequest.php',
    'Google\\Service\\CloudDebugger\\UpdateActiveBreakpointResponse' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/UpdateActiveBreakpointResponse.php',
    'Google\\Service\\CloudDebugger\\Variable' => $vendorDir . '/google/apiclient-services/src/CloudDebugger/Variable.php',
    'Google\\Service\\CloudDeploy' => $vendorDir . '/google/apiclient-services/src/CloudDeploy.php',
    'Google\\Service\\CloudDeploy\\AbandonReleaseRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AbandonReleaseRequest.php',
    'Google\\Service\\CloudDeploy\\AbandonReleaseResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AbandonReleaseResponse.php',
    'Google\\Service\\CloudDeploy\\AdvanceChildRolloutJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceChildRolloutJob.php',
    'Google\\Service\\CloudDeploy\\AdvanceChildRolloutJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceChildRolloutJobRun.php',
    'Google\\Service\\CloudDeploy\\AdvanceRolloutOperation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceRolloutOperation.php',
    'Google\\Service\\CloudDeploy\\AdvanceRolloutRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceRolloutRequest.php',
    'Google\\Service\\CloudDeploy\\AdvanceRolloutResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceRolloutResponse.php',
    'Google\\Service\\CloudDeploy\\AdvanceRolloutRule' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AdvanceRolloutRule.php',
    'Google\\Service\\CloudDeploy\\AnthosCluster' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AnthosCluster.php',
    'Google\\Service\\CloudDeploy\\ApproveRolloutRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ApproveRolloutRequest.php',
    'Google\\Service\\CloudDeploy\\ApproveRolloutResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ApproveRolloutResponse.php',
    'Google\\Service\\CloudDeploy\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AuditConfig.php',
    'Google\\Service\\CloudDeploy\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AuditLogConfig.php',
    'Google\\Service\\CloudDeploy\\Automation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Automation.php',
    'Google\\Service\\CloudDeploy\\AutomationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationEvent.php',
    'Google\\Service\\CloudDeploy\\AutomationResourceSelector' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationResourceSelector.php',
    'Google\\Service\\CloudDeploy\\AutomationRolloutMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationRolloutMetadata.php',
    'Google\\Service\\CloudDeploy\\AutomationRule' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationRule.php',
    'Google\\Service\\CloudDeploy\\AutomationRuleCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationRuleCondition.php',
    'Google\\Service\\CloudDeploy\\AutomationRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationRun.php',
    'Google\\Service\\CloudDeploy\\AutomationRunEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/AutomationRunEvent.php',
    'Google\\Service\\CloudDeploy\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Binding.php',
    'Google\\Service\\CloudDeploy\\BuildArtifact' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/BuildArtifact.php',
    'Google\\Service\\CloudDeploy\\Canary' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Canary.php',
    'Google\\Service\\CloudDeploy\\CanaryDeployment' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CanaryDeployment.php',
    'Google\\Service\\CloudDeploy\\CancelAutomationRunRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CancelAutomationRunRequest.php',
    'Google\\Service\\CloudDeploy\\CancelAutomationRunResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CancelAutomationRunResponse.php',
    'Google\\Service\\CloudDeploy\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CancelOperationRequest.php',
    'Google\\Service\\CloudDeploy\\CancelRolloutRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CancelRolloutRequest.php',
    'Google\\Service\\CloudDeploy\\CancelRolloutResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CancelRolloutResponse.php',
    'Google\\Service\\CloudDeploy\\ChildRolloutJobs' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ChildRolloutJobs.php',
    'Google\\Service\\CloudDeploy\\CloudRunConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CloudRunConfig.php',
    'Google\\Service\\CloudDeploy\\CloudRunLocation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CloudRunLocation.php',
    'Google\\Service\\CloudDeploy\\CloudRunMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CloudRunMetadata.php',
    'Google\\Service\\CloudDeploy\\CloudRunRenderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CloudRunRenderMetadata.php',
    'Google\\Service\\CloudDeploy\\ClouddeployEmpty' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ClouddeployEmpty.php',
    'Google\\Service\\CloudDeploy\\Config' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Config.php',
    'Google\\Service\\CloudDeploy\\CreateChildRolloutJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CreateChildRolloutJob.php',
    'Google\\Service\\CloudDeploy\\CreateChildRolloutJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CreateChildRolloutJobRun.php',
    'Google\\Service\\CloudDeploy\\CustomCanaryDeployment' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomCanaryDeployment.php',
    'Google\\Service\\CloudDeploy\\CustomMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomMetadata.php',
    'Google\\Service\\CloudDeploy\\CustomTarget' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomTarget.php',
    'Google\\Service\\CloudDeploy\\CustomTargetDeployMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomTargetDeployMetadata.php',
    'Google\\Service\\CloudDeploy\\CustomTargetSkaffoldActions' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomTargetSkaffoldActions.php',
    'Google\\Service\\CloudDeploy\\CustomTargetType' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomTargetType.php',
    'Google\\Service\\CloudDeploy\\CustomTargetTypeNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/CustomTargetTypeNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\Date' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Date.php',
    'Google\\Service\\CloudDeploy\\DefaultPool' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DefaultPool.php',
    'Google\\Service\\CloudDeploy\\DeliveryPipeline' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeliveryPipeline.php',
    'Google\\Service\\CloudDeploy\\DeliveryPipelineNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeliveryPipelineNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\DeployArtifact' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployArtifact.php',
    'Google\\Service\\CloudDeploy\\DeployJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployJob.php',
    'Google\\Service\\CloudDeploy\\DeployJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployJobRun.php',
    'Google\\Service\\CloudDeploy\\DeployJobRunMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployJobRunMetadata.php',
    'Google\\Service\\CloudDeploy\\DeployParameters' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployParameters.php',
    'Google\\Service\\CloudDeploy\\DeployPolicyNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeployPolicyNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\DeploymentJobs' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/DeploymentJobs.php',
    'Google\\Service\\CloudDeploy\\ExecutionConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ExecutionConfig.php',
    'Google\\Service\\CloudDeploy\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Expr.php',
    'Google\\Service\\CloudDeploy\\GatewayServiceMesh' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/GatewayServiceMesh.php',
    'Google\\Service\\CloudDeploy\\GkeCluster' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/GkeCluster.php',
    'Google\\Service\\CloudDeploy\\IgnoreJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/IgnoreJobRequest.php',
    'Google\\Service\\CloudDeploy\\IgnoreJobResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/IgnoreJobResponse.php',
    'Google\\Service\\CloudDeploy\\Job' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Job.php',
    'Google\\Service\\CloudDeploy\\JobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/JobRun.php',
    'Google\\Service\\CloudDeploy\\JobRunNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/JobRunNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\KubernetesConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/KubernetesConfig.php',
    'Google\\Service\\CloudDeploy\\ListAutomationRunsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListAutomationRunsResponse.php',
    'Google\\Service\\CloudDeploy\\ListAutomationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListAutomationsResponse.php',
    'Google\\Service\\CloudDeploy\\ListCustomTargetTypesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListCustomTargetTypesResponse.php',
    'Google\\Service\\CloudDeploy\\ListDeliveryPipelinesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListDeliveryPipelinesResponse.php',
    'Google\\Service\\CloudDeploy\\ListJobRunsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListJobRunsResponse.php',
    'Google\\Service\\CloudDeploy\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListLocationsResponse.php',
    'Google\\Service\\CloudDeploy\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListOperationsResponse.php',
    'Google\\Service\\CloudDeploy\\ListReleasesResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListReleasesResponse.php',
    'Google\\Service\\CloudDeploy\\ListRolloutsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListRolloutsResponse.php',
    'Google\\Service\\CloudDeploy\\ListTargetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ListTargetsResponse.php',
    'Google\\Service\\CloudDeploy\\Location' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Location.php',
    'Google\\Service\\CloudDeploy\\Metadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Metadata.php',
    'Google\\Service\\CloudDeploy\\MultiTarget' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/MultiTarget.php',
    'Google\\Service\\CloudDeploy\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Operation.php',
    'Google\\Service\\CloudDeploy\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/OperationMetadata.php',
    'Google\\Service\\CloudDeploy\\Phase' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Phase.php',
    'Google\\Service\\CloudDeploy\\PhaseArtifact' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PhaseArtifact.php',
    'Google\\Service\\CloudDeploy\\PhaseConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PhaseConfig.php',
    'Google\\Service\\CloudDeploy\\PipelineCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PipelineCondition.php',
    'Google\\Service\\CloudDeploy\\PipelineReadyCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PipelineReadyCondition.php',
    'Google\\Service\\CloudDeploy\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Policy.php',
    'Google\\Service\\CloudDeploy\\Postdeploy' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Postdeploy.php',
    'Google\\Service\\CloudDeploy\\PostdeployJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PostdeployJob.php',
    'Google\\Service\\CloudDeploy\\PostdeployJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PostdeployJobRun.php',
    'Google\\Service\\CloudDeploy\\Predeploy' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Predeploy.php',
    'Google\\Service\\CloudDeploy\\PredeployJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PredeployJob.php',
    'Google\\Service\\CloudDeploy\\PredeployJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PredeployJobRun.php',
    'Google\\Service\\CloudDeploy\\PrivatePool' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PrivatePool.php',
    'Google\\Service\\CloudDeploy\\PromoteReleaseOperation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PromoteReleaseOperation.php',
    'Google\\Service\\CloudDeploy\\PromoteReleaseRule' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/PromoteReleaseRule.php',
    'Google\\Service\\CloudDeploy\\Release' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Release.php',
    'Google\\Service\\CloudDeploy\\ReleaseCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ReleaseCondition.php',
    'Google\\Service\\CloudDeploy\\ReleaseNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ReleaseNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\ReleaseReadyCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ReleaseReadyCondition.php',
    'Google\\Service\\CloudDeploy\\ReleaseRenderEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ReleaseRenderEvent.php',
    'Google\\Service\\CloudDeploy\\RenderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RenderMetadata.php',
    'Google\\Service\\CloudDeploy\\RepairMode' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RepairMode.php',
    'Google\\Service\\CloudDeploy\\RepairPhase' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RepairPhase.php',
    'Google\\Service\\CloudDeploy\\RepairRolloutOperation' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RepairRolloutOperation.php',
    'Google\\Service\\CloudDeploy\\RepairRolloutRule' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RepairRolloutRule.php',
    'Google\\Service\\CloudDeploy\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/Projects.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsCustomTargetTypes' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsCustomTargetTypes.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelines' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelines.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelinesAutomationRuns' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelinesAutomationRuns.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelinesAutomations' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelinesAutomations.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelinesReleases' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelinesReleases.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelinesReleasesRollouts' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelinesReleasesRollouts.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsDeliveryPipelinesReleasesRolloutsJobRuns' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsDeliveryPipelinesReleasesRolloutsJobRuns.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudDeploy\\Resource\\ProjectsLocationsTargets' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Resource/ProjectsLocationsTargets.php',
    'Google\\Service\\CloudDeploy\\Retry' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Retry.php',
    'Google\\Service\\CloudDeploy\\RetryAttempt' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RetryAttempt.php',
    'Google\\Service\\CloudDeploy\\RetryJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RetryJobRequest.php',
    'Google\\Service\\CloudDeploy\\RetryJobResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RetryJobResponse.php',
    'Google\\Service\\CloudDeploy\\RetryPhase' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RetryPhase.php',
    'Google\\Service\\CloudDeploy\\Rollback' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Rollback.php',
    'Google\\Service\\CloudDeploy\\RollbackAttempt' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RollbackAttempt.php',
    'Google\\Service\\CloudDeploy\\RollbackTargetConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RollbackTargetConfig.php',
    'Google\\Service\\CloudDeploy\\RollbackTargetRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RollbackTargetRequest.php',
    'Google\\Service\\CloudDeploy\\RollbackTargetResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RollbackTargetResponse.php',
    'Google\\Service\\CloudDeploy\\Rollout' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Rollout.php',
    'Google\\Service\\CloudDeploy\\RolloutNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RolloutNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\RolloutUpdateEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RolloutUpdateEvent.php',
    'Google\\Service\\CloudDeploy\\RuntimeConfig' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/RuntimeConfig.php',
    'Google\\Service\\CloudDeploy\\SerialPipeline' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SerialPipeline.php',
    'Google\\Service\\CloudDeploy\\ServiceNetworking' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/ServiceNetworking.php',
    'Google\\Service\\CloudDeploy\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SetIamPolicyRequest.php',
    'Google\\Service\\CloudDeploy\\SkaffoldGCBRepoSource' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldGCBRepoSource.php',
    'Google\\Service\\CloudDeploy\\SkaffoldGCSSource' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldGCSSource.php',
    'Google\\Service\\CloudDeploy\\SkaffoldGitSource' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldGitSource.php',
    'Google\\Service\\CloudDeploy\\SkaffoldModules' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldModules.php',
    'Google\\Service\\CloudDeploy\\SkaffoldSupportedCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldSupportedCondition.php',
    'Google\\Service\\CloudDeploy\\SkaffoldVersion' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/SkaffoldVersion.php',
    'Google\\Service\\CloudDeploy\\Stage' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Stage.php',
    'Google\\Service\\CloudDeploy\\Standard' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Standard.php',
    'Google\\Service\\CloudDeploy\\Status' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Status.php',
    'Google\\Service\\CloudDeploy\\Strategy' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Strategy.php',
    'Google\\Service\\CloudDeploy\\Target' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/Target.php',
    'Google\\Service\\CloudDeploy\\TargetArtifact' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetArtifact.php',
    'Google\\Service\\CloudDeploy\\TargetAttribute' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetAttribute.php',
    'Google\\Service\\CloudDeploy\\TargetNotificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetNotificationEvent.php',
    'Google\\Service\\CloudDeploy\\TargetRender' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetRender.php',
    'Google\\Service\\CloudDeploy\\TargetsPresentCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetsPresentCondition.php',
    'Google\\Service\\CloudDeploy\\TargetsTypeCondition' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TargetsTypeCondition.php',
    'Google\\Service\\CloudDeploy\\TerminateJobRunRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TerminateJobRunRequest.php',
    'Google\\Service\\CloudDeploy\\TerminateJobRunResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TerminateJobRunResponse.php',
    'Google\\Service\\CloudDeploy\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudDeploy\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudDeploy\\VerifyJob' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/VerifyJob.php',
    'Google\\Service\\CloudDeploy\\VerifyJobRun' => $vendorDir . '/google/apiclient-services/src/CloudDeploy/VerifyJobRun.php',
    'Google\\Service\\CloudDomains' => $vendorDir . '/google/apiclient-services/src/CloudDomains.php',
    'Google\\Service\\CloudDomains\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudDomains/AuditConfig.php',
    'Google\\Service\\CloudDomains\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudDomains/AuditLogConfig.php',
    'Google\\Service\\CloudDomains\\AuthorizationCode' => $vendorDir . '/google/apiclient-services/src/CloudDomains/AuthorizationCode.php',
    'Google\\Service\\CloudDomains\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Binding.php',
    'Google\\Service\\CloudDomains\\ConfigureContactSettingsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ConfigureContactSettingsRequest.php',
    'Google\\Service\\CloudDomains\\ConfigureDnsSettingsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ConfigureDnsSettingsRequest.php',
    'Google\\Service\\CloudDomains\\ConfigureManagementSettingsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ConfigureManagementSettingsRequest.php',
    'Google\\Service\\CloudDomains\\Contact' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Contact.php',
    'Google\\Service\\CloudDomains\\ContactSettings' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ContactSettings.php',
    'Google\\Service\\CloudDomains\\CustomDns' => $vendorDir . '/google/apiclient-services/src/CloudDomains/CustomDns.php',
    'Google\\Service\\CloudDomains\\DnsSettings' => $vendorDir . '/google/apiclient-services/src/CloudDomains/DnsSettings.php',
    'Google\\Service\\CloudDomains\\Domain' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Domain.php',
    'Google\\Service\\CloudDomains\\DomainForwarding' => $vendorDir . '/google/apiclient-services/src/CloudDomains/DomainForwarding.php',
    'Google\\Service\\CloudDomains\\DsRecord' => $vendorDir . '/google/apiclient-services/src/CloudDomains/DsRecord.php',
    'Google\\Service\\CloudDomains\\EmailForwarding' => $vendorDir . '/google/apiclient-services/src/CloudDomains/EmailForwarding.php',
    'Google\\Service\\CloudDomains\\ExportRegistrationRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ExportRegistrationRequest.php',
    'Google\\Service\\CloudDomains\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Expr.php',
    'Google\\Service\\CloudDomains\\GeoPolicy' => $vendorDir . '/google/apiclient-services/src/CloudDomains/GeoPolicy.php',
    'Google\\Service\\CloudDomains\\GeoPolicyItem' => $vendorDir . '/google/apiclient-services/src/CloudDomains/GeoPolicyItem.php',
    'Google\\Service\\CloudDomains\\GlueRecord' => $vendorDir . '/google/apiclient-services/src/CloudDomains/GlueRecord.php',
    'Google\\Service\\CloudDomains\\GoogleDomainsDns' => $vendorDir . '/google/apiclient-services/src/CloudDomains/GoogleDomainsDns.php',
    'Google\\Service\\CloudDomains\\HealthCheckTargets' => $vendorDir . '/google/apiclient-services/src/CloudDomains/HealthCheckTargets.php',
    'Google\\Service\\CloudDomains\\ImportDomainRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ImportDomainRequest.php',
    'Google\\Service\\CloudDomains\\InitiatePushTransferRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/InitiatePushTransferRequest.php',
    'Google\\Service\\CloudDomains\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ListLocationsResponse.php',
    'Google\\Service\\CloudDomains\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ListOperationsResponse.php',
    'Google\\Service\\CloudDomains\\ListRegistrationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ListRegistrationsResponse.php',
    'Google\\Service\\CloudDomains\\LoadBalancerTarget' => $vendorDir . '/google/apiclient-services/src/CloudDomains/LoadBalancerTarget.php',
    'Google\\Service\\CloudDomains\\Location' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Location.php',
    'Google\\Service\\CloudDomains\\ManagementSettings' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ManagementSettings.php',
    'Google\\Service\\CloudDomains\\Money' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Money.php',
    'Google\\Service\\CloudDomains\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Operation.php',
    'Google\\Service\\CloudDomains\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudDomains/OperationMetadata.php',
    'Google\\Service\\CloudDomains\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Policy.php',
    'Google\\Service\\CloudDomains\\PostalAddress' => $vendorDir . '/google/apiclient-services/src/CloudDomains/PostalAddress.php',
    'Google\\Service\\CloudDomains\\PrimaryBackupPolicy' => $vendorDir . '/google/apiclient-services/src/CloudDomains/PrimaryBackupPolicy.php',
    'Google\\Service\\CloudDomains\\RRSetRoutingPolicy' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RRSetRoutingPolicy.php',
    'Google\\Service\\CloudDomains\\RegisterDomainRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RegisterDomainRequest.php',
    'Google\\Service\\CloudDomains\\RegisterParameters' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RegisterParameters.php',
    'Google\\Service\\CloudDomains\\Registration' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Registration.php',
    'Google\\Service\\CloudDomains\\RenewDomainRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RenewDomainRequest.php',
    'Google\\Service\\CloudDomains\\ResetAuthorizationCodeRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ResetAuthorizationCodeRequest.php',
    'Google\\Service\\CloudDomains\\ResourceRecordSet' => $vendorDir . '/google/apiclient-services/src/CloudDomains/ResourceRecordSet.php',
    'Google\\Service\\CloudDomains\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Resource/Projects.php',
    'Google\\Service\\CloudDomains\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudDomains\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudDomains\\Resource\\ProjectsLocationsRegistrations' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Resource/ProjectsLocationsRegistrations.php',
    'Google\\Service\\CloudDomains\\RetrieveGoogleDomainsDnsRecordsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RetrieveGoogleDomainsDnsRecordsResponse.php',
    'Google\\Service\\CloudDomains\\RetrieveGoogleDomainsForwardingConfigResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RetrieveGoogleDomainsForwardingConfigResponse.php',
    'Google\\Service\\CloudDomains\\RetrieveImportableDomainsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RetrieveImportableDomainsResponse.php',
    'Google\\Service\\CloudDomains\\RetrieveRegisterParametersResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RetrieveRegisterParametersResponse.php',
    'Google\\Service\\CloudDomains\\RetrieveTransferParametersResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/RetrieveTransferParametersResponse.php',
    'Google\\Service\\CloudDomains\\SearchDomainsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/SearchDomainsResponse.php',
    'Google\\Service\\CloudDomains\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/SetIamPolicyRequest.php',
    'Google\\Service\\CloudDomains\\Status' => $vendorDir . '/google/apiclient-services/src/CloudDomains/Status.php',
    'Google\\Service\\CloudDomains\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudDomains\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudDomains/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudDomains\\TransferDomainRequest' => $vendorDir . '/google/apiclient-services/src/CloudDomains/TransferDomainRequest.php',
    'Google\\Service\\CloudDomains\\TransferParameters' => $vendorDir . '/google/apiclient-services/src/CloudDomains/TransferParameters.php',
    'Google\\Service\\CloudDomains\\WrrPolicy' => $vendorDir . '/google/apiclient-services/src/CloudDomains/WrrPolicy.php',
    'Google\\Service\\CloudDomains\\WrrPolicyItem' => $vendorDir . '/google/apiclient-services/src/CloudDomains/WrrPolicyItem.php',
    'Google\\Service\\CloudFilestore' => $vendorDir . '/google/apiclient-services/src/CloudFilestore.php',
    'Google\\Service\\CloudFilestore\\Backup' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Backup.php',
    'Google\\Service\\CloudFilestore\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/CancelOperationRequest.php',
    'Google\\Service\\CloudFilestore\\DailyCycle' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/DailyCycle.php',
    'Google\\Service\\CloudFilestore\\Date' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Date.php',
    'Google\\Service\\CloudFilestore\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/DenyMaintenancePeriod.php',
    'Google\\Service\\CloudFilestore\\FileEmpty' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/FileEmpty.php',
    'Google\\Service\\CloudFilestore\\FileShareConfig' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/FileShareConfig.php',
    'Google\\Service\\CloudFilestore\\FixedIOPS' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/FixedIOPS.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1Instance' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1Instance.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion.php',
    'Google\\Service\\CloudFilestore\\GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata.php',
    'Google\\Service\\CloudFilestore\\IOPSPerGB' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/IOPSPerGB.php',
    'Google\\Service\\CloudFilestore\\Instance' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Instance.php',
    'Google\\Service\\CloudFilestore\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ListBackupsResponse.php',
    'Google\\Service\\CloudFilestore\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ListInstancesResponse.php',
    'Google\\Service\\CloudFilestore\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ListLocationsResponse.php',
    'Google\\Service\\CloudFilestore\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ListOperationsResponse.php',
    'Google\\Service\\CloudFilestore\\ListSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ListSnapshotsResponse.php',
    'Google\\Service\\CloudFilestore\\Location' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Location.php',
    'Google\\Service\\CloudFilestore\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/MaintenancePolicy.php',
    'Google\\Service\\CloudFilestore\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/MaintenanceWindow.php',
    'Google\\Service\\CloudFilestore\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/NetworkConfig.php',
    'Google\\Service\\CloudFilestore\\NfsExportOptions' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/NfsExportOptions.php',
    'Google\\Service\\CloudFilestore\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Operation.php',
    'Google\\Service\\CloudFilestore\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/OperationMetadata.php',
    'Google\\Service\\CloudFilestore\\PerformanceConfig' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/PerformanceConfig.php',
    'Google\\Service\\CloudFilestore\\PerformanceLimits' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/PerformanceLimits.php',
    'Google\\Service\\CloudFilestore\\PromoteReplicaRequest' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/PromoteReplicaRequest.php',
    'Google\\Service\\CloudFilestore\\ReplicaConfig' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/ReplicaConfig.php',
    'Google\\Service\\CloudFilestore\\Replication' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Replication.php',
    'Google\\Service\\CloudFilestore\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/Projects.php',
    'Google\\Service\\CloudFilestore\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudFilestore\\Resource\\ProjectsLocationsBackups' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/ProjectsLocationsBackups.php',
    'Google\\Service\\CloudFilestore\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\CloudFilestore\\Resource\\ProjectsLocationsInstancesSnapshots' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/ProjectsLocationsInstancesSnapshots.php',
    'Google\\Service\\CloudFilestore\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudFilestore\\RestoreInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/RestoreInstanceRequest.php',
    'Google\\Service\\CloudFilestore\\RevertInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/RevertInstanceRequest.php',
    'Google\\Service\\CloudFilestore\\Schedule' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Schedule.php',
    'Google\\Service\\CloudFilestore\\Snapshot' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Snapshot.php',
    'Google\\Service\\CloudFilestore\\Status' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/Status.php',
    'Google\\Service\\CloudFilestore\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/TimeOfDay.php',
    'Google\\Service\\CloudFilestore\\UpdatePolicy' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/UpdatePolicy.php',
    'Google\\Service\\CloudFilestore\\WeeklyCycle' => $vendorDir . '/google/apiclient-services/src/CloudFilestore/WeeklyCycle.php',
    'Google\\Service\\CloudFunctions' => $vendorDir . '/google/apiclient-services/src/CloudFunctions.php',
    'Google\\Service\\CloudFunctions\\AbortFunctionUpgradeRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/AbortFunctionUpgradeRequest.php',
    'Google\\Service\\CloudFunctions\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/AuditConfig.php',
    'Google\\Service\\CloudFunctions\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/AuditLogConfig.php',
    'Google\\Service\\CloudFunctions\\AutomaticUpdatePolicy' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/AutomaticUpdatePolicy.php',
    'Google\\Service\\CloudFunctions\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Binding.php',
    'Google\\Service\\CloudFunctions\\BuildConfig' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/BuildConfig.php',
    'Google\\Service\\CloudFunctions\\CallFunctionRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/CallFunctionRequest.php',
    'Google\\Service\\CloudFunctions\\CallFunctionResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/CallFunctionResponse.php',
    'Google\\Service\\CloudFunctions\\CloudFunction' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/CloudFunction.php',
    'Google\\Service\\CloudFunctions\\CloudfunctionsFunction' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/CloudfunctionsFunction.php',
    'Google\\Service\\CloudFunctions\\CommitFunctionUpgradeRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/CommitFunctionUpgradeRequest.php',
    'Google\\Service\\CloudFunctions\\Date' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Date.php',
    'Google\\Service\\CloudFunctions\\EventFilter' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/EventFilter.php',
    'Google\\Service\\CloudFunctions\\EventTrigger' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/EventTrigger.php',
    'Google\\Service\\CloudFunctions\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Expr.php',
    'Google\\Service\\CloudFunctions\\FailurePolicy' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/FailurePolicy.php',
    'Google\\Service\\CloudFunctions\\GenerateDownloadUrlRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GenerateDownloadUrlRequest.php',
    'Google\\Service\\CloudFunctions\\GenerateDownloadUrlResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GenerateDownloadUrlResponse.php',
    'Google\\Service\\CloudFunctions\\GenerateUploadUrlRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GenerateUploadUrlRequest.php',
    'Google\\Service\\CloudFunctions\\GenerateUploadUrlResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GenerateUploadUrlResponse.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2LocationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2OperationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2Stage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2Stage.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2StateMessage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2StateMessage.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2alphaLocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2alphaLocationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2alphaOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2alphaOperationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2alphaStage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2alphaStage.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2alphaStateMessage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2alphaStateMessage.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2betaLocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2betaLocationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2betaOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2betaOperationMetadata.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2betaStage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2betaStage.php',
    'Google\\Service\\CloudFunctions\\GoogleCloudFunctionsV2betaStateMessage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/GoogleCloudFunctionsV2betaStateMessage.php',
    'Google\\Service\\CloudFunctions\\HttpsTrigger' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/HttpsTrigger.php',
    'Google\\Service\\CloudFunctions\\ListFunctionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/ListFunctionsResponse.php',
    'Google\\Service\\CloudFunctions\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/ListLocationsResponse.php',
    'Google\\Service\\CloudFunctions\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/ListOperationsResponse.php',
    'Google\\Service\\CloudFunctions\\ListRuntimesResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/ListRuntimesResponse.php',
    'Google\\Service\\CloudFunctions\\Location' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Location.php',
    'Google\\Service\\CloudFunctions\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/LocationMetadata.php',
    'Google\\Service\\CloudFunctions\\OnDeployUpdatePolicy' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/OnDeployUpdatePolicy.php',
    'Google\\Service\\CloudFunctions\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Operation.php',
    'Google\\Service\\CloudFunctions\\OperationMetadataV1' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/OperationMetadataV1.php',
    'Google\\Service\\CloudFunctions\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Policy.php',
    'Google\\Service\\CloudFunctions\\RedirectFunctionUpgradeTrafficRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/RedirectFunctionUpgradeTrafficRequest.php',
    'Google\\Service\\CloudFunctions\\RepoSource' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/RepoSource.php',
    'Google\\Service\\CloudFunctions\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/Operations.php',
    'Google\\Service\\CloudFunctions\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/Projects.php',
    'Google\\Service\\CloudFunctions\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudFunctions\\Resource\\ProjectsLocationsFunctions' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/ProjectsLocationsFunctions.php',
    'Google\\Service\\CloudFunctions\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudFunctions\\Resource\\ProjectsLocationsRuntimes' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Resource/ProjectsLocationsRuntimes.php',
    'Google\\Service\\CloudFunctions\\Retry' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Retry.php',
    'Google\\Service\\CloudFunctions\\RollbackFunctionUpgradeTrafficRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/RollbackFunctionUpgradeTrafficRequest.php',
    'Google\\Service\\CloudFunctions\\Runtime' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Runtime.php',
    'Google\\Service\\CloudFunctions\\SecretEnvVar' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SecretEnvVar.php',
    'Google\\Service\\CloudFunctions\\SecretVersion' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SecretVersion.php',
    'Google\\Service\\CloudFunctions\\SecretVolume' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SecretVolume.php',
    'Google\\Service\\CloudFunctions\\ServiceConfig' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/ServiceConfig.php',
    'Google\\Service\\CloudFunctions\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SetIamPolicyRequest.php',
    'Google\\Service\\CloudFunctions\\SetupFunctionUpgradeConfigRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SetupFunctionUpgradeConfigRequest.php',
    'Google\\Service\\CloudFunctions\\Source' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Source.php',
    'Google\\Service\\CloudFunctions\\SourceProvenance' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SourceProvenance.php',
    'Google\\Service\\CloudFunctions\\SourceRepository' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/SourceRepository.php',
    'Google\\Service\\CloudFunctions\\Stage' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Stage.php',
    'Google\\Service\\CloudFunctions\\Status' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/Status.php',
    'Google\\Service\\CloudFunctions\\StorageSource' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/StorageSource.php',
    'Google\\Service\\CloudFunctions\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudFunctions\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudFunctions\\UpgradeInfo' => $vendorDir . '/google/apiclient-services/src/CloudFunctions/UpgradeInfo.php',
    'Google\\Service\\CloudHealthcare' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare.php',
    'Google\\Service\\CloudHealthcare\\ActivateConsentRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ActivateConsentRequest.php',
    'Google\\Service\\CloudHealthcare\\AnalyzeEntitiesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/AnalyzeEntitiesRequest.php',
    'Google\\Service\\CloudHealthcare\\AnalyzeEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/AnalyzeEntitiesResponse.php',
    'Google\\Service\\CloudHealthcare\\ArchiveUserDataMappingRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ArchiveUserDataMappingRequest.php',
    'Google\\Service\\CloudHealthcare\\ArchiveUserDataMappingResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ArchiveUserDataMappingResponse.php',
    'Google\\Service\\CloudHealthcare\\Attribute' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Attribute.php',
    'Google\\Service\\CloudHealthcare\\AttributeDefinition' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/AttributeDefinition.php',
    'Google\\Service\\CloudHealthcare\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/AuditConfig.php',
    'Google\\Service\\CloudHealthcare\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/AuditLogConfig.php',
    'Google\\Service\\CloudHealthcare\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Binding.php',
    'Google\\Service\\CloudHealthcare\\BlobStorageInfo' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/BlobStorageInfo.php',
    'Google\\Service\\CloudHealthcare\\BlobStorageSettings' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/BlobStorageSettings.php',
    'Google\\Service\\CloudHealthcare\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CancelOperationRequest.php',
    'Google\\Service\\CloudHealthcare\\CharacterMaskConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CharacterMaskConfig.php',
    'Google\\Service\\CloudHealthcare\\CheckDataAccessRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CheckDataAccessRequest.php',
    'Google\\Service\\CloudHealthcare\\CheckDataAccessResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CheckDataAccessResponse.php',
    'Google\\Service\\CloudHealthcare\\Consent' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Consent.php',
    'Google\\Service\\CloudHealthcare\\ConsentArtifact' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ConsentArtifact.php',
    'Google\\Service\\CloudHealthcare\\ConsentEvaluation' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ConsentEvaluation.php',
    'Google\\Service\\CloudHealthcare\\ConsentList' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ConsentList.php',
    'Google\\Service\\CloudHealthcare\\ConsentStore' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ConsentStore.php',
    'Google\\Service\\CloudHealthcare\\CreateMessageRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CreateMessageRequest.php',
    'Google\\Service\\CloudHealthcare\\CryptoHashConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/CryptoHashConfig.php',
    'Google\\Service\\CloudHealthcare\\Dataset' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Dataset.php',
    'Google\\Service\\CloudHealthcare\\DateShiftConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DateShiftConfig.php',
    'Google\\Service\\CloudHealthcare\\DeidentifiedStoreDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifiedStoreDestination.php',
    'Google\\Service\\CloudHealthcare\\DeidentifyConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifyConfig.php',
    'Google\\Service\\CloudHealthcare\\DeidentifyDatasetRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifyDatasetRequest.php',
    'Google\\Service\\CloudHealthcare\\DeidentifyDicomStoreRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifyDicomStoreRequest.php',
    'Google\\Service\\CloudHealthcare\\DeidentifyFhirStoreRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifyFhirStoreRequest.php',
    'Google\\Service\\CloudHealthcare\\DeidentifySummary' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DeidentifySummary.php',
    'Google\\Service\\CloudHealthcare\\DicomConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DicomConfig.php',
    'Google\\Service\\CloudHealthcare\\DicomFilterConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DicomFilterConfig.php',
    'Google\\Service\\CloudHealthcare\\DicomStore' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DicomStore.php',
    'Google\\Service\\CloudHealthcare\\DicomStoreMetrics' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/DicomStoreMetrics.php',
    'Google\\Service\\CloudHealthcare\\EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/EncryptionSpec.php',
    'Google\\Service\\CloudHealthcare\\Entity' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Entity.php',
    'Google\\Service\\CloudHealthcare\\EntityMention' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/EntityMention.php',
    'Google\\Service\\CloudHealthcare\\EntityMentionRelationship' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/EntityMentionRelationship.php',
    'Google\\Service\\CloudHealthcare\\EvaluateUserConsentsRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/EvaluateUserConsentsRequest.php',
    'Google\\Service\\CloudHealthcare\\EvaluateUserConsentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/EvaluateUserConsentsResponse.php',
    'Google\\Service\\CloudHealthcare\\ExportDicomDataRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportDicomDataRequest.php',
    'Google\\Service\\CloudHealthcare\\ExportDicomDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportDicomDataResponse.php',
    'Google\\Service\\CloudHealthcare\\ExportMessagesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportMessagesRequest.php',
    'Google\\Service\\CloudHealthcare\\ExportMessagesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportMessagesResponse.php',
    'Google\\Service\\CloudHealthcare\\ExportResourcesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportResourcesRequest.php',
    'Google\\Service\\CloudHealthcare\\ExportResourcesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ExportResourcesResponse.php',
    'Google\\Service\\CloudHealthcare\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Expr.php',
    'Google\\Service\\CloudHealthcare\\Feature' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Feature.php',
    'Google\\Service\\CloudHealthcare\\FhirConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirConfig.php',
    'Google\\Service\\CloudHealthcare\\FhirFilter' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirFilter.php',
    'Google\\Service\\CloudHealthcare\\FhirNotificationConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirNotificationConfig.php',
    'Google\\Service\\CloudHealthcare\\FhirStore' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirStore.php',
    'Google\\Service\\CloudHealthcare\\FhirStoreMetric' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirStoreMetric.php',
    'Google\\Service\\CloudHealthcare\\FhirStoreMetrics' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FhirStoreMetrics.php',
    'Google\\Service\\CloudHealthcare\\Field' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Field.php',
    'Google\\Service\\CloudHealthcare\\FieldMetadata' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/FieldMetadata.php',
    'Google\\Service\\CloudHealthcare\\GcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GcsDestination.php',
    'Google\\Service\\CloudHealthcare\\GcsSource' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GcsSource.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1ConsentGcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1ConsentGcsDestination.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1ConsentPolicy' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1ConsentPolicy.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DeidentifyDeidentifyDicomStoreSummary' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DeidentifyDeidentifyDicomStoreSummary.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DeidentifyDeidentifyFhirStoreSummary' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DeidentifyDeidentifyFhirStoreSummary.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DicomBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DicomBigQueryDestination.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DicomGcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DicomGcsDestination.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DicomGcsSource' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DicomGcsSource.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1DicomStreamConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1DicomStreamConfig.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1FhirBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1FhirBigQueryDestination.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1FhirGcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1FhirGcsDestination.php',
    'Google\\Service\\CloudHealthcare\\GoogleCloudHealthcareV1FhirGcsSource' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GoogleCloudHealthcareV1FhirGcsSource.php',
    'Google\\Service\\CloudHealthcare\\GroupOrSegment' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/GroupOrSegment.php',
    'Google\\Service\\CloudHealthcare\\HealthcareEmpty' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/HealthcareEmpty.php',
    'Google\\Service\\CloudHealthcare\\Hl7SchemaConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7SchemaConfig.php',
    'Google\\Service\\CloudHealthcare\\Hl7TypesConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7TypesConfig.php',
    'Google\\Service\\CloudHealthcare\\Hl7V2NotificationConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7V2NotificationConfig.php',
    'Google\\Service\\CloudHealthcare\\Hl7V2Store' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7V2Store.php',
    'Google\\Service\\CloudHealthcare\\Hl7V2StoreMetric' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7V2StoreMetric.php',
    'Google\\Service\\CloudHealthcare\\Hl7V2StoreMetrics' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Hl7V2StoreMetrics.php',
    'Google\\Service\\CloudHealthcare\\HttpBody' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/HttpBody.php',
    'Google\\Service\\CloudHealthcare\\Image' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Image.php',
    'Google\\Service\\CloudHealthcare\\ImageConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImageConfig.php',
    'Google\\Service\\CloudHealthcare\\ImportDicomDataRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportDicomDataRequest.php',
    'Google\\Service\\CloudHealthcare\\ImportDicomDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportDicomDataResponse.php',
    'Google\\Service\\CloudHealthcare\\ImportMessagesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportMessagesRequest.php',
    'Google\\Service\\CloudHealthcare\\ImportMessagesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportMessagesResponse.php',
    'Google\\Service\\CloudHealthcare\\ImportResourcesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportResourcesRequest.php',
    'Google\\Service\\CloudHealthcare\\ImportResourcesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ImportResourcesResponse.php',
    'Google\\Service\\CloudHealthcare\\InfoTypeTransformation' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/InfoTypeTransformation.php',
    'Google\\Service\\CloudHealthcare\\IngestMessageRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/IngestMessageRequest.php',
    'Google\\Service\\CloudHealthcare\\IngestMessageResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/IngestMessageResponse.php',
    'Google\\Service\\CloudHealthcare\\KmsWrappedCryptoKey' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/KmsWrappedCryptoKey.php',
    'Google\\Service\\CloudHealthcare\\LinkedEntity' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/LinkedEntity.php',
    'Google\\Service\\CloudHealthcare\\ListAttributeDefinitionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListAttributeDefinitionsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListConsentArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListConsentArtifactsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListConsentRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListConsentRevisionsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListConsentStoresResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListConsentStoresResponse.php',
    'Google\\Service\\CloudHealthcare\\ListConsentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListConsentsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListDatasetsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListDicomStoresResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListDicomStoresResponse.php',
    'Google\\Service\\CloudHealthcare\\ListFhirStoresResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListFhirStoresResponse.php',
    'Google\\Service\\CloudHealthcare\\ListHl7V2StoresResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListHl7V2StoresResponse.php',
    'Google\\Service\\CloudHealthcare\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListLocationsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListMessagesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListMessagesResponse.php',
    'Google\\Service\\CloudHealthcare\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListOperationsResponse.php',
    'Google\\Service\\CloudHealthcare\\ListUserDataMappingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ListUserDataMappingsResponse.php',
    'Google\\Service\\CloudHealthcare\\Location' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Location.php',
    'Google\\Service\\CloudHealthcare\\Message' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Message.php',
    'Google\\Service\\CloudHealthcare\\NotificationConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/NotificationConfig.php',
    'Google\\Service\\CloudHealthcare\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Operation.php',
    'Google\\Service\\CloudHealthcare\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/OperationMetadata.php',
    'Google\\Service\\CloudHealthcare\\ParsedData' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ParsedData.php',
    'Google\\Service\\CloudHealthcare\\ParserConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ParserConfig.php',
    'Google\\Service\\CloudHealthcare\\PatientId' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/PatientId.php',
    'Google\\Service\\CloudHealthcare\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Policy.php',
    'Google\\Service\\CloudHealthcare\\ProgressCounter' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ProgressCounter.php',
    'Google\\Service\\CloudHealthcare\\PubsubDestination' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/PubsubDestination.php',
    'Google\\Service\\CloudHealthcare\\QueryAccessibleDataRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/QueryAccessibleDataRequest.php',
    'Google\\Service\\CloudHealthcare\\QueryAccessibleDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/QueryAccessibleDataResponse.php',
    'Google\\Service\\CloudHealthcare\\RedactConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RedactConfig.php',
    'Google\\Service\\CloudHealthcare\\RejectConsentRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RejectConsentRequest.php',
    'Google\\Service\\CloudHealthcare\\ReplaceWithInfoTypeConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ReplaceWithInfoTypeConfig.php',
    'Google\\Service\\CloudHealthcare\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/Projects.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasets' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasets.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsConsentStores' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsConsentStores.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsConsentStoresAttributeDefinitions' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsConsentStoresAttributeDefinitions.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsConsentStoresConsentArtifacts' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsConsentStoresConsentArtifacts.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsConsentStoresConsents' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsConsentStoresConsents.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsConsentStoresUserDataMappings' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsConsentStoresUserDataMappings.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDataMapperWorkspaces' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDataMapperWorkspaces.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStores' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStores.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresDicomWeb' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresDicomWeb.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresDicomWebStudies' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresDicomWebStudies.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresDicomWebStudiesSeries' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresDicomWebStudiesSeries.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresDicomWebStudiesSeriesInstances' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresDicomWebStudiesSeriesInstances.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresStudies' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresStudies.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresStudiesSeries' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresStudiesSeries.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresStudiesSeriesInstances' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresStudiesSeriesInstances.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsDicomStoresStudiesSeriesInstancesFrames' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsDicomStoresStudiesSeriesInstancesFrames.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsFhirStores' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsFhirStores.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsFhirStoresFhir' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsFhirStoresFhir.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsHl7V2Stores' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsHl7V2Stores.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsHl7V2StoresMessages' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsHl7V2StoresMessages.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsDatasetsOperations' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsDatasetsOperations.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsServices' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsServices.php',
    'Google\\Service\\CloudHealthcare\\Resource\\ProjectsLocationsServicesNlp' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resource/ProjectsLocationsServicesNlp.php',
    'Google\\Service\\CloudHealthcare\\Resources' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Resources.php',
    'Google\\Service\\CloudHealthcare\\Result' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Result.php',
    'Google\\Service\\CloudHealthcare\\RevokeConsentRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RevokeConsentRequest.php',
    'Google\\Service\\CloudHealthcare\\RollbackFhirResourceFilteringFields' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackFhirResourceFilteringFields.php',
    'Google\\Service\\CloudHealthcare\\RollbackFhirResourcesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackFhirResourcesRequest.php',
    'Google\\Service\\CloudHealthcare\\RollbackFhirResourcesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackFhirResourcesResponse.php',
    'Google\\Service\\CloudHealthcare\\RollbackHL7MessagesFilteringFields' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackHL7MessagesFilteringFields.php',
    'Google\\Service\\CloudHealthcare\\RollbackHl7V2MessagesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackHl7V2MessagesRequest.php',
    'Google\\Service\\CloudHealthcare\\RollbackHl7V2MessagesResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/RollbackHl7V2MessagesResponse.php',
    'Google\\Service\\CloudHealthcare\\SchemaConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SchemaConfig.php',
    'Google\\Service\\CloudHealthcare\\SchemaGroup' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SchemaGroup.php',
    'Google\\Service\\CloudHealthcare\\SchemaPackage' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SchemaPackage.php',
    'Google\\Service\\CloudHealthcare\\SchemaSegment' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SchemaSegment.php',
    'Google\\Service\\CloudHealthcare\\SchematizedData' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SchematizedData.php',
    'Google\\Service\\CloudHealthcare\\SearchResourcesRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SearchResourcesRequest.php',
    'Google\\Service\\CloudHealthcare\\Segment' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Segment.php',
    'Google\\Service\\CloudHealthcare\\SeriesMetrics' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SeriesMetrics.php',
    'Google\\Service\\CloudHealthcare\\SetBlobStorageSettingsRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SetBlobStorageSettingsRequest.php',
    'Google\\Service\\CloudHealthcare\\SetBlobStorageSettingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SetBlobStorageSettingsResponse.php',
    'Google\\Service\\CloudHealthcare\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/SetIamPolicyRequest.php',
    'Google\\Service\\CloudHealthcare\\Signature' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Signature.php',
    'Google\\Service\\CloudHealthcare\\Status' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Status.php',
    'Google\\Service\\CloudHealthcare\\StorageInfo' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/StorageInfo.php',
    'Google\\Service\\CloudHealthcare\\StreamConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/StreamConfig.php',
    'Google\\Service\\CloudHealthcare\\StructuredStorageInfo' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/StructuredStorageInfo.php',
    'Google\\Service\\CloudHealthcare\\StudyMetrics' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/StudyMetrics.php',
    'Google\\Service\\CloudHealthcare\\TagFilterList' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TagFilterList.php',
    'Google\\Service\\CloudHealthcare\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudHealthcare\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudHealthcare\\TextConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TextConfig.php',
    'Google\\Service\\CloudHealthcare\\TextSpan' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TextSpan.php',
    'Google\\Service\\CloudHealthcare\\TimePartitioning' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/TimePartitioning.php',
    'Google\\Service\\CloudHealthcare\\Type' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/Type.php',
    'Google\\Service\\CloudHealthcare\\UserDataMapping' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/UserDataMapping.php',
    'Google\\Service\\CloudHealthcare\\ValidationConfig' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/ValidationConfig.php',
    'Google\\Service\\CloudHealthcare\\VersionSource' => $vendorDir . '/google/apiclient-services/src/CloudHealthcare/VersionSource.php',
    'Google\\Service\\CloudIAP' => $vendorDir . '/google/apiclient-services/src/CloudIAP.php',
    'Google\\Service\\CloudIAP\\AccessDeniedPageSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/AccessDeniedPageSettings.php',
    'Google\\Service\\CloudIAP\\AccessSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/AccessSettings.php',
    'Google\\Service\\CloudIAP\\AllowedDomainsSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/AllowedDomainsSettings.php',
    'Google\\Service\\CloudIAP\\ApplicationSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ApplicationSettings.php',
    'Google\\Service\\CloudIAP\\AttributePropagationSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/AttributePropagationSettings.php',
    'Google\\Service\\CloudIAP\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Binding.php',
    'Google\\Service\\CloudIAP\\Brand' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Brand.php',
    'Google\\Service\\CloudIAP\\CorsSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/CorsSettings.php',
    'Google\\Service\\CloudIAP\\CsmSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/CsmSettings.php',
    'Google\\Service\\CloudIAP\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Expr.php',
    'Google\\Service\\CloudIAP\\GcipSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/GcipSettings.php',
    'Google\\Service\\CloudIAP\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudIAP/GetIamPolicyRequest.php',
    'Google\\Service\\CloudIAP\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/CloudIAP/GetPolicyOptions.php',
    'Google\\Service\\CloudIAP\\IapEmpty' => $vendorDir . '/google/apiclient-services/src/CloudIAP/IapEmpty.php',
    'Google\\Service\\CloudIAP\\IapResource' => $vendorDir . '/google/apiclient-services/src/CloudIAP/IapResource.php',
    'Google\\Service\\CloudIAP\\IapSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/IapSettings.php',
    'Google\\Service\\CloudIAP\\IdentityAwareProxyClient' => $vendorDir . '/google/apiclient-services/src/CloudIAP/IdentityAwareProxyClient.php',
    'Google\\Service\\CloudIAP\\ListBrandsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ListBrandsResponse.php',
    'Google\\Service\\CloudIAP\\ListIdentityAwareProxyClientsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ListIdentityAwareProxyClientsResponse.php',
    'Google\\Service\\CloudIAP\\ListTunnelDestGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ListTunnelDestGroupsResponse.php',
    'Google\\Service\\CloudIAP\\NextStateOfTags' => $vendorDir . '/google/apiclient-services/src/CloudIAP/NextStateOfTags.php',
    'Google\\Service\\CloudIAP\\OAuth2' => $vendorDir . '/google/apiclient-services/src/CloudIAP/OAuth2.php',
    'Google\\Service\\CloudIAP\\OAuthSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/OAuthSettings.php',
    'Google\\Service\\CloudIAP\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Policy.php',
    'Google\\Service\\CloudIAP\\PolicyDelegationSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/PolicyDelegationSettings.php',
    'Google\\Service\\CloudIAP\\PolicyName' => $vendorDir . '/google/apiclient-services/src/CloudIAP/PolicyName.php',
    'Google\\Service\\CloudIAP\\ReauthSettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ReauthSettings.php',
    'Google\\Service\\CloudIAP\\ResetIdentityAwareProxyClientSecretRequest' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ResetIdentityAwareProxyClientSecretRequest.php',
    'Google\\Service\\CloudIAP\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/Projects.php',
    'Google\\Service\\CloudIAP\\Resource\\ProjectsBrands' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/ProjectsBrands.php',
    'Google\\Service\\CloudIAP\\Resource\\ProjectsBrandsIdentityAwareProxyClients' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/ProjectsBrandsIdentityAwareProxyClients.php',
    'Google\\Service\\CloudIAP\\Resource\\ProjectsIapTunnel' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/ProjectsIapTunnel.php',
    'Google\\Service\\CloudIAP\\Resource\\ProjectsIapTunnelLocations' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/ProjectsIapTunnelLocations.php',
    'Google\\Service\\CloudIAP\\Resource\\ProjectsIapTunnelLocationsDestGroups' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/ProjectsIapTunnelLocationsDestGroups.php',
    'Google\\Service\\CloudIAP\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/CloudIAP/Resource/V1.php',
    'Google\\Service\\CloudIAP\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudIAP/SetIamPolicyRequest.php',
    'Google\\Service\\CloudIAP\\TagsFullState' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TagsFullState.php',
    'Google\\Service\\CloudIAP\\TagsFullStateForChildResource' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TagsFullStateForChildResource.php',
    'Google\\Service\\CloudIAP\\TagsPartialState' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TagsPartialState.php',
    'Google\\Service\\CloudIAP\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudIAP\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudIAP\\TunnelDestGroup' => $vendorDir . '/google/apiclient-services/src/CloudIAP/TunnelDestGroup.php',
    'Google\\Service\\CloudIAP\\ValidateIapAttributeExpressionResponse' => $vendorDir . '/google/apiclient-services/src/CloudIAP/ValidateIapAttributeExpressionResponse.php',
    'Google\\Service\\CloudIAP\\WorkforceIdentitySettings' => $vendorDir . '/google/apiclient-services/src/CloudIAP/WorkforceIdentitySettings.php',
    'Google\\Service\\CloudIdentity' => $vendorDir . '/google/apiclient-services/src/CloudIdentity.php',
    'Google\\Service\\CloudIdentity\\AddIdpCredentialOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/AddIdpCredentialOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\AddIdpCredentialRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/AddIdpCredentialRequest.php',
    'Google\\Service\\CloudIdentity\\CancelUserInvitationRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CancelUserInvitationRequest.php',
    'Google\\Service\\CloudIdentity\\CheckTransitiveMembershipResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CheckTransitiveMembershipResponse.php',
    'Google\\Service\\CloudIdentity\\CreateGroupMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CreateGroupMetadata.php',
    'Google\\Service\\CloudIdentity\\CreateInboundSamlSsoProfileOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CreateInboundSamlSsoProfileOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\CreateInboundSsoAssignmentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CreateInboundSsoAssignmentOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\CreateMembershipMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/CreateMembershipMetadata.php',
    'Google\\Service\\CloudIdentity\\DeleteGroupMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DeleteGroupMetadata.php',
    'Google\\Service\\CloudIdentity\\DeleteIdpCredentialOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DeleteIdpCredentialOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\DeleteInboundSamlSsoProfileOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DeleteInboundSamlSsoProfileOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\DeleteInboundSsoAssignmentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DeleteInboundSsoAssignmentOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\DeleteMembershipMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DeleteMembershipMetadata.php',
    'Google\\Service\\CloudIdentity\\DsaPublicKeyInfo' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DsaPublicKeyInfo.php',
    'Google\\Service\\CloudIdentity\\DynamicGroupMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DynamicGroupMetadata.php',
    'Google\\Service\\CloudIdentity\\DynamicGroupQuery' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DynamicGroupQuery.php',
    'Google\\Service\\CloudIdentity\\DynamicGroupStatus' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/DynamicGroupStatus.php',
    'Google\\Service\\CloudIdentity\\EntityKey' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/EntityKey.php',
    'Google\\Service\\CloudIdentity\\ExpiryDetail' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ExpiryDetail.php',
    'Google\\Service\\CloudIdentity\\GetMembershipGraphMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GetMembershipGraphMetadata.php',
    'Google\\Service\\CloudIdentity\\GetMembershipGraphResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GetMembershipGraphResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1AndroidAttributes' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1AndroidAttributes.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ApproveDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ApproveDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ApproveDeviceUserRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ApproveDeviceUserRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ApproveDeviceUserResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ApproveDeviceUserResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1BlockDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1BlockDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1BlockDeviceUserRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1BlockDeviceUserRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1BlockDeviceUserResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1BlockDeviceUserResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1BrowserAttributes' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1BrowserAttributes.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1BrowserInfo' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1BrowserInfo.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CertificateAttributes' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CertificateAttributes.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CertificateTemplate' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CertificateTemplate.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ClientState' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ClientState.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CreateDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CreateDeviceMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1CustomAttributeValue' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1CustomAttributeValue.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1DeleteDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1DeleteDeviceMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1DeleteDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1DeleteDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1Device' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1Device.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1DeviceUser' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1DeviceUser.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ListClientStatesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ListClientStatesResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ListDeviceUsersResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ListDeviceUsersResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ListDevicesResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1ListEndpointAppsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1ListEndpointAppsMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1LookupSelfDeviceUsersResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1LookupSelfDeviceUsersResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1SignoutDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1SignoutDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1UpdateClientStateMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1UpdateClientStateMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1UpdateDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1UpdateDeviceMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceResponse.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceUserMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceUserMetadata.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest.php',
    'Google\\Service\\CloudIdentity\\GoogleAppsCloudidentityDevicesV1WipeDeviceUserResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GoogleAppsCloudidentityDevicesV1WipeDeviceUserResponse.php',
    'Google\\Service\\CloudIdentity\\Group' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Group.php',
    'Google\\Service\\CloudIdentity\\GroupRelation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/GroupRelation.php',
    'Google\\Service\\CloudIdentity\\IdpCredential' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/IdpCredential.php',
    'Google\\Service\\CloudIdentity\\InboundSamlSsoProfile' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/InboundSamlSsoProfile.php',
    'Google\\Service\\CloudIdentity\\InboundSsoAssignment' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/InboundSsoAssignment.php',
    'Google\\Service\\CloudIdentity\\IsInvitableUserResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/IsInvitableUserResponse.php',
    'Google\\Service\\CloudIdentity\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListGroupsResponse.php',
    'Google\\Service\\CloudIdentity\\ListIdpCredentialsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListIdpCredentialsResponse.php',
    'Google\\Service\\CloudIdentity\\ListInboundSamlSsoProfilesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListInboundSamlSsoProfilesResponse.php',
    'Google\\Service\\CloudIdentity\\ListInboundSsoAssignmentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListInboundSsoAssignmentsResponse.php',
    'Google\\Service\\CloudIdentity\\ListMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListMembershipsResponse.php',
    'Google\\Service\\CloudIdentity\\ListUserInvitationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ListUserInvitationsResponse.php',
    'Google\\Service\\CloudIdentity\\LookupGroupNameResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/LookupGroupNameResponse.php',
    'Google\\Service\\CloudIdentity\\LookupMembershipNameResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/LookupMembershipNameResponse.php',
    'Google\\Service\\CloudIdentity\\MemberRelation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MemberRelation.php',
    'Google\\Service\\CloudIdentity\\MemberRestriction' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MemberRestriction.php',
    'Google\\Service\\CloudIdentity\\Membership' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Membership.php',
    'Google\\Service\\CloudIdentity\\MembershipAdjacencyList' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MembershipAdjacencyList.php',
    'Google\\Service\\CloudIdentity\\MembershipRelation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MembershipRelation.php',
    'Google\\Service\\CloudIdentity\\MembershipRole' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MembershipRole.php',
    'Google\\Service\\CloudIdentity\\MembershipRoleRestrictionEvaluation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/MembershipRoleRestrictionEvaluation.php',
    'Google\\Service\\CloudIdentity\\ModifyMembershipRolesRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ModifyMembershipRolesRequest.php',
    'Google\\Service\\CloudIdentity\\ModifyMembershipRolesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/ModifyMembershipRolesResponse.php',
    'Google\\Service\\CloudIdentity\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Operation.php',
    'Google\\Service\\CloudIdentity\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/Customers.php',
    'Google\\Service\\CloudIdentity\\Resource\\CustomersUserinvitations' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/CustomersUserinvitations.php',
    'Google\\Service\\CloudIdentity\\Resource\\Devices' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/Devices.php',
    'Google\\Service\\CloudIdentity\\Resource\\DevicesDeviceUsers' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/DevicesDeviceUsers.php',
    'Google\\Service\\CloudIdentity\\Resource\\DevicesDeviceUsersClientStates' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/DevicesDeviceUsersClientStates.php',
    'Google\\Service\\CloudIdentity\\Resource\\Groups' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/Groups.php',
    'Google\\Service\\CloudIdentity\\Resource\\GroupsMemberships' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/GroupsMemberships.php',
    'Google\\Service\\CloudIdentity\\Resource\\InboundSamlSsoProfiles' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/InboundSamlSsoProfiles.php',
    'Google\\Service\\CloudIdentity\\Resource\\InboundSamlSsoProfilesIdpCredentials' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/InboundSamlSsoProfilesIdpCredentials.php',
    'Google\\Service\\CloudIdentity\\Resource\\InboundSsoAssignments' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Resource/InboundSsoAssignments.php',
    'Google\\Service\\CloudIdentity\\RestrictionEvaluation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/RestrictionEvaluation.php',
    'Google\\Service\\CloudIdentity\\RestrictionEvaluations' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/RestrictionEvaluations.php',
    'Google\\Service\\CloudIdentity\\RsaPublicKeyInfo' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/RsaPublicKeyInfo.php',
    'Google\\Service\\CloudIdentity\\SamlIdpConfig' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SamlIdpConfig.php',
    'Google\\Service\\CloudIdentity\\SamlSpConfig' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SamlSpConfig.php',
    'Google\\Service\\CloudIdentity\\SamlSsoInfo' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SamlSsoInfo.php',
    'Google\\Service\\CloudIdentity\\SearchDirectGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SearchDirectGroupsResponse.php',
    'Google\\Service\\CloudIdentity\\SearchGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SearchGroupsResponse.php',
    'Google\\Service\\CloudIdentity\\SearchTransitiveGroupsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SearchTransitiveGroupsResponse.php',
    'Google\\Service\\CloudIdentity\\SearchTransitiveMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SearchTransitiveMembershipsResponse.php',
    'Google\\Service\\CloudIdentity\\SecuritySettings' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SecuritySettings.php',
    'Google\\Service\\CloudIdentity\\SendUserInvitationRequest' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SendUserInvitationRequest.php',
    'Google\\Service\\CloudIdentity\\SignInBehavior' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/SignInBehavior.php',
    'Google\\Service\\CloudIdentity\\Status' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/Status.php',
    'Google\\Service\\CloudIdentity\\TransitiveMembershipRole' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/TransitiveMembershipRole.php',
    'Google\\Service\\CloudIdentity\\UpdateGroupMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UpdateGroupMetadata.php',
    'Google\\Service\\CloudIdentity\\UpdateInboundSamlSsoProfileOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UpdateInboundSamlSsoProfileOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\UpdateInboundSsoAssignmentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UpdateInboundSsoAssignmentOperationMetadata.php',
    'Google\\Service\\CloudIdentity\\UpdateMembershipMetadata' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UpdateMembershipMetadata.php',
    'Google\\Service\\CloudIdentity\\UpdateMembershipRolesParams' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UpdateMembershipRolesParams.php',
    'Google\\Service\\CloudIdentity\\UserInvitation' => $vendorDir . '/google/apiclient-services/src/CloudIdentity/UserInvitation.php',
    'Google\\Service\\CloudIot' => $vendorDir . '/google/apiclient-services/src/CloudIot.php',
    'Google\\Service\\CloudIot\\BindDeviceToGatewayRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/BindDeviceToGatewayRequest.php',
    'Google\\Service\\CloudIot\\BindDeviceToGatewayResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/BindDeviceToGatewayResponse.php',
    'Google\\Service\\CloudIot\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudIot/Binding.php',
    'Google\\Service\\CloudIot\\CloudiotEmpty' => $vendorDir . '/google/apiclient-services/src/CloudIot/CloudiotEmpty.php',
    'Google\\Service\\CloudIot\\Device' => $vendorDir . '/google/apiclient-services/src/CloudIot/Device.php',
    'Google\\Service\\CloudIot\\DeviceConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/DeviceConfig.php',
    'Google\\Service\\CloudIot\\DeviceCredential' => $vendorDir . '/google/apiclient-services/src/CloudIot/DeviceCredential.php',
    'Google\\Service\\CloudIot\\DeviceRegistry' => $vendorDir . '/google/apiclient-services/src/CloudIot/DeviceRegistry.php',
    'Google\\Service\\CloudIot\\DeviceState' => $vendorDir . '/google/apiclient-services/src/CloudIot/DeviceState.php',
    'Google\\Service\\CloudIot\\EventNotificationConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/EventNotificationConfig.php',
    'Google\\Service\\CloudIot\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudIot/Expr.php',
    'Google\\Service\\CloudIot\\GatewayConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/GatewayConfig.php',
    'Google\\Service\\CloudIot\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/GetIamPolicyRequest.php',
    'Google\\Service\\CloudIot\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/CloudIot/GetPolicyOptions.php',
    'Google\\Service\\CloudIot\\HttpConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/HttpConfig.php',
    'Google\\Service\\CloudIot\\ListDeviceConfigVersionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/ListDeviceConfigVersionsResponse.php',
    'Google\\Service\\CloudIot\\ListDeviceRegistriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/ListDeviceRegistriesResponse.php',
    'Google\\Service\\CloudIot\\ListDeviceStatesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/ListDeviceStatesResponse.php',
    'Google\\Service\\CloudIot\\ListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/ListDevicesResponse.php',
    'Google\\Service\\CloudIot\\ModifyCloudToDeviceConfigRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/ModifyCloudToDeviceConfigRequest.php',
    'Google\\Service\\CloudIot\\MqttConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/MqttConfig.php',
    'Google\\Service\\CloudIot\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudIot/Policy.php',
    'Google\\Service\\CloudIot\\PublicKeyCertificate' => $vendorDir . '/google/apiclient-services/src/CloudIot/PublicKeyCertificate.php',
    'Google\\Service\\CloudIot\\PublicKeyCredential' => $vendorDir . '/google/apiclient-services/src/CloudIot/PublicKeyCredential.php',
    'Google\\Service\\CloudIot\\RegistryCredential' => $vendorDir . '/google/apiclient-services/src/CloudIot/RegistryCredential.php',
    'Google\\Service\\CloudIot\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/Projects.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistries' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistries.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistriesDevices' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistriesDevices.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistriesDevicesConfigVersions' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistriesDevicesConfigVersions.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistriesDevicesStates' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistriesDevicesStates.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistriesGroups' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistriesGroups.php',
    'Google\\Service\\CloudIot\\Resource\\ProjectsLocationsRegistriesGroupsDevices' => $vendorDir . '/google/apiclient-services/src/CloudIot/Resource/ProjectsLocationsRegistriesGroupsDevices.php',
    'Google\\Service\\CloudIot\\SendCommandToDeviceRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/SendCommandToDeviceRequest.php',
    'Google\\Service\\CloudIot\\SendCommandToDeviceResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/SendCommandToDeviceResponse.php',
    'Google\\Service\\CloudIot\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/SetIamPolicyRequest.php',
    'Google\\Service\\CloudIot\\StateNotificationConfig' => $vendorDir . '/google/apiclient-services/src/CloudIot/StateNotificationConfig.php',
    'Google\\Service\\CloudIot\\Status' => $vendorDir . '/google/apiclient-services/src/CloudIot/Status.php',
    'Google\\Service\\CloudIot\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudIot\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudIot\\UnbindDeviceFromGatewayRequest' => $vendorDir . '/google/apiclient-services/src/CloudIot/UnbindDeviceFromGatewayRequest.php',
    'Google\\Service\\CloudIot\\UnbindDeviceFromGatewayResponse' => $vendorDir . '/google/apiclient-services/src/CloudIot/UnbindDeviceFromGatewayResponse.php',
    'Google\\Service\\CloudIot\\X509CertificateDetails' => $vendorDir . '/google/apiclient-services/src/CloudIot/X509CertificateDetails.php',
    'Google\\Service\\CloudKMS' => $vendorDir . '/google/apiclient-services/src/CloudKMS.php',
    'Google\\Service\\CloudKMS\\AsymmetricDecryptRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AsymmetricDecryptRequest.php',
    'Google\\Service\\CloudKMS\\AsymmetricDecryptResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AsymmetricDecryptResponse.php',
    'Google\\Service\\CloudKMS\\AsymmetricSignRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AsymmetricSignRequest.php',
    'Google\\Service\\CloudKMS\\AsymmetricSignResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AsymmetricSignResponse.php',
    'Google\\Service\\CloudKMS\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AuditConfig.php',
    'Google\\Service\\CloudKMS\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AuditLogConfig.php',
    'Google\\Service\\CloudKMS\\AutokeyConfig' => $vendorDir . '/google/apiclient-services/src/CloudKMS/AutokeyConfig.php',
    'Google\\Service\\CloudKMS\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Binding.php',
    'Google\\Service\\CloudKMS\\Certificate' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Certificate.php',
    'Google\\Service\\CloudKMS\\CertificateChains' => $vendorDir . '/google/apiclient-services/src/CloudKMS/CertificateChains.php',
    'Google\\Service\\CloudKMS\\CryptoKey' => $vendorDir . '/google/apiclient-services/src/CloudKMS/CryptoKey.php',
    'Google\\Service\\CloudKMS\\CryptoKeyVersion' => $vendorDir . '/google/apiclient-services/src/CloudKMS/CryptoKeyVersion.php',
    'Google\\Service\\CloudKMS\\CryptoKeyVersionTemplate' => $vendorDir . '/google/apiclient-services/src/CloudKMS/CryptoKeyVersionTemplate.php',
    'Google\\Service\\CloudKMS\\DecryptRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/DecryptRequest.php',
    'Google\\Service\\CloudKMS\\DecryptResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/DecryptResponse.php',
    'Google\\Service\\CloudKMS\\DestroyCryptoKeyVersionRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/DestroyCryptoKeyVersionRequest.php',
    'Google\\Service\\CloudKMS\\Digest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Digest.php',
    'Google\\Service\\CloudKMS\\EkmConfig' => $vendorDir . '/google/apiclient-services/src/CloudKMS/EkmConfig.php',
    'Google\\Service\\CloudKMS\\EkmConnection' => $vendorDir . '/google/apiclient-services/src/CloudKMS/EkmConnection.php',
    'Google\\Service\\CloudKMS\\EncryptRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/EncryptRequest.php',
    'Google\\Service\\CloudKMS\\EncryptResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/EncryptResponse.php',
    'Google\\Service\\CloudKMS\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Expr.php',
    'Google\\Service\\CloudKMS\\ExternalProtectionLevelOptions' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ExternalProtectionLevelOptions.php',
    'Google\\Service\\CloudKMS\\GenerateRandomBytesRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/GenerateRandomBytesRequest.php',
    'Google\\Service\\CloudKMS\\GenerateRandomBytesResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/GenerateRandomBytesResponse.php',
    'Google\\Service\\CloudKMS\\ImportCryptoKeyVersionRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ImportCryptoKeyVersionRequest.php',
    'Google\\Service\\CloudKMS\\ImportJob' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ImportJob.php',
    'Google\\Service\\CloudKMS\\KeyAccessJustificationsPolicy' => $vendorDir . '/google/apiclient-services/src/CloudKMS/KeyAccessJustificationsPolicy.php',
    'Google\\Service\\CloudKMS\\KeyHandle' => $vendorDir . '/google/apiclient-services/src/CloudKMS/KeyHandle.php',
    'Google\\Service\\CloudKMS\\KeyOperationAttestation' => $vendorDir . '/google/apiclient-services/src/CloudKMS/KeyOperationAttestation.php',
    'Google\\Service\\CloudKMS\\KeyRing' => $vendorDir . '/google/apiclient-services/src/CloudKMS/KeyRing.php',
    'Google\\Service\\CloudKMS\\ListCryptoKeyVersionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListCryptoKeyVersionsResponse.php',
    'Google\\Service\\CloudKMS\\ListCryptoKeysResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListCryptoKeysResponse.php',
    'Google\\Service\\CloudKMS\\ListEkmConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListEkmConnectionsResponse.php',
    'Google\\Service\\CloudKMS\\ListImportJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListImportJobsResponse.php',
    'Google\\Service\\CloudKMS\\ListKeyHandlesResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListKeyHandlesResponse.php',
    'Google\\Service\\CloudKMS\\ListKeyRingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListKeyRingsResponse.php',
    'Google\\Service\\CloudKMS\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ListLocationsResponse.php',
    'Google\\Service\\CloudKMS\\Location' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Location.php',
    'Google\\Service\\CloudKMS\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudKMS/LocationMetadata.php',
    'Google\\Service\\CloudKMS\\MacSignRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/MacSignRequest.php',
    'Google\\Service\\CloudKMS\\MacSignResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/MacSignResponse.php',
    'Google\\Service\\CloudKMS\\MacVerifyRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/MacVerifyRequest.php',
    'Google\\Service\\CloudKMS\\MacVerifyResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/MacVerifyResponse.php',
    'Google\\Service\\CloudKMS\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Operation.php',
    'Google\\Service\\CloudKMS\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Policy.php',
    'Google\\Service\\CloudKMS\\PublicKey' => $vendorDir . '/google/apiclient-services/src/CloudKMS/PublicKey.php',
    'Google\\Service\\CloudKMS\\RawDecryptRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/RawDecryptRequest.php',
    'Google\\Service\\CloudKMS\\RawDecryptResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/RawDecryptResponse.php',
    'Google\\Service\\CloudKMS\\RawEncryptRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/RawEncryptRequest.php',
    'Google\\Service\\CloudKMS\\RawEncryptResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/RawEncryptResponse.php',
    'Google\\Service\\CloudKMS\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/Folders.php',
    'Google\\Service\\CloudKMS\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/Projects.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsEkmConfig' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsEkmConfig.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsEkmConnections' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsEkmConnections.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsKeyHandles' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsKeyHandles.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsKeyRings' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsKeyRings.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsKeyRingsCryptoKeys' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsKeyRingsCryptoKeys.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsKeyRingsCryptoKeysCryptoKeyVersions' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsKeyRingsCryptoKeysCryptoKeyVersions.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsKeyRingsImportJobs' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsKeyRingsImportJobs.php',
    'Google\\Service\\CloudKMS\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudKMS\\RestoreCryptoKeyVersionRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/RestoreCryptoKeyVersionRequest.php',
    'Google\\Service\\CloudKMS\\ServiceResolver' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ServiceResolver.php',
    'Google\\Service\\CloudKMS\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/SetIamPolicyRequest.php',
    'Google\\Service\\CloudKMS\\ShowEffectiveAutokeyConfigResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/ShowEffectiveAutokeyConfigResponse.php',
    'Google\\Service\\CloudKMS\\Status' => $vendorDir . '/google/apiclient-services/src/CloudKMS/Status.php',
    'Google\\Service\\CloudKMS\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudKMS\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudKMS\\UpdateCryptoKeyPrimaryVersionRequest' => $vendorDir . '/google/apiclient-services/src/CloudKMS/UpdateCryptoKeyPrimaryVersionRequest.php',
    'Google\\Service\\CloudKMS\\VerifyConnectivityResponse' => $vendorDir . '/google/apiclient-services/src/CloudKMS/VerifyConnectivityResponse.php',
    'Google\\Service\\CloudKMS\\WrappingPublicKey' => $vendorDir . '/google/apiclient-services/src/CloudKMS/WrappingPublicKey.php',
    'Google\\Service\\CloudLifeSciences' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences.php',
    'Google\\Service\\CloudLifeSciences\\Accelerator' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Accelerator.php',
    'Google\\Service\\CloudLifeSciences\\Action' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Action.php',
    'Google\\Service\\CloudLifeSciences\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/CancelOperationRequest.php',
    'Google\\Service\\CloudLifeSciences\\ContainerKilledEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ContainerKilledEvent.php',
    'Google\\Service\\CloudLifeSciences\\ContainerStartedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ContainerStartedEvent.php',
    'Google\\Service\\CloudLifeSciences\\ContainerStoppedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ContainerStoppedEvent.php',
    'Google\\Service\\CloudLifeSciences\\DelayedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/DelayedEvent.php',
    'Google\\Service\\CloudLifeSciences\\Disk' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Disk.php',
    'Google\\Service\\CloudLifeSciences\\Event' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Event.php',
    'Google\\Service\\CloudLifeSciences\\ExistingDisk' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ExistingDisk.php',
    'Google\\Service\\CloudLifeSciences\\FailedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/FailedEvent.php',
    'Google\\Service\\CloudLifeSciences\\LifesciencesEmpty' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/LifesciencesEmpty.php',
    'Google\\Service\\CloudLifeSciences\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ListLocationsResponse.php',
    'Google\\Service\\CloudLifeSciences\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ListOperationsResponse.php',
    'Google\\Service\\CloudLifeSciences\\Location' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Location.php',
    'Google\\Service\\CloudLifeSciences\\Metadata' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Metadata.php',
    'Google\\Service\\CloudLifeSciences\\Mount' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Mount.php',
    'Google\\Service\\CloudLifeSciences\\NFSMount' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/NFSMount.php',
    'Google\\Service\\CloudLifeSciences\\Network' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Network.php',
    'Google\\Service\\CloudLifeSciences\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Operation.php',
    'Google\\Service\\CloudLifeSciences\\PersistentDisk' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/PersistentDisk.php',
    'Google\\Service\\CloudLifeSciences\\Pipeline' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Pipeline.php',
    'Google\\Service\\CloudLifeSciences\\PullStartedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/PullStartedEvent.php',
    'Google\\Service\\CloudLifeSciences\\PullStoppedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/PullStoppedEvent.php',
    'Google\\Service\\CloudLifeSciences\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Resource/Projects.php',
    'Google\\Service\\CloudLifeSciences\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudLifeSciences\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudLifeSciences\\Resource\\ProjectsLocationsPipelines' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Resource/ProjectsLocationsPipelines.php',
    'Google\\Service\\CloudLifeSciences\\Resources' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Resources.php',
    'Google\\Service\\CloudLifeSciences\\RunPipelineRequest' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/RunPipelineRequest.php',
    'Google\\Service\\CloudLifeSciences\\RunPipelineResponse' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/RunPipelineResponse.php',
    'Google\\Service\\CloudLifeSciences\\Secret' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Secret.php',
    'Google\\Service\\CloudLifeSciences\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/ServiceAccount.php',
    'Google\\Service\\CloudLifeSciences\\Status' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Status.php',
    'Google\\Service\\CloudLifeSciences\\UnexpectedExitStatusEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/UnexpectedExitStatusEvent.php',
    'Google\\Service\\CloudLifeSciences\\VirtualMachine' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/VirtualMachine.php',
    'Google\\Service\\CloudLifeSciences\\Volume' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/Volume.php',
    'Google\\Service\\CloudLifeSciences\\WorkerAssignedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/WorkerAssignedEvent.php',
    'Google\\Service\\CloudLifeSciences\\WorkerReleasedEvent' => $vendorDir . '/google/apiclient-services/src/CloudLifeSciences/WorkerReleasedEvent.php',
    'Google\\Service\\CloudMachineLearningEngine' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleApiHttpBody.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AcceleratorConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AddTrialMeasurementRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AddTrialMeasurementRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AutoScaling' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AutoScaling.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AutomatedStoppingConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AutomatedStoppingConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AutomatedStoppingConfigDecayCurveAutomatedStoppingConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AutomatedStoppingConfigDecayCurveAutomatedStoppingConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1AutomatedStoppingConfigMedianAutomatedStoppingConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1AutomatedStoppingConfigMedianAutomatedStoppingConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1BuiltInAlgorithmOutput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1BuiltInAlgorithmOutput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1CancelJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1CancelJobRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Capability' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Capability.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1CheckTrialEarlyStoppingStateMetatdata' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1CheckTrialEarlyStoppingStateMetatdata.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1CheckTrialEarlyStoppingStateRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1CheckTrialEarlyStoppingStateRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1CheckTrialEarlyStoppingStateResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1CheckTrialEarlyStoppingStateResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1CompleteTrialRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1CompleteTrialRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Config' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Config.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ContainerPort' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ContainerPort.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ContainerSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ContainerSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1DiskConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1DiskConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1EncryptionConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1EnvVar' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1EnvVar.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ExplainRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ExplainRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ExplanationConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ExplanationConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1GetConfigResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1GetConfigResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1HyperparameterOutput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1HyperparameterOutput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1HyperparameterOutputHyperparameterMetric' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1HyperparameterOutputHyperparameterMetric.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1HyperparameterSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1HyperparameterSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1IntegratedGradientsAttribution' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1IntegratedGradientsAttribution.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Job' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Job.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListJobsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListLocationsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListModelsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListModelsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListOptimalTrialsRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListOptimalTrialsRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListOptimalTrialsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListOptimalTrialsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListStudiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListStudiesResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListTrialsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListTrialsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ListVersionsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Location' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Location.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ManualScaling' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ManualScaling.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Measurement' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Measurement.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1MeasurementMetric' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1MeasurementMetric.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1MetricSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1MetricSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Model' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Model.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1OperationMetadata.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ParameterSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ParameterSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1PredictRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1PredictRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1PredictionInput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1PredictionInput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1PredictionOutput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1PredictionOutput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1ReplicaConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1ReplicaConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1RequestLoggingConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1RequestLoggingConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1RouteMap' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1RouteMap.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1SampledShapleyAttribution' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1SampledShapleyAttribution.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Scheduling' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Scheduling.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1SetDefaultVersionRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1SetDefaultVersionRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StopTrialRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StopTrialRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Study' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Study.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigMetricSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigMetricSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecCategoricalValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecCategoricalValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecDiscreteValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecDiscreteValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecDoubleValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecDoubleValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecIntegerValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecIntegerValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecMatchingParentCategoricalValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecMatchingParentCategoricalValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecMatchingParentDiscreteValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecMatchingParentDiscreteValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1StudyConfigParameterSpecMatchingParentIntValueSpec' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1StudyConfigParameterSpecMatchingParentIntValueSpec.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1SuggestTrialsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1SuggestTrialsMetadata.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1SuggestTrialsRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1SuggestTrialsRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1SuggestTrialsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1SuggestTrialsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1TrainingInput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1TrainingInput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1TrainingOutput' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1TrainingOutput.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Trial' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Trial.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1TrialParameter' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1TrialParameter.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1Version' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1Version.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleCloudMlV1XraiAttribution' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleCloudMlV1XraiAttribution.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1AuditConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1Binding.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1Policy.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleLongrunningOperation.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleRpcStatus.php',
    'Google\\Service\\CloudMachineLearningEngine\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/GoogleTypeExpr.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/Projects.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsJobs' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsJobs.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsLocationsStudies' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsLocationsStudies.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsLocationsStudiesTrials' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsLocationsStudiesTrials.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsModels' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsModels.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsModelsVersions' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsModelsVersions.php',
    'Google\\Service\\CloudMachineLearningEngine\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/CloudMachineLearningEngine/Resource/ProjectsOperations.php',
    'Google\\Service\\CloudMemorystoreforMemcached' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\ApplyParametersRequest' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/ApplyParametersRequest.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/CancelOperationRequest.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\DailyCycle' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/DailyCycle.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Date' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Date.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/DenyMaintenancePeriod.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudMemcacheV1LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudMemcacheV1LocationMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudMemcacheV1MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudMemcacheV1MaintenancePolicy.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudMemcacheV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudMemcacheV1OperationMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudMemcacheV1UpgradeInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudMemcacheV1UpgradeInstanceRequest.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudMemcacheV1ZoneMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudMemcacheV1ZoneMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1Instance' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1Instance.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Instance' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Instance.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\InstanceMessage' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/InstanceMessage.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/ListInstancesResponse.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/ListLocationsResponse.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/ListOperationsResponse.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Location' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Location.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/LocationMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/MaintenancePolicy.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/MaintenanceSchedule.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/MaintenanceWindow.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\MemcacheEmpty' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/MemcacheEmpty.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\MemcacheParameters' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/MemcacheParameters.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Node' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Node.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\NodeConfig' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/NodeConfig.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Operation.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/OperationMetadata.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\RescheduleMaintenanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/RescheduleMaintenanceRequest.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Resource/Projects.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Schedule' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Schedule.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\Status' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/Status.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/TimeOfDay.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\UpdateParametersRequest' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/UpdateParametersRequest.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\UpdatePolicy' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/UpdatePolicy.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\WeeklyCycle' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/WeeklyCycle.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\WeeklyMaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/WeeklyMaintenanceWindow.php',
    'Google\\Service\\CloudMemorystoreforMemcached\\ZoneMetadata' => $vendorDir . '/google/apiclient-services/src/CloudMemorystoreforMemcached/ZoneMetadata.php',
    'Google\\Service\\CloudNaturalLanguage' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeEntitiesRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeEntitiesRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeEntitiesResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeEntitySentimentRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeEntitySentimentRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeEntitySentimentResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeEntitySentimentResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeSentimentRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeSentimentRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeSentimentResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeSentimentResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeSyntaxRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeSyntaxRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\AnalyzeSyntaxResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnalyzeSyntaxResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\AnnotateTextRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnnotateTextRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\AnnotateTextRequestFeatures' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnnotateTextRequestFeatures.php',
    'Google\\Service\\CloudNaturalLanguage\\AnnotateTextResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/AnnotateTextResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\ClassificationCategory' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ClassificationCategory.php',
    'Google\\Service\\CloudNaturalLanguage\\ClassificationModelOptions' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ClassificationModelOptions.php',
    'Google\\Service\\CloudNaturalLanguage\\ClassifyTextRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ClassifyTextRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\ClassifyTextResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ClassifyTextResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\Color' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Color.php',
    'Google\\Service\\CloudNaturalLanguage\\CpuMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/CpuMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\DependencyEdge' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/DependencyEdge.php',
    'Google\\Service\\CloudNaturalLanguage\\DiskMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/DiskMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\Document' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Document.php',
    'Google\\Service\\CloudNaturalLanguage\\Entity' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Entity.php',
    'Google\\Service\\CloudNaturalLanguage\\EntityMention' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/EntityMention.php',
    'Google\\Service\\CloudNaturalLanguage\\Features' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Features.php',
    'Google\\Service\\CloudNaturalLanguage\\GpuMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/GpuMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\InfraUsage' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/InfraUsage.php',
    'Google\\Service\\CloudNaturalLanguage\\ModerateTextRequest' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ModerateTextRequest.php',
    'Google\\Service\\CloudNaturalLanguage\\ModerateTextResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/ModerateTextResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\PartOfSpeech' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/PartOfSpeech.php',
    'Google\\Service\\CloudNaturalLanguage\\RamMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/RamMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\Resource\\Documents' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Resource/Documents.php',
    'Google\\Service\\CloudNaturalLanguage\\Sentence' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Sentence.php',
    'Google\\Service\\CloudNaturalLanguage\\Sentiment' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Sentiment.php',
    'Google\\Service\\CloudNaturalLanguage\\Status' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Status.php',
    'Google\\Service\\CloudNaturalLanguage\\TextSpan' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/TextSpan.php',
    'Google\\Service\\CloudNaturalLanguage\\Token' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/Token.php',
    'Google\\Service\\CloudNaturalLanguage\\TpuMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/TpuMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\V1Model' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/V1Model.php',
    'Google\\Service\\CloudNaturalLanguage\\V2Model' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/V2Model.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSArrayStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSArrayStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSBatchPredictResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSBatchPredictResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSBoundingBoxMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSBoundingBoxMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSBoundingBoxMetricsEntryConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSBoundingBoxMetricsEntryConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSCategoryStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSCategoryStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSCategoryStatsSingleCategoryStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSCategoryStatsSingleCategoryStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSClassificationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSClassificationEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSColorMap' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSColorMap.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSColorMapIntColor' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSColorMapIntColor.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSColumnSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSColumnSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSColumnSpecCorrelatedColumn' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSColumnSpecCorrelatedColumn.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSColumnSpecForecastingMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSColumnSpecForecastingMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSCommonStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSCommonStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSConfusionMatrix' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSConfusionMatrix.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSConfusionMatrixRow' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSConfusionMatrixRow.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSCoreMlFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSCoreMlFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSCorrelationStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSCorrelationStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSDataErrors' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSDataErrors.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSDataStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSDataStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSDataType' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSDataType.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSDockerFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSDockerFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSEdgeTpuTfLiteFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSEdgeTpuTfLiteFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSEvaluationMetricsSet' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSEvaluationMetricsSet.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSExampleSet' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSExampleSet.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSExportModelOutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSExportModelOutputConfig.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSFileSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSFileSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSFloat64Stats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSFloat64Stats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSFloat64StatsHistogramBucket' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSFloat64StatsHistogramBucket.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageClassificationTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageClassificationTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageExportModelSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageExportModelSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageModelArtifactSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageModelArtifactSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageModelServingSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageModelServingSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageModelServingSpecModelThroughputEstimation' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageModelServingSpecModelThroughputEstimation.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageObjectDetectionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageObjectDetectionEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageObjectDetectionModelSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageObjectDetectionModelSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageSegmentationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageSegmentationEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageSegmentationEvaluationMetricsConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageSegmentationEvaluationMetricsConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSImageSegmentationTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSImageSegmentationTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSIntegratedGradientsAttribution' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSIntegratedGradientsAttribution.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSMetricEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSMetricEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSMetricEntryLabel' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSMetricEntryLabel.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSModelArtifactItem' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSModelArtifactItem.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSPreprocessResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSPreprocessResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSRegressionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSRegressionEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSRegressionMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSRegressionMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSReportingMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSReportingMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSResponseExplanationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSResponseExplanationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSResponseExplanationMetadataInputMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSResponseExplanationMetadataInputMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSResponseExplanationMetadataOutputMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSResponseExplanationMetadataOutputMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSResponseExplanationParameters' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSResponseExplanationParameters.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSResponseExplanationSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSResponseExplanationSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSRow' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSRow.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechEvaluationMetricsSubModelEvaluationMetric' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechEvaluationMetricsSubModelEvaluationMetric.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechModelSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechModelSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechModelSpecSubModelSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechModelSpecSubModelSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechPreprocessResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechPreprocessResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSSpeechPreprocessStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSSpeechPreprocessStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSStringStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSStringStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSStringStatsUnigramStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSStringStatsUnigramStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSStructStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSStructStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSStructType' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSStructType.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTableSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTableSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesClassificationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesClassificationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesClassificationMetricsCurveMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesClassificationMetricsCurveMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesDatasetMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesModelColumnInfo' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesModelColumnInfo.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesModelStructure' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesModelStructure.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesModelStructureModelParameters' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesModelStructureModelParameters.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesModelStructureModelParametersParameter' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesModelStructureModelParametersParameter.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesPreprocessResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesPreprocessResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesRegressionMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesRegressionMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTablesTrainingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTablesTrainingOperationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTextComponentModel' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTextComponentModel.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTextExtractionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTextExtractionEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTextSentimentEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTextSentimentEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTextToSpeechTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTextToSpeechTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTextTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTextTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTfJsFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTfJsFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTfLiteFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTfLiteFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTfSavedModelFormat' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTfSavedModelFormat.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTimestampStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTimestampStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTimestampStatsGranularStats' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTimestampStatsGranularStats.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTrackMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTrackMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTrackMetricsEntryConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTrackMetricsEntryConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTrainingObjectivePoint' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTrainingObjectivePoint.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTranslationEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTranslationEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTranslationPreprocessResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTranslationPreprocessResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTranslationTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTranslationTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSTuningTrial' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSTuningTrial.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoActionMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoActionMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoActionMetricsEntryConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoActionMetricsEntryConfidenceMetricsEntry.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoActionRecognitionEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoActionRecognitionEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoActionRecognitionTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoActionRecognitionTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoBatchPredictOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoBatchPredictOperationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoClassificationTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoClassificationTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoExportModelSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoExportModelSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoModelArtifactSpec' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoModelArtifactSpec.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoObjectTrackingEvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoObjectTrackingEvaluationMetrics.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoObjectTrackingTrainResponse' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoObjectTrackingTrainResponse.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVideoTrainingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVideoTrainingOperationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVisionErrorAnalysisConfig' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVisionErrorAnalysisConfig.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVisionTrainingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVisionTrainingOperationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSVisualization' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSVisualization.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSXpsOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSXpsOperationMetadata.php',
    'Google\\Service\\CloudNaturalLanguage\\XPSXraiAttribution' => $vendorDir . '/google/apiclient-services/src/CloudNaturalLanguage/XPSXraiAttribution.php',
    'Google\\Service\\CloudOSLogin' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin.php',
    'Google\\Service\\CloudOSLogin\\ImportSshPublicKeyResponse' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/ImportSshPublicKeyResponse.php',
    'Google\\Service\\CloudOSLogin\\LoginProfile' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/LoginProfile.php',
    'Google\\Service\\CloudOSLogin\\OsloginEmpty' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/OsloginEmpty.php',
    'Google\\Service\\CloudOSLogin\\PosixAccount' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/PosixAccount.php',
    'Google\\Service\\CloudOSLogin\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/Resource/Users.php',
    'Google\\Service\\CloudOSLogin\\Resource\\UsersProjects' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/Resource/UsersProjects.php',
    'Google\\Service\\CloudOSLogin\\Resource\\UsersSshPublicKey' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/Resource/UsersSshPublicKey.php',
    'Google\\Service\\CloudOSLogin\\Resource\\UsersSshPublicKeys' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/Resource/UsersSshPublicKeys.php',
    'Google\\Service\\CloudOSLogin\\SshPublicKey' => $vendorDir . '/google/apiclient-services/src/CloudOSLogin/SshPublicKey.php',
    'Google\\Service\\CloudProfiler' => $vendorDir . '/google/apiclient-services/src/CloudProfiler.php',
    'Google\\Service\\CloudProfiler\\CreateProfileRequest' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/CreateProfileRequest.php',
    'Google\\Service\\CloudProfiler\\Deployment' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/Deployment.php',
    'Google\\Service\\CloudProfiler\\ListProfilesResponse' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/ListProfilesResponse.php',
    'Google\\Service\\CloudProfiler\\Profile' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/Profile.php',
    'Google\\Service\\CloudProfiler\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/Resource/Projects.php',
    'Google\\Service\\CloudProfiler\\Resource\\ProjectsProfiles' => $vendorDir . '/google/apiclient-services/src/CloudProfiler/Resource/ProjectsProfiles.php',
    'Google\\Service\\CloudRedis' => $vendorDir . '/google/apiclient-services/src/CloudRedis.php',
    'Google\\Service\\CloudRedis\\AOFConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/AOFConfig.php',
    'Google\\Service\\CloudRedis\\AssetLocation' => $vendorDir . '/google/apiclient-services/src/CloudRedis/AssetLocation.php',
    'Google\\Service\\CloudRedis\\AvailabilityConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudRedis/AvailabilityConfiguration.php',
    'Google\\Service\\CloudRedis\\BackupConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudRedis/BackupConfiguration.php',
    'Google\\Service\\CloudRedis\\BackupRun' => $vendorDir . '/google/apiclient-services/src/CloudRedis/BackupRun.php',
    'Google\\Service\\CloudRedis\\BlobstoreLocation' => $vendorDir . '/google/apiclient-services/src/CloudRedis/BlobstoreLocation.php',
    'Google\\Service\\CloudRedis\\CertChain' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CertChain.php',
    'Google\\Service\\CloudRedis\\CertificateAuthority' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CertificateAuthority.php',
    'Google\\Service\\CloudRedis\\CloudAsset' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CloudAsset.php',
    'Google\\Service\\CloudRedis\\CloudAssetComposition' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CloudAssetComposition.php',
    'Google\\Service\\CloudRedis\\Cluster' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Cluster.php',
    'Google\\Service\\CloudRedis\\ClusterMaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ClusterMaintenancePolicy.php',
    'Google\\Service\\CloudRedis\\ClusterMaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ClusterMaintenanceSchedule.php',
    'Google\\Service\\CloudRedis\\ClusterPersistenceConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ClusterPersistenceConfig.php',
    'Google\\Service\\CloudRedis\\ClusterSlots' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ClusterSlots.php',
    'Google\\Service\\CloudRedis\\ClusterWeeklyMaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ClusterWeeklyMaintenanceWindow.php',
    'Google\\Service\\CloudRedis\\Compliance' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Compliance.php',
    'Google\\Service\\CloudRedis\\CrossClusterReplicationConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CrossClusterReplicationConfig.php',
    'Google\\Service\\CloudRedis\\CustomMetadataData' => $vendorDir . '/google/apiclient-services/src/CloudRedis/CustomMetadataData.php',
    'Google\\Service\\CloudRedis\\DatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseMetadata.php',
    'Google\\Service\\CloudRedis\\DatabaseResourceFeed' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseResourceFeed.php',
    'Google\\Service\\CloudRedis\\DatabaseResourceHealthSignalData' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseResourceHealthSignalData.php',
    'Google\\Service\\CloudRedis\\DatabaseResourceId' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseResourceId.php',
    'Google\\Service\\CloudRedis\\DatabaseResourceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseResourceMetadata.php',
    'Google\\Service\\CloudRedis\\DatabaseResourceRecommendationSignalData' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DatabaseResourceRecommendationSignalData.php',
    'Google\\Service\\CloudRedis\\DirectLocationAssignment' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DirectLocationAssignment.php',
    'Google\\Service\\CloudRedis\\DiscoveryEndpoint' => $vendorDir . '/google/apiclient-services/src/CloudRedis/DiscoveryEndpoint.php',
    'Google\\Service\\CloudRedis\\Endpoint' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Endpoint.php',
    'Google\\Service\\CloudRedis\\Entitlement' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Entitlement.php',
    'Google\\Service\\CloudRedis\\ExportInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ExportInstanceRequest.php',
    'Google\\Service\\CloudRedis\\ExtraParameter' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ExtraParameter.php',
    'Google\\Service\\CloudRedis\\FailoverInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/FailoverInstanceRequest.php',
    'Google\\Service\\CloudRedis\\GcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudRedis/GcsDestination.php',
    'Google\\Service\\CloudRedis\\GcsSource' => $vendorDir . '/google/apiclient-services/src/CloudRedis/GcsSource.php',
    'Google\\Service\\CloudRedis\\GoogleCloudRedisV1LocationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/GoogleCloudRedisV1LocationMetadata.php',
    'Google\\Service\\CloudRedis\\GoogleCloudRedisV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/GoogleCloudRedisV1OperationMetadata.php',
    'Google\\Service\\CloudRedis\\GoogleCloudRedisV1ZoneMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/GoogleCloudRedisV1ZoneMetadata.php',
    'Google\\Service\\CloudRedis\\ImportInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ImportInstanceRequest.php',
    'Google\\Service\\CloudRedis\\InputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/InputConfig.php',
    'Google\\Service\\CloudRedis\\Instance' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Instance.php',
    'Google\\Service\\CloudRedis\\InstanceAuthString' => $vendorDir . '/google/apiclient-services/src/CloudRedis/InstanceAuthString.php',
    'Google\\Service\\CloudRedis\\InternalResourceMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/InternalResourceMetadata.php',
    'Google\\Service\\CloudRedis\\IsolationExpectations' => $vendorDir . '/google/apiclient-services/src/CloudRedis/IsolationExpectations.php',
    'Google\\Service\\CloudRedis\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ListClustersResponse.php',
    'Google\\Service\\CloudRedis\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ListInstancesResponse.php',
    'Google\\Service\\CloudRedis\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ListLocationsResponse.php',
    'Google\\Service\\CloudRedis\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ListOperationsResponse.php',
    'Google\\Service\\CloudRedis\\Location' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Location.php',
    'Google\\Service\\CloudRedis\\LocationAssignment' => $vendorDir . '/google/apiclient-services/src/CloudRedis/LocationAssignment.php',
    'Google\\Service\\CloudRedis\\LocationData' => $vendorDir . '/google/apiclient-services/src/CloudRedis/LocationData.php',
    'Google\\Service\\CloudRedis\\MachineConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudRedis/MachineConfiguration.php',
    'Google\\Service\\CloudRedis\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/CloudRedis/MaintenancePolicy.php',
    'Google\\Service\\CloudRedis\\MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/CloudRedis/MaintenanceSchedule.php',
    'Google\\Service\\CloudRedis\\ManagedCertificateAuthority' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ManagedCertificateAuthority.php',
    'Google\\Service\\CloudRedis\\Membership' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Membership.php',
    'Google\\Service\\CloudRedis\\NodeInfo' => $vendorDir . '/google/apiclient-services/src/CloudRedis/NodeInfo.php',
    'Google\\Service\\CloudRedis\\ObservabilityMetricData' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ObservabilityMetricData.php',
    'Google\\Service\\CloudRedis\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Operation.php',
    'Google\\Service\\CloudRedis\\OperationError' => $vendorDir . '/google/apiclient-services/src/CloudRedis/OperationError.php',
    'Google\\Service\\CloudRedis\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/OperationMetadata.php',
    'Google\\Service\\CloudRedis\\OutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/OutputConfig.php',
    'Google\\Service\\CloudRedis\\PersistenceConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/PersistenceConfig.php',
    'Google\\Service\\CloudRedis\\PlacerLocation' => $vendorDir . '/google/apiclient-services/src/CloudRedis/PlacerLocation.php',
    'Google\\Service\\CloudRedis\\PrivateServiceConnect' => $vendorDir . '/google/apiclient-services/src/CloudRedis/PrivateServiceConnect.php',
    'Google\\Service\\CloudRedis\\Product' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Product.php',
    'Google\\Service\\CloudRedis\\PscConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/PscConfig.php',
    'Google\\Service\\CloudRedis\\PscConnection' => $vendorDir . '/google/apiclient-services/src/CloudRedis/PscConnection.php',
    'Google\\Service\\CloudRedis\\RDBConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RDBConfig.php',
    'Google\\Service\\CloudRedis\\ReconciliationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ReconciliationOperationMetadata.php',
    'Google\\Service\\CloudRedis\\RedisEmpty' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RedisEmpty.php',
    'Google\\Service\\CloudRedis\\RegionalMigDistributionPolicy' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RegionalMigDistributionPolicy.php',
    'Google\\Service\\CloudRedis\\RemoteCluster' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RemoteCluster.php',
    'Google\\Service\\CloudRedis\\RequirementOverride' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RequirementOverride.php',
    'Google\\Service\\CloudRedis\\RescheduleClusterMaintenanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RescheduleClusterMaintenanceRequest.php',
    'Google\\Service\\CloudRedis\\RescheduleMaintenanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RescheduleMaintenanceRequest.php',
    'Google\\Service\\CloudRedis\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Resource/Projects.php',
    'Google\\Service\\CloudRedis\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudRedis\\Resource\\ProjectsLocationsClusters' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Resource/ProjectsLocationsClusters.php',
    'Google\\Service\\CloudRedis\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\CloudRedis\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudRedis\\RetentionSettings' => $vendorDir . '/google/apiclient-services/src/CloudRedis/RetentionSettings.php',
    'Google\\Service\\CloudRedis\\SpannerLocation' => $vendorDir . '/google/apiclient-services/src/CloudRedis/SpannerLocation.php',
    'Google\\Service\\CloudRedis\\StateInfo' => $vendorDir . '/google/apiclient-services/src/CloudRedis/StateInfo.php',
    'Google\\Service\\CloudRedis\\Status' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Status.php',
    'Google\\Service\\CloudRedis\\Tags' => $vendorDir . '/google/apiclient-services/src/CloudRedis/Tags.php',
    'Google\\Service\\CloudRedis\\TenantProjectProxy' => $vendorDir . '/google/apiclient-services/src/CloudRedis/TenantProjectProxy.php',
    'Google\\Service\\CloudRedis\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/CloudRedis/TimeOfDay.php',
    'Google\\Service\\CloudRedis\\TlsCertificate' => $vendorDir . '/google/apiclient-services/src/CloudRedis/TlsCertificate.php',
    'Google\\Service\\CloudRedis\\TypedValue' => $vendorDir . '/google/apiclient-services/src/CloudRedis/TypedValue.php',
    'Google\\Service\\CloudRedis\\UpdateInfo' => $vendorDir . '/google/apiclient-services/src/CloudRedis/UpdateInfo.php',
    'Google\\Service\\CloudRedis\\UpgradeInstanceRequest' => $vendorDir . '/google/apiclient-services/src/CloudRedis/UpgradeInstanceRequest.php',
    'Google\\Service\\CloudRedis\\UserLabels' => $vendorDir . '/google/apiclient-services/src/CloudRedis/UserLabels.php',
    'Google\\Service\\CloudRedis\\WeeklyMaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/CloudRedis/WeeklyMaintenanceWindow.php',
    'Google\\Service\\CloudRedis\\ZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ZoneConfiguration.php',
    'Google\\Service\\CloudRedis\\ZoneDistributionConfig' => $vendorDir . '/google/apiclient-services/src/CloudRedis/ZoneDistributionConfig.php',
    'Google\\Service\\CloudResourceManager' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager.php',
    'Google\\Service\\CloudResourceManager\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/AuditConfig.php',
    'Google\\Service\\CloudResourceManager\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/AuditLogConfig.php',
    'Google\\Service\\CloudResourceManager\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Binding.php',
    'Google\\Service\\CloudResourceManager\\CloudresourcemanagerEmpty' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CloudresourcemanagerEmpty.php',
    'Google\\Service\\CloudResourceManager\\CloudresourcemanagerGoogleCloudResourcemanagerV2alpha1FolderOperation' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CloudresourcemanagerGoogleCloudResourcemanagerV2alpha1FolderOperation.php',
    'Google\\Service\\CloudResourceManager\\CloudresourcemanagerGoogleCloudResourcemanagerV2beta1FolderOperation' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CloudresourcemanagerGoogleCloudResourcemanagerV2beta1FolderOperation.php',
    'Google\\Service\\CloudResourceManager\\CreateFolderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CreateFolderMetadata.php',
    'Google\\Service\\CloudResourceManager\\CreateProjectMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CreateProjectMetadata.php',
    'Google\\Service\\CloudResourceManager\\CreateTagBindingMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CreateTagBindingMetadata.php',
    'Google\\Service\\CloudResourceManager\\CreateTagKeyMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CreateTagKeyMetadata.php',
    'Google\\Service\\CloudResourceManager\\CreateTagValueMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/CreateTagValueMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteFolderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteFolderMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteOrganizationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteOrganizationMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteProjectMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteProjectMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteTagBindingMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteTagBindingMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteTagKeyMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteTagKeyMetadata.php',
    'Google\\Service\\CloudResourceManager\\DeleteTagValueMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/DeleteTagValueMetadata.php',
    'Google\\Service\\CloudResourceManager\\EffectiveTag' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/EffectiveTag.php',
    'Google\\Service\\CloudResourceManager\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Expr.php',
    'Google\\Service\\CloudResourceManager\\Folder' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Folder.php',
    'Google\\Service\\CloudResourceManager\\FolderOperation' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/FolderOperation.php',
    'Google\\Service\\CloudResourceManager\\FolderOperationError' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/FolderOperationError.php',
    'Google\\Service\\CloudResourceManager\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/GetIamPolicyRequest.php',
    'Google\\Service\\CloudResourceManager\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/GetPolicyOptions.php',
    'Google\\Service\\CloudResourceManager\\Lien' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Lien.php',
    'Google\\Service\\CloudResourceManager\\ListEffectiveTagsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListEffectiveTagsResponse.php',
    'Google\\Service\\CloudResourceManager\\ListFoldersResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListFoldersResponse.php',
    'Google\\Service\\CloudResourceManager\\ListLiensResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListLiensResponse.php',
    'Google\\Service\\CloudResourceManager\\ListProjectsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListProjectsResponse.php',
    'Google\\Service\\CloudResourceManager\\ListTagBindingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListTagBindingsResponse.php',
    'Google\\Service\\CloudResourceManager\\ListTagHoldsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListTagHoldsResponse.php',
    'Google\\Service\\CloudResourceManager\\ListTagKeysResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListTagKeysResponse.php',
    'Google\\Service\\CloudResourceManager\\ListTagValuesResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ListTagValuesResponse.php',
    'Google\\Service\\CloudResourceManager\\MoveFolderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/MoveFolderMetadata.php',
    'Google\\Service\\CloudResourceManager\\MoveFolderRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/MoveFolderRequest.php',
    'Google\\Service\\CloudResourceManager\\MoveProjectMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/MoveProjectMetadata.php',
    'Google\\Service\\CloudResourceManager\\MoveProjectRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/MoveProjectRequest.php',
    'Google\\Service\\CloudResourceManager\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Operation.php',
    'Google\\Service\\CloudResourceManager\\Organization' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Organization.php',
    'Google\\Service\\CloudResourceManager\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Policy.php',
    'Google\\Service\\CloudResourceManager\\Project' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Project.php',
    'Google\\Service\\CloudResourceManager\\ProjectCreationStatus' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/ProjectCreationStatus.php',
    'Google\\Service\\CloudResourceManager\\Resource\\EffectiveTags' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/EffectiveTags.php',
    'Google\\Service\\CloudResourceManager\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/Folders.php',
    'Google\\Service\\CloudResourceManager\\Resource\\Liens' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/Liens.php',
    'Google\\Service\\CloudResourceManager\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/Operations.php',
    'Google\\Service\\CloudResourceManager\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/Organizations.php',
    'Google\\Service\\CloudResourceManager\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/Projects.php',
    'Google\\Service\\CloudResourceManager\\Resource\\TagBindings' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/TagBindings.php',
    'Google\\Service\\CloudResourceManager\\Resource\\TagKeys' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/TagKeys.php',
    'Google\\Service\\CloudResourceManager\\Resource\\TagValues' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/TagValues.php',
    'Google\\Service\\CloudResourceManager\\Resource\\TagValuesTagHolds' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Resource/TagValuesTagHolds.php',
    'Google\\Service\\CloudResourceManager\\SearchFoldersResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/SearchFoldersResponse.php',
    'Google\\Service\\CloudResourceManager\\SearchOrganizationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/SearchOrganizationsResponse.php',
    'Google\\Service\\CloudResourceManager\\SearchProjectsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/SearchProjectsResponse.php',
    'Google\\Service\\CloudResourceManager\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/SetIamPolicyRequest.php',
    'Google\\Service\\CloudResourceManager\\Status' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/Status.php',
    'Google\\Service\\CloudResourceManager\\TagBinding' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TagBinding.php',
    'Google\\Service\\CloudResourceManager\\TagHold' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TagHold.php',
    'Google\\Service\\CloudResourceManager\\TagKey' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TagKey.php',
    'Google\\Service\\CloudResourceManager\\TagValue' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TagValue.php',
    'Google\\Service\\CloudResourceManager\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudResourceManager\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudResourceManager\\UndeleteFolderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UndeleteFolderMetadata.php',
    'Google\\Service\\CloudResourceManager\\UndeleteFolderRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UndeleteFolderRequest.php',
    'Google\\Service\\CloudResourceManager\\UndeleteOrganizationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UndeleteOrganizationMetadata.php',
    'Google\\Service\\CloudResourceManager\\UndeleteProjectMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UndeleteProjectMetadata.php',
    'Google\\Service\\CloudResourceManager\\UndeleteProjectRequest' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UndeleteProjectRequest.php',
    'Google\\Service\\CloudResourceManager\\UpdateFolderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UpdateFolderMetadata.php',
    'Google\\Service\\CloudResourceManager\\UpdateProjectMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UpdateProjectMetadata.php',
    'Google\\Service\\CloudResourceManager\\UpdateTagKeyMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UpdateTagKeyMetadata.php',
    'Google\\Service\\CloudResourceManager\\UpdateTagValueMetadata' => $vendorDir . '/google/apiclient-services/src/CloudResourceManager/UpdateTagValueMetadata.php',
    'Google\\Service\\CloudRetail' => $vendorDir . '/google/apiclient-services/src/CloudRetail.php',
    'Google\\Service\\CloudRetail\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleApiHttpBody.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingErrorContext' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingErrorContext.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingErrorLog' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingErrorLog.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingHttpRequestContext' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingHttpRequestContext.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingImportErrorContext' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingImportErrorContext.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingServiceContext' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingServiceContext.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailLoggingSourceLocation' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailLoggingSourceLocation.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddCatalogAttributeRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddCatalogAttributeRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddControlRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddControlRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddFulfillmentPlacesRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddFulfillmentPlacesRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddLocalInventoriesRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddLocalInventoriesRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AddLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AddLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2AttributesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2AttributesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Audience' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Audience.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2BigQueryOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2BigQueryOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2BigQuerySource' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2BigQuerySource.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Catalog' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Catalog.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttribute' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttribute.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttributeFacetConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttributeFacetConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttributeFacetConfigIgnoredFacetValues' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttributeFacetConfigIgnoredFacetValues.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttributeFacetConfigMergedFacet' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttributeFacetConfigMergedFacet.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttributeFacetConfigMergedFacetValue' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttributeFacetConfigMergedFacetValue.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CatalogAttributeFacetConfigRerankConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CatalogAttributeFacetConfigRerankConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ColorInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ColorInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompleteQueryResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompleteQueryResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompleteQueryResponseAttributeResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompleteQueryResponseAttributeResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompleteQueryResponseCompletionResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompleteQueryResponseCompletionResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompleteQueryResponseRecentSearchResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompleteQueryResponseRecentSearchResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompletionConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompletionConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompletionDataInputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompletionDataInputConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CompletionDetail' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CompletionDetail.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Condition' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Condition.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ConditionQueryTerm' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ConditionQueryTerm.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ConditionTimeRange' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ConditionTimeRange.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Control' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Control.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CreateModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CreateModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2CustomAttribute' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2CustomAttribute.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExperimentInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExperimentInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExperimentInfoServingConfigExperiment' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExperimentInfoServingConfigExperiment.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExportAnalyticsMetricsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExportAnalyticsMetricsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExportAnalyticsMetricsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExportAnalyticsMetricsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ExportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ExportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2FulfillmentInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2FulfillmentInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2GcsOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2GcsOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2GcsSource' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2GcsSource.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2GetDefaultBranchResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2GetDefaultBranchResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Image' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Image.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportCompletionDataRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportCompletionDataRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportCompletionDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportCompletionDataResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportProductsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportProductsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportUserEventsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ImportUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Interval' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Interval.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ListCatalogsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ListCatalogsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ListControlsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ListControlsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ListModelsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ListModelsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ListProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ListServingConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ListServingConfigsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2LocalInventory' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2LocalInventory.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Model' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Model.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ModelFrequentlyBoughtTogetherFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ModelFrequentlyBoughtTogetherFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ModelModelFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ModelModelFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ModelServingConfigList' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ModelServingConfigList.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2OutputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2OutputConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2OutputConfigBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2OutputConfigBigQueryDestination.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2OutputConfigGcsDestination' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2OutputConfigGcsDestination.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2OutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2OutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PauseModelRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PauseModelRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PredictRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PredictRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PredictResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PredictResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PredictResponsePredictionResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PredictResponsePredictionResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PriceInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PriceInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PriceInfoPriceRange' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PriceInfoPriceRange.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Product' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Product.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ProductDetail' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ProductDetail.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ProductInlineSource' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ProductInlineSource.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ProductInputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ProductInputConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ProductLevelConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ProductLevelConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Promotion' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Promotion.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurchaseTransaction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurchaseTransaction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeProductsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeProductsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeProductsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeProductsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeUserEventsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2PurgeUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2PurgeUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Rating' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Rating.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RejoinUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RejoinUserEventsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RejoinUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RejoinUserEventsRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RejoinUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RejoinUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveCatalogAttributeRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveCatalogAttributeRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveControlRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveControlRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveFulfillmentPlacesRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveFulfillmentPlacesRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveLocalInventoriesRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveLocalInventoriesRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RemoveLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RemoveLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ReplaceCatalogAttributeRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ReplaceCatalogAttributeRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ResumeModelRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ResumeModelRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2Rule' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2Rule.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleBoostAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleBoostAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleDoNotAssociateAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleDoNotAssociateAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleFilterAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleFilterAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleForceReturnFacetAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleForceReturnFacetAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleForceReturnFacetActionFacetPositionAdjustment' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleForceReturnFacetActionFacetPositionAdjustment.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleIgnoreAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleIgnoreAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleOnewaySynonymsAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleOnewaySynonymsAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleRedirectAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleRedirectAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleRemoveFacetAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleRemoveFacetAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleReplacementAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleReplacementAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2RuleTwowaySynonymsAction' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2RuleTwowaySynonymsAction.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestBoostSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestBoostSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestDynamicFacetSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestDynamicFacetSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestFacetSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestFacetSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestFacetSpecFacetKey' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestFacetSpecFacetKey.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestPersonalizationSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestPersonalizationSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestQueryExpansionSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestQueryExpansionSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchRequestSpellCorrectionSpec' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchRequestSpellCorrectionSpec.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchResponseFacet' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchResponseFacet.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchResponseFacetFacetValue' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchResponseFacetFacetValue.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchResponseQueryExpansionInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchResponseQueryExpansionInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SearchResponseSearchResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SearchResponseSearchResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2ServingConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2ServingConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SetDefaultBranchRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SetDefaultBranchRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SetInventoryMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SetInventoryMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SetInventoryRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SetInventoryRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2SetInventoryResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2SetInventoryResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2TuneModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2TuneModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2TuneModelRequest' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2TuneModelRequest.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2TuneModelResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2TuneModelResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2UserEvent' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2UserEvent.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2UserEventImportSummary' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2UserEventImportSummary.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2UserEventInlineSource' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2UserEventInlineSource.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2UserEventInputConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2UserEventInputConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2UserInfo' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2UserInfo.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaAddFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaAddFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaAddFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaAddFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaAddLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaAddLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaAddLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaAddLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaBigQueryOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaBigQueryOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaCreateMerchantCenterAccountLinkMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaCreateMerchantCenterAccountLinkMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaCreateModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaCreateModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaEnrollSolutionMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaEnrollSolutionMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaEnrollSolutionResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaEnrollSolutionResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaExportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaExportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaExportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaExportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaExportProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaExportProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaExportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaExportUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaGcsOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaGcsOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaImportCompletionDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaImportCompletionDataResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaImportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaImportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaImportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaImportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaImportProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaImportProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaImportUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaMerchantCenterAccountLink' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaMerchantCenterAccountLink.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaMerchantCenterAccountLinkMerchantCenterFeedFilter' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaMerchantCenterAccountLinkMerchantCenterFeedFilter.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModel' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModel.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelFrequentlyBoughtTogetherFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelFrequentlyBoughtTogetherFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelModelFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelModelFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelPageOptimizationConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelPageOptimizationConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelPageOptimizationConfigCandidate' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelPageOptimizationConfigCandidate.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelPageOptimizationConfigPanel.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaModelServingConfigList' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaModelServingConfigList.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaPurgeMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaPurgeMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaPurgeProductsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaPurgeProductsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaPurgeProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaPurgeProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaPurgeUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaPurgeUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRejoinUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRejoinUserEventsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRejoinUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRejoinUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRemoveFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRemoveFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRemoveFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRemoveFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRemoveLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRemoveLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaRemoveLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaRemoveLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaSetInventoryMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaSetInventoryMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaSetInventoryResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaSetInventoryResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaSetLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaSetLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaSetLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaSetLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaTransformedUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaTransformedUserEventsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaTuneModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaTuneModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaTuneModelResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaTuneModelResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2alphaUserEventImportSummary' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2alphaUserEventImportSummary.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaAddFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaAddFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaAddFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaAddFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaAddLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaAddLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaAddLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaAddLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaBigQueryOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaBigQueryOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaCreateMerchantCenterAccountLinkMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaCreateMerchantCenterAccountLinkMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaCreateModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaCreateModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaExportAnalyticsMetricsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaExportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaExportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaExportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaExportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaExportProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaExportProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaExportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaExportUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaGcsOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaGcsOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaImportCompletionDataResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaImportCompletionDataResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaImportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaImportErrorsConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaImportMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaImportMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaImportProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaImportProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaImportUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaMerchantCenterAccountLink' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaMerchantCenterAccountLink.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaMerchantCenterAccountLinkMerchantCenterFeedFilter' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaMerchantCenterAccountLinkMerchantCenterFeedFilter.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaModel' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaModel.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaModelFrequentlyBoughtTogetherFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaModelFrequentlyBoughtTogetherFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaModelModelFeaturesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaModelModelFeaturesConfig.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaModelServingConfigList' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaModelServingConfigList.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaOutputResult' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaOutputResult.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaPurgeMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaPurgeMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaPurgeProductsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaPurgeProductsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaPurgeProductsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaPurgeProductsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaPurgeUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaPurgeUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRejoinUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRejoinUserEventsMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRejoinUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRejoinUserEventsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRemoveFulfillmentPlacesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRemoveFulfillmentPlacesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRemoveFulfillmentPlacesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRemoveFulfillmentPlacesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRemoveLocalInventoriesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRemoveLocalInventoriesMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaRemoveLocalInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaRemoveLocalInventoriesResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaSetInventoryMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaSetInventoryMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaSetInventoryResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaSetInventoryResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaTuneModelMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaTuneModelMetadata.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaTuneModelResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaTuneModelResponse.php',
    'Google\\Service\\CloudRetail\\GoogleCloudRetailV2betaUserEventImportSummary' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleCloudRetailV2betaUserEventImportSummary.php',
    'Google\\Service\\CloudRetail\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\CloudRetail\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleLongrunningOperation.php',
    'Google\\Service\\CloudRetail\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudRetail\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleRpcStatus.php',
    'Google\\Service\\CloudRetail\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/CloudRetail/GoogleTypeDate.php',
    'Google\\Service\\CloudRetail\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/Projects.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogs' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogs.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsAttributesConfig' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsAttributesConfig.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsBranches' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsBranches.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsBranchesOperations' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsBranchesOperations.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsBranchesProducts' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsBranchesProducts.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsCompletionData' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsCompletionData.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsControls' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsControls.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsModels' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsModels.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsOperations' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsOperations.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsPlacements' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsPlacements.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsServingConfigs' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsServingConfigs.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsCatalogsUserEvents' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsCatalogsUserEvents.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudRetail\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/CloudRetail/Resource/ProjectsOperations.php',
    'Google\\Service\\CloudRun' => $vendorDir . '/google/apiclient-services/src/CloudRun.php',
    'Google\\Service\\CloudRun\\Addressable' => $vendorDir . '/google/apiclient-services/src/CloudRun/Addressable.php',
    'Google\\Service\\CloudRun\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/AuditConfig.php',
    'Google\\Service\\CloudRun\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/AuditLogConfig.php',
    'Google\\Service\\CloudRun\\AuthorizedDomain' => $vendorDir . '/google/apiclient-services/src/CloudRun/AuthorizedDomain.php',
    'Google\\Service\\CloudRun\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudRun/Binding.php',
    'Google\\Service\\CloudRun\\ConfigMapEnvSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/ConfigMapEnvSource.php',
    'Google\\Service\\CloudRun\\ConfigMapKeySelector' => $vendorDir . '/google/apiclient-services/src/CloudRun/ConfigMapKeySelector.php',
    'Google\\Service\\CloudRun\\ConfigMapVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/ConfigMapVolumeSource.php',
    'Google\\Service\\CloudRun\\Configuration' => $vendorDir . '/google/apiclient-services/src/CloudRun/Configuration.php',
    'Google\\Service\\CloudRun\\ConfigurationSpec' => $vendorDir . '/google/apiclient-services/src/CloudRun/ConfigurationSpec.php',
    'Google\\Service\\CloudRun\\ConfigurationStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/ConfigurationStatus.php',
    'Google\\Service\\CloudRun\\Container' => $vendorDir . '/google/apiclient-services/src/CloudRun/Container.php',
    'Google\\Service\\CloudRun\\ContainerPort' => $vendorDir . '/google/apiclient-services/src/CloudRun/ContainerPort.php',
    'Google\\Service\\CloudRun\\DomainMapping' => $vendorDir . '/google/apiclient-services/src/CloudRun/DomainMapping.php',
    'Google\\Service\\CloudRun\\DomainMappingSpec' => $vendorDir . '/google/apiclient-services/src/CloudRun/DomainMappingSpec.php',
    'Google\\Service\\CloudRun\\DomainMappingStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/DomainMappingStatus.php',
    'Google\\Service\\CloudRun\\EnvFromSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/EnvFromSource.php',
    'Google\\Service\\CloudRun\\EnvVar' => $vendorDir . '/google/apiclient-services/src/CloudRun/EnvVar.php',
    'Google\\Service\\CloudRun\\EnvVarSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/EnvVarSource.php',
    'Google\\Service\\CloudRun\\ExecAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/ExecAction.php',
    'Google\\Service\\CloudRun\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudRun/Expr.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2BinaryAuthorization' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2BinaryAuthorization.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2CloudSqlInstance' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2CloudSqlInstance.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2Condition' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2Condition.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2Container' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2Container.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2ContainerPort' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2ContainerPort.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2EnvVar' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2EnvVar.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2EnvVarSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2EnvVarSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2ListRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2ListRevisionsResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2ListServicesResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2ResourceRequirements' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2ResourceRequirements.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2Revision' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2Revision.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2RevisionScaling' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2RevisionScaling.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2RevisionTemplate' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2RevisionTemplate.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2SecretKeySelector' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2SecretKeySelector.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2SecretVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2SecretVolumeSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2Service' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2Service.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2TrafficTarget' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2TrafficTarget.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2TrafficTargetStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2TrafficTargetStatus.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2VersionToPath' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2VersionToPath.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2Volume' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2Volume.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2VolumeMount' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2VolumeMount.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunOpV2VpcAccess' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunOpV2VpcAccess.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV1Condition' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV1Condition.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2BinaryAuthorization' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2BinaryAuthorization.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2BuildpacksBuild' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2BuildpacksBuild.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2CancelExecutionRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2CancelExecutionRequest.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2CloudSqlInstance' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2CloudSqlInstance.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Condition' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Condition.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Container' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Container.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ContainerOverride' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ContainerOverride.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ContainerPort' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ContainerPort.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ContainerStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ContainerStatus.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2DockerBuild' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2DockerBuild.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2EmptyDirVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2EmptyDirVolumeSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2EnvVar' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2EnvVar.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2EnvVarSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2EnvVarSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Execution' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Execution.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ExecutionReference' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ExecutionReference.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ExecutionTemplate' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ExecutionTemplate.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ExportImageRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ExportImageRequest.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ExportImageResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ExportImageResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ExportStatusResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ExportStatusResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2GCSVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2GCSVolumeSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2GRPCAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2GRPCAction.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2HTTPGetAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2HTTPGetAction.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2HTTPHeader' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2HTTPHeader.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ImageExportStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ImageExportStatus.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Job' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Job.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ListExecutionsResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ListJobsResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ListRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ListRevisionsResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ListServicesResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ListTasksResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ListTasksResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Metadata' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Metadata.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2NFSVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2NFSVolumeSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2NetworkInterface' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2NetworkInterface.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2NodeSelector' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2NodeSelector.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Overrides' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Overrides.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Probe' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Probe.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ResourceRequirements' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ResourceRequirements.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Revision' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Revision.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2RevisionScaling' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2RevisionScaling.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2RevisionScalingStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2RevisionScalingStatus.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2RevisionTemplate' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2RevisionTemplate.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2RunJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2RunJobRequest.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2SecretKeySelector' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2SecretKeySelector.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2SecretVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2SecretVolumeSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Service' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Service.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ServiceMesh' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ServiceMesh.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2ServiceScaling' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2ServiceScaling.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2StorageSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2StorageSource.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2SubmitBuildRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2SubmitBuildRequest.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2SubmitBuildResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2SubmitBuildResponse.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2TCPSocketAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2TCPSocketAction.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Task' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Task.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2TaskAttemptResult' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2TaskAttemptResult.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2TaskTemplate' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2TaskTemplate.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2TrafficTarget' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2TrafficTarget.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2TrafficTargetStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2TrafficTargetStatus.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2VersionToPath' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2VersionToPath.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2Volume' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2Volume.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2VolumeMount' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2VolumeMount.php',
    'Google\\Service\\CloudRun\\GoogleCloudRunV2VpcAccess' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleCloudRunV2VpcAccess.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1ApprovalConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1ApprovalConfig.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1ApprovalResult' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1ApprovalResult.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1ArtifactObjects' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1ArtifactObjects.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Artifacts' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Artifacts.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Build' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Build.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1BuildApproval' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1BuildApproval.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1BuildOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1BuildOperationMetadata.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1BuildOptions' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1BuildOptions.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1BuildStep' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1BuildStep.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1BuiltImage' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1BuiltImage.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1ConnectedRepository' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1ConnectedRepository.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1DeveloperConnectConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1DeveloperConnectConfig.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1FailureInfo' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1FailureInfo.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1FileHashes' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1FileHashes.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1GCSLocation' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1GCSLocation.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1GitConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1GitConfig.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1GitSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1GitSource.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Hash' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Hash.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1HttpConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1HttpConfig.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1InlineSecret' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1InlineSecret.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1MavenArtifact' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1MavenArtifact.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1NpmPackage' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1NpmPackage.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1PoolOption' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1PoolOption.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1PythonPackage' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1PythonPackage.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1RepoSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1RepoSource.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Results' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Results.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Secret' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Secret.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1SecretManagerSecret' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1SecretManagerSecret.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Secrets' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Secrets.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Source' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Source.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1SourceProvenance' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1SourceProvenance.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1StorageSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1StorageSource.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1StorageSourceManifest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1StorageSourceManifest.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1TimeSpan' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1TimeSpan.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1UploadedMavenArtifact' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1UploadedNpmPackage' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1UploadedNpmPackage.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1UploadedPythonPackage' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1UploadedPythonPackage.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Volume' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Volume.php',
    'Google\\Service\\CloudRun\\GoogleDevtoolsCloudbuildV1Warning' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleDevtoolsCloudbuildV1Warning.php',
    'Google\\Service\\CloudRun\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1AuditConfig.php',
    'Google\\Service\\CloudRun\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\CloudRun\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1Binding.php',
    'Google\\Service\\CloudRun\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1Policy.php',
    'Google\\Service\\CloudRun\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\CloudRun\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\CloudRun\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\CloudRun\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\CloudRun\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\CloudRun\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleLongrunningOperation.php',
    'Google\\Service\\CloudRun\\GoogleLongrunningWaitOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleLongrunningWaitOperationRequest.php',
    'Google\\Service\\CloudRun\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudRun\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleRpcStatus.php',
    'Google\\Service\\CloudRun\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/CloudRun/GoogleTypeExpr.php',
    'Google\\Service\\CloudRun\\HTTPGetAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/HTTPGetAction.php',
    'Google\\Service\\CloudRun\\HTTPHeader' => $vendorDir . '/google/apiclient-services/src/CloudRun/HTTPHeader.php',
    'Google\\Service\\CloudRun\\KeyToPath' => $vendorDir . '/google/apiclient-services/src/CloudRun/KeyToPath.php',
    'Google\\Service\\CloudRun\\ListAuthorizedDomainsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListAuthorizedDomainsResponse.php',
    'Google\\Service\\CloudRun\\ListConfigurationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListConfigurationsResponse.php',
    'Google\\Service\\CloudRun\\ListDomainMappingsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListDomainMappingsResponse.php',
    'Google\\Service\\CloudRun\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListLocationsResponse.php',
    'Google\\Service\\CloudRun\\ListMeta' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListMeta.php',
    'Google\\Service\\CloudRun\\ListRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListRevisionsResponse.php',
    'Google\\Service\\CloudRun\\ListRoutesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListRoutesResponse.php',
    'Google\\Service\\CloudRun\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/ListServicesResponse.php',
    'Google\\Service\\CloudRun\\LocalObjectReference' => $vendorDir . '/google/apiclient-services/src/CloudRun/LocalObjectReference.php',
    'Google\\Service\\CloudRun\\Location' => $vendorDir . '/google/apiclient-services/src/CloudRun/Location.php',
    'Google\\Service\\CloudRun\\ObjectMeta' => $vendorDir . '/google/apiclient-services/src/CloudRun/ObjectMeta.php',
    'Google\\Service\\CloudRun\\OwnerReference' => $vendorDir . '/google/apiclient-services/src/CloudRun/OwnerReference.php',
    'Google\\Service\\CloudRun\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudRun/Policy.php',
    'Google\\Service\\CloudRun\\Probe' => $vendorDir . '/google/apiclient-services/src/CloudRun/Probe.php',
    'Google\\Service\\CloudRun\\Proto2BridgeMessageSet' => $vendorDir . '/google/apiclient-services/src/CloudRun/Proto2BridgeMessageSet.php',
    'Google\\Service\\CloudRun\\ResourceRecord' => $vendorDir . '/google/apiclient-services/src/CloudRun/ResourceRecord.php',
    'Google\\Service\\CloudRun\\ResourceRequirements' => $vendorDir . '/google/apiclient-services/src/CloudRun/ResourceRequirements.php',
    'Google\\Service\\CloudRun\\Resource\\Namespaces' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/Namespaces.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesAuthorizeddomains' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesAuthorizeddomains.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesConfigurations' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesConfigurations.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesDomainmappings' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesDomainmappings.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesRevisions' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesRevisions.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesRoutes' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesRoutes.php',
    'Google\\Service\\CloudRun\\Resource\\NamespacesServices' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/NamespacesServices.php',
    'Google\\Service\\CloudRun\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/Operations.php',
    'Google\\Service\\CloudRun\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/Projects.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsAuthorizeddomains' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsAuthorizeddomains.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsAuthorizeddomains' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsAuthorizeddomains.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsBuilds' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsBuilds.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsConfigurations' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsConfigurations.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsDomainmappings' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsDomainmappings.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsJobs' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsJobs.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsJobsExecutions' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsJobsExecutions.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsJobsExecutionsTasks' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsJobsExecutionsTasks.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsRevisions' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsRevisions.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsRoutes' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsRoutes.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsServices' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsServices.php',
    'Google\\Service\\CloudRun\\Resource\\ProjectsLocationsServicesRevisions' => $vendorDir . '/google/apiclient-services/src/CloudRun/Resource/ProjectsLocationsServicesRevisions.php',
    'Google\\Service\\CloudRun\\Revision' => $vendorDir . '/google/apiclient-services/src/CloudRun/Revision.php',
    'Google\\Service\\CloudRun\\RevisionSpec' => $vendorDir . '/google/apiclient-services/src/CloudRun/RevisionSpec.php',
    'Google\\Service\\CloudRun\\RevisionStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/RevisionStatus.php',
    'Google\\Service\\CloudRun\\RevisionTemplate' => $vendorDir . '/google/apiclient-services/src/CloudRun/RevisionTemplate.php',
    'Google\\Service\\CloudRun\\Route' => $vendorDir . '/google/apiclient-services/src/CloudRun/Route.php',
    'Google\\Service\\CloudRun\\RouteSpec' => $vendorDir . '/google/apiclient-services/src/CloudRun/RouteSpec.php',
    'Google\\Service\\CloudRun\\RouteStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/RouteStatus.php',
    'Google\\Service\\CloudRun\\RunEmpty' => $vendorDir . '/google/apiclient-services/src/CloudRun/RunEmpty.php',
    'Google\\Service\\CloudRun\\SecretEnvSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/SecretEnvSource.php',
    'Google\\Service\\CloudRun\\SecretKeySelector' => $vendorDir . '/google/apiclient-services/src/CloudRun/SecretKeySelector.php',
    'Google\\Service\\CloudRun\\SecretVolumeSource' => $vendorDir . '/google/apiclient-services/src/CloudRun/SecretVolumeSource.php',
    'Google\\Service\\CloudRun\\SecurityContext' => $vendorDir . '/google/apiclient-services/src/CloudRun/SecurityContext.php',
    'Google\\Service\\CloudRun\\Service' => $vendorDir . '/google/apiclient-services/src/CloudRun/Service.php',
    'Google\\Service\\CloudRun\\ServiceSpec' => $vendorDir . '/google/apiclient-services/src/CloudRun/ServiceSpec.php',
    'Google\\Service\\CloudRun\\ServiceStatus' => $vendorDir . '/google/apiclient-services/src/CloudRun/ServiceStatus.php',
    'Google\\Service\\CloudRun\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/SetIamPolicyRequest.php',
    'Google\\Service\\CloudRun\\Status' => $vendorDir . '/google/apiclient-services/src/CloudRun/Status.php',
    'Google\\Service\\CloudRun\\StatusCause' => $vendorDir . '/google/apiclient-services/src/CloudRun/StatusCause.php',
    'Google\\Service\\CloudRun\\StatusDetails' => $vendorDir . '/google/apiclient-services/src/CloudRun/StatusDetails.php',
    'Google\\Service\\CloudRun\\TCPSocketAction' => $vendorDir . '/google/apiclient-services/src/CloudRun/TCPSocketAction.php',
    'Google\\Service\\CloudRun\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudRun/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudRun\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRun/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudRun\\TrafficTarget' => $vendorDir . '/google/apiclient-services/src/CloudRun/TrafficTarget.php',
    'Google\\Service\\CloudRun\\UtilStatusProto' => $vendorDir . '/google/apiclient-services/src/CloudRun/UtilStatusProto.php',
    'Google\\Service\\CloudRun\\Volume' => $vendorDir . '/google/apiclient-services/src/CloudRun/Volume.php',
    'Google\\Service\\CloudRun\\VolumeMount' => $vendorDir . '/google/apiclient-services/src/CloudRun/VolumeMount.php',
    'Google\\Service\\CloudRuntimeConfig' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig.php',
    'Google\\Service\\CloudRuntimeConfig\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/CancelOperationRequest.php',
    'Google\\Service\\CloudRuntimeConfig\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/ListOperationsResponse.php',
    'Google\\Service\\CloudRuntimeConfig\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/Operation.php',
    'Google\\Service\\CloudRuntimeConfig\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/Resource/Operations.php',
    'Google\\Service\\CloudRuntimeConfig\\RuntimeconfigEmpty' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/RuntimeconfigEmpty.php',
    'Google\\Service\\CloudRuntimeConfig\\Status' => $vendorDir . '/google/apiclient-services/src/CloudRuntimeConfig/Status.php',
    'Google\\Service\\CloudScheduler' => $vendorDir . '/google/apiclient-services/src/CloudScheduler.php',
    'Google\\Service\\CloudScheduler\\AppEngineHttpTarget' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/AppEngineHttpTarget.php',
    'Google\\Service\\CloudScheduler\\AppEngineRouting' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/AppEngineRouting.php',
    'Google\\Service\\CloudScheduler\\CloudschedulerEmpty' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/CloudschedulerEmpty.php',
    'Google\\Service\\CloudScheduler\\HttpTarget' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/HttpTarget.php',
    'Google\\Service\\CloudScheduler\\Job' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Job.php',
    'Google\\Service\\CloudScheduler\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/ListJobsResponse.php',
    'Google\\Service\\CloudScheduler\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/ListLocationsResponse.php',
    'Google\\Service\\CloudScheduler\\Location' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Location.php',
    'Google\\Service\\CloudScheduler\\OAuthToken' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/OAuthToken.php',
    'Google\\Service\\CloudScheduler\\OidcToken' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/OidcToken.php',
    'Google\\Service\\CloudScheduler\\PauseJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/PauseJobRequest.php',
    'Google\\Service\\CloudScheduler\\PubsubMessage' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/PubsubMessage.php',
    'Google\\Service\\CloudScheduler\\PubsubTarget' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/PubsubTarget.php',
    'Google\\Service\\CloudScheduler\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Resource/Projects.php',
    'Google\\Service\\CloudScheduler\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudScheduler\\Resource\\ProjectsLocationsJobs' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Resource/ProjectsLocationsJobs.php',
    'Google\\Service\\CloudScheduler\\ResumeJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/ResumeJobRequest.php',
    'Google\\Service\\CloudScheduler\\RetryConfig' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/RetryConfig.php',
    'Google\\Service\\CloudScheduler\\RunJobRequest' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/RunJobRequest.php',
    'Google\\Service\\CloudScheduler\\Status' => $vendorDir . '/google/apiclient-services/src/CloudScheduler/Status.php',
    'Google\\Service\\CloudSearch' => $vendorDir . '/google/apiclient-services/src/CloudSearch.php',
    'Google\\Service\\CloudSearch\\AbuseReportingConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AbuseReportingConfig.php',
    'Google\\Service\\CloudSearch\\AckInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AckInfo.php',
    'Google\\Service\\CloudSearch\\AclFixRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AclFixRequest.php',
    'Google\\Service\\CloudSearch\\AclFixStatus' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AclFixStatus.php',
    'Google\\Service\\CloudSearch\\AclInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AclInfo.php',
    'Google\\Service\\CloudSearch\\Action' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Action.php',
    'Google\\Service\\CloudSearch\\ActionParameter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ActionParameter.php',
    'Google\\Service\\CloudSearch\\AddOnFrameStartingState' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AddOnFrameStartingState.php',
    'Google\\Service\\CloudSearch\\AddOnStartingState' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AddOnStartingState.php',
    'Google\\Service\\CloudSearch\\AddonComposeUiActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AddonComposeUiActionMarkup.php',
    'Google\\Service\\CloudSearch\\AffectedMembership' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AffectedMembership.php',
    'Google\\Service\\CloudSearch\\AllAuthenticatedUsersProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AllAuthenticatedUsersProto.php',
    'Google\\Service\\CloudSearch\\Annotation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Annotation.php',
    'Google\\Service\\CloudSearch\\AnnotationInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AnnotationInfo.php',
    'Google\\Service\\CloudSearch\\AppId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteAnnotation.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteAppId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteAppId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteAttachment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteAttachment.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBabelMessageProps' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBabelMessageProps.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBabelPlaceholderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBabelPlaceholderMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBabelPlaceholderMetadataDeleteMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBabelPlaceholderMetadataDeleteMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBabelPlaceholderMetadataEditMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBabelPlaceholderMetadataEditMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBabelPlaceholderMetadataHangoutVideoEventMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBabelPlaceholderMetadataHangoutVideoEventMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBackendDlpScanSummary' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBackendDlpScanSummary.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBackendLabelsCommunalLabelTag' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBackendLabelsCommunalLabelTag.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBackendLabelsPersonalLabelTag' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBackendLabelsPersonalLabelTag.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteBotResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteBotResponse.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteCardCapabilityMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteCardCapabilityMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteConsentedAppUnfurlMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteConsentedAppUnfurlMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteContentReport' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteContentReport.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteContentReportJustification' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteContentReportJustification.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteCustomEmojiMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteCustomEmojiMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteCustomerId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteCustomerId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDataLossPreventionMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDataLossPreventionMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDmId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDmId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDriveMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDriveMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDriveMetadataAclFixRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDriveMetadataAclFixRequest.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDriveMetadataAclFixStatus' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDriveMetadataAclFixStatus.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteDriveMetadataLegacyUploadMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteDriveMetadataLegacyUploadMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFormatMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFormatMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFrontendBotInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFrontendBotInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFrontendBotInfoSupportUrls' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFrontendBotInfoSupportUrls.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFrontendMember' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFrontendMember.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFrontendRoster' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFrontendRoster.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteFrontendUser' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteFrontendUser.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteGroupId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteGroupId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteGroupRetentionSettingsUpdatedMetaData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteGroupRetentionSettingsUpdatedMetaData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteGsuiteIntegrationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteGsuiteIntegrationMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteIncomingWebhookChangedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteIncomingWebhookChangedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteIntegrationConfigMutation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteIntegrationConfigMutation.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteIntegrationConfigUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteIntegrationConfigUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteInviteeInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteInviteeInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMemberId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMemberId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMembershipChangedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMembershipChangedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMembershipChangedMetadataAffectedMembership' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMembershipChangedMetadataAffectedMembership.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessage.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageAttributes' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageAttributes.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageContentReportSummary' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageContentReportSummary.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageParentId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageParentId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteMessageProps' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteMessageProps.php',
    'Google\\Service\\CloudSearch\\AppsDynamitePinnedItemId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamitePinnedItemId.php',
    'Google\\Service\\CloudSearch\\AppsDynamitePrivateMessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamitePrivateMessageInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteQuotedMessageMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteQuotedMessageMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteReadReceiptsSettingsUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteReadReceiptsSettingsUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteRequiredMessageFeaturesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteRequiredMessageFeaturesMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteRoomUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteRoomUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteRoomUpdatedMetadataGroupDetailsUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteRoomUpdatedMetadataGroupDetailsUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteRoomUpdatedMetadataRoomRenameMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteRoomUpdatedMetadataRoomRenameMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteRosterId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteRosterId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAction.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedActionActionParameter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedActionActionParameter.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedActivityFeedAnnotationData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedActivityFeedAnnotationData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedActivityFeedAnnotationDataUserInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedActivityFeedAnnotationDataUserInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAppProfile' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAppProfile.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantAnnotationData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantAnnotationData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantDebugContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantDebugContext.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantFeedbackContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantFeedbackContext.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantFeedbackContextFeedbackChip' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantFeedbackContextFeedbackChip.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantSessionContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantSessionContext.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantSuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantSuggestion.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAssistantUnfulfillableRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAssistantUnfulfillableRequest.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedAvatarInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedAvatarInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedBackendUploadMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedBackendUploadMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedBackendUploadMetadataMigratedFromHangoutsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedBackendUploadMetadataMigratedFromHangoutsMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedBackendUploadMetadataMigratedFromHangoutsMetadataPhotoId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedBackendUploadMetadataMigratedFromHangoutsMetadataPhotoId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedBorderStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedBorderStyle.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedButton.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedButtonList' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedButtonList.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCalendarEventAnnotationData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCalendarEventAnnotationData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCalendarEventAnnotationDataCalendarEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCalendarEventAnnotationDataCalendarEvent.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCalendarEventAnnotationDataCalendarEventTime' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCalendarEventAnnotationDataCalendarEventTime.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCalendarEventAnnotationDataEventCreation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCalendarEventAnnotationDataEventCreation.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCallAnnotationData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCallAnnotationData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCallMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCallMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCard.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCardCardAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCardCardAction.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCardCardHeader' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCardCardHeader.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCardClickSuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCardClickSuggestion.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCardSection' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCardSection.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemActivityInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemActivityInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemActivityInfoFeedItemNudge' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemActivityInfoFeedItemNudge.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemActivityInfoFeedItemReactions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemActivityInfoFeedItemReactions.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemActivityInfoFeedItemThreadReply' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemActivityInfoFeedItemThreadReply.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemActivityInfoFeedItemUserMention' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemActivityInfoFeedItemUserMention.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedChatItemGroupInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedChatItemGroupInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedColumns' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedColumns.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedColumnsColumn' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedColumnsColumn.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedColumnsColumnWidgets' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedColumnsColumnWidgets.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedContentReportType' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedContentReportType.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedCustomEmoji' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedCustomEmoji.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDateTimePicker' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDateTimePicker.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDecoratedText' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDecoratedText.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDecoratedTextSwitchControl' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDecoratedTextSwitchControl.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDimension' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDimension.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDivider' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDivider.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDlpMetricsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDlpMetricsMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedDocument' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedDocument.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedEmoji' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedEmoji.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedFindDocumentSuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedFindDocumentSuggestion.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedGrid' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedGrid.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedGridGridItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedGridGridItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedGroupDetails' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedGroupDetails.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedGroupVisibility' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedGroupVisibility.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedIcon' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedIcon.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedImage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedImage.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedImageComponent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedImageComponent.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedImageCropStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedImageCropStyle.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedJustification' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedJustification.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedJustificationPerson' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedJustificationPerson.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedMeetMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedMeetMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedMessageComponentSearchInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedMessageComponentSearchInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedMessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedMessageInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedMessageIntegrationPayload' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedMessageIntegrationPayload.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedMessageSearchInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedMessageSearchInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOnClick' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOnClick.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOpenLink' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOpenLink.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOpenLinkAppUri' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOpenLinkAppUri.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOpenLinkAppUriIntent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOpenLinkAppUriIntent.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOpenLinkAppUriIntentExtraData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOpenLinkAppUriIntentExtraData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOrganizationInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOrganizationInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOrganizationInfoConsumerInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOrganizationInfoConsumerInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOrganizationInfoCustomerInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOrganizationInfoCustomerInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedOriginAppSuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedOriginAppSuggestion.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedPhoneNumber' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedPhoneNumber.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedReaction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedReaction.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedRetentionSettings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedRetentionSettings.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSegmentedMembershipCount' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSegmentedMembershipCount.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSegmentedMembershipCounts' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSegmentedMembershipCounts.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSelectionInput' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSelectionInput.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSelectionInputSelectionItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSelectionInputSelectionItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSpaceInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSpaceInfo.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSuggestions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSuggestions.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedSuggestionsSuggestionItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedSuggestionsSuggestionItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataAssigneeChange' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataAssigneeChange.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataCompletionChange' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataCompletionChange.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataCreation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataCreation.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataDeletionChange' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataDeletionChange.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataTaskProperties' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataTaskProperties.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksAnnotationDataUserDefinedMessage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksAnnotationDataUserDefinedMessage.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTasksMessageIntegrationPayload' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTasksMessageIntegrationPayload.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTextInput' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTextInput.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTextParagraph' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTextParagraph.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTextSegment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTextSegment.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTextSegmentsWithDescription' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTextSegmentsWithDescription.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedTextWithDescription' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedTextWithDescription.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedUserBlockRelationship' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedUserBlockRelationship.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedVideoReference' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedVideoReference.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSharedWidget' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSharedWidget.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSlashCommandMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSlashCommandMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteSpaceId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteSpaceId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageAction.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageActionActionParameter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageActionActionParameter.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageBorderStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageBorderStyle.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageButton.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageButtonList' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageButtonList.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageCard.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageCardCardAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageCardCardAction.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageCardCardHeader' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageCardCardHeader.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageCardSection' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageCardSection.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageColumns' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageColumns.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageColumnsColumn' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageColumnsColumn.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageColumnsColumnWidgets' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageColumnsColumnWidgets.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageDateTimePicker' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageDateTimePicker.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageDecoratedText' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageDecoratedText.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageDecoratedTextSwitchControl' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageDecoratedTextSwitchControl.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageDivider' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageDivider.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageGrid' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageGrid.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageGridGridItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageGridGridItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageIcon' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageIcon.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageImage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageImage.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageImageComponent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageImageComponent.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageImageCropStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageImageCropStyle.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageMaterialIcon' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageMaterialIcon.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageOnClick' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageOnClick.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageOpenLink' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageOpenLink.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageOpenLinkAppUri' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageOpenLinkAppUri.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageOpenLinkAppUriIntent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageOpenLinkAppUriIntent.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageOpenLinkAppUriIntentExtraData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageOpenLinkAppUriIntentExtraData.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageSelectionInput' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageSelectionInput.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageSelectionInputSelectionItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageSelectionInputSelectionItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageSuggestions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageSuggestions.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageSuggestionsSuggestionItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageSuggestionsSuggestionItem.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageTextInput' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageTextInput.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageTextParagraph' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageTextParagraph.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteStorageWidget' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteStorageWidget.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteTombstoneMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteTombstoneMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteTopicId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteTopicId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteUploadMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteUploadMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteUrlMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteUrlMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteUserId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteUserId.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteUserMentionMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteUserMentionMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteV1ApiCompatV1Action' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteV1ApiCompatV1Action.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteV1ApiCompatV1ActionConfirm' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteV1ApiCompatV1ActionConfirm.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteV1ApiCompatV1Attachment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteV1ApiCompatV1Attachment.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteV1ApiCompatV1Field' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteV1ApiCompatV1Field.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteVideoCallMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteVideoCallMetadata.php',
    'Google\\Service\\CloudSearch\\AppsDynamiteYoutubeMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsDynamiteYoutubeMetadata.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupAddAttachmentsActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupAddAttachmentsActionMarkup.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupAddAttachmentsActionMarkupAddonAttachment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupAddAttachmentsActionMarkupAddonAttachment.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkup.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupEntryPointMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupEntryPointMarkup.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupError' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupError.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupParameter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupConferenceDataMarkupParameter.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupEditAttendeesActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupEditAttendeesActionMarkup.php',
    'Google\\Service\\CloudSearch\\AppsExtensionsMarkupCalendarClientActionMarkupEditConferenceDataActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AppsExtensionsMarkupCalendarClientActionMarkupEditConferenceDataActionMarkup.php',
    'Google\\Service\\CloudSearch\\Attachment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Attachment.php',
    'Google\\Service\\CloudSearch\\AttachmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AttachmentMetadata.php',
    'Google\\Service\\CloudSearch\\Attribute' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Attribute.php',
    'Google\\Service\\CloudSearch\\AttributeRemoved' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AttributeRemoved.php',
    'Google\\Service\\CloudSearch\\AttributeSet' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AttributeSet.php',
    'Google\\Service\\CloudSearch\\Attributes' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Attributes.php',
    'Google\\Service\\CloudSearch\\AuditLoggingSettings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AuditLoggingSettings.php',
    'Google\\Service\\CloudSearch\\AuthorizedItemId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AuthorizedItemId.php',
    'Google\\Service\\CloudSearch\\AutoComplete' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AutoComplete.php',
    'Google\\Service\\CloudSearch\\AutoCompleteItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AutoCompleteItem.php',
    'Google\\Service\\CloudSearch\\AvatarInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/AvatarInfo.php',
    'Google\\Service\\CloudSearch\\BabelMessageProps' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BabelMessageProps.php',
    'Google\\Service\\CloudSearch\\BabelPlaceholderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BabelPlaceholderMetadata.php',
    'Google\\Service\\CloudSearch\\BackgroundColoredText' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BackgroundColoredText.php',
    'Google\\Service\\CloudSearch\\BooleanOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BooleanOperatorOptions.php',
    'Google\\Service\\CloudSearch\\BooleanPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BooleanPropertyOptions.php',
    'Google\\Service\\CloudSearch\\BorderStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BorderStyle.php',
    'Google\\Service\\CloudSearch\\BotInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BotInfo.php',
    'Google\\Service\\CloudSearch\\BotMessageMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BotMessageMetadata.php',
    'Google\\Service\\CloudSearch\\BotResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BotResponse.php',
    'Google\\Service\\CloudSearch\\BroadcastAccess' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BroadcastAccess.php',
    'Google\\Service\\CloudSearch\\BroadcastSessionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BroadcastSessionInfo.php',
    'Google\\Service\\CloudSearch\\BroadcastStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/BroadcastStats.php',
    'Google\\Service\\CloudSearch\\Button' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Button.php',
    'Google\\Service\\CloudSearch\\CalendarClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CalendarClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\CalendarEventMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CalendarEventMetadata.php',
    'Google\\Service\\CloudSearch\\CallInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CallInfo.php',
    'Google\\Service\\CloudSearch\\CallSettings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CallSettings.php',
    'Google\\Service\\CloudSearch\\CapTokenHolderProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CapTokenHolderProto.php',
    'Google\\Service\\CloudSearch\\Card' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Card.php',
    'Google\\Service\\CloudSearch\\CardAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CardAction.php',
    'Google\\Service\\CloudSearch\\CardCapabilityMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CardCapabilityMetadata.php',
    'Google\\Service\\CloudSearch\\CardHeader' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CardHeader.php',
    'Google\\Service\\CloudSearch\\CaribouAttributeValue' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CaribouAttributeValue.php',
    'Google\\Service\\CloudSearch\\ChatClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\ChatConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConfig.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataAttachmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataAttachmentMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataBotMessageMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataBotMessageMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataCalendarEventMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataCalendarEventMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataDeleteMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataDeleteMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataEditMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataEditMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataTasksMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataTasksMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverDynamitePlaceholderMetadataVideoCallMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverDynamitePlaceholderMetadataVideoCallMetadata.php',
    'Google\\Service\\CloudSearch\\ChatConserverMessageContent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatConserverMessageContent.php',
    'Google\\Service\\CloudSearch\\ChatContentExtension' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatContentExtension.php',
    'Google\\Service\\CloudSearch\\ChatProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ChatProto.php',
    'Google\\Service\\CloudSearch\\CheckAccessResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CheckAccessResponse.php',
    'Google\\Service\\CloudSearch\\CircleProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CircleProto.php',
    'Google\\Service\\CloudSearch\\ClientContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ClientContext.php',
    'Google\\Service\\CloudSearch\\CloudPrincipalProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CloudPrincipalProto.php',
    'Google\\Service\\CloudSearch\\ClusterInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ClusterInfo.php',
    'Google\\Service\\CloudSearch\\CoActivity' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CoActivity.php',
    'Google\\Service\\CloudSearch\\Collaboration' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Collaboration.php',
    'Google\\Service\\CloudSearch\\Color' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Color.php',
    'Google\\Service\\CloudSearch\\CommunalLabelTag' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CommunalLabelTag.php',
    'Google\\Service\\CloudSearch\\CompositeFilter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CompositeFilter.php',
    'Google\\Service\\CloudSearch\\ConsentedAppUnfurlMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ConsentedAppUnfurlMetadata.php',
    'Google\\Service\\CloudSearch\\ContactGroupProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContactGroupProto.php',
    'Google\\Service\\CloudSearch\\Content' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Content.php',
    'Google\\Service\\CloudSearch\\ContentReport' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContentReport.php',
    'Google\\Service\\CloudSearch\\ContentReportJustification' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContentReportJustification.php',
    'Google\\Service\\CloudSearch\\ContentReportSummary' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContentReportSummary.php',
    'Google\\Service\\CloudSearch\\Context' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Context.php',
    'Google\\Service\\CloudSearch\\ContextAttribute' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContextAttribute.php',
    'Google\\Service\\CloudSearch\\ContextualAddOnMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ContextualAddOnMarkup.php',
    'Google\\Service\\CloudSearch\\CseInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CseInfo.php',
    'Google\\Service\\CloudSearch\\CustomEmoji' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomEmoji.php',
    'Google\\Service\\CloudSearch\\CustomEmojiMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomEmojiMetadata.php',
    'Google\\Service\\CloudSearch\\CustomFunctionReturnValueMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomFunctionReturnValueMarkup.php',
    'Google\\Service\\CloudSearch\\CustomerId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerId.php',
    'Google\\Service\\CloudSearch\\CustomerIndexStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerIndexStats.php',
    'Google\\Service\\CloudSearch\\CustomerQueryStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerQueryStats.php',
    'Google\\Service\\CloudSearch\\CustomerSearchApplicationStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerSearchApplicationStats.php',
    'Google\\Service\\CloudSearch\\CustomerSessionStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerSessionStats.php',
    'Google\\Service\\CloudSearch\\CustomerSettings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerSettings.php',
    'Google\\Service\\CloudSearch\\CustomerUserStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/CustomerUserStats.php',
    'Google\\Service\\CloudSearch\\DataLossPreventionMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DataLossPreventionMetadata.php',
    'Google\\Service\\CloudSearch\\DataSource' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DataSource.php',
    'Google\\Service\\CloudSearch\\DataSourceIndexStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DataSourceIndexStats.php',
    'Google\\Service\\CloudSearch\\DataSourceRestriction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DataSourceRestriction.php',
    'Google\\Service\\CloudSearch\\Date' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Date.php',
    'Google\\Service\\CloudSearch\\DateOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DateOperatorOptions.php',
    'Google\\Service\\CloudSearch\\DatePropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DatePropertyOptions.php',
    'Google\\Service\\CloudSearch\\DateTimePicker' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DateTimePicker.php',
    'Google\\Service\\CloudSearch\\DateValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DateValues.php',
    'Google\\Service\\CloudSearch\\DebugOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DebugOptions.php',
    'Google\\Service\\CloudSearch\\DebugResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DebugResponse.php',
    'Google\\Service\\CloudSearch\\DeepLinkData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DeepLinkData.php',
    'Google\\Service\\CloudSearch\\DeleteMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DeleteMetadata.php',
    'Google\\Service\\CloudSearch\\DeleteQueueItemsRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DeleteQueueItemsRequest.php',
    'Google\\Service\\CloudSearch\\DeliveryMedium' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DeliveryMedium.php',
    'Google\\Service\\CloudSearch\\DisplayedProperty' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DisplayedProperty.php',
    'Google\\Service\\CloudSearch\\Divider' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Divider.php',
    'Google\\Service\\CloudSearch\\DlpAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DlpAction.php',
    'Google\\Service\\CloudSearch\\DlpMessageScanRecord' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DlpMessageScanRecord.php',
    'Google\\Service\\CloudSearch\\DlpScanSummary' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DlpScanSummary.php',
    'Google\\Service\\CloudSearch\\DmId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DmId.php',
    'Google\\Service\\CloudSearch\\DocumentInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DocumentInfo.php',
    'Google\\Service\\CloudSearch\\DoubleOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DoubleOperatorOptions.php',
    'Google\\Service\\CloudSearch\\DoublePropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DoublePropertyOptions.php',
    'Google\\Service\\CloudSearch\\DoubleValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DoubleValues.php',
    'Google\\Service\\CloudSearch\\DriveClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\DriveFollowUpRestrict' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveFollowUpRestrict.php',
    'Google\\Service\\CloudSearch\\DriveLocationRestrict' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveLocationRestrict.php',
    'Google\\Service\\CloudSearch\\DriveMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveMetadata.php',
    'Google\\Service\\CloudSearch\\DriveMimeTypeRestrict' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveMimeTypeRestrict.php',
    'Google\\Service\\CloudSearch\\DriveTimeSpanRestrict' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DriveTimeSpanRestrict.php',
    'Google\\Service\\CloudSearch\\DynamiteMessagesScoringInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DynamiteMessagesScoringInfo.php',
    'Google\\Service\\CloudSearch\\DynamitePlaceholderMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DynamitePlaceholderMetadata.php',
    'Google\\Service\\CloudSearch\\DynamiteSpacesScoringInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/DynamiteSpacesScoringInfo.php',
    'Google\\Service\\CloudSearch\\EditMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EditMetadata.php',
    'Google\\Service\\CloudSearch\\EditorClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EditorClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\EmailAddress' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EmailAddress.php',
    'Google\\Service\\CloudSearch\\EmailOwnerProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EmailOwnerProto.php',
    'Google\\Service\\CloudSearch\\EmbedClientItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EmbedClientItem.php',
    'Google\\Service\\CloudSearch\\Emoji' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Emoji.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazFrontendTeamsLink' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazFrontendTeamsLink.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazFrontendTeamsPersonCorePhoneNumber' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazFrontendTeamsPersonCorePhoneNumber.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAgendaEntry' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAgendaEntry.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAgendaGroupCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAgendaGroupCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAgendaGroupCardProtoContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAgendaGroupCardProtoContext.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAgendaItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAgendaItem.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAnswerAnswerList' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAnswerAnswerList.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAnswerAnswerListLabeledAnswer' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAnswerAnswerListLabeledAnswer.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAnswerSuggestedQueryAnswerCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAnswerSuggestedQueryAnswerCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAnswerSuggestedQueryCategory' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAnswerSuggestedQueryCategory.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickAssistCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickAssistCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCardMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCardMetadata.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonDebugInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonDebugInfo.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonDocument' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonDocument.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonDocumentDriveDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonDocumentDriveDocumentMetadata.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonDocumentJustification' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonDocumentJustification.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonPerson' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonPerson.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickCommonPersonBirthday' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickCommonPersonBirthday.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickConflictingEventsCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickConflictingEventsCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickDocumentGroup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickDocumentGroup.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickDocumentPerCategoryList' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickDocumentPerCategoryList.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickDocumentPerCategoryListDocumentPerCategoryListEntry' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickDocumentPerCategoryListDocumentPerCategoryListEntry.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickFindMeetingTimeCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickFindMeetingTimeCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickGap' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickGap.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickGenericAnswerCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickGenericAnswerCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickGetAndKeepAheadCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickGetAndKeepAheadCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickGetAndKeepAheadCardProtoDeclinedEvents' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickGetAndKeepAheadCardProtoDeclinedEvents.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickMeetingNotesCardError' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickMeetingNotesCardError.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickMeetingNotesCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickMeetingNotesCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickMeetingNotesCardRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickMeetingNotesCardRequest.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickNlpMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickNlpMetadata.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleAnswerDisambiguationInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleAnswerDisambiguationInfo.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleAnswerDisambiguationInfoDisambiguationPerson' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleAnswerDisambiguationInfoDisambiguationPerson.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleAnswerPeopleAnswerCardHeader' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleAnswerPeopleAnswerCardHeader.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleAnswerPersonAnswerCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleAnswerPersonAnswerCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleAnswerRelatedPeopleAnswerCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleAnswerRelatedPeopleAnswerCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPeopleDisambiguationCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPeopleDisambiguationCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPerson' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPerson.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPersonProfileCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPersonProfileCard.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPersonProfileCardRelatedPeople' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPersonProfileCardRelatedPeople.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickPersonalizedDocsCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickPersonalizedDocsCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickRankingParams' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickRankingParams.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickRecentDocumentsCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickRecentDocumentsCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickScheduledMeeting' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickScheduledMeeting.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickShareMeetingDocsCardProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickShareMeetingDocsCardProto.php',
    'Google\\Service\\CloudSearch\\EnterpriseTopazSidekickTimeSlot' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnterpriseTopazSidekickTimeSlot.php',
    'Google\\Service\\CloudSearch\\EnumOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnumOperatorOptions.php',
    'Google\\Service\\CloudSearch\\EnumPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnumPropertyOptions.php',
    'Google\\Service\\CloudSearch\\EnumValuePair' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnumValuePair.php',
    'Google\\Service\\CloudSearch\\EnumValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EnumValues.php',
    'Google\\Service\\CloudSearch\\ErrorInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ErrorInfo.php',
    'Google\\Service\\CloudSearch\\ErrorMessage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ErrorMessage.php',
    'Google\\Service\\CloudSearch\\EventAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EventAnnotation.php',
    'Google\\Service\\CloudSearch\\EventProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/EventProto.php',
    'Google\\Service\\CloudSearch\\FacetBucket' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FacetBucket.php',
    'Google\\Service\\CloudSearch\\FacetOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FacetOptions.php',
    'Google\\Service\\CloudSearch\\FacetResult' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FacetResult.php',
    'Google\\Service\\CloudSearch\\FieldViolation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FieldViolation.php',
    'Google\\Service\\CloudSearch\\Filter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Filter.php',
    'Google\\Service\\CloudSearch\\FilterCreated' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FilterCreated.php',
    'Google\\Service\\CloudSearch\\FilterDeleted' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FilterDeleted.php',
    'Google\\Service\\CloudSearch\\FilterOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FilterOptions.php',
    'Google\\Service\\CloudSearch\\FilterUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FilterUpdate.php',
    'Google\\Service\\CloudSearch\\FixedFooter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FixedFooter.php',
    'Google\\Service\\CloudSearch\\Folder' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Folder.php',
    'Google\\Service\\CloudSearch\\FolderAttribute' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FolderAttribute.php',
    'Google\\Service\\CloudSearch\\FormAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FormAction.php',
    'Google\\Service\\CloudSearch\\FormatMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FormatMetadata.php',
    'Google\\Service\\CloudSearch\\Formatting' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Formatting.php',
    'Google\\Service\\CloudSearch\\FreshnessOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FreshnessOptions.php',
    'Google\\Service\\CloudSearch\\FuseboxItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FuseboxItem.php',
    'Google\\Service\\CloudSearch\\FuseboxItemThreadMatchInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FuseboxItemThreadMatchInfo.php',
    'Google\\Service\\CloudSearch\\FuseboxPrefUpdatePreState' => $vendorDir . '/google/apiclient-services/src/CloudSearch/FuseboxPrefUpdatePreState.php',
    'Google\\Service\\CloudSearch\\GSuitePrincipal' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GSuitePrincipal.php',
    'Google\\Service\\CloudSearch\\GaiaGroupProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GaiaGroupProto.php',
    'Google\\Service\\CloudSearch\\GaiaUserProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GaiaUserProto.php',
    'Google\\Service\\CloudSearch\\GatewayAccess' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GatewayAccess.php',
    'Google\\Service\\CloudSearch\\GatewaySipAccess' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GatewaySipAccess.php',
    'Google\\Service\\CloudSearch\\GetCustomerIndexStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetCustomerIndexStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetCustomerQueryStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetCustomerQueryStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetCustomerSearchApplicationStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetCustomerSearchApplicationStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetCustomerSessionStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetCustomerSessionStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetCustomerUserStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetCustomerUserStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetDataSourceIndexStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetDataSourceIndexStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetSearchApplicationQueryStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetSearchApplicationQueryStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetSearchApplicationSessionStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetSearchApplicationSessionStatsResponse.php',
    'Google\\Service\\CloudSearch\\GetSearchApplicationUserStatsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GetSearchApplicationUserStatsResponse.php',
    'Google\\Service\\CloudSearch\\GmailClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GmailClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\GoogleChatConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatConfig.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1ContextualAddOnMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1ContextualAddOnMarkup.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1ContextualAddOnMarkupCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1ContextualAddOnMarkupCard.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1ContextualAddOnMarkupCardCardAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1ContextualAddOnMarkupCardCardAction.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1ContextualAddOnMarkupCardCardHeader' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1ContextualAddOnMarkupCardCardHeader.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1ContextualAddOnMarkupCardSection' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1ContextualAddOnMarkupCardSection.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkup.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupButton.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupFormAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupFormAction.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupFormActionActionParameter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupFormActionActionParameter.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupImage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupImage.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupImageButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupImageButton.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupKeyValue' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupKeyValue.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupOnClick' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupOnClick.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupOpenLink' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupOpenLink.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupTextButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupTextButton.php',
    'Google\\Service\\CloudSearch\\GoogleChatV1WidgetMarkupTextParagraph' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleChatV1WidgetMarkupTextParagraph.php',
    'Google\\Service\\CloudSearch\\GoogleDocsMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleDocsMetadata.php',
    'Google\\Service\\CloudSearch\\GoogleDocsResultInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GoogleDocsResultInfo.php',
    'Google\\Service\\CloudSearch\\Grid' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Grid.php',
    'Google\\Service\\CloudSearch\\GridItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GridItem.php',
    'Google\\Service\\CloudSearch\\GroupDetailsUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GroupDetailsUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\GroupId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GroupId.php',
    'Google\\Service\\CloudSearch\\GroupLinkSharingModificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GroupLinkSharingModificationEvent.php',
    'Google\\Service\\CloudSearch\\GroupRetentionSettingsUpdatedMetaData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GroupRetentionSettingsUpdatedMetaData.php',
    'Google\\Service\\CloudSearch\\GsuiteIntegrationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/GsuiteIntegrationMetadata.php',
    'Google\\Service\\CloudSearch\\HangoutEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HangoutEvent.php',
    'Google\\Service\\CloudSearch\\HangoutVideoEventMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HangoutVideoEventMetadata.php',
    'Google\\Service\\CloudSearch\\HashtagData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HashtagData.php',
    'Google\\Service\\CloudSearch\\History' => $vendorDir . '/google/apiclient-services/src/CloudSearch/History.php',
    'Google\\Service\\CloudSearch\\HistoryRecord' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HistoryRecord.php',
    'Google\\Service\\CloudSearch\\HostAppActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HostAppActionMarkup.php',
    'Google\\Service\\CloudSearch\\HostProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HostProto.php',
    'Google\\Service\\CloudSearch\\HtmlOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HtmlOperatorOptions.php',
    'Google\\Service\\CloudSearch\\HtmlPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HtmlPropertyOptions.php',
    'Google\\Service\\CloudSearch\\HtmlValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/HtmlValues.php',
    'Google\\Service\\CloudSearch\\IconImage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IconImage.php',
    'Google\\Service\\CloudSearch\\Id' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Id.php',
    'Google\\Service\\CloudSearch\\Image' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Image.php',
    'Google\\Service\\CloudSearch\\ImageButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImageButton.php',
    'Google\\Service\\CloudSearch\\ImageComponent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImageComponent.php',
    'Google\\Service\\CloudSearch\\ImageCropStyle' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImageCropStyle.php',
    'Google\\Service\\CloudSearch\\ImageKeyValue' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImageKeyValue.php',
    'Google\\Service\\CloudSearch\\ImapSessionContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapSessionContext.php',
    'Google\\Service\\CloudSearch\\ImapSyncDelete' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapSyncDelete.php',
    'Google\\Service\\CloudSearch\\ImapUidsReassign' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapUidsReassign.php',
    'Google\\Service\\CloudSearch\\ImapUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapUpdate.php',
    'Google\\Service\\CloudSearch\\ImapsyncFolderAttributeFolderMessage' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapsyncFolderAttributeFolderMessage.php',
    'Google\\Service\\CloudSearch\\ImapsyncFolderAttributeFolderMessageFlags' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ImapsyncFolderAttributeFolderMessageFlags.php',
    'Google\\Service\\CloudSearch\\IncomingWebhookChangedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IncomingWebhookChangedMetadata.php',
    'Google\\Service\\CloudSearch\\IndexItemOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IndexItemOptions.php',
    'Google\\Service\\CloudSearch\\IndexItemRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IndexItemRequest.php',
    'Google\\Service\\CloudSearch\\InitializeCustomerRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/InitializeCustomerRequest.php',
    'Google\\Service\\CloudSearch\\InsertContent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/InsertContent.php',
    'Google\\Service\\CloudSearch\\IntegerFacetingOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegerFacetingOptions.php',
    'Google\\Service\\CloudSearch\\IntegerOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegerOperatorOptions.php',
    'Google\\Service\\CloudSearch\\IntegerPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegerPropertyOptions.php',
    'Google\\Service\\CloudSearch\\IntegerValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegerValues.php',
    'Google\\Service\\CloudSearch\\IntegrationConfigMutation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegrationConfigMutation.php',
    'Google\\Service\\CloudSearch\\IntegrationConfigUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/IntegrationConfigUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\Interaction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Interaction.php',
    'Google\\Service\\CloudSearch\\InteractionData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/InteractionData.php',
    'Google\\Service\\CloudSearch\\InviteAcceptedEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/InviteAcceptedEvent.php',
    'Google\\Service\\CloudSearch\\InviteeInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/InviteeInfo.php',
    'Google\\Service\\CloudSearch\\Item' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Item.php',
    'Google\\Service\\CloudSearch\\ItemAcl' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemAcl.php',
    'Google\\Service\\CloudSearch\\ItemContent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemContent.php',
    'Google\\Service\\CloudSearch\\ItemCountByStatus' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemCountByStatus.php',
    'Google\\Service\\CloudSearch\\ItemMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemMetadata.php',
    'Google\\Service\\CloudSearch\\ItemParts' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemParts.php',
    'Google\\Service\\CloudSearch\\ItemStatus' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemStatus.php',
    'Google\\Service\\CloudSearch\\ItemStructuredData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemStructuredData.php',
    'Google\\Service\\CloudSearch\\ItemThread' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ItemThread.php',
    'Google\\Service\\CloudSearch\\JobsettedServerSpec' => $vendorDir . '/google/apiclient-services/src/CloudSearch/JobsettedServerSpec.php',
    'Google\\Service\\CloudSearch\\KeyValue' => $vendorDir . '/google/apiclient-services/src/CloudSearch/KeyValue.php',
    'Google\\Service\\CloudSearch\\LabelAdded' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelAdded.php',
    'Google\\Service\\CloudSearch\\LabelCreated' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelCreated.php',
    'Google\\Service\\CloudSearch\\LabelDeleted' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelDeleted.php',
    'Google\\Service\\CloudSearch\\LabelRemoved' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelRemoved.php',
    'Google\\Service\\CloudSearch\\LabelRenamed' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelRenamed.php',
    'Google\\Service\\CloudSearch\\LabelUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelUpdate.php',
    'Google\\Service\\CloudSearch\\LabelUpdated' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LabelUpdated.php',
    'Google\\Service\\CloudSearch\\Labels' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Labels.php',
    'Google\\Service\\CloudSearch\\LanguageConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LanguageConfig.php',
    'Google\\Service\\CloudSearch\\LdapGroupProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LdapGroupProto.php',
    'Google\\Service\\CloudSearch\\LdapUserProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LdapUserProto.php',
    'Google\\Service\\CloudSearch\\LegacyUploadMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LegacyUploadMetadata.php',
    'Google\\Service\\CloudSearch\\LinkData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/LinkData.php',
    'Google\\Service\\CloudSearch\\ListDataSourceResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListDataSourceResponse.php',
    'Google\\Service\\CloudSearch\\ListItemNamesForUnmappedIdentityResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListItemNamesForUnmappedIdentityResponse.php',
    'Google\\Service\\CloudSearch\\ListItemsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListItemsResponse.php',
    'Google\\Service\\CloudSearch\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListOperationsResponse.php',
    'Google\\Service\\CloudSearch\\ListQuerySourcesResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListQuerySourcesResponse.php',
    'Google\\Service\\CloudSearch\\ListSearchApplicationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListSearchApplicationsResponse.php',
    'Google\\Service\\CloudSearch\\ListUnmappedIdentitiesResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ListUnmappedIdentitiesResponse.php',
    'Google\\Service\\CloudSearch\\MapInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MapInfo.php',
    'Google\\Service\\CloudSearch\\MapTile' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MapTile.php',
    'Google\\Service\\CloudSearch\\MatchInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MatchInfo.php',
    'Google\\Service\\CloudSearch\\MatchRange' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MatchRange.php',
    'Google\\Service\\CloudSearch\\MdbGroupProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MdbGroupProto.php',
    'Google\\Service\\CloudSearch\\MdbUserProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MdbUserProto.php',
    'Google\\Service\\CloudSearch\\Media' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Media.php',
    'Google\\Service\\CloudSearch\\MeetingSpace' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MeetingSpace.php',
    'Google\\Service\\CloudSearch\\Member' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Member.php',
    'Google\\Service\\CloudSearch\\MemberId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MemberId.php',
    'Google\\Service\\CloudSearch\\MembershipChangeEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MembershipChangeEvent.php',
    'Google\\Service\\CloudSearch\\MembershipChangedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MembershipChangedMetadata.php',
    'Google\\Service\\CloudSearch\\Menu' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Menu.php',
    'Google\\Service\\CloudSearch\\MenuItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MenuItem.php',
    'Google\\Service\\CloudSearch\\Message' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Message.php',
    'Google\\Service\\CloudSearch\\MessageAdded' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageAdded.php',
    'Google\\Service\\CloudSearch\\MessageAttributes' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageAttributes.php',
    'Google\\Service\\CloudSearch\\MessageContent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageContent.php',
    'Google\\Service\\CloudSearch\\MessageDeleted' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageDeleted.php',
    'Google\\Service\\CloudSearch\\MessageId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageId.php',
    'Google\\Service\\CloudSearch\\MessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageInfo.php',
    'Google\\Service\\CloudSearch\\MessageParentId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageParentId.php',
    'Google\\Service\\CloudSearch\\MessageProps' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageProps.php',
    'Google\\Service\\CloudSearch\\MessageReference' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageReference.php',
    'Google\\Service\\CloudSearch\\MessageSet' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MessageSet.php',
    'Google\\Service\\CloudSearch\\Metadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Metadata.php',
    'Google\\Service\\CloudSearch\\Metaline' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Metaline.php',
    'Google\\Service\\CloudSearch\\MultiKey' => $vendorDir . '/google/apiclient-services/src/CloudSearch/MultiKey.php',
    'Google\\Service\\CloudSearch\\Name' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Name.php',
    'Google\\Service\\CloudSearch\\NamedProperty' => $vendorDir . '/google/apiclient-services/src/CloudSearch/NamedProperty.php',
    'Google\\Service\\CloudSearch\\OAuthConsumerProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OAuthConsumerProto.php',
    'Google\\Service\\CloudSearch\\ObjectDefinition' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ObjectDefinition.php',
    'Google\\Service\\CloudSearch\\ObjectDisplayOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ObjectDisplayOptions.php',
    'Google\\Service\\CloudSearch\\ObjectOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ObjectOptions.php',
    'Google\\Service\\CloudSearch\\ObjectPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ObjectPropertyOptions.php',
    'Google\\Service\\CloudSearch\\ObjectValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ObjectValues.php',
    'Google\\Service\\CloudSearch\\OnClick' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OnClick.php',
    'Google\\Service\\CloudSearch\\OpenCreatedDraftActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OpenCreatedDraftActionMarkup.php',
    'Google\\Service\\CloudSearch\\OpenLink' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OpenLink.php',
    'Google\\Service\\CloudSearch\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Operation.php',
    'Google\\Service\\CloudSearch\\OsVersion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OsVersion.php',
    'Google\\Service\\CloudSearch\\OtrChatMessageEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OtrChatMessageEvent.php',
    'Google\\Service\\CloudSearch\\OtrModificationEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/OtrModificationEvent.php',
    'Google\\Service\\CloudSearch\\PackagingServiceClient' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PackagingServiceClient.php',
    'Google\\Service\\CloudSearch\\PaygateInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PaygateInfo.php',
    'Google\\Service\\CloudSearch\\PeoplePromotionCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PeoplePromotionCard.php',
    'Google\\Service\\CloudSearch\\PeopleSuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PeopleSuggestion.php',
    'Google\\Service\\CloudSearch\\Person' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Person.php',
    'Google\\Service\\CloudSearch\\PersonCore' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PersonCore.php',
    'Google\\Service\\CloudSearch\\PersonalLabelTag' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PersonalLabelTag.php',
    'Google\\Service\\CloudSearch\\PhoneAccess' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PhoneAccess.php',
    'Google\\Service\\CloudSearch\\PhoneNumber' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PhoneNumber.php',
    'Google\\Service\\CloudSearch\\Photo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Photo.php',
    'Google\\Service\\CloudSearch\\PinnedItemId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PinnedItemId.php',
    'Google\\Service\\CloudSearch\\PollItemsRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PollItemsRequest.php',
    'Google\\Service\\CloudSearch\\PollItemsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PollItemsResponse.php',
    'Google\\Service\\CloudSearch\\PossiblyTrimmedModel' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PossiblyTrimmedModel.php',
    'Google\\Service\\CloudSearch\\PostiniUserProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PostiniUserProto.php',
    'Google\\Service\\CloudSearch\\PreState' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PreState.php',
    'Google\\Service\\CloudSearch\\PrefDeleted' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PrefDeleted.php',
    'Google\\Service\\CloudSearch\\PrefUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PrefUpdate.php',
    'Google\\Service\\CloudSearch\\PrefWritten' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PrefWritten.php',
    'Google\\Service\\CloudSearch\\Presenter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Presenter.php',
    'Google\\Service\\CloudSearch\\Principal' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Principal.php',
    'Google\\Service\\CloudSearch\\PrincipalProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PrincipalProto.php',
    'Google\\Service\\CloudSearch\\PrivateMessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PrivateMessageInfo.php',
    'Google\\Service\\CloudSearch\\ProcessingError' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ProcessingError.php',
    'Google\\Service\\CloudSearch\\PropertyDefinition' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PropertyDefinition.php',
    'Google\\Service\\CloudSearch\\PropertyDisplayOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PropertyDisplayOptions.php',
    'Google\\Service\\CloudSearch\\Provenance' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Provenance.php',
    'Google\\Service\\CloudSearch\\PushItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PushItem.php',
    'Google\\Service\\CloudSearch\\PushItemRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/PushItemRequest.php',
    'Google\\Service\\CloudSearch\\QueryActivity' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryActivity.php',
    'Google\\Service\\CloudSearch\\QueryCountByStatus' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryCountByStatus.php',
    'Google\\Service\\CloudSearch\\QueryInterpretation' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryInterpretation.php',
    'Google\\Service\\CloudSearch\\QueryInterpretationConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryInterpretationConfig.php',
    'Google\\Service\\CloudSearch\\QueryInterpretationOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryInterpretationOptions.php',
    'Google\\Service\\CloudSearch\\QueryItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryItem.php',
    'Google\\Service\\CloudSearch\\QueryOperator' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QueryOperator.php',
    'Google\\Service\\CloudSearch\\QuerySource' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QuerySource.php',
    'Google\\Service\\CloudSearch\\QuerySuggestion' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QuerySuggestion.php',
    'Google\\Service\\CloudSearch\\QuotedMessageMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/QuotedMessageMetadata.php',
    'Google\\Service\\CloudSearch\\Rank' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Rank.php',
    'Google\\Service\\CloudSearch\\RbacRoleProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RbacRoleProto.php',
    'Google\\Service\\CloudSearch\\RbacSubjectProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RbacSubjectProto.php',
    'Google\\Service\\CloudSearch\\ReactionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ReactionInfo.php',
    'Google\\Service\\CloudSearch\\ReadReceiptsSettingsUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ReadReceiptsSettingsUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\Recipient' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Recipient.php',
    'Google\\Service\\CloudSearch\\RecordingEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RecordingEvent.php',
    'Google\\Service\\CloudSearch\\RecordingInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RecordingInfo.php',
    'Google\\Service\\CloudSearch\\RecordingSessionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RecordingSessionInfo.php',
    'Google\\Service\\CloudSearch\\Reference' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Reference.php',
    'Google\\Service\\CloudSearch\\References' => $vendorDir . '/google/apiclient-services/src/CloudSearch/References.php',
    'Google\\Service\\CloudSearch\\RemoveActivityRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RemoveActivityRequest.php',
    'Google\\Service\\CloudSearch\\RemoveActivityResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RemoveActivityResponse.php',
    'Google\\Service\\CloudSearch\\RenameEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RenameEvent.php',
    'Google\\Service\\CloudSearch\\RepositoryError' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RepositoryError.php',
    'Google\\Service\\CloudSearch\\RequestFileScope' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RequestFileScope.php',
    'Google\\Service\\CloudSearch\\RequestFileScopeForActiveDocument' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RequestFileScopeForActiveDocument.php',
    'Google\\Service\\CloudSearch\\RequestOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RequestOptions.php',
    'Google\\Service\\CloudSearch\\RequiredMessageFeaturesMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RequiredMessageFeaturesMetadata.php',
    'Google\\Service\\CloudSearch\\ResetSearchApplicationRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResetSearchApplicationRequest.php',
    'Google\\Service\\CloudSearch\\ResourceRoleProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResourceRoleProto.php',
    'Google\\Service\\CloudSearch\\Resource\\Debug' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Debug.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugDatasources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugDatasources.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugDatasourcesItems' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugDatasourcesItems.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugDatasourcesItemsUnmappedids' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugDatasourcesItemsUnmappedids.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugIdentitysources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugIdentitysources.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugIdentitysourcesItems' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugIdentitysourcesItems.php',
    'Google\\Service\\CloudSearch\\Resource\\DebugIdentitysourcesUnmappedids' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/DebugIdentitysourcesUnmappedids.php',
    'Google\\Service\\CloudSearch\\Resource\\Indexing' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Indexing.php',
    'Google\\Service\\CloudSearch\\Resource\\IndexingDatasources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/IndexingDatasources.php',
    'Google\\Service\\CloudSearch\\Resource\\IndexingDatasourcesItems' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/IndexingDatasourcesItems.php',
    'Google\\Service\\CloudSearch\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Media.php',
    'Google\\Service\\CloudSearch\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Operations.php',
    'Google\\Service\\CloudSearch\\Resource\\OperationsLro' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/OperationsLro.php',
    'Google\\Service\\CloudSearch\\Resource\\Query' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Query.php',
    'Google\\Service\\CloudSearch\\Resource\\QuerySources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/QuerySources.php',
    'Google\\Service\\CloudSearch\\Resource\\Settings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Settings.php',
    'Google\\Service\\CloudSearch\\Resource\\SettingsDatasources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/SettingsDatasources.php',
    'Google\\Service\\CloudSearch\\Resource\\SettingsSearchapplications' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/SettingsSearchapplications.php',
    'Google\\Service\\CloudSearch\\Resource\\Stats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/Stats.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsIndex' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsIndex.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsIndexDatasources' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsIndexDatasources.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsQuery' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsQuery.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsQuerySearchapplications' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsQuerySearchapplications.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsSession' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsSession.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsSessionSearchapplications' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsSessionSearchapplications.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsUser' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsUser.php',
    'Google\\Service\\CloudSearch\\Resource\\StatsUserSearchapplications' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/StatsUserSearchapplications.php',
    'Google\\Service\\CloudSearch\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Resource/V1.php',
    'Google\\Service\\CloudSearch\\ResponseDebugInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResponseDebugInfo.php',
    'Google\\Service\\CloudSearch\\RestrictItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RestrictItem.php',
    'Google\\Service\\CloudSearch\\ResultCounts' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResultCounts.php',
    'Google\\Service\\CloudSearch\\ResultDebugInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResultDebugInfo.php',
    'Google\\Service\\CloudSearch\\ResultDisplayField' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResultDisplayField.php',
    'Google\\Service\\CloudSearch\\ResultDisplayLine' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResultDisplayLine.php',
    'Google\\Service\\CloudSearch\\ResultDisplayMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ResultDisplayMetadata.php',
    'Google\\Service\\CloudSearch\\RetrievalImportance' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RetrievalImportance.php',
    'Google\\Service\\CloudSearch\\RewrittenQueries' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RewrittenQueries.php',
    'Google\\Service\\CloudSearch\\RewrittenQuery' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RewrittenQuery.php',
    'Google\\Service\\CloudSearch\\RoomRenameMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RoomRenameMetadata.php',
    'Google\\Service\\CloudSearch\\RoomUpdatedMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RoomUpdatedMetadata.php',
    'Google\\Service\\CloudSearch\\Roster' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Roster.php',
    'Google\\Service\\CloudSearch\\RosterId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RosterId.php',
    'Google\\Service\\CloudSearch\\RpcOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/RpcOptions.php',
    'Google\\Service\\CloudSearch\\SafeHtmlProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SafeHtmlProto.php',
    'Google\\Service\\CloudSearch\\SafeUrlProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SafeUrlProto.php',
    'Google\\Service\\CloudSearch\\Schema' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Schema.php',
    'Google\\Service\\CloudSearch\\ScoringConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ScoringConfig.php',
    'Google\\Service\\CloudSearch\\SearchApplication' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchApplication.php',
    'Google\\Service\\CloudSearch\\SearchApplicationQueryStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchApplicationQueryStats.php',
    'Google\\Service\\CloudSearch\\SearchApplicationSessionStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchApplicationSessionStats.php',
    'Google\\Service\\CloudSearch\\SearchApplicationUserStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchApplicationUserStats.php',
    'Google\\Service\\CloudSearch\\SearchItemsByViewUrlRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchItemsByViewUrlRequest.php',
    'Google\\Service\\CloudSearch\\SearchItemsByViewUrlResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchItemsByViewUrlResponse.php',
    'Google\\Service\\CloudSearch\\SearchLinkData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchLinkData.php',
    'Google\\Service\\CloudSearch\\SearchQualityMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchQualityMetadata.php',
    'Google\\Service\\CloudSearch\\SearchRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchRequest.php',
    'Google\\Service\\CloudSearch\\SearchResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchResponse.php',
    'Google\\Service\\CloudSearch\\SearchResult' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SearchResult.php',
    'Google\\Service\\CloudSearch\\Section' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Section.php',
    'Google\\Service\\CloudSearch\\Segment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Segment.php',
    'Google\\Service\\CloudSearch\\SelectionControl' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SelectionControl.php',
    'Google\\Service\\CloudSearch\\SelectionItem' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SelectionItem.php',
    'Google\\Service\\CloudSearch\\SessionContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SessionContext.php',
    'Google\\Service\\CloudSearch\\SessionEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SessionEvent.php',
    'Google\\Service\\CloudSearch\\SessionStateInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SessionStateInfo.php',
    'Google\\Service\\CloudSearch\\Settings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Settings.php',
    'Google\\Service\\CloudSearch\\ShareScope' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ShareScope.php',
    'Google\\Service\\CloudSearch\\SheetsClientActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SheetsClientActionMarkup.php',
    'Google\\Service\\CloudSearch\\SigningKeyPossessorProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SigningKeyPossessorProto.php',
    'Google\\Service\\CloudSearch\\SimpleSecretHolderProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SimpleSecretHolderProto.php',
    'Google\\Service\\CloudSearch\\SimpleSecretLabelProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SimpleSecretLabelProto.php',
    'Google\\Service\\CloudSearch\\SlashCommandMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SlashCommandMetadata.php',
    'Google\\Service\\CloudSearch\\Snippet' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Snippet.php',
    'Google\\Service\\CloudSearch\\SocialCommonAttachmentAttachment' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SocialCommonAttachmentAttachment.php',
    'Google\\Service\\CloudSearch\\SocialGraphNodeProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SocialGraphNodeProto.php',
    'Google\\Service\\CloudSearch\\SortOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SortOptions.php',
    'Google\\Service\\CloudSearch\\Source' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Source.php',
    'Google\\Service\\CloudSearch\\SourceConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SourceConfig.php',
    'Google\\Service\\CloudSearch\\SourceCrowdingConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SourceCrowdingConfig.php',
    'Google\\Service\\CloudSearch\\SourceMessageInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SourceMessageInfo.php',
    'Google\\Service\\CloudSearch\\SourceResultCount' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SourceResultCount.php',
    'Google\\Service\\CloudSearch\\SourceScoringConfig' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SourceScoringConfig.php',
    'Google\\Service\\CloudSearch\\SpaceId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SpaceId.php',
    'Google\\Service\\CloudSearch\\SpaceInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SpaceInfo.php',
    'Google\\Service\\CloudSearch\\SpellResult' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SpellResult.php',
    'Google\\Service\\CloudSearch\\SquareProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SquareProto.php',
    'Google\\Service\\CloudSearch\\StartUploadItemRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StartUploadItemRequest.php',
    'Google\\Service\\CloudSearch\\Status' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Status.php',
    'Google\\Service\\CloudSearch\\StoredParticipantId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StoredParticipantId.php',
    'Google\\Service\\CloudSearch\\StreamViewerStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StreamViewerStats.php',
    'Google\\Service\\CloudSearch\\StreamingSessionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StreamingSessionInfo.php',
    'Google\\Service\\CloudSearch\\StructuredDataObject' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StructuredDataObject.php',
    'Google\\Service\\CloudSearch\\StructuredResult' => $vendorDir . '/google/apiclient-services/src/CloudSearch/StructuredResult.php',
    'Google\\Service\\CloudSearch\\SuggestRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SuggestRequest.php',
    'Google\\Service\\CloudSearch\\SuggestResponse' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SuggestResponse.php',
    'Google\\Service\\CloudSearch\\SuggestResult' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SuggestResult.php',
    'Google\\Service\\CloudSearch\\SupportUrls' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SupportUrls.php',
    'Google\\Service\\CloudSearch\\SwitchWidget' => $vendorDir . '/google/apiclient-services/src/CloudSearch/SwitchWidget.php',
    'Google\\Service\\CloudSearch\\TaskActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TaskActionMarkup.php',
    'Google\\Service\\CloudSearch\\TasksMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TasksMetadata.php',
    'Google\\Service\\CloudSearch\\TextButton' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextButton.php',
    'Google\\Service\\CloudSearch\\TextField' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextField.php',
    'Google\\Service\\CloudSearch\\TextKeyValue' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextKeyValue.php',
    'Google\\Service\\CloudSearch\\TextOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextOperatorOptions.php',
    'Google\\Service\\CloudSearch\\TextParagraph' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextParagraph.php',
    'Google\\Service\\CloudSearch\\TextPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextPropertyOptions.php',
    'Google\\Service\\CloudSearch\\TextValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TextValues.php',
    'Google\\Service\\CloudSearch\\ThirdPartyGenericCard' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ThirdPartyGenericCard.php',
    'Google\\Service\\CloudSearch\\ThreadKeySet' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ThreadKeySet.php',
    'Google\\Service\\CloudSearch\\ThreadUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ThreadUpdate.php',
    'Google\\Service\\CloudSearch\\TimestampOperatorOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TimestampOperatorOptions.php',
    'Google\\Service\\CloudSearch\\TimestampPropertyOptions' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TimestampPropertyOptions.php',
    'Google\\Service\\CloudSearch\\TimestampValues' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TimestampValues.php',
    'Google\\Service\\CloudSearch\\TombstoneMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TombstoneMetadata.php',
    'Google\\Service\\CloudSearch\\Toolbar' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Toolbar.php',
    'Google\\Service\\CloudSearch\\TopicId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TopicId.php',
    'Google\\Service\\CloudSearch\\TopicState' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TopicState.php',
    'Google\\Service\\CloudSearch\\TopicStateUpdate' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TopicStateUpdate.php',
    'Google\\Service\\CloudSearch\\TransactionContext' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TransactionContext.php',
    'Google\\Service\\CloudSearch\\TransactionDebugInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TransactionDebugInfo.php',
    'Google\\Service\\CloudSearch\\TranscriptionSessionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TranscriptionSessionInfo.php',
    'Google\\Service\\CloudSearch\\TransientData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TransientData.php',
    'Google\\Service\\CloudSearch\\Trigger' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Trigger.php',
    'Google\\Service\\CloudSearch\\TriggerAction' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TriggerAction.php',
    'Google\\Service\\CloudSearch\\TriggerKey' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TriggerKey.php',
    'Google\\Service\\CloudSearch\\Triggers' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Triggers.php',
    'Google\\Service\\CloudSearch\\TrustedResourceUrlProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TrustedResourceUrlProto.php',
    'Google\\Service\\CloudSearch\\TypeInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/TypeInfo.php',
    'Google\\Service\\CloudSearch\\UniversalPhoneAccess' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UniversalPhoneAccess.php',
    'Google\\Service\\CloudSearch\\UnmappedIdentity' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UnmappedIdentity.php',
    'Google\\Service\\CloudSearch\\UnreserveItemsRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UnreserveItemsRequest.php',
    'Google\\Service\\CloudSearch\\UpdateBccRecipients' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateBccRecipients.php',
    'Google\\Service\\CloudSearch\\UpdateBody' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateBody.php',
    'Google\\Service\\CloudSearch\\UpdateCcRecipients' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateCcRecipients.php',
    'Google\\Service\\CloudSearch\\UpdateDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateDataSourceRequest.php',
    'Google\\Service\\CloudSearch\\UpdateDraftActionMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateDraftActionMarkup.php',
    'Google\\Service\\CloudSearch\\UpdateSchemaRequest' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateSchemaRequest.php',
    'Google\\Service\\CloudSearch\\UpdateSubject' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateSubject.php',
    'Google\\Service\\CloudSearch\\UpdateToRecipients' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UpdateToRecipients.php',
    'Google\\Service\\CloudSearch\\UploadItemRef' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UploadItemRef.php',
    'Google\\Service\\CloudSearch\\UploadMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UploadMetadata.php',
    'Google\\Service\\CloudSearch\\UrlMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UrlMetadata.php',
    'Google\\Service\\CloudSearch\\User' => $vendorDir . '/google/apiclient-services/src/CloudSearch/User.php',
    'Google\\Service\\CloudSearch\\UserActivity' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserActivity.php',
    'Google\\Service\\CloudSearch\\UserDisplayInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserDisplayInfo.php',
    'Google\\Service\\CloudSearch\\UserId' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserId.php',
    'Google\\Service\\CloudSearch\\UserInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserInfo.php',
    'Google\\Service\\CloudSearch\\UserMentionData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserMentionData.php',
    'Google\\Service\\CloudSearch\\UserMentionMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/UserMentionMetadata.php',
    'Google\\Service\\CloudSearch\\VPCSettings' => $vendorDir . '/google/apiclient-services/src/CloudSearch/VPCSettings.php',
    'Google\\Service\\CloudSearch\\Value' => $vendorDir . '/google/apiclient-services/src/CloudSearch/Value.php',
    'Google\\Service\\CloudSearch\\ValueFilter' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ValueFilter.php',
    'Google\\Service\\CloudSearch\\VideoCallMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/VideoCallMetadata.php',
    'Google\\Service\\CloudSearch\\VideoInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/VideoInfo.php',
    'Google\\Service\\CloudSearch\\VoicePhoneNumber' => $vendorDir . '/google/apiclient-services/src/CloudSearch/VoicePhoneNumber.php',
    'Google\\Service\\CloudSearch\\VoicePhoneNumberI18nData' => $vendorDir . '/google/apiclient-services/src/CloudSearch/VoicePhoneNumberI18nData.php',
    'Google\\Service\\CloudSearch\\WhiteboardInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/WhiteboardInfo.php',
    'Google\\Service\\CloudSearch\\WidgetMarkup' => $vendorDir . '/google/apiclient-services/src/CloudSearch/WidgetMarkup.php',
    'Google\\Service\\CloudSearch\\WonderCardDelete' => $vendorDir . '/google/apiclient-services/src/CloudSearch/WonderCardDelete.php',
    'Google\\Service\\CloudSearch\\WonderMessageMapping' => $vendorDir . '/google/apiclient-services/src/CloudSearch/WonderMessageMapping.php',
    'Google\\Service\\CloudSearch\\WrappedResourceKey' => $vendorDir . '/google/apiclient-services/src/CloudSearch/WrappedResourceKey.php',
    'Google\\Service\\CloudSearch\\YouTubeBroadcastSessionInfo' => $vendorDir . '/google/apiclient-services/src/CloudSearch/YouTubeBroadcastSessionInfo.php',
    'Google\\Service\\CloudSearch\\YouTubeBroadcastStats' => $vendorDir . '/google/apiclient-services/src/CloudSearch/YouTubeBroadcastStats.php',
    'Google\\Service\\CloudSearch\\YouTubeLiveBroadcastEvent' => $vendorDir . '/google/apiclient-services/src/CloudSearch/YouTubeLiveBroadcastEvent.php',
    'Google\\Service\\CloudSearch\\YoutubeMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSearch/YoutubeMetadata.php',
    'Google\\Service\\CloudSearch\\YoutubeUserProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/YoutubeUserProto.php',
    'Google\\Service\\CloudSearch\\ZwiebackSessionProto' => $vendorDir . '/google/apiclient-services/src/CloudSearch/ZwiebackSessionProto.php',
    'Google\\Service\\CloudSecurityToken' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIamV1Binding.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1AccessBoundary' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1AccessBoundary.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1AccessBoundaryRule' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1AccessBoundaryRule.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1ExchangeOauthTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1ExchangeOauthTokenRequest.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1ExchangeOauthTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1ExchangeOauthTokenResponse.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1ExchangeTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1ExchangeTokenRequest.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1ExchangeTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1ExchangeTokenResponse.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1IntrospectTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1IntrospectTokenRequest.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1IntrospectTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1IntrospectTokenResponse.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1Options' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1Options.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1betaAccessBoundary' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1betaAccessBoundary.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1betaAccessBoundaryRule' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1betaAccessBoundaryRule.php',
    'Google\\Service\\CloudSecurityToken\\GoogleIdentityStsV1betaOptions' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleIdentityStsV1betaOptions.php',
    'Google\\Service\\CloudSecurityToken\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/GoogleTypeExpr.php',
    'Google\\Service\\CloudSecurityToken\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/CloudSecurityToken/Resource/V1.php',
    'Google\\Service\\CloudShell' => $vendorDir . '/google/apiclient-services/src/CloudShell.php',
    'Google\\Service\\CloudShell\\AddPublicKeyMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/AddPublicKeyMetadata.php',
    'Google\\Service\\CloudShell\\AddPublicKeyRequest' => $vendorDir . '/google/apiclient-services/src/CloudShell/AddPublicKeyRequest.php',
    'Google\\Service\\CloudShell\\AddPublicKeyResponse' => $vendorDir . '/google/apiclient-services/src/CloudShell/AddPublicKeyResponse.php',
    'Google\\Service\\CloudShell\\AuthorizeEnvironmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/AuthorizeEnvironmentMetadata.php',
    'Google\\Service\\CloudShell\\AuthorizeEnvironmentRequest' => $vendorDir . '/google/apiclient-services/src/CloudShell/AuthorizeEnvironmentRequest.php',
    'Google\\Service\\CloudShell\\AuthorizeEnvironmentResponse' => $vendorDir . '/google/apiclient-services/src/CloudShell/AuthorizeEnvironmentResponse.php',
    'Google\\Service\\CloudShell\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudShell/CancelOperationRequest.php',
    'Google\\Service\\CloudShell\\CloudshellEmpty' => $vendorDir . '/google/apiclient-services/src/CloudShell/CloudshellEmpty.php',
    'Google\\Service\\CloudShell\\CreateEnvironmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/CreateEnvironmentMetadata.php',
    'Google\\Service\\CloudShell\\DeleteEnvironmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/DeleteEnvironmentMetadata.php',
    'Google\\Service\\CloudShell\\Environment' => $vendorDir . '/google/apiclient-services/src/CloudShell/Environment.php',
    'Google\\Service\\CloudShell\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudShell/ListOperationsResponse.php',
    'Google\\Service\\CloudShell\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudShell/Operation.php',
    'Google\\Service\\CloudShell\\RemovePublicKeyMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/RemovePublicKeyMetadata.php',
    'Google\\Service\\CloudShell\\RemovePublicKeyRequest' => $vendorDir . '/google/apiclient-services/src/CloudShell/RemovePublicKeyRequest.php',
    'Google\\Service\\CloudShell\\RemovePublicKeyResponse' => $vendorDir . '/google/apiclient-services/src/CloudShell/RemovePublicKeyResponse.php',
    'Google\\Service\\CloudShell\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudShell/Resource/Operations.php',
    'Google\\Service\\CloudShell\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/CloudShell/Resource/Users.php',
    'Google\\Service\\CloudShell\\Resource\\UsersEnvironments' => $vendorDir . '/google/apiclient-services/src/CloudShell/Resource/UsersEnvironments.php',
    'Google\\Service\\CloudShell\\StartEnvironmentMetadata' => $vendorDir . '/google/apiclient-services/src/CloudShell/StartEnvironmentMetadata.php',
    'Google\\Service\\CloudShell\\StartEnvironmentRequest' => $vendorDir . '/google/apiclient-services/src/CloudShell/StartEnvironmentRequest.php',
    'Google\\Service\\CloudShell\\StartEnvironmentResponse' => $vendorDir . '/google/apiclient-services/src/CloudShell/StartEnvironmentResponse.php',
    'Google\\Service\\CloudShell\\Status' => $vendorDir . '/google/apiclient-services/src/CloudShell/Status.php',
    'Google\\Service\\CloudSourceRepositories' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories.php',
    'Google\\Service\\CloudSourceRepositories\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/AuditConfig.php',
    'Google\\Service\\CloudSourceRepositories\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/AuditLogConfig.php',
    'Google\\Service\\CloudSourceRepositories\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Binding.php',
    'Google\\Service\\CloudSourceRepositories\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Expr.php',
    'Google\\Service\\CloudSourceRepositories\\ListReposResponse' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/ListReposResponse.php',
    'Google\\Service\\CloudSourceRepositories\\MirrorConfig' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/MirrorConfig.php',
    'Google\\Service\\CloudSourceRepositories\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Operation.php',
    'Google\\Service\\CloudSourceRepositories\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Policy.php',
    'Google\\Service\\CloudSourceRepositories\\ProjectConfig' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/ProjectConfig.php',
    'Google\\Service\\CloudSourceRepositories\\PubsubConfig' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/PubsubConfig.php',
    'Google\\Service\\CloudSourceRepositories\\Repo' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Repo.php',
    'Google\\Service\\CloudSourceRepositories\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Resource/Projects.php',
    'Google\\Service\\CloudSourceRepositories\\Resource\\ProjectsRepos' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Resource/ProjectsRepos.php',
    'Google\\Service\\CloudSourceRepositories\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/SetIamPolicyRequest.php',
    'Google\\Service\\CloudSourceRepositories\\SourcerepoEmpty' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/SourcerepoEmpty.php',
    'Google\\Service\\CloudSourceRepositories\\Status' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/Status.php',
    'Google\\Service\\CloudSourceRepositories\\SyncRepoMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/SyncRepoMetadata.php',
    'Google\\Service\\CloudSourceRepositories\\SyncRepoRequest' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/SyncRepoRequest.php',
    'Google\\Service\\CloudSourceRepositories\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudSourceRepositories\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudSourceRepositories\\UpdateProjectConfigRequest' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/UpdateProjectConfigRequest.php',
    'Google\\Service\\CloudSourceRepositories\\UpdateRepoRequest' => $vendorDir . '/google/apiclient-services/src/CloudSourceRepositories/UpdateRepoRequest.php',
    'Google\\Service\\CloudSupport' => $vendorDir . '/google/apiclient-services/src/CloudSupport.php',
    'Google\\Service\\CloudSupport\\Actor' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Actor.php',
    'Google\\Service\\CloudSupport\\Attachment' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Attachment.php',
    'Google\\Service\\CloudSupport\\Blobstore2Info' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Blobstore2Info.php',
    'Google\\Service\\CloudSupport\\CaseClassification' => $vendorDir . '/google/apiclient-services/src/CloudSupport/CaseClassification.php',
    'Google\\Service\\CloudSupport\\CloseCaseRequest' => $vendorDir . '/google/apiclient-services/src/CloudSupport/CloseCaseRequest.php',
    'Google\\Service\\CloudSupport\\CloudsupportCase' => $vendorDir . '/google/apiclient-services/src/CloudSupport/CloudsupportCase.php',
    'Google\\Service\\CloudSupport\\Comment' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Comment.php',
    'Google\\Service\\CloudSupport\\CompositeMedia' => $vendorDir . '/google/apiclient-services/src/CloudSupport/CompositeMedia.php',
    'Google\\Service\\CloudSupport\\ContentTypeInfo' => $vendorDir . '/google/apiclient-services/src/CloudSupport/ContentTypeInfo.php',
    'Google\\Service\\CloudSupport\\CreateAttachmentRequest' => $vendorDir . '/google/apiclient-services/src/CloudSupport/CreateAttachmentRequest.php',
    'Google\\Service\\CloudSupport\\DiffChecksumsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DiffChecksumsResponse.php',
    'Google\\Service\\CloudSupport\\DiffDownloadResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DiffDownloadResponse.php',
    'Google\\Service\\CloudSupport\\DiffUploadRequest' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DiffUploadRequest.php',
    'Google\\Service\\CloudSupport\\DiffUploadResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DiffUploadResponse.php',
    'Google\\Service\\CloudSupport\\DiffVersionResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DiffVersionResponse.php',
    'Google\\Service\\CloudSupport\\DownloadParameters' => $vendorDir . '/google/apiclient-services/src/CloudSupport/DownloadParameters.php',
    'Google\\Service\\CloudSupport\\EscalateCaseRequest' => $vendorDir . '/google/apiclient-services/src/CloudSupport/EscalateCaseRequest.php',
    'Google\\Service\\CloudSupport\\Escalation' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Escalation.php',
    'Google\\Service\\CloudSupport\\ListAttachmentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/ListAttachmentsResponse.php',
    'Google\\Service\\CloudSupport\\ListCasesResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/ListCasesResponse.php',
    'Google\\Service\\CloudSupport\\ListCommentsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/ListCommentsResponse.php',
    'Google\\Service\\CloudSupport\\Media' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Media.php',
    'Google\\Service\\CloudSupport\\ObjectId' => $vendorDir . '/google/apiclient-services/src/CloudSupport/ObjectId.php',
    'Google\\Service\\CloudSupport\\Resource\\Attachments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Attachments.php',
    'Google\\Service\\CloudSupport\\Resource\\CaseClassifications' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/CaseClassifications.php',
    'Google\\Service\\CloudSupport\\Resource\\Cases' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Cases.php',
    'Google\\Service\\CloudSupport\\Resource\\CasesAttachments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/CasesAttachments.php',
    'Google\\Service\\CloudSupport\\Resource\\CasesComments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/CasesComments.php',
    'Google\\Service\\CloudSupport\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Customers.php',
    'Google\\Service\\CloudSupport\\Resource\\CustomersCases' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/CustomersCases.php',
    'Google\\Service\\CloudSupport\\Resource\\CustomersCasesComments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/CustomersCasesComments.php',
    'Google\\Service\\CloudSupport\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Media.php',
    'Google\\Service\\CloudSupport\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Organizations.php',
    'Google\\Service\\CloudSupport\\Resource\\OrganizationsCases' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/OrganizationsCases.php',
    'Google\\Service\\CloudSupport\\Resource\\OrganizationsCasesComments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/OrganizationsCasesComments.php',
    'Google\\Service\\CloudSupport\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/Projects.php',
    'Google\\Service\\CloudSupport\\Resource\\ProjectsCases' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/ProjectsCases.php',
    'Google\\Service\\CloudSupport\\Resource\\ProjectsCasesComments' => $vendorDir . '/google/apiclient-services/src/CloudSupport/Resource/ProjectsCasesComments.php',
    'Google\\Service\\CloudSupport\\SearchCaseClassificationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/SearchCaseClassificationsResponse.php',
    'Google\\Service\\CloudSupport\\SearchCasesResponse' => $vendorDir . '/google/apiclient-services/src/CloudSupport/SearchCasesResponse.php',
    'Google\\Service\\CloudSupport\\WorkflowOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudSupport/WorkflowOperationMetadata.php',
    'Google\\Service\\CloudTalentSolution' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution.php',
    'Google\\Service\\CloudTalentSolution\\ApplicationInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ApplicationInfo.php',
    'Google\\Service\\CloudTalentSolution\\BatchCreateJobsRequest' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchCreateJobsRequest.php',
    'Google\\Service\\CloudTalentSolution\\BatchCreateJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchCreateJobsResponse.php',
    'Google\\Service\\CloudTalentSolution\\BatchDeleteJobsRequest' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchDeleteJobsRequest.php',
    'Google\\Service\\CloudTalentSolution\\BatchDeleteJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchDeleteJobsResponse.php',
    'Google\\Service\\CloudTalentSolution\\BatchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchOperationMetadata.php',
    'Google\\Service\\CloudTalentSolution\\BatchUpdateJobsRequest' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchUpdateJobsRequest.php',
    'Google\\Service\\CloudTalentSolution\\BatchUpdateJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/BatchUpdateJobsResponse.php',
    'Google\\Service\\CloudTalentSolution\\ClientEvent' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ClientEvent.php',
    'Google\\Service\\CloudTalentSolution\\CommuteFilter' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CommuteFilter.php',
    'Google\\Service\\CloudTalentSolution\\CommuteInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CommuteInfo.php',
    'Google\\Service\\CloudTalentSolution\\Company' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Company.php',
    'Google\\Service\\CloudTalentSolution\\CompanyDerivedInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompanyDerivedInfo.php',
    'Google\\Service\\CloudTalentSolution\\CompensationEntry' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompensationEntry.php',
    'Google\\Service\\CloudTalentSolution\\CompensationFilter' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompensationFilter.php',
    'Google\\Service\\CloudTalentSolution\\CompensationInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompensationInfo.php',
    'Google\\Service\\CloudTalentSolution\\CompensationRange' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompensationRange.php',
    'Google\\Service\\CloudTalentSolution\\CompleteQueryResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompleteQueryResponse.php',
    'Google\\Service\\CloudTalentSolution\\CompletionResult' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CompletionResult.php',
    'Google\\Service\\CloudTalentSolution\\CustomAttribute' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CustomAttribute.php',
    'Google\\Service\\CloudTalentSolution\\CustomRankingInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/CustomRankingInfo.php',
    'Google\\Service\\CloudTalentSolution\\DeviceInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/DeviceInfo.php',
    'Google\\Service\\CloudTalentSolution\\HistogramQuery' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/HistogramQuery.php',
    'Google\\Service\\CloudTalentSolution\\HistogramQueryResult' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/HistogramQueryResult.php',
    'Google\\Service\\CloudTalentSolution\\Job' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Job.php',
    'Google\\Service\\CloudTalentSolution\\JobDerivedInfo' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/JobDerivedInfo.php',
    'Google\\Service\\CloudTalentSolution\\JobEvent' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/JobEvent.php',
    'Google\\Service\\CloudTalentSolution\\JobQuery' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/JobQuery.php',
    'Google\\Service\\CloudTalentSolution\\JobResult' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/JobResult.php',
    'Google\\Service\\CloudTalentSolution\\JobsEmpty' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/JobsEmpty.php',
    'Google\\Service\\CloudTalentSolution\\LatLng' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/LatLng.php',
    'Google\\Service\\CloudTalentSolution\\ListCompaniesResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ListCompaniesResponse.php',
    'Google\\Service\\CloudTalentSolution\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ListJobsResponse.php',
    'Google\\Service\\CloudTalentSolution\\ListTenantsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ListTenantsResponse.php',
    'Google\\Service\\CloudTalentSolution\\Location' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Location.php',
    'Google\\Service\\CloudTalentSolution\\LocationFilter' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/LocationFilter.php',
    'Google\\Service\\CloudTalentSolution\\MatchingJob' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/MatchingJob.php',
    'Google\\Service\\CloudTalentSolution\\MendelDebugInput' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/MendelDebugInput.php',
    'Google\\Service\\CloudTalentSolution\\Money' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Money.php',
    'Google\\Service\\CloudTalentSolution\\NamespacedDebugInput' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/NamespacedDebugInput.php',
    'Google\\Service\\CloudTalentSolution\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Operation.php',
    'Google\\Service\\CloudTalentSolution\\PostalAddress' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/PostalAddress.php',
    'Google\\Service\\CloudTalentSolution\\ProcessingOptions' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ProcessingOptions.php',
    'Google\\Service\\CloudTalentSolution\\RequestMetadata' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/RequestMetadata.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/Projects.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/ProjectsOperations.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\ProjectsTenants' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/ProjectsTenants.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\ProjectsTenantsClientEvents' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/ProjectsTenantsClientEvents.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\ProjectsTenantsCompanies' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/ProjectsTenantsCompanies.php',
    'Google\\Service\\CloudTalentSolution\\Resource\\ProjectsTenantsJobs' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Resource/ProjectsTenantsJobs.php',
    'Google\\Service\\CloudTalentSolution\\ResponseMetadata' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/ResponseMetadata.php',
    'Google\\Service\\CloudTalentSolution\\SearchJobsRequest' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/SearchJobsRequest.php',
    'Google\\Service\\CloudTalentSolution\\SearchJobsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/SearchJobsResponse.php',
    'Google\\Service\\CloudTalentSolution\\SpellingCorrection' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/SpellingCorrection.php',
    'Google\\Service\\CloudTalentSolution\\Status' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Status.php',
    'Google\\Service\\CloudTalentSolution\\Tenant' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/Tenant.php',
    'Google\\Service\\CloudTalentSolution\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/TimeOfDay.php',
    'Google\\Service\\CloudTalentSolution\\TimestampRange' => $vendorDir . '/google/apiclient-services/src/CloudTalentSolution/TimestampRange.php',
    'Google\\Service\\CloudTasks' => $vendorDir . '/google/apiclient-services/src/CloudTasks.php',
    'Google\\Service\\CloudTasks\\AppEngineHttpRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/AppEngineHttpRequest.php',
    'Google\\Service\\CloudTasks\\AppEngineRouting' => $vendorDir . '/google/apiclient-services/src/CloudTasks/AppEngineRouting.php',
    'Google\\Service\\CloudTasks\\Attempt' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Attempt.php',
    'Google\\Service\\CloudTasks\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Binding.php',
    'Google\\Service\\CloudTasks\\BufferTaskRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/BufferTaskRequest.php',
    'Google\\Service\\CloudTasks\\BufferTaskResponse' => $vendorDir . '/google/apiclient-services/src/CloudTasks/BufferTaskResponse.php',
    'Google\\Service\\CloudTasks\\CloudtasksEmpty' => $vendorDir . '/google/apiclient-services/src/CloudTasks/CloudtasksEmpty.php',
    'Google\\Service\\CloudTasks\\CmekConfig' => $vendorDir . '/google/apiclient-services/src/CloudTasks/CmekConfig.php',
    'Google\\Service\\CloudTasks\\CreateTaskRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/CreateTaskRequest.php',
    'Google\\Service\\CloudTasks\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Expr.php',
    'Google\\Service\\CloudTasks\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/GetIamPolicyRequest.php',
    'Google\\Service\\CloudTasks\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/CloudTasks/GetPolicyOptions.php',
    'Google\\Service\\CloudTasks\\Header' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Header.php',
    'Google\\Service\\CloudTasks\\HeaderOverride' => $vendorDir . '/google/apiclient-services/src/CloudTasks/HeaderOverride.php',
    'Google\\Service\\CloudTasks\\HttpBody' => $vendorDir . '/google/apiclient-services/src/CloudTasks/HttpBody.php',
    'Google\\Service\\CloudTasks\\HttpRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/HttpRequest.php',
    'Google\\Service\\CloudTasks\\HttpTarget' => $vendorDir . '/google/apiclient-services/src/CloudTasks/HttpTarget.php',
    'Google\\Service\\CloudTasks\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTasks/ListLocationsResponse.php',
    'Google\\Service\\CloudTasks\\ListQueuesResponse' => $vendorDir . '/google/apiclient-services/src/CloudTasks/ListQueuesResponse.php',
    'Google\\Service\\CloudTasks\\ListTasksResponse' => $vendorDir . '/google/apiclient-services/src/CloudTasks/ListTasksResponse.php',
    'Google\\Service\\CloudTasks\\Location' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Location.php',
    'Google\\Service\\CloudTasks\\OAuthToken' => $vendorDir . '/google/apiclient-services/src/CloudTasks/OAuthToken.php',
    'Google\\Service\\CloudTasks\\OidcToken' => $vendorDir . '/google/apiclient-services/src/CloudTasks/OidcToken.php',
    'Google\\Service\\CloudTasks\\PathOverride' => $vendorDir . '/google/apiclient-services/src/CloudTasks/PathOverride.php',
    'Google\\Service\\CloudTasks\\PauseQueueRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/PauseQueueRequest.php',
    'Google\\Service\\CloudTasks\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Policy.php',
    'Google\\Service\\CloudTasks\\PurgeQueueRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/PurgeQueueRequest.php',
    'Google\\Service\\CloudTasks\\QueryOverride' => $vendorDir . '/google/apiclient-services/src/CloudTasks/QueryOverride.php',
    'Google\\Service\\CloudTasks\\Queue' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Queue.php',
    'Google\\Service\\CloudTasks\\RateLimits' => $vendorDir . '/google/apiclient-services/src/CloudTasks/RateLimits.php',
    'Google\\Service\\CloudTasks\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Resource/Projects.php',
    'Google\\Service\\CloudTasks\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudTasks\\Resource\\ProjectsLocationsQueues' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Resource/ProjectsLocationsQueues.php',
    'Google\\Service\\CloudTasks\\Resource\\ProjectsLocationsQueuesTasks' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Resource/ProjectsLocationsQueuesTasks.php',
    'Google\\Service\\CloudTasks\\ResumeQueueRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/ResumeQueueRequest.php',
    'Google\\Service\\CloudTasks\\RetryConfig' => $vendorDir . '/google/apiclient-services/src/CloudTasks/RetryConfig.php',
    'Google\\Service\\CloudTasks\\RunTaskRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/RunTaskRequest.php',
    'Google\\Service\\CloudTasks\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/SetIamPolicyRequest.php',
    'Google\\Service\\CloudTasks\\StackdriverLoggingConfig' => $vendorDir . '/google/apiclient-services/src/CloudTasks/StackdriverLoggingConfig.php',
    'Google\\Service\\CloudTasks\\Status' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Status.php',
    'Google\\Service\\CloudTasks\\Task' => $vendorDir . '/google/apiclient-services/src/CloudTasks/Task.php',
    'Google\\Service\\CloudTasks\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudTasks/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudTasks\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudTasks/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudTasks\\UriOverride' => $vendorDir . '/google/apiclient-services/src/CloudTasks/UriOverride.php',
    'Google\\Service\\CloudTrace' => $vendorDir . '/google/apiclient-services/src/CloudTrace.php',
    'Google\\Service\\CloudTrace\\Annotation' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Annotation.php',
    'Google\\Service\\CloudTrace\\AttributeValue' => $vendorDir . '/google/apiclient-services/src/CloudTrace/AttributeValue.php',
    'Google\\Service\\CloudTrace\\Attributes' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Attributes.php',
    'Google\\Service\\CloudTrace\\BatchWriteSpansRequest' => $vendorDir . '/google/apiclient-services/src/CloudTrace/BatchWriteSpansRequest.php',
    'Google\\Service\\CloudTrace\\CloudtraceEmpty' => $vendorDir . '/google/apiclient-services/src/CloudTrace/CloudtraceEmpty.php',
    'Google\\Service\\CloudTrace\\Link' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Link.php',
    'Google\\Service\\CloudTrace\\Links' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Links.php',
    'Google\\Service\\CloudTrace\\MessageEvent' => $vendorDir . '/google/apiclient-services/src/CloudTrace/MessageEvent.php',
    'Google\\Service\\CloudTrace\\Module' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Module.php',
    'Google\\Service\\CloudTrace\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Resource/Projects.php',
    'Google\\Service\\CloudTrace\\Resource\\ProjectsTraces' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Resource/ProjectsTraces.php',
    'Google\\Service\\CloudTrace\\Resource\\ProjectsTracesSpans' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Resource/ProjectsTracesSpans.php',
    'Google\\Service\\CloudTrace\\Span' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Span.php',
    'Google\\Service\\CloudTrace\\StackFrame' => $vendorDir . '/google/apiclient-services/src/CloudTrace/StackFrame.php',
    'Google\\Service\\CloudTrace\\StackFrames' => $vendorDir . '/google/apiclient-services/src/CloudTrace/StackFrames.php',
    'Google\\Service\\CloudTrace\\StackTrace' => $vendorDir . '/google/apiclient-services/src/CloudTrace/StackTrace.php',
    'Google\\Service\\CloudTrace\\Status' => $vendorDir . '/google/apiclient-services/src/CloudTrace/Status.php',
    'Google\\Service\\CloudTrace\\TimeEvent' => $vendorDir . '/google/apiclient-services/src/CloudTrace/TimeEvent.php',
    'Google\\Service\\CloudTrace\\TimeEvents' => $vendorDir . '/google/apiclient-services/src/CloudTrace/TimeEvents.php',
    'Google\\Service\\CloudTrace\\TruncatableString' => $vendorDir . '/google/apiclient-services/src/CloudTrace/TruncatableString.php',
    'Google\\Service\\CloudVideoIntelligence' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1AnnotateVideoProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1AnnotateVideoProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1AnnotateVideoRequest' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1AnnotateVideoRequest.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1AnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1AnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1DetectedAttribute' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1DetectedAttribute.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1DetectedLandmark' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1DetectedLandmark.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1Entity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1Entity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ExplicitContentAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ExplicitContentAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ExplicitContentDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ExplicitContentDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ExplicitContentFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ExplicitContentFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1FaceAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1FaceDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1FaceDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1FaceDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1FaceDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1FaceFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1FaceFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1FaceSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1FaceSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1LabelAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1LabelAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1LabelDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1LabelDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1LabelFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1LabelFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1LabelSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1LabelSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1LogoRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1LogoRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1NormalizedBoundingBox' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1NormalizedBoundingBox.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1NormalizedBoundingPoly.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1NormalizedVertex.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ObjectTrackingAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ObjectTrackingConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ObjectTrackingConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ObjectTrackingFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1PersonDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1PersonDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1PersonDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1PersonDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1ShotChangeDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1ShotChangeDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1SpeechContext' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1SpeechContext.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1SpeechRecognitionAlternative.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1SpeechTranscription' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1SpeechTranscription.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1SpeechTranscriptionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1SpeechTranscriptionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1TextAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1TextDetectionConfig' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1TextDetectionConfig.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1TextFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1TextFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1TextSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1TextSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1TimestampedObject' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1TimestampedObject.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1Track' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1Track.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1VideoAnnotationProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1VideoAnnotationProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1VideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1VideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1VideoContext' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1VideoContext.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1VideoSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1VideoSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1WordInfo' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1WordInfo.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2AnnotateVideoProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2AnnotateVideoProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2AnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2AnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2DetectedAttribute' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2DetectedAttribute.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2DetectedLandmark' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2DetectedLandmark.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2Entity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2Entity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2ExplicitContentFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2ExplicitContentFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2FaceAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2FaceDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2FaceDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2FaceFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2FaceFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2FaceSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2FaceSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2LabelAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2LabelAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2LabelFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2LabelFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2LabelSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2LabelSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2NormalizedBoundingBox' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2NormalizedBoundingBox.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2NormalizedBoundingPoly.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2NormalizedVertex.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2ObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2ObjectTrackingAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2ObjectTrackingFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2PersonDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2PersonDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2SpeechTranscription' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2SpeechTranscription.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2TextAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2TextAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2TextFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2TextFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2TextSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2TextSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2TimestampedObject' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2TimestampedObject.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2Track' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2Track.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2VideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2VideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2VideoSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2VideoSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1beta2WordInfo' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1beta2WordInfo.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1AnnotateVideoProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1AnnotateVideoProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1AnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1AnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1DetectedAttribute' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1DetectedAttribute.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1DetectedLandmark' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1DetectedLandmark.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1Entity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1Entity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1FaceAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1FaceDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1FaceDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1FaceFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1FaceFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1FaceSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1FaceSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1LabelAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1LabelAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1LabelFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1LabelFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1LabelSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1LabelSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1NormalizedBoundingBox' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1NormalizedBoundingBox.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1NormalizedBoundingPoly.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1NormalizedVertex.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1ObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1ObjectTrackingAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1ObjectTrackingFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1PersonDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1PersonDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1SpeechTranscription' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1SpeechTranscription.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1TextAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1TextFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1TextFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1TextSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1TextSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1TimestampedObject' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1TimestampedObject.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1Track' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1Track.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1VideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1VideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1VideoSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1VideoSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p1beta1WordInfo' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p1beta1WordInfo.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1AnnotateVideoProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1AnnotateVideoProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1AnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1AnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1DetectedAttribute' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1DetectedAttribute.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1DetectedLandmark' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1DetectedLandmark.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1Entity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1Entity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1ExplicitContentFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1ExplicitContentFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1FaceAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1FaceDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1FaceDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1FaceFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1FaceFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1FaceSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1FaceSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1LabelAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1LabelAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1LabelFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1LabelFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1LabelSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1LabelSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingBox' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingBox.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingPoly.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1NormalizedVertex.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1ObjectTrackingFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1PersonDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1PersonDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1SpeechTranscription' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1SpeechTranscription.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1TextAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1TextFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1TextFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1TextSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1TextSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1TimestampedObject' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1TimestampedObject.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1Track' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1Track.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1VideoSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1VideoSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p2beta1WordInfo' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p2beta1WordInfo.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1AnnotateVideoProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1AnnotateVideoProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1AnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1AnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1Celebrity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1Celebrity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1CelebrityRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1CelebrityRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1CelebrityTrack' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1CelebrityTrack.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1DetectedAttribute' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1DetectedAttribute.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1DetectedLandmark' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1DetectedLandmark.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1Entity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1Entity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1ExplicitContentFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1ExplicitContentFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1FaceAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1FaceDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1FaceDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1FaceFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1FaceFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1FaceSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1FaceSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1LabelAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1LabelAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1LabelFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1LabelFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1LabelSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1LabelSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1NormalizedBoundingBox' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1NormalizedBoundingBox.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1NormalizedBoundingPoly.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1NormalizedVertex.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1ObjectTrackingFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1PersonDetectionAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1PersonDetectionAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1RecognizedCelebrity' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1RecognizedCelebrity.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1SpeechRecognitionAlternative.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1SpeechTranscription' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1SpeechTranscription.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1TextAnnotation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1TextFrame' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1TextFrame.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1TextSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1TextSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1TimestampedObject' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1TimestampedObject.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1Track' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1Track.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1VideoSegment' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1VideoSegment.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleCloudVideointelligenceV1p3beta1WordInfo' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleCloudVideointelligenceV1p3beta1WordInfo.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleLongrunningOperation.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudVideoIntelligence\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/GoogleRpcStatus.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/Operations.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\OperationsProjects' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/OperationsProjects.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\OperationsProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/OperationsProjectsLocations.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\OperationsProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/OperationsProjectsLocationsOperations.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/Projects.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudVideoIntelligence\\Resource\\Videos' => $vendorDir . '/google/apiclient-services/src/CloudVideoIntelligence/Resource/Videos.php',
    'Google\\Service\\CloudWorkstations' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations.php',
    'Google\\Service\\CloudWorkstations\\Accelerator' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Accelerator.php',
    'Google\\Service\\CloudWorkstations\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/AuditConfig.php',
    'Google\\Service\\CloudWorkstations\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/AuditLogConfig.php',
    'Google\\Service\\CloudWorkstations\\Binding' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Binding.php',
    'Google\\Service\\CloudWorkstations\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/CancelOperationRequest.php',
    'Google\\Service\\CloudWorkstations\\Container' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Container.php',
    'Google\\Service\\CloudWorkstations\\CustomerEncryptionKey' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/CustomerEncryptionKey.php',
    'Google\\Service\\CloudWorkstations\\DomainConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/DomainConfig.php',
    'Google\\Service\\CloudWorkstations\\EphemeralDirectory' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/EphemeralDirectory.php',
    'Google\\Service\\CloudWorkstations\\Expr' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Expr.php',
    'Google\\Service\\CloudWorkstations\\GceConfidentialInstanceConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GceConfidentialInstanceConfig.php',
    'Google\\Service\\CloudWorkstations\\GceInstance' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GceInstance.php',
    'Google\\Service\\CloudWorkstations\\GcePersistentDisk' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GcePersistentDisk.php',
    'Google\\Service\\CloudWorkstations\\GceRegionalPersistentDisk' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GceRegionalPersistentDisk.php',
    'Google\\Service\\CloudWorkstations\\GceShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GceShieldedInstanceConfig.php',
    'Google\\Service\\CloudWorkstations\\GenerateAccessTokenRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GenerateAccessTokenRequest.php',
    'Google\\Service\\CloudWorkstations\\GenerateAccessTokenResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GenerateAccessTokenResponse.php',
    'Google\\Service\\CloudWorkstations\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/GoogleProtobufEmpty.php',
    'Google\\Service\\CloudWorkstations\\Host' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Host.php',
    'Google\\Service\\CloudWorkstations\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListLocationsResponse.php',
    'Google\\Service\\CloudWorkstations\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListOperationsResponse.php',
    'Google\\Service\\CloudWorkstations\\ListUsableWorkstationConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListUsableWorkstationConfigsResponse.php',
    'Google\\Service\\CloudWorkstations\\ListUsableWorkstationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListUsableWorkstationsResponse.php',
    'Google\\Service\\CloudWorkstations\\ListWorkstationClustersResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListWorkstationClustersResponse.php',
    'Google\\Service\\CloudWorkstations\\ListWorkstationConfigsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListWorkstationConfigsResponse.php',
    'Google\\Service\\CloudWorkstations\\ListWorkstationsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ListWorkstationsResponse.php',
    'Google\\Service\\CloudWorkstations\\Location' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Location.php',
    'Google\\Service\\CloudWorkstations\\Operation' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Operation.php',
    'Google\\Service\\CloudWorkstations\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/OperationMetadata.php',
    'Google\\Service\\CloudWorkstations\\PersistentDirectory' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/PersistentDirectory.php',
    'Google\\Service\\CloudWorkstations\\Policy' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Policy.php',
    'Google\\Service\\CloudWorkstations\\PortRange' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/PortRange.php',
    'Google\\Service\\CloudWorkstations\\PrivateClusterConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/PrivateClusterConfig.php',
    'Google\\Service\\CloudWorkstations\\ReadinessCheck' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/ReadinessCheck.php',
    'Google\\Service\\CloudWorkstations\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/Projects.php',
    'Google\\Service\\CloudWorkstations\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/ProjectsLocations.php',
    'Google\\Service\\CloudWorkstations\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\CloudWorkstations\\Resource\\ProjectsLocationsWorkstationClusters' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/ProjectsLocationsWorkstationClusters.php',
    'Google\\Service\\CloudWorkstations\\Resource\\ProjectsLocationsWorkstationClustersWorkstationConfigs' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/ProjectsLocationsWorkstationClustersWorkstationConfigs.php',
    'Google\\Service\\CloudWorkstations\\Resource\\ProjectsLocationsWorkstationClustersWorkstationConfigsWorkstations' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Resource/ProjectsLocationsWorkstationClustersWorkstationConfigsWorkstations.php',
    'Google\\Service\\CloudWorkstations\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/SetIamPolicyRequest.php',
    'Google\\Service\\CloudWorkstations\\StartWorkstationRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/StartWorkstationRequest.php',
    'Google\\Service\\CloudWorkstations\\Status' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Status.php',
    'Google\\Service\\CloudWorkstations\\StopWorkstationRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/StopWorkstationRequest.php',
    'Google\\Service\\CloudWorkstations\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/TestIamPermissionsRequest.php',
    'Google\\Service\\CloudWorkstations\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/TestIamPermissionsResponse.php',
    'Google\\Service\\CloudWorkstations\\Workstation' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/Workstation.php',
    'Google\\Service\\CloudWorkstations\\WorkstationCluster' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/WorkstationCluster.php',
    'Google\\Service\\CloudWorkstations\\WorkstationConfig' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/WorkstationConfig.php',
    'Google\\Service\\CloudWorkstations\\WorkstationsEmpty' => $vendorDir . '/google/apiclient-services/src/CloudWorkstations/WorkstationsEmpty.php',
    'Google\\Service\\Cloudbilling' => $vendorDir . '/google/apiclient-services/src/Cloudbilling.php',
    'Google\\Service\\Cloudbilling\\AggregationInfo' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/AggregationInfo.php',
    'Google\\Service\\Cloudbilling\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/AuditConfig.php',
    'Google\\Service\\Cloudbilling\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/AuditLogConfig.php',
    'Google\\Service\\Cloudbilling\\BillingAccount' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/BillingAccount.php',
    'Google\\Service\\Cloudbilling\\Binding' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Binding.php',
    'Google\\Service\\Cloudbilling\\Category' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Category.php',
    'Google\\Service\\Cloudbilling\\Expr' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Expr.php',
    'Google\\Service\\Cloudbilling\\GeoTaxonomy' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/GeoTaxonomy.php',
    'Google\\Service\\Cloudbilling\\ListBillingAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/ListBillingAccountsResponse.php',
    'Google\\Service\\Cloudbilling\\ListProjectBillingInfoResponse' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/ListProjectBillingInfoResponse.php',
    'Google\\Service\\Cloudbilling\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/ListServicesResponse.php',
    'Google\\Service\\Cloudbilling\\ListSkusResponse' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/ListSkusResponse.php',
    'Google\\Service\\Cloudbilling\\Money' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Money.php',
    'Google\\Service\\Cloudbilling\\MoveBillingAccountRequest' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/MoveBillingAccountRequest.php',
    'Google\\Service\\Cloudbilling\\Policy' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Policy.php',
    'Google\\Service\\Cloudbilling\\PricingExpression' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/PricingExpression.php',
    'Google\\Service\\Cloudbilling\\PricingInfo' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/PricingInfo.php',
    'Google\\Service\\Cloudbilling\\ProjectBillingInfo' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/ProjectBillingInfo.php',
    'Google\\Service\\Cloudbilling\\Resource\\BillingAccounts' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/BillingAccounts.php',
    'Google\\Service\\Cloudbilling\\Resource\\BillingAccountsProjects' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/BillingAccountsProjects.php',
    'Google\\Service\\Cloudbilling\\Resource\\BillingAccountsSubAccounts' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/BillingAccountsSubAccounts.php',
    'Google\\Service\\Cloudbilling\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/Organizations.php',
    'Google\\Service\\Cloudbilling\\Resource\\OrganizationsBillingAccounts' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/OrganizationsBillingAccounts.php',
    'Google\\Service\\Cloudbilling\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/Projects.php',
    'Google\\Service\\Cloudbilling\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/Services.php',
    'Google\\Service\\Cloudbilling\\Resource\\ServicesSkus' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Resource/ServicesSkus.php',
    'Google\\Service\\Cloudbilling\\Service' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Service.php',
    'Google\\Service\\Cloudbilling\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/SetIamPolicyRequest.php',
    'Google\\Service\\Cloudbilling\\Sku' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/Sku.php',
    'Google\\Service\\Cloudbilling\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/TestIamPermissionsRequest.php',
    'Google\\Service\\Cloudbilling\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/TestIamPermissionsResponse.php',
    'Google\\Service\\Cloudbilling\\TierRate' => $vendorDir . '/google/apiclient-services/src/Cloudbilling/TierRate.php',
    'Google\\Service\\Cloudchannel' => $vendorDir . '/google/apiclient-services/src/Cloudchannel.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ActivateEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ActivateEntitlementRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1AdminUser' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1AdminUser.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1AssociationInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1AssociationInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1BillableSku' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1BillableSku.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1BillingAccount' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1BillingAccount.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1BillingAccountPurchaseInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1BillingAccountPurchaseInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CancelEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CancelEntitlementRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ChangeOfferRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ChangeOfferRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ChangeParametersRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ChangeParametersRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ChangeRenewalSettingsRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ChangeRenewalSettingsRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ChannelPartnerLink' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ChannelPartnerLink.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ChannelPartnerRepricingConfig' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ChannelPartnerRepricingConfig.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CloudIdentityCustomerAccount' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CloudIdentityCustomerAccount.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CloudIdentityInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CloudIdentityInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Column' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Column.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CommitmentSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CommitmentSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ConditionalOverride' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ConditionalOverride.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Constraints' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Constraints.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ContactInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ContactInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CreateEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CreateEntitlementRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Customer' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Customer.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CustomerConstraints' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CustomerConstraints.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CustomerEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CustomerEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1CustomerRepricingConfig' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1CustomerRepricingConfig.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1DateRange' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1DateRange.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1EduData' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1EduData.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Entitlement' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Entitlement.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1EntitlementChange' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1EntitlementChange.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1EntitlementEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1EntitlementEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1FetchReportResultsRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1FetchReportResultsRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1FetchReportResultsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1FetchReportResultsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ImportCustomerRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ImportCustomerRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListChannelPartnerLinksResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListChannelPartnerLinksResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListCustomerRepricingConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListCustomerRepricingConfigsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListCustomersResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListEntitlementChangesResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListEntitlementChangesResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListEntitlementsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListEntitlementsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListOffersResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListOffersResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListProductsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListPurchasableOffersResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListPurchasableOffersResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListPurchasableSkusResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListPurchasableSkusResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListReportsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListReportsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListSkuGroupBillableSkusResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListSkuGroupBillableSkusResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListSkuGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListSkuGroupsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListSkusResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListSkusResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListSubscribersResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListSubscribersResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListTransferableOffersRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListTransferableOffersRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListTransferableOffersResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListTransferableOffersResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListTransferableSkusRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListTransferableSkusRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ListTransferableSkusResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ListTransferableSkusResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1MarketingInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1MarketingInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Media' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Media.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Offer' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Offer.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1OperationMetadata.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Parameter' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Parameter.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ParameterDefinition' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ParameterDefinition.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PercentageAdjustment' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PercentageAdjustment.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Period' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Period.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Plan' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Plan.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Price' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Price.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PriceByResource' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PriceByResource.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PricePhase' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PricePhase.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PriceTier' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PriceTier.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Product' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Product.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ProvisionCloudIdentityRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ProvisionCloudIdentityRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ProvisionedService' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ProvisionedService.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PurchasableOffer' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PurchasableOffer.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1PurchasableSku' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1PurchasableSku.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1QueryEligibleBillingAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1QueryEligibleBillingAccountsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RegisterSubscriberRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RegisterSubscriberRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RegisterSubscriberResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RegisterSubscriberResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RenewalSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RenewalSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Report' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Report.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ReportJob' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ReportJob.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ReportResultsMetadata' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ReportResultsMetadata.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ReportStatus' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ReportStatus.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1ReportValue' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1ReportValue.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RepricingAdjustment' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RepricingAdjustment.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RepricingCondition' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RepricingCondition.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RepricingConfig' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RepricingConfig.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RepricingConfigChannelPartnerGranularity' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RepricingConfigChannelPartnerGranularity.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RepricingConfigEntitlementGranularity' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RepricingConfigEntitlementGranularity.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Row' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Row.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RunReportJobRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RunReportJobRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1RunReportJobResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1RunReportJobResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Sku' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Sku.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1SkuGroup' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1SkuGroup.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1SkuGroupCondition' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1SkuGroupCondition.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1SkuPurchaseGroup' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1SkuPurchaseGroup.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1StartPaidServiceRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1StartPaidServiceRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1SubscriberEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1SubscriberEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1SuspendEntitlementRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1SuspendEntitlementRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferEligibility' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferEligibility.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferEntitlementsRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferEntitlementsRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferEntitlementsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferEntitlementsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferEntitlementsToGoogleRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferEntitlementsToGoogleRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferableOffer' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferableOffer.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TransferableSku' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TransferableSku.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1TrialSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1TrialSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1UnregisterSubscriberRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1UnregisterSubscriberRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1UnregisterSubscriberResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1UnregisterSubscriberResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1UpdateChannelPartnerLinkRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1UpdateChannelPartnerLinkRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1Value' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1Value.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1AssociationInfo' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1AssociationInfo.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1ChannelPartnerEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1ChannelPartnerEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Column' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Column.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1CommitmentSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1CommitmentSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1CustomerEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1CustomerEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1DateRange' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1DateRange.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Entitlement' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Entitlement.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1EntitlementEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1EntitlementEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1OperationMetadata.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Parameter' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Parameter.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Period' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Period.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1ProvisionedService' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1ProvisionedService.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1RenewalSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1RenewalSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Report' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Report.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1ReportJob' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1ReportJob.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1ReportResultsMetadata' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1ReportResultsMetadata.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1ReportStatus' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1ReportStatus.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1RunReportJobResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1RunReportJobResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1SubscriberEvent' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1SubscriberEvent.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1TransferEntitlementsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1TransferEntitlementsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1TrialSettings' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1TrialSettings.php',
    'Google\\Service\\Cloudchannel\\GoogleCloudChannelV1alpha1Value' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleCloudChannelV1alpha1Value.php',
    'Google\\Service\\Cloudchannel\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\Cloudchannel\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Cloudchannel\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleLongrunningOperation.php',
    'Google\\Service\\Cloudchannel\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleProtobufEmpty.php',
    'Google\\Service\\Cloudchannel\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleRpcStatus.php',
    'Google\\Service\\Cloudchannel\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypeDate.php',
    'Google\\Service\\Cloudchannel\\GoogleTypeDateTime' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypeDateTime.php',
    'Google\\Service\\Cloudchannel\\GoogleTypeDecimal' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypeDecimal.php',
    'Google\\Service\\Cloudchannel\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypeMoney.php',
    'Google\\Service\\Cloudchannel\\GoogleTypePostalAddress' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypePostalAddress.php',
    'Google\\Service\\Cloudchannel\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/GoogleTypeTimeZone.php',
    'Google\\Service\\Cloudchannel\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/Accounts.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsChannelPartnerLinks' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsChannelPartnerLinks.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsChannelPartnerLinksChannelPartnerRepricingConfigs' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsChannelPartnerLinksChannelPartnerRepricingConfigs.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsChannelPartnerLinksCustomers' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsChannelPartnerLinksCustomers.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsCustomers' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsCustomers.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsCustomersCustomerRepricingConfigs' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsCustomersCustomerRepricingConfigs.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsCustomersEntitlements' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsCustomersEntitlements.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsOffers' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsOffers.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsReportJobs' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsReportJobs.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsReports' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsReports.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsSkuGroups' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsSkuGroups.php',
    'Google\\Service\\Cloudchannel\\Resource\\AccountsSkuGroupsBillableSkus' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/AccountsSkuGroupsBillableSkus.php',
    'Google\\Service\\Cloudchannel\\Resource\\Integrators' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/Integrators.php',
    'Google\\Service\\Cloudchannel\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/Operations.php',
    'Google\\Service\\Cloudchannel\\Resource\\Products' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/Products.php',
    'Google\\Service\\Cloudchannel\\Resource\\ProductsSkus' => $vendorDir . '/google/apiclient-services/src/Cloudchannel/Resource/ProductsSkus.php',
    'Google\\Service\\Clouderrorreporting' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting.php',
    'Google\\Service\\Clouderrorreporting\\DeleteEventsResponse' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/DeleteEventsResponse.php',
    'Google\\Service\\Clouderrorreporting\\ErrorContext' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ErrorContext.php',
    'Google\\Service\\Clouderrorreporting\\ErrorEvent' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ErrorEvent.php',
    'Google\\Service\\Clouderrorreporting\\ErrorGroup' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ErrorGroup.php',
    'Google\\Service\\Clouderrorreporting\\ErrorGroupStats' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ErrorGroupStats.php',
    'Google\\Service\\Clouderrorreporting\\HttpRequestContext' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/HttpRequestContext.php',
    'Google\\Service\\Clouderrorreporting\\ListEventsResponse' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ListEventsResponse.php',
    'Google\\Service\\Clouderrorreporting\\ListGroupStatsResponse' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ListGroupStatsResponse.php',
    'Google\\Service\\Clouderrorreporting\\ReportErrorEventResponse' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ReportErrorEventResponse.php',
    'Google\\Service\\Clouderrorreporting\\ReportedErrorEvent' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ReportedErrorEvent.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/Projects.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsEvents' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsEvents.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsGroupStats' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsGroupStats.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsGroups' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsGroups.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsLocations.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsLocationsEvents' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsLocationsEvents.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsLocationsGroupStats' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsLocationsGroupStats.php',
    'Google\\Service\\Clouderrorreporting\\Resource\\ProjectsLocationsGroups' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/Resource/ProjectsLocationsGroups.php',
    'Google\\Service\\Clouderrorreporting\\ServiceContext' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/ServiceContext.php',
    'Google\\Service\\Clouderrorreporting\\SourceLocation' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/SourceLocation.php',
    'Google\\Service\\Clouderrorreporting\\SourceReference' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/SourceReference.php',
    'Google\\Service\\Clouderrorreporting\\TimedCount' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/TimedCount.php',
    'Google\\Service\\Clouderrorreporting\\TrackingIssue' => $vendorDir . '/google/apiclient-services/src/Clouderrorreporting/TrackingIssue.php',
    'Google\\Service\\Compute' => $vendorDir . '/google/apiclient-services/src/Compute.php',
    'Google\\Service\\Compute\\AWSV4Signature' => $vendorDir . '/google/apiclient-services/src/Compute/AWSV4Signature.php',
    'Google\\Service\\Compute\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorConfig.php',
    'Google\\Service\\Compute\\AcceleratorType' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorType.php',
    'Google\\Service\\Compute\\AcceleratorTypeAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeAggregatedList.php',
    'Google\\Service\\Compute\\AcceleratorTypeAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeAggregatedListWarning.php',
    'Google\\Service\\Compute\\AcceleratorTypeAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeAggregatedListWarningData.php',
    'Google\\Service\\Compute\\AcceleratorTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeList.php',
    'Google\\Service\\Compute\\AcceleratorTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeListWarning.php',
    'Google\\Service\\Compute\\AcceleratorTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypeListWarningData.php',
    'Google\\Service\\Compute\\AcceleratorTypesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypesScopedList.php',
    'Google\\Service\\Compute\\AcceleratorTypesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypesScopedListWarning.php',
    'Google\\Service\\Compute\\AcceleratorTypesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AcceleratorTypesScopedListWarningData.php',
    'Google\\Service\\Compute\\AccessConfig' => $vendorDir . '/google/apiclient-services/src/Compute/AccessConfig.php',
    'Google\\Service\\Compute\\Address' => $vendorDir . '/google/apiclient-services/src/Compute/Address.php',
    'Google\\Service\\Compute\\AddressAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/AddressAggregatedList.php',
    'Google\\Service\\Compute\\AddressAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AddressAggregatedListWarning.php',
    'Google\\Service\\Compute\\AddressAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AddressAggregatedListWarningData.php',
    'Google\\Service\\Compute\\AddressList' => $vendorDir . '/google/apiclient-services/src/Compute/AddressList.php',
    'Google\\Service\\Compute\\AddressListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AddressListWarning.php',
    'Google\\Service\\Compute\\AddressListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AddressListWarningData.php',
    'Google\\Service\\Compute\\AddressesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/AddressesScopedList.php',
    'Google\\Service\\Compute\\AddressesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AddressesScopedListWarning.php',
    'Google\\Service\\Compute\\AddressesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AddressesScopedListWarningData.php',
    'Google\\Service\\Compute\\AdvancedMachineFeatures' => $vendorDir . '/google/apiclient-services/src/Compute/AdvancedMachineFeatures.php',
    'Google\\Service\\Compute\\AliasIpRange' => $vendorDir . '/google/apiclient-services/src/Compute/AliasIpRange.php',
    'Google\\Service\\Compute\\AllocationAggregateReservation' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationAggregateReservation.php',
    'Google\\Service\\Compute\\AllocationAggregateReservationReservedResourceInfo' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationAggregateReservationReservedResourceInfo.php',
    'Google\\Service\\Compute\\AllocationAggregateReservationReservedResourceInfoAccelerator' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationAggregateReservationReservedResourceInfoAccelerator.php',
    'Google\\Service\\Compute\\AllocationResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationResourceStatus.php',
    'Google\\Service\\Compute\\AllocationResourceStatusSpecificSKUAllocation' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationResourceStatusSpecificSKUAllocation.php',
    'Google\\Service\\Compute\\AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk.php',
    'Google\\Service\\Compute\\AllocationSpecificSKUAllocationReservedInstanceProperties' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationSpecificSKUAllocationReservedInstanceProperties.php',
    'Google\\Service\\Compute\\AllocationSpecificSKUReservation' => $vendorDir . '/google/apiclient-services/src/Compute/AllocationSpecificSKUReservation.php',
    'Google\\Service\\Compute\\AttachedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/AttachedDisk.php',
    'Google\\Service\\Compute\\AttachedDiskInitializeParams' => $vendorDir . '/google/apiclient-services/src/Compute/AttachedDiskInitializeParams.php',
    'Google\\Service\\Compute\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Compute/AuditConfig.php',
    'Google\\Service\\Compute\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/AuditLogConfig.php',
    'Google\\Service\\Compute\\AuthorizationLoggingOptions' => $vendorDir . '/google/apiclient-services/src/Compute/AuthorizationLoggingOptions.php',
    'Google\\Service\\Compute\\Autoscaler' => $vendorDir . '/google/apiclient-services/src/Compute/Autoscaler.php',
    'Google\\Service\\Compute\\AutoscalerAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerAggregatedList.php',
    'Google\\Service\\Compute\\AutoscalerAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerAggregatedListWarning.php',
    'Google\\Service\\Compute\\AutoscalerAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerAggregatedListWarningData.php',
    'Google\\Service\\Compute\\AutoscalerList' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerList.php',
    'Google\\Service\\Compute\\AutoscalerListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerListWarning.php',
    'Google\\Service\\Compute\\AutoscalerListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerListWarningData.php',
    'Google\\Service\\Compute\\AutoscalerStatusDetails' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalerStatusDetails.php',
    'Google\\Service\\Compute\\AutoscalersScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalersScopedList.php',
    'Google\\Service\\Compute\\AutoscalersScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalersScopedListWarning.php',
    'Google\\Service\\Compute\\AutoscalersScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalersScopedListWarningData.php',
    'Google\\Service\\Compute\\AutoscalingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicy.php',
    'Google\\Service\\Compute\\AutoscalingPolicyCpuUtilization' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicyCpuUtilization.php',
    'Google\\Service\\Compute\\AutoscalingPolicyCustomMetricUtilization' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicyCustomMetricUtilization.php',
    'Google\\Service\\Compute\\AutoscalingPolicyLoadBalancingUtilization' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicyLoadBalancingUtilization.php',
    'Google\\Service\\Compute\\AutoscalingPolicyScaleInControl' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicyScaleInControl.php',
    'Google\\Service\\Compute\\AutoscalingPolicyScalingSchedule' => $vendorDir . '/google/apiclient-services/src/Compute/AutoscalingPolicyScalingSchedule.php',
    'Google\\Service\\Compute\\Backend' => $vendorDir . '/google/apiclient-services/src/Compute/Backend.php',
    'Google\\Service\\Compute\\BackendBucket' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucket.php',
    'Google\\Service\\Compute\\BackendBucketCdnPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketCdnPolicy.php',
    'Google\\Service\\Compute\\BackendBucketCdnPolicyBypassCacheOnRequestHeader' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketCdnPolicyBypassCacheOnRequestHeader.php',
    'Google\\Service\\Compute\\BackendBucketCdnPolicyCacheKeyPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketCdnPolicyCacheKeyPolicy.php',
    'Google\\Service\\Compute\\BackendBucketCdnPolicyNegativeCachingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketCdnPolicyNegativeCachingPolicy.php',
    'Google\\Service\\Compute\\BackendBucketList' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketList.php',
    'Google\\Service\\Compute\\BackendBucketListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketListWarning.php',
    'Google\\Service\\Compute\\BackendBucketListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/BackendBucketListWarningData.php',
    'Google\\Service\\Compute\\BackendService' => $vendorDir . '/google/apiclient-services/src/Compute/BackendService.php',
    'Google\\Service\\Compute\\BackendServiceAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceAggregatedList.php',
    'Google\\Service\\Compute\\BackendServiceAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceAggregatedListWarning.php',
    'Google\\Service\\Compute\\BackendServiceAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceAggregatedListWarningData.php',
    'Google\\Service\\Compute\\BackendServiceCdnPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceCdnPolicy.php',
    'Google\\Service\\Compute\\BackendServiceCdnPolicyBypassCacheOnRequestHeader' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceCdnPolicyBypassCacheOnRequestHeader.php',
    'Google\\Service\\Compute\\BackendServiceCdnPolicyNegativeCachingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceCdnPolicyNegativeCachingPolicy.php',
    'Google\\Service\\Compute\\BackendServiceConnectionTrackingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceConnectionTrackingPolicy.php',
    'Google\\Service\\Compute\\BackendServiceFailoverPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceFailoverPolicy.php',
    'Google\\Service\\Compute\\BackendServiceGroupHealth' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceGroupHealth.php',
    'Google\\Service\\Compute\\BackendServiceIAP' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceIAP.php',
    'Google\\Service\\Compute\\BackendServiceList' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceList.php',
    'Google\\Service\\Compute\\BackendServiceListUsable' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceListUsable.php',
    'Google\\Service\\Compute\\BackendServiceListUsableWarning' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceListUsableWarning.php',
    'Google\\Service\\Compute\\BackendServiceListUsableWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceListUsableWarningData.php',
    'Google\\Service\\Compute\\BackendServiceListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceListWarning.php',
    'Google\\Service\\Compute\\BackendServiceListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceListWarningData.php',
    'Google\\Service\\Compute\\BackendServiceLocalityLoadBalancingPolicyConfig' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceLocalityLoadBalancingPolicyConfig.php',
    'Google\\Service\\Compute\\BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.php',
    'Google\\Service\\Compute\\BackendServiceLocalityLoadBalancingPolicyConfigPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceLocalityLoadBalancingPolicyConfigPolicy.php',
    'Google\\Service\\Compute\\BackendServiceLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceLogConfig.php',
    'Google\\Service\\Compute\\BackendServiceReference' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceReference.php',
    'Google\\Service\\Compute\\BackendServiceUsedBy' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServiceUsedBy.php',
    'Google\\Service\\Compute\\BackendServicesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServicesScopedList.php',
    'Google\\Service\\Compute\\BackendServicesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServicesScopedListWarning.php',
    'Google\\Service\\Compute\\BackendServicesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/BackendServicesScopedListWarningData.php',
    'Google\\Service\\Compute\\BfdPacket' => $vendorDir . '/google/apiclient-services/src/Compute/BfdPacket.php',
    'Google\\Service\\Compute\\BfdStatus' => $vendorDir . '/google/apiclient-services/src/Compute/BfdStatus.php',
    'Google\\Service\\Compute\\BfdStatusPacketCounts' => $vendorDir . '/google/apiclient-services/src/Compute/BfdStatusPacketCounts.php',
    'Google\\Service\\Compute\\Binding' => $vendorDir . '/google/apiclient-services/src/Compute/Binding.php',
    'Google\\Service\\Compute\\BulkInsertDiskResource' => $vendorDir . '/google/apiclient-services/src/Compute/BulkInsertDiskResource.php',
    'Google\\Service\\Compute\\BulkInsertInstanceResource' => $vendorDir . '/google/apiclient-services/src/Compute/BulkInsertInstanceResource.php',
    'Google\\Service\\Compute\\BulkInsertInstanceResourcePerInstanceProperties' => $vendorDir . '/google/apiclient-services/src/Compute/BulkInsertInstanceResourcePerInstanceProperties.php',
    'Google\\Service\\Compute\\BulkInsertOperationStatus' => $vendorDir . '/google/apiclient-services/src/Compute/BulkInsertOperationStatus.php',
    'Google\\Service\\Compute\\CacheInvalidationRule' => $vendorDir . '/google/apiclient-services/src/Compute/CacheInvalidationRule.php',
    'Google\\Service\\Compute\\CacheKeyPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/CacheKeyPolicy.php',
    'Google\\Service\\Compute\\CircuitBreakers' => $vendorDir . '/google/apiclient-services/src/Compute/CircuitBreakers.php',
    'Google\\Service\\Compute\\Commitment' => $vendorDir . '/google/apiclient-services/src/Compute/Commitment.php',
    'Google\\Service\\Compute\\CommitmentAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentAggregatedList.php',
    'Google\\Service\\Compute\\CommitmentAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentAggregatedListWarning.php',
    'Google\\Service\\Compute\\CommitmentAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentAggregatedListWarningData.php',
    'Google\\Service\\Compute\\CommitmentList' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentList.php',
    'Google\\Service\\Compute\\CommitmentListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentListWarning.php',
    'Google\\Service\\Compute\\CommitmentListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentListWarningData.php',
    'Google\\Service\\Compute\\CommitmentsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentsScopedList.php',
    'Google\\Service\\Compute\\CommitmentsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentsScopedListWarning.php',
    'Google\\Service\\Compute\\CommitmentsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/CommitmentsScopedListWarningData.php',
    'Google\\Service\\Compute\\Condition' => $vendorDir . '/google/apiclient-services/src/Compute/Condition.php',
    'Google\\Service\\Compute\\ConfidentialInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Compute/ConfidentialInstanceConfig.php',
    'Google\\Service\\Compute\\ConnectionDraining' => $vendorDir . '/google/apiclient-services/src/Compute/ConnectionDraining.php',
    'Google\\Service\\Compute\\ConsistentHashLoadBalancerSettings' => $vendorDir . '/google/apiclient-services/src/Compute/ConsistentHashLoadBalancerSettings.php',
    'Google\\Service\\Compute\\ConsistentHashLoadBalancerSettingsHttpCookie' => $vendorDir . '/google/apiclient-services/src/Compute/ConsistentHashLoadBalancerSettingsHttpCookie.php',
    'Google\\Service\\Compute\\CorsPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/CorsPolicy.php',
    'Google\\Service\\Compute\\CustomErrorResponsePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/CustomErrorResponsePolicy.php',
    'Google\\Service\\Compute\\CustomErrorResponsePolicyCustomErrorResponseRule' => $vendorDir . '/google/apiclient-services/src/Compute/CustomErrorResponsePolicyCustomErrorResponseRule.php',
    'Google\\Service\\Compute\\CustomerEncryptionKey' => $vendorDir . '/google/apiclient-services/src/Compute/CustomerEncryptionKey.php',
    'Google\\Service\\Compute\\CustomerEncryptionKeyProtectedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/CustomerEncryptionKeyProtectedDisk.php',
    'Google\\Service\\Compute\\DeprecationStatus' => $vendorDir . '/google/apiclient-services/src/Compute/DeprecationStatus.php',
    'Google\\Service\\Compute\\Disk' => $vendorDir . '/google/apiclient-services/src/Compute/Disk.php',
    'Google\\Service\\Compute\\DiskAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskAggregatedList.php',
    'Google\\Service\\Compute\\DiskAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DiskAggregatedListWarning.php',
    'Google\\Service\\Compute\\DiskAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DiskAggregatedListWarningData.php',
    'Google\\Service\\Compute\\DiskAsyncReplication' => $vendorDir . '/google/apiclient-services/src/Compute/DiskAsyncReplication.php',
    'Google\\Service\\Compute\\DiskAsyncReplicationList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskAsyncReplicationList.php',
    'Google\\Service\\Compute\\DiskInstantiationConfig' => $vendorDir . '/google/apiclient-services/src/Compute/DiskInstantiationConfig.php',
    'Google\\Service\\Compute\\DiskList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskList.php',
    'Google\\Service\\Compute\\DiskListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DiskListWarning.php',
    'Google\\Service\\Compute\\DiskListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DiskListWarningData.php',
    'Google\\Service\\Compute\\DiskMoveRequest' => $vendorDir . '/google/apiclient-services/src/Compute/DiskMoveRequest.php',
    'Google\\Service\\Compute\\DiskParams' => $vendorDir . '/google/apiclient-services/src/Compute/DiskParams.php',
    'Google\\Service\\Compute\\DiskResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/DiskResourceStatus.php',
    'Google\\Service\\Compute\\DiskResourceStatusAsyncReplicationStatus' => $vendorDir . '/google/apiclient-services/src/Compute/DiskResourceStatusAsyncReplicationStatus.php',
    'Google\\Service\\Compute\\DiskType' => $vendorDir . '/google/apiclient-services/src/Compute/DiskType.php',
    'Google\\Service\\Compute\\DiskTypeAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeAggregatedList.php',
    'Google\\Service\\Compute\\DiskTypeAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeAggregatedListWarning.php',
    'Google\\Service\\Compute\\DiskTypeAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeAggregatedListWarningData.php',
    'Google\\Service\\Compute\\DiskTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeList.php',
    'Google\\Service\\Compute\\DiskTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeListWarning.php',
    'Google\\Service\\Compute\\DiskTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypeListWarningData.php',
    'Google\\Service\\Compute\\DiskTypesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypesScopedList.php',
    'Google\\Service\\Compute\\DiskTypesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypesScopedListWarning.php',
    'Google\\Service\\Compute\\DiskTypesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DiskTypesScopedListWarningData.php',
    'Google\\Service\\Compute\\DisksAddResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/DisksAddResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\DisksRemoveResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/DisksRemoveResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\DisksResizeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/DisksResizeRequest.php',
    'Google\\Service\\Compute\\DisksScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/DisksScopedList.php',
    'Google\\Service\\Compute\\DisksScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/DisksScopedListWarning.php',
    'Google\\Service\\Compute\\DisksScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/DisksScopedListWarningData.php',
    'Google\\Service\\Compute\\DisksStartAsyncReplicationRequest' => $vendorDir . '/google/apiclient-services/src/Compute/DisksStartAsyncReplicationRequest.php',
    'Google\\Service\\Compute\\DisksStopGroupAsyncReplicationResource' => $vendorDir . '/google/apiclient-services/src/Compute/DisksStopGroupAsyncReplicationResource.php',
    'Google\\Service\\Compute\\DisplayDevice' => $vendorDir . '/google/apiclient-services/src/Compute/DisplayDevice.php',
    'Google\\Service\\Compute\\DistributionPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/DistributionPolicy.php',
    'Google\\Service\\Compute\\DistributionPolicyZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/Compute/DistributionPolicyZoneConfiguration.php',
    'Google\\Service\\Compute\\Duration' => $vendorDir . '/google/apiclient-services/src/Compute/Duration.php',
    'Google\\Service\\Compute\\ErrorInfo' => $vendorDir . '/google/apiclient-services/src/Compute/ErrorInfo.php',
    'Google\\Service\\Compute\\ExchangedPeeringRoute' => $vendorDir . '/google/apiclient-services/src/Compute/ExchangedPeeringRoute.php',
    'Google\\Service\\Compute\\ExchangedPeeringRoutesList' => $vendorDir . '/google/apiclient-services/src/Compute/ExchangedPeeringRoutesList.php',
    'Google\\Service\\Compute\\ExchangedPeeringRoutesListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ExchangedPeeringRoutesListWarning.php',
    'Google\\Service\\Compute\\ExchangedPeeringRoutesListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ExchangedPeeringRoutesListWarningData.php',
    'Google\\Service\\Compute\\Expr' => $vendorDir . '/google/apiclient-services/src/Compute/Expr.php',
    'Google\\Service\\Compute\\ExternalVpnGateway' => $vendorDir . '/google/apiclient-services/src/Compute/ExternalVpnGateway.php',
    'Google\\Service\\Compute\\ExternalVpnGatewayInterface' => $vendorDir . '/google/apiclient-services/src/Compute/ExternalVpnGatewayInterface.php',
    'Google\\Service\\Compute\\ExternalVpnGatewayList' => $vendorDir . '/google/apiclient-services/src/Compute/ExternalVpnGatewayList.php',
    'Google\\Service\\Compute\\ExternalVpnGatewayListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ExternalVpnGatewayListWarning.php',
    'Google\\Service\\Compute\\ExternalVpnGatewayListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ExternalVpnGatewayListWarningData.php',
    'Google\\Service\\Compute\\FileContentBuffer' => $vendorDir . '/google/apiclient-services/src/Compute/FileContentBuffer.php',
    'Google\\Service\\Compute\\Firewall' => $vendorDir . '/google/apiclient-services/src/Compute/Firewall.php',
    'Google\\Service\\Compute\\FirewallAllowed' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallAllowed.php',
    'Google\\Service\\Compute\\FirewallDenied' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallDenied.php',
    'Google\\Service\\Compute\\FirewallList' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallList.php',
    'Google\\Service\\Compute\\FirewallListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallListWarning.php',
    'Google\\Service\\Compute\\FirewallListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallListWarningData.php',
    'Google\\Service\\Compute\\FirewallLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallLogConfig.php',
    'Google\\Service\\Compute\\FirewallPoliciesListAssociationsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPoliciesListAssociationsResponse.php',
    'Google\\Service\\Compute\\FirewallPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicy.php',
    'Google\\Service\\Compute\\FirewallPolicyAssociation' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyAssociation.php',
    'Google\\Service\\Compute\\FirewallPolicyList' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyList.php',
    'Google\\Service\\Compute\\FirewallPolicyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyListWarning.php',
    'Google\\Service\\Compute\\FirewallPolicyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyListWarningData.php',
    'Google\\Service\\Compute\\FirewallPolicyRule' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyRule.php',
    'Google\\Service\\Compute\\FirewallPolicyRuleMatcher' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyRuleMatcher.php',
    'Google\\Service\\Compute\\FirewallPolicyRuleMatcherLayer4Config' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyRuleMatcherLayer4Config.php',
    'Google\\Service\\Compute\\FirewallPolicyRuleSecureTag' => $vendorDir . '/google/apiclient-services/src/Compute/FirewallPolicyRuleSecureTag.php',
    'Google\\Service\\Compute\\FixedOrPercent' => $vendorDir . '/google/apiclient-services/src/Compute/FixedOrPercent.php',
    'Google\\Service\\Compute\\ForwardingRule' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRule.php',
    'Google\\Service\\Compute\\ForwardingRuleAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleAggregatedList.php',
    'Google\\Service\\Compute\\ForwardingRuleAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleAggregatedListWarning.php',
    'Google\\Service\\Compute\\ForwardingRuleAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleAggregatedListWarningData.php',
    'Google\\Service\\Compute\\ForwardingRuleList' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleList.php',
    'Google\\Service\\Compute\\ForwardingRuleListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleListWarning.php',
    'Google\\Service\\Compute\\ForwardingRuleListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleListWarningData.php',
    'Google\\Service\\Compute\\ForwardingRuleReference' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleReference.php',
    'Google\\Service\\Compute\\ForwardingRuleServiceDirectoryRegistration' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRuleServiceDirectoryRegistration.php',
    'Google\\Service\\Compute\\ForwardingRulesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRulesScopedList.php',
    'Google\\Service\\Compute\\ForwardingRulesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRulesScopedListWarning.php',
    'Google\\Service\\Compute\\ForwardingRulesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ForwardingRulesScopedListWarningData.php',
    'Google\\Service\\Compute\\FutureReservation' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservation.php',
    'Google\\Service\\Compute\\FutureReservationSpecificSKUProperties' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationSpecificSKUProperties.php',
    'Google\\Service\\Compute\\FutureReservationStatus' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationStatus.php',
    'Google\\Service\\Compute\\FutureReservationStatusExistingMatchingUsageInfo' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationStatusExistingMatchingUsageInfo.php',
    'Google\\Service\\Compute\\FutureReservationStatusLastKnownGoodState' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationStatusLastKnownGoodState.php',
    'Google\\Service\\Compute\\FutureReservationStatusLastKnownGoodStateFutureReservationSpecs' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.php',
    'Google\\Service\\Compute\\FutureReservationStatusSpecificSKUProperties' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationStatusSpecificSKUProperties.php',
    'Google\\Service\\Compute\\FutureReservationTimeWindow' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationTimeWindow.php',
    'Google\\Service\\Compute\\FutureReservationsAggregatedListResponse' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsAggregatedListResponse.php',
    'Google\\Service\\Compute\\FutureReservationsAggregatedListResponseWarning' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsAggregatedListResponseWarning.php',
    'Google\\Service\\Compute\\FutureReservationsAggregatedListResponseWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsAggregatedListResponseWarningData.php',
    'Google\\Service\\Compute\\FutureReservationsListResponse' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsListResponse.php',
    'Google\\Service\\Compute\\FutureReservationsListResponseWarning' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsListResponseWarning.php',
    'Google\\Service\\Compute\\FutureReservationsListResponseWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsListResponseWarningData.php',
    'Google\\Service\\Compute\\FutureReservationsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsScopedList.php',
    'Google\\Service\\Compute\\FutureReservationsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsScopedListWarning.php',
    'Google\\Service\\Compute\\FutureReservationsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/FutureReservationsScopedListWarningData.php',
    'Google\\Service\\Compute\\GRPCHealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/GRPCHealthCheck.php',
    'Google\\Service\\Compute\\GlobalAddressesMoveRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalAddressesMoveRequest.php',
    'Google\\Service\\Compute\\GlobalNetworkEndpointGroupsAttachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalNetworkEndpointGroupsAttachEndpointsRequest.php',
    'Google\\Service\\Compute\\GlobalNetworkEndpointGroupsDetachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalNetworkEndpointGroupsDetachEndpointsRequest.php',
    'Google\\Service\\Compute\\GlobalOrganizationSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalOrganizationSetPolicyRequest.php',
    'Google\\Service\\Compute\\GlobalSetLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalSetLabelsRequest.php',
    'Google\\Service\\Compute\\GlobalSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/GlobalSetPolicyRequest.php',
    'Google\\Service\\Compute\\GuestAttributes' => $vendorDir . '/google/apiclient-services/src/Compute/GuestAttributes.php',
    'Google\\Service\\Compute\\GuestAttributesEntry' => $vendorDir . '/google/apiclient-services/src/Compute/GuestAttributesEntry.php',
    'Google\\Service\\Compute\\GuestAttributesValue' => $vendorDir . '/google/apiclient-services/src/Compute/GuestAttributesValue.php',
    'Google\\Service\\Compute\\GuestOsFeature' => $vendorDir . '/google/apiclient-services/src/Compute/GuestOsFeature.php',
    'Google\\Service\\Compute\\HTTP2HealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/HTTP2HealthCheck.php',
    'Google\\Service\\Compute\\HealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheck.php',
    'Google\\Service\\Compute\\HealthCheckList' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckList.php',
    'Google\\Service\\Compute\\HealthCheckListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckListWarning.php',
    'Google\\Service\\Compute\\HealthCheckListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckListWarningData.php',
    'Google\\Service\\Compute\\HealthCheckLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckLogConfig.php',
    'Google\\Service\\Compute\\HealthCheckReference' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckReference.php',
    'Google\\Service\\Compute\\HealthCheckService' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckService.php',
    'Google\\Service\\Compute\\HealthCheckServiceReference' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckServiceReference.php',
    'Google\\Service\\Compute\\HealthCheckServicesList' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckServicesList.php',
    'Google\\Service\\Compute\\HealthCheckServicesListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckServicesListWarning.php',
    'Google\\Service\\Compute\\HealthCheckServicesListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HealthCheckServicesListWarningData.php',
    'Google\\Service\\Compute\\HealthChecksAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksAggregatedList.php',
    'Google\\Service\\Compute\\HealthChecksAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksAggregatedListWarning.php',
    'Google\\Service\\Compute\\HealthChecksAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksAggregatedListWarningData.php',
    'Google\\Service\\Compute\\HealthChecksScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksScopedList.php',
    'Google\\Service\\Compute\\HealthChecksScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksScopedListWarning.php',
    'Google\\Service\\Compute\\HealthChecksScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HealthChecksScopedListWarningData.php',
    'Google\\Service\\Compute\\HealthStatus' => $vendorDir . '/google/apiclient-services/src/Compute/HealthStatus.php',
    'Google\\Service\\Compute\\HealthStatusForNetworkEndpoint' => $vendorDir . '/google/apiclient-services/src/Compute/HealthStatusForNetworkEndpoint.php',
    'Google\\Service\\Compute\\Help' => $vendorDir . '/google/apiclient-services/src/Compute/Help.php',
    'Google\\Service\\Compute\\HelpLink' => $vendorDir . '/google/apiclient-services/src/Compute/HelpLink.php',
    'Google\\Service\\Compute\\HostRule' => $vendorDir . '/google/apiclient-services/src/Compute/HostRule.php',
    'Google\\Service\\Compute\\HttpFaultAbort' => $vendorDir . '/google/apiclient-services/src/Compute/HttpFaultAbort.php',
    'Google\\Service\\Compute\\HttpFaultDelay' => $vendorDir . '/google/apiclient-services/src/Compute/HttpFaultDelay.php',
    'Google\\Service\\Compute\\HttpFaultInjection' => $vendorDir . '/google/apiclient-services/src/Compute/HttpFaultInjection.php',
    'Google\\Service\\Compute\\HttpHeaderAction' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHeaderAction.php',
    'Google\\Service\\Compute\\HttpHeaderMatch' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHeaderMatch.php',
    'Google\\Service\\Compute\\HttpHeaderOption' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHeaderOption.php',
    'Google\\Service\\Compute\\HttpHealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHealthCheck.php',
    'Google\\Service\\Compute\\HttpHealthCheckList' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHealthCheckList.php',
    'Google\\Service\\Compute\\HttpHealthCheckListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHealthCheckListWarning.php',
    'Google\\Service\\Compute\\HttpHealthCheckListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HttpHealthCheckListWarningData.php',
    'Google\\Service\\Compute\\HttpQueryParameterMatch' => $vendorDir . '/google/apiclient-services/src/Compute/HttpQueryParameterMatch.php',
    'Google\\Service\\Compute\\HttpRedirectAction' => $vendorDir . '/google/apiclient-services/src/Compute/HttpRedirectAction.php',
    'Google\\Service\\Compute\\HttpRetryPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/HttpRetryPolicy.php',
    'Google\\Service\\Compute\\HttpRouteAction' => $vendorDir . '/google/apiclient-services/src/Compute/HttpRouteAction.php',
    'Google\\Service\\Compute\\HttpRouteRule' => $vendorDir . '/google/apiclient-services/src/Compute/HttpRouteRule.php',
    'Google\\Service\\Compute\\HttpRouteRuleMatch' => $vendorDir . '/google/apiclient-services/src/Compute/HttpRouteRuleMatch.php',
    'Google\\Service\\Compute\\HttpsHealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/HttpsHealthCheck.php',
    'Google\\Service\\Compute\\HttpsHealthCheckList' => $vendorDir . '/google/apiclient-services/src/Compute/HttpsHealthCheckList.php',
    'Google\\Service\\Compute\\HttpsHealthCheckListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/HttpsHealthCheckListWarning.php',
    'Google\\Service\\Compute\\HttpsHealthCheckListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/HttpsHealthCheckListWarningData.php',
    'Google\\Service\\Compute\\Image' => $vendorDir . '/google/apiclient-services/src/Compute/Image.php',
    'Google\\Service\\Compute\\ImageFamilyView' => $vendorDir . '/google/apiclient-services/src/Compute/ImageFamilyView.php',
    'Google\\Service\\Compute\\ImageList' => $vendorDir . '/google/apiclient-services/src/Compute/ImageList.php',
    'Google\\Service\\Compute\\ImageListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ImageListWarning.php',
    'Google\\Service\\Compute\\ImageListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ImageListWarningData.php',
    'Google\\Service\\Compute\\ImageRawDisk' => $vendorDir . '/google/apiclient-services/src/Compute/ImageRawDisk.php',
    'Google\\Service\\Compute\\InitialStateConfig' => $vendorDir . '/google/apiclient-services/src/Compute/InitialStateConfig.php',
    'Google\\Service\\Compute\\Instance' => $vendorDir . '/google/apiclient-services/src/Compute/Instance.php',
    'Google\\Service\\Compute\\InstanceAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceAggregatedList.php',
    'Google\\Service\\Compute\\InstanceAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceAggregatedListWarning.php',
    'Google\\Service\\Compute\\InstanceAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InstanceConsumptionData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceConsumptionData.php',
    'Google\\Service\\Compute\\InstanceConsumptionInfo' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceConsumptionInfo.php',
    'Google\\Service\\Compute\\InstanceGroup' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroup.php',
    'Google\\Service\\Compute\\InstanceGroupAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupAggregatedList.php',
    'Google\\Service\\Compute\\InstanceGroupAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupAggregatedListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupList.php',
    'Google\\Service\\Compute\\InstanceGroupListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManager' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManager.php',
    'Google\\Service\\Compute\\InstanceGroupManagerActionsSummary' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerActionsSummary.php',
    'Google\\Service\\Compute\\InstanceGroupManagerAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerAggregatedList.php',
    'Google\\Service\\Compute\\InstanceGroupManagerAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerAggregatedListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupManagerAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManagerAllInstancesConfig' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerAllInstancesConfig.php',
    'Google\\Service\\Compute\\InstanceGroupManagerAutoHealingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerAutoHealingPolicy.php',
    'Google\\Service\\Compute\\InstanceGroupManagerInstanceLifecyclePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerInstanceLifecyclePolicy.php',
    'Google\\Service\\Compute\\InstanceGroupManagerList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerList.php',
    'Google\\Service\\Compute\\InstanceGroupManagerListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupManagerListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatus.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusError' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusError.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusErrorErrors' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusErrorErrors.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusErrorErrorsErrorDetails' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusErrorErrorsErrorDetails.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusLastAttempt' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusLastAttempt.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusLastAttemptError' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusLastAttemptError.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusLastAttemptErrorErrors' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusLastAttemptErrorErrors.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestStatusLastAttemptErrorErrorsErrorDetails' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestStatusLastAttemptErrorErrorsErrorDetails.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestsListResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestsListResponse.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestsListResponseWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestsListResponseWarning.php',
    'Google\\Service\\Compute\\InstanceGroupManagerResizeRequestsListResponseWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerResizeRequestsListResponseWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManagerStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerStatus.php',
    'Google\\Service\\Compute\\InstanceGroupManagerStatusAllInstancesConfig' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerStatusAllInstancesConfig.php',
    'Google\\Service\\Compute\\InstanceGroupManagerStatusStateful' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerStatusStateful.php',
    'Google\\Service\\Compute\\InstanceGroupManagerStatusStatefulPerInstanceConfigs' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerStatusStatefulPerInstanceConfigs.php',
    'Google\\Service\\Compute\\InstanceGroupManagerStatusVersionTarget' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerStatusVersionTarget.php',
    'Google\\Service\\Compute\\InstanceGroupManagerUpdatePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerUpdatePolicy.php',
    'Google\\Service\\Compute\\InstanceGroupManagerVersion' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagerVersion.php',
    'Google\\Service\\Compute\\InstanceGroupManagersAbandonInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersAbandonInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersApplyUpdatesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersApplyUpdatesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersCreateInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersCreateInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersDeleteInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersDeleteInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersDeletePerInstanceConfigsReq' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersDeletePerInstanceConfigsReq.php',
    'Google\\Service\\Compute\\InstanceGroupManagersListErrorsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersListErrorsResponse.php',
    'Google\\Service\\Compute\\InstanceGroupManagersListManagedInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersListManagedInstancesResponse.php',
    'Google\\Service\\Compute\\InstanceGroupManagersListPerInstanceConfigsResp' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersListPerInstanceConfigsResp.php',
    'Google\\Service\\Compute\\InstanceGroupManagersListPerInstanceConfigsRespWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersListPerInstanceConfigsRespWarning.php',
    'Google\\Service\\Compute\\InstanceGroupManagersListPerInstanceConfigsRespWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersListPerInstanceConfigsRespWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManagersPatchPerInstanceConfigsReq' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersPatchPerInstanceConfigsReq.php',
    'Google\\Service\\Compute\\InstanceGroupManagersRecreateInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersRecreateInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersScopedList.php',
    'Google\\Service\\Compute\\InstanceGroupManagersScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersScopedListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupManagersScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersScopedListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupManagersSetInstanceTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersSetInstanceTemplateRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersSetTargetPoolsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersSetTargetPoolsRequest.php',
    'Google\\Service\\Compute\\InstanceGroupManagersUpdatePerInstanceConfigsReq' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupManagersUpdatePerInstanceConfigsReq.php',
    'Google\\Service\\Compute\\InstanceGroupsAddInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsAddInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupsListInstances' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsListInstances.php',
    'Google\\Service\\Compute\\InstanceGroupsListInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsListInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupsListInstancesWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsListInstancesWarning.php',
    'Google\\Service\\Compute\\InstanceGroupsListInstancesWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsListInstancesWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupsRemoveInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsRemoveInstancesRequest.php',
    'Google\\Service\\Compute\\InstanceGroupsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsScopedList.php',
    'Google\\Service\\Compute\\InstanceGroupsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsScopedListWarning.php',
    'Google\\Service\\Compute\\InstanceGroupsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsScopedListWarningData.php',
    'Google\\Service\\Compute\\InstanceGroupsSetNamedPortsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceGroupsSetNamedPortsRequest.php',
    'Google\\Service\\Compute\\InstanceList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceList.php',
    'Google\\Service\\Compute\\InstanceListReferrers' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceListReferrers.php',
    'Google\\Service\\Compute\\InstanceListReferrersWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceListReferrersWarning.php',
    'Google\\Service\\Compute\\InstanceListReferrersWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceListReferrersWarningData.php',
    'Google\\Service\\Compute\\InstanceListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceListWarning.php',
    'Google\\Service\\Compute\\InstanceListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceListWarningData.php',
    'Google\\Service\\Compute\\InstanceManagedByIgmError' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceManagedByIgmError.php',
    'Google\\Service\\Compute\\InstanceManagedByIgmErrorInstanceActionDetails' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceManagedByIgmErrorInstanceActionDetails.php',
    'Google\\Service\\Compute\\InstanceManagedByIgmErrorManagedInstanceError' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceManagedByIgmErrorManagedInstanceError.php',
    'Google\\Service\\Compute\\InstanceMoveRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceMoveRequest.php',
    'Google\\Service\\Compute\\InstanceParams' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceParams.php',
    'Google\\Service\\Compute\\InstanceProperties' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceProperties.php',
    'Google\\Service\\Compute\\InstancePropertiesPatch' => $vendorDir . '/google/apiclient-services/src/Compute/InstancePropertiesPatch.php',
    'Google\\Service\\Compute\\InstanceReference' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceReference.php',
    'Google\\Service\\Compute\\InstanceSettings' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceSettings.php',
    'Google\\Service\\Compute\\InstanceSettingsMetadata' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceSettingsMetadata.php',
    'Google\\Service\\Compute\\InstanceTemplate' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplate.php',
    'Google\\Service\\Compute\\InstanceTemplateAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateAggregatedList.php',
    'Google\\Service\\Compute\\InstanceTemplateAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateAggregatedListWarning.php',
    'Google\\Service\\Compute\\InstanceTemplateAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InstanceTemplateList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateList.php',
    'Google\\Service\\Compute\\InstanceTemplateListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateListWarning.php',
    'Google\\Service\\Compute\\InstanceTemplateListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplateListWarningData.php',
    'Google\\Service\\Compute\\InstanceTemplatesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplatesScopedList.php',
    'Google\\Service\\Compute\\InstanceTemplatesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplatesScopedListWarning.php',
    'Google\\Service\\Compute\\InstanceTemplatesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceTemplatesScopedListWarningData.php',
    'Google\\Service\\Compute\\InstanceWithNamedPorts' => $vendorDir . '/google/apiclient-services/src/Compute/InstanceWithNamedPorts.php',
    'Google\\Service\\Compute\\InstancesAddResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesAddResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\InstancesBulkInsertOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesBulkInsertOperationMetadata.php',
    'Google\\Service\\Compute\\InstancesGetEffectiveFirewallsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesGetEffectiveFirewallsResponse.php',
    'Google\\Service\\Compute\\InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.php',
    'Google\\Service\\Compute\\InstancesRemoveResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesRemoveResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\InstancesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesScopedList.php',
    'Google\\Service\\Compute\\InstancesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesScopedListWarning.php',
    'Google\\Service\\Compute\\InstancesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesScopedListWarningData.php',
    'Google\\Service\\Compute\\InstancesSetLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetLabelsRequest.php',
    'Google\\Service\\Compute\\InstancesSetMachineResourcesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetMachineResourcesRequest.php',
    'Google\\Service\\Compute\\InstancesSetMachineTypeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetMachineTypeRequest.php',
    'Google\\Service\\Compute\\InstancesSetMinCpuPlatformRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetMinCpuPlatformRequest.php',
    'Google\\Service\\Compute\\InstancesSetNameRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetNameRequest.php',
    'Google\\Service\\Compute\\InstancesSetSecurityPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetSecurityPolicyRequest.php',
    'Google\\Service\\Compute\\InstancesSetServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesSetServiceAccountRequest.php',
    'Google\\Service\\Compute\\InstancesStartWithEncryptionKeyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/InstancesStartWithEncryptionKeyRequest.php',
    'Google\\Service\\Compute\\InstantSnapshot' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshot.php',
    'Google\\Service\\Compute\\InstantSnapshotAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotAggregatedList.php',
    'Google\\Service\\Compute\\InstantSnapshotAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotAggregatedListWarning.php',
    'Google\\Service\\Compute\\InstantSnapshotAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InstantSnapshotList' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotList.php',
    'Google\\Service\\Compute\\InstantSnapshotListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotListWarning.php',
    'Google\\Service\\Compute\\InstantSnapshotListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotListWarningData.php',
    'Google\\Service\\Compute\\InstantSnapshotResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotResourceStatus.php',
    'Google\\Service\\Compute\\InstantSnapshotsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotsScopedList.php',
    'Google\\Service\\Compute\\InstantSnapshotsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotsScopedListWarning.php',
    'Google\\Service\\Compute\\InstantSnapshotsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InstantSnapshotsScopedListWarningData.php',
    'Google\\Service\\Compute\\Int64RangeMatch' => $vendorDir . '/google/apiclient-services/src/Compute/Int64RangeMatch.php',
    'Google\\Service\\Compute\\Interconnect' => $vendorDir . '/google/apiclient-services/src/Compute/Interconnect.php',
    'Google\\Service\\Compute\\InterconnectAttachment' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachment.php',
    'Google\\Service\\Compute\\InterconnectAttachmentAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentAggregatedList.php',
    'Google\\Service\\Compute\\InterconnectAttachmentAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentAggregatedListWarning.php',
    'Google\\Service\\Compute\\InterconnectAttachmentAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentAggregatedListWarningData.php',
    'Google\\Service\\Compute\\InterconnectAttachmentConfigurationConstraints' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentConfigurationConstraints.php',
    'Google\\Service\\Compute\\InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange.php',
    'Google\\Service\\Compute\\InterconnectAttachmentList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentList.php',
    'Google\\Service\\Compute\\InterconnectAttachmentListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentListWarning.php',
    'Google\\Service\\Compute\\InterconnectAttachmentListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentListWarningData.php',
    'Google\\Service\\Compute\\InterconnectAttachmentPartnerMetadata' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentPartnerMetadata.php',
    'Google\\Service\\Compute\\InterconnectAttachmentPrivateInfo' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentPrivateInfo.php',
    'Google\\Service\\Compute\\InterconnectAttachmentsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentsScopedList.php',
    'Google\\Service\\Compute\\InterconnectAttachmentsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentsScopedListWarning.php',
    'Google\\Service\\Compute\\InterconnectAttachmentsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectAttachmentsScopedListWarningData.php',
    'Google\\Service\\Compute\\InterconnectCircuitInfo' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectCircuitInfo.php',
    'Google\\Service\\Compute\\InterconnectDiagnostics' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnostics.php',
    'Google\\Service\\Compute\\InterconnectDiagnosticsARPEntry' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnosticsARPEntry.php',
    'Google\\Service\\Compute\\InterconnectDiagnosticsLinkLACPStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnosticsLinkLACPStatus.php',
    'Google\\Service\\Compute\\InterconnectDiagnosticsLinkOpticalPower' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnosticsLinkOpticalPower.php',
    'Google\\Service\\Compute\\InterconnectDiagnosticsLinkStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnosticsLinkStatus.php',
    'Google\\Service\\Compute\\InterconnectDiagnosticsMacsecStatus' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectDiagnosticsMacsecStatus.php',
    'Google\\Service\\Compute\\InterconnectList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectList.php',
    'Google\\Service\\Compute\\InterconnectListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectListWarning.php',
    'Google\\Service\\Compute\\InterconnectListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectListWarningData.php',
    'Google\\Service\\Compute\\InterconnectLocation' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectLocation.php',
    'Google\\Service\\Compute\\InterconnectLocationList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectLocationList.php',
    'Google\\Service\\Compute\\InterconnectLocationListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectLocationListWarning.php',
    'Google\\Service\\Compute\\InterconnectLocationListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectLocationListWarningData.php',
    'Google\\Service\\Compute\\InterconnectLocationRegionInfo' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectLocationRegionInfo.php',
    'Google\\Service\\Compute\\InterconnectMacsec' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectMacsec.php',
    'Google\\Service\\Compute\\InterconnectMacsecConfig' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectMacsecConfig.php',
    'Google\\Service\\Compute\\InterconnectMacsecConfigPreSharedKey' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectMacsecConfigPreSharedKey.php',
    'Google\\Service\\Compute\\InterconnectMacsecPreSharedKey' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectMacsecPreSharedKey.php',
    'Google\\Service\\Compute\\InterconnectOutageNotification' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectOutageNotification.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocation' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocation.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationConstraints' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationConstraints.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationConstraintsSubnetLengthRange' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationConstraintsSubnetLengthRange.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationList' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationList.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationListWarning.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationListWarningData.php',
    'Google\\Service\\Compute\\InterconnectRemoteLocationPermittedConnections' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectRemoteLocationPermittedConnections.php',
    'Google\\Service\\Compute\\InterconnectsGetDiagnosticsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectsGetDiagnosticsResponse.php',
    'Google\\Service\\Compute\\InterconnectsGetMacsecConfigResponse' => $vendorDir . '/google/apiclient-services/src/Compute/InterconnectsGetMacsecConfigResponse.php',
    'Google\\Service\\Compute\\License' => $vendorDir . '/google/apiclient-services/src/Compute/License.php',
    'Google\\Service\\Compute\\LicenseCode' => $vendorDir . '/google/apiclient-services/src/Compute/LicenseCode.php',
    'Google\\Service\\Compute\\LicenseCodeLicenseAlias' => $vendorDir . '/google/apiclient-services/src/Compute/LicenseCodeLicenseAlias.php',
    'Google\\Service\\Compute\\LicenseResourceCommitment' => $vendorDir . '/google/apiclient-services/src/Compute/LicenseResourceCommitment.php',
    'Google\\Service\\Compute\\LicenseResourceRequirements' => $vendorDir . '/google/apiclient-services/src/Compute/LicenseResourceRequirements.php',
    'Google\\Service\\Compute\\LicensesListResponse' => $vendorDir . '/google/apiclient-services/src/Compute/LicensesListResponse.php',
    'Google\\Service\\Compute\\LicensesListResponseWarning' => $vendorDir . '/google/apiclient-services/src/Compute/LicensesListResponseWarning.php',
    'Google\\Service\\Compute\\LicensesListResponseWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/LicensesListResponseWarningData.php',
    'Google\\Service\\Compute\\LocalDisk' => $vendorDir . '/google/apiclient-services/src/Compute/LocalDisk.php',
    'Google\\Service\\Compute\\LocalizedMessage' => $vendorDir . '/google/apiclient-services/src/Compute/LocalizedMessage.php',
    'Google\\Service\\Compute\\LocationPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/LocationPolicy.php',
    'Google\\Service\\Compute\\LocationPolicyLocation' => $vendorDir . '/google/apiclient-services/src/Compute/LocationPolicyLocation.php',
    'Google\\Service\\Compute\\LocationPolicyLocationConstraints' => $vendorDir . '/google/apiclient-services/src/Compute/LocationPolicyLocationConstraints.php',
    'Google\\Service\\Compute\\LogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/LogConfig.php',
    'Google\\Service\\Compute\\LogConfigCloudAuditOptions' => $vendorDir . '/google/apiclient-services/src/Compute/LogConfigCloudAuditOptions.php',
    'Google\\Service\\Compute\\LogConfigCounterOptions' => $vendorDir . '/google/apiclient-services/src/Compute/LogConfigCounterOptions.php',
    'Google\\Service\\Compute\\LogConfigCounterOptionsCustomField' => $vendorDir . '/google/apiclient-services/src/Compute/LogConfigCounterOptionsCustomField.php',
    'Google\\Service\\Compute\\LogConfigDataAccessOptions' => $vendorDir . '/google/apiclient-services/src/Compute/LogConfigDataAccessOptions.php',
    'Google\\Service\\Compute\\MachineImage' => $vendorDir . '/google/apiclient-services/src/Compute/MachineImage.php',
    'Google\\Service\\Compute\\MachineImageList' => $vendorDir . '/google/apiclient-services/src/Compute/MachineImageList.php',
    'Google\\Service\\Compute\\MachineImageListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/MachineImageListWarning.php',
    'Google\\Service\\Compute\\MachineImageListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/MachineImageListWarningData.php',
    'Google\\Service\\Compute\\MachineType' => $vendorDir . '/google/apiclient-services/src/Compute/MachineType.php',
    'Google\\Service\\Compute\\MachineTypeAccelerators' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeAccelerators.php',
    'Google\\Service\\Compute\\MachineTypeAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeAggregatedList.php',
    'Google\\Service\\Compute\\MachineTypeAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeAggregatedListWarning.php',
    'Google\\Service\\Compute\\MachineTypeAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeAggregatedListWarningData.php',
    'Google\\Service\\Compute\\MachineTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeList.php',
    'Google\\Service\\Compute\\MachineTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeListWarning.php',
    'Google\\Service\\Compute\\MachineTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeListWarningData.php',
    'Google\\Service\\Compute\\MachineTypeScratchDisks' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypeScratchDisks.php',
    'Google\\Service\\Compute\\MachineTypesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypesScopedList.php',
    'Google\\Service\\Compute\\MachineTypesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypesScopedListWarning.php',
    'Google\\Service\\Compute\\MachineTypesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/MachineTypesScopedListWarningData.php',
    'Google\\Service\\Compute\\ManagedInstance' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstance.php',
    'Google\\Service\\Compute\\ManagedInstanceInstanceHealth' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceInstanceHealth.php',
    'Google\\Service\\Compute\\ManagedInstanceLastAttempt' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceLastAttempt.php',
    'Google\\Service\\Compute\\ManagedInstanceLastAttemptErrors' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceLastAttemptErrors.php',
    'Google\\Service\\Compute\\ManagedInstanceLastAttemptErrorsErrors' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceLastAttemptErrorsErrors.php',
    'Google\\Service\\Compute\\ManagedInstanceLastAttemptErrorsErrorsErrorDetails' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceLastAttemptErrorsErrorsErrorDetails.php',
    'Google\\Service\\Compute\\ManagedInstanceVersion' => $vendorDir . '/google/apiclient-services/src/Compute/ManagedInstanceVersion.php',
    'Google\\Service\\Compute\\Metadata' => $vendorDir . '/google/apiclient-services/src/Compute/Metadata.php',
    'Google\\Service\\Compute\\MetadataFilter' => $vendorDir . '/google/apiclient-services/src/Compute/MetadataFilter.php',
    'Google\\Service\\Compute\\MetadataFilterLabelMatch' => $vendorDir . '/google/apiclient-services/src/Compute/MetadataFilterLabelMatch.php',
    'Google\\Service\\Compute\\MetadataItems' => $vendorDir . '/google/apiclient-services/src/Compute/MetadataItems.php',
    'Google\\Service\\Compute\\NamedPort' => $vendorDir . '/google/apiclient-services/src/Compute/NamedPort.php',
    'Google\\Service\\Compute\\NatIpInfo' => $vendorDir . '/google/apiclient-services/src/Compute/NatIpInfo.php',
    'Google\\Service\\Compute\\NatIpInfoNatIpInfoMapping' => $vendorDir . '/google/apiclient-services/src/Compute/NatIpInfoNatIpInfoMapping.php',
    'Google\\Service\\Compute\\NatIpInfoResponse' => $vendorDir . '/google/apiclient-services/src/Compute/NatIpInfoResponse.php',
    'Google\\Service\\Compute\\Network' => $vendorDir . '/google/apiclient-services/src/Compute/Network.php',
    'Google\\Service\\Compute\\NetworkAttachment' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachment.php',
    'Google\\Service\\Compute\\NetworkAttachmentAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentAggregatedList.php',
    'Google\\Service\\Compute\\NetworkAttachmentAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentAggregatedListWarning.php',
    'Google\\Service\\Compute\\NetworkAttachmentAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NetworkAttachmentConnectedEndpoint' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentConnectedEndpoint.php',
    'Google\\Service\\Compute\\NetworkAttachmentList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentList.php',
    'Google\\Service\\Compute\\NetworkAttachmentListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentListWarning.php',
    'Google\\Service\\Compute\\NetworkAttachmentListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentListWarningData.php',
    'Google\\Service\\Compute\\NetworkAttachmentsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentsScopedList.php',
    'Google\\Service\\Compute\\NetworkAttachmentsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentsScopedListWarning.php',
    'Google\\Service\\Compute\\NetworkAttachmentsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkAttachmentsScopedListWarningData.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityService' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityService.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServiceAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServiceAggregatedList.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServiceAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServiceAggregatedListWarning.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServiceAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServiceAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServicesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServicesScopedList.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServicesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServicesScopedListWarning.php',
    'Google\\Service\\Compute\\NetworkEdgeSecurityServicesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEdgeSecurityServicesScopedListWarningData.php',
    'Google\\Service\\Compute\\NetworkEndpoint' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpoint.php',
    'Google\\Service\\Compute\\NetworkEndpointGroup' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroup.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupAggregatedList.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupAggregatedListWarning.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupAppEngine' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupAppEngine.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupCloudFunction' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupCloudFunction.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupCloudRun' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupCloudRun.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupList.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupListWarning.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupListWarningData.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupPscData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupPscData.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsAttachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsAttachEndpointsRequest.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsDetachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsDetachEndpointsRequest.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsListEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsListEndpointsRequest.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsListNetworkEndpoints' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsListNetworkEndpoints.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsListNetworkEndpointsWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsListNetworkEndpointsWarning.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsListNetworkEndpointsWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsListNetworkEndpointsWarningData.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsScopedList.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsScopedListWarning.php',
    'Google\\Service\\Compute\\NetworkEndpointGroupsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointGroupsScopedListWarningData.php',
    'Google\\Service\\Compute\\NetworkEndpointWithHealthStatus' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkEndpointWithHealthStatus.php',
    'Google\\Service\\Compute\\NetworkInterface' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkInterface.php',
    'Google\\Service\\Compute\\NetworkList' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkList.php',
    'Google\\Service\\Compute\\NetworkListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkListWarning.php',
    'Google\\Service\\Compute\\NetworkListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkListWarningData.php',
    'Google\\Service\\Compute\\NetworkPeering' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkPeering.php',
    'Google\\Service\\Compute\\NetworkPerformanceConfig' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkPerformanceConfig.php',
    'Google\\Service\\Compute\\NetworkRoutingConfig' => $vendorDir . '/google/apiclient-services/src/Compute/NetworkRoutingConfig.php',
    'Google\\Service\\Compute\\NetworksAddPeeringRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworksAddPeeringRequest.php',
    'Google\\Service\\Compute\\NetworksGetEffectiveFirewallsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/NetworksGetEffectiveFirewallsResponse.php',
    'Google\\Service\\Compute\\NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.php',
    'Google\\Service\\Compute\\NetworksRemovePeeringRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworksRemovePeeringRequest.php',
    'Google\\Service\\Compute\\NetworksUpdatePeeringRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NetworksUpdatePeeringRequest.php',
    'Google\\Service\\Compute\\NodeGroup' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroup.php',
    'Google\\Service\\Compute\\NodeGroupAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupAggregatedList.php',
    'Google\\Service\\Compute\\NodeGroupAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupAggregatedListWarning.php',
    'Google\\Service\\Compute\\NodeGroupAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NodeGroupAutoscalingPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupAutoscalingPolicy.php',
    'Google\\Service\\Compute\\NodeGroupList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupList.php',
    'Google\\Service\\Compute\\NodeGroupListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupListWarning.php',
    'Google\\Service\\Compute\\NodeGroupListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupListWarningData.php',
    'Google\\Service\\Compute\\NodeGroupMaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupMaintenanceWindow.php',
    'Google\\Service\\Compute\\NodeGroupNode' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupNode.php',
    'Google\\Service\\Compute\\NodeGroupsAddNodesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsAddNodesRequest.php',
    'Google\\Service\\Compute\\NodeGroupsDeleteNodesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsDeleteNodesRequest.php',
    'Google\\Service\\Compute\\NodeGroupsListNodes' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsListNodes.php',
    'Google\\Service\\Compute\\NodeGroupsListNodesWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsListNodesWarning.php',
    'Google\\Service\\Compute\\NodeGroupsListNodesWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsListNodesWarningData.php',
    'Google\\Service\\Compute\\NodeGroupsPerformMaintenanceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsPerformMaintenanceRequest.php',
    'Google\\Service\\Compute\\NodeGroupsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsScopedList.php',
    'Google\\Service\\Compute\\NodeGroupsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsScopedListWarning.php',
    'Google\\Service\\Compute\\NodeGroupsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsScopedListWarningData.php',
    'Google\\Service\\Compute\\NodeGroupsSetNodeTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsSetNodeTemplateRequest.php',
    'Google\\Service\\Compute\\NodeGroupsSimulateMaintenanceEventRequest' => $vendorDir . '/google/apiclient-services/src/Compute/NodeGroupsSimulateMaintenanceEventRequest.php',
    'Google\\Service\\Compute\\NodeTemplate' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplate.php',
    'Google\\Service\\Compute\\NodeTemplateAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateAggregatedList.php',
    'Google\\Service\\Compute\\NodeTemplateAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateAggregatedListWarning.php',
    'Google\\Service\\Compute\\NodeTemplateAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NodeTemplateList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateList.php',
    'Google\\Service\\Compute\\NodeTemplateListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateListWarning.php',
    'Google\\Service\\Compute\\NodeTemplateListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateListWarningData.php',
    'Google\\Service\\Compute\\NodeTemplateNodeTypeFlexibility' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplateNodeTypeFlexibility.php',
    'Google\\Service\\Compute\\NodeTemplatesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplatesScopedList.php',
    'Google\\Service\\Compute\\NodeTemplatesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplatesScopedListWarning.php',
    'Google\\Service\\Compute\\NodeTemplatesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTemplatesScopedListWarningData.php',
    'Google\\Service\\Compute\\NodeType' => $vendorDir . '/google/apiclient-services/src/Compute/NodeType.php',
    'Google\\Service\\Compute\\NodeTypeAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeAggregatedList.php',
    'Google\\Service\\Compute\\NodeTypeAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeAggregatedListWarning.php',
    'Google\\Service\\Compute\\NodeTypeAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeAggregatedListWarningData.php',
    'Google\\Service\\Compute\\NodeTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeList.php',
    'Google\\Service\\Compute\\NodeTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeListWarning.php',
    'Google\\Service\\Compute\\NodeTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypeListWarningData.php',
    'Google\\Service\\Compute\\NodeTypesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypesScopedList.php',
    'Google\\Service\\Compute\\NodeTypesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypesScopedListWarning.php',
    'Google\\Service\\Compute\\NodeTypesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NodeTypesScopedListWarningData.php',
    'Google\\Service\\Compute\\NotificationEndpoint' => $vendorDir . '/google/apiclient-services/src/Compute/NotificationEndpoint.php',
    'Google\\Service\\Compute\\NotificationEndpointGrpcSettings' => $vendorDir . '/google/apiclient-services/src/Compute/NotificationEndpointGrpcSettings.php',
    'Google\\Service\\Compute\\NotificationEndpointList' => $vendorDir . '/google/apiclient-services/src/Compute/NotificationEndpointList.php',
    'Google\\Service\\Compute\\NotificationEndpointListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/NotificationEndpointListWarning.php',
    'Google\\Service\\Compute\\NotificationEndpointListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/NotificationEndpointListWarningData.php',
    'Google\\Service\\Compute\\Operation' => $vendorDir . '/google/apiclient-services/src/Compute/Operation.php',
    'Google\\Service\\Compute\\OperationAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/OperationAggregatedList.php',
    'Google\\Service\\Compute\\OperationAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/OperationAggregatedListWarning.php',
    'Google\\Service\\Compute\\OperationAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/OperationAggregatedListWarningData.php',
    'Google\\Service\\Compute\\OperationError' => $vendorDir . '/google/apiclient-services/src/Compute/OperationError.php',
    'Google\\Service\\Compute\\OperationErrorErrors' => $vendorDir . '/google/apiclient-services/src/Compute/OperationErrorErrors.php',
    'Google\\Service\\Compute\\OperationErrorErrorsErrorDetails' => $vendorDir . '/google/apiclient-services/src/Compute/OperationErrorErrorsErrorDetails.php',
    'Google\\Service\\Compute\\OperationList' => $vendorDir . '/google/apiclient-services/src/Compute/OperationList.php',
    'Google\\Service\\Compute\\OperationListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/OperationListWarning.php',
    'Google\\Service\\Compute\\OperationListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/OperationListWarningData.php',
    'Google\\Service\\Compute\\OperationWarnings' => $vendorDir . '/google/apiclient-services/src/Compute/OperationWarnings.php',
    'Google\\Service\\Compute\\OperationWarningsData' => $vendorDir . '/google/apiclient-services/src/Compute/OperationWarningsData.php',
    'Google\\Service\\Compute\\OperationsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/OperationsScopedList.php',
    'Google\\Service\\Compute\\OperationsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/OperationsScopedListWarning.php',
    'Google\\Service\\Compute\\OperationsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/OperationsScopedListWarningData.php',
    'Google\\Service\\Compute\\OutlierDetection' => $vendorDir . '/google/apiclient-services/src/Compute/OutlierDetection.php',
    'Google\\Service\\Compute\\PacketIntervals' => $vendorDir . '/google/apiclient-services/src/Compute/PacketIntervals.php',
    'Google\\Service\\Compute\\PacketMirroring' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroring.php',
    'Google\\Service\\Compute\\PacketMirroringAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringAggregatedList.php',
    'Google\\Service\\Compute\\PacketMirroringAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringAggregatedListWarning.php',
    'Google\\Service\\Compute\\PacketMirroringAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringAggregatedListWarningData.php',
    'Google\\Service\\Compute\\PacketMirroringFilter' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringFilter.php',
    'Google\\Service\\Compute\\PacketMirroringForwardingRuleInfo' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringForwardingRuleInfo.php',
    'Google\\Service\\Compute\\PacketMirroringList' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringList.php',
    'Google\\Service\\Compute\\PacketMirroringListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringListWarning.php',
    'Google\\Service\\Compute\\PacketMirroringListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringListWarningData.php',
    'Google\\Service\\Compute\\PacketMirroringMirroredResourceInfo' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringMirroredResourceInfo.php',
    'Google\\Service\\Compute\\PacketMirroringMirroredResourceInfoInstanceInfo' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringMirroredResourceInfoInstanceInfo.php',
    'Google\\Service\\Compute\\PacketMirroringMirroredResourceInfoSubnetInfo' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringMirroredResourceInfoSubnetInfo.php',
    'Google\\Service\\Compute\\PacketMirroringNetworkInfo' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringNetworkInfo.php',
    'Google\\Service\\Compute\\PacketMirroringsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringsScopedList.php',
    'Google\\Service\\Compute\\PacketMirroringsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringsScopedListWarning.php',
    'Google\\Service\\Compute\\PacketMirroringsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PacketMirroringsScopedListWarningData.php',
    'Google\\Service\\Compute\\PathMatcher' => $vendorDir . '/google/apiclient-services/src/Compute/PathMatcher.php',
    'Google\\Service\\Compute\\PathRule' => $vendorDir . '/google/apiclient-services/src/Compute/PathRule.php',
    'Google\\Service\\Compute\\PerInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Compute/PerInstanceConfig.php',
    'Google\\Service\\Compute\\Policy' => $vendorDir . '/google/apiclient-services/src/Compute/Policy.php',
    'Google\\Service\\Compute\\PreconfiguredWafSet' => $vendorDir . '/google/apiclient-services/src/Compute/PreconfiguredWafSet.php',
    'Google\\Service\\Compute\\PreservedState' => $vendorDir . '/google/apiclient-services/src/Compute/PreservedState.php',
    'Google\\Service\\Compute\\PreservedStatePreservedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/PreservedStatePreservedDisk.php',
    'Google\\Service\\Compute\\PreservedStatePreservedNetworkIp' => $vendorDir . '/google/apiclient-services/src/Compute/PreservedStatePreservedNetworkIp.php',
    'Google\\Service\\Compute\\PreservedStatePreservedNetworkIpIpAddress' => $vendorDir . '/google/apiclient-services/src/Compute/PreservedStatePreservedNetworkIpIpAddress.php',
    'Google\\Service\\Compute\\Project' => $vendorDir . '/google/apiclient-services/src/Compute/Project.php',
    'Google\\Service\\Compute\\ProjectsDisableXpnResourceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsDisableXpnResourceRequest.php',
    'Google\\Service\\Compute\\ProjectsEnableXpnResourceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsEnableXpnResourceRequest.php',
    'Google\\Service\\Compute\\ProjectsGetXpnResources' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsGetXpnResources.php',
    'Google\\Service\\Compute\\ProjectsListXpnHostsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsListXpnHostsRequest.php',
    'Google\\Service\\Compute\\ProjectsSetCloudArmorTierRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsSetCloudArmorTierRequest.php',
    'Google\\Service\\Compute\\ProjectsSetDefaultNetworkTierRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ProjectsSetDefaultNetworkTierRequest.php',
    'Google\\Service\\Compute\\PublicAdvertisedPrefix' => $vendorDir . '/google/apiclient-services/src/Compute/PublicAdvertisedPrefix.php',
    'Google\\Service\\Compute\\PublicAdvertisedPrefixList' => $vendorDir . '/google/apiclient-services/src/Compute/PublicAdvertisedPrefixList.php',
    'Google\\Service\\Compute\\PublicAdvertisedPrefixListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PublicAdvertisedPrefixListWarning.php',
    'Google\\Service\\Compute\\PublicAdvertisedPrefixListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PublicAdvertisedPrefixListWarningData.php',
    'Google\\Service\\Compute\\PublicAdvertisedPrefixPublicDelegatedPrefix' => $vendorDir . '/google/apiclient-services/src/Compute/PublicAdvertisedPrefixPublicDelegatedPrefix.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefix' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefix.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixAggregatedList.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixAggregatedListWarning.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixAggregatedListWarningData.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixList' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixList.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixListWarning.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixListWarningData.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixPublicDelegatedSubPrefix' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixPublicDelegatedSubPrefix.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixesScopedList.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixesScopedListWarning.php',
    'Google\\Service\\Compute\\PublicDelegatedPrefixesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/PublicDelegatedPrefixesScopedListWarningData.php',
    'Google\\Service\\Compute\\Quota' => $vendorDir . '/google/apiclient-services/src/Compute/Quota.php',
    'Google\\Service\\Compute\\QuotaExceededInfo' => $vendorDir . '/google/apiclient-services/src/Compute/QuotaExceededInfo.php',
    'Google\\Service\\Compute\\Reference' => $vendorDir . '/google/apiclient-services/src/Compute/Reference.php',
    'Google\\Service\\Compute\\Region' => $vendorDir . '/google/apiclient-services/src/Compute/Region.php',
    'Google\\Service\\Compute\\RegionAddressesMoveRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionAddressesMoveRequest.php',
    'Google\\Service\\Compute\\RegionAutoscalerList' => $vendorDir . '/google/apiclient-services/src/Compute/RegionAutoscalerList.php',
    'Google\\Service\\Compute\\RegionAutoscalerListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionAutoscalerListWarning.php',
    'Google\\Service\\Compute\\RegionAutoscalerListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionAutoscalerListWarningData.php',
    'Google\\Service\\Compute\\RegionDiskTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDiskTypeList.php',
    'Google\\Service\\Compute\\RegionDiskTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDiskTypeListWarning.php',
    'Google\\Service\\Compute\\RegionDiskTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDiskTypeListWarningData.php',
    'Google\\Service\\Compute\\RegionDisksAddResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDisksAddResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\RegionDisksRemoveResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDisksRemoveResourcePoliciesRequest.php',
    'Google\\Service\\Compute\\RegionDisksResizeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDisksResizeRequest.php',
    'Google\\Service\\Compute\\RegionDisksStartAsyncReplicationRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionDisksStartAsyncReplicationRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupList' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupList.php',
    'Google\\Service\\Compute\\RegionInstanceGroupListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupListWarning.php',
    'Google\\Service\\Compute\\RegionInstanceGroupListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupListWarningData.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerDeleteInstanceConfigReq' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerDeleteInstanceConfigReq.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerList' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerList.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerListWarning.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerListWarningData.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerPatchInstanceConfigReq' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerPatchInstanceConfigReq.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagerUpdateInstanceConfigReq' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagerUpdateInstanceConfigReq.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersAbandonInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersAbandonInstancesRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersApplyUpdatesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersApplyUpdatesRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersCreateInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersCreateInstancesRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersDeleteInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersDeleteInstancesRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersListErrorsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersListErrorsResponse.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersListInstanceConfigsResp' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersListInstanceConfigsResp.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersListInstanceConfigsRespWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersListInstanceConfigsRespWarning.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersListInstanceConfigsRespWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersListInstanceConfigsRespWarningData.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersListInstancesResponse.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersRecreateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersRecreateRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersSetTargetPoolsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersSetTargetPoolsRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupManagersSetTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupManagersSetTemplateRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupsListInstances' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupsListInstances.php',
    'Google\\Service\\Compute\\RegionInstanceGroupsListInstancesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupsListInstancesRequest.php',
    'Google\\Service\\Compute\\RegionInstanceGroupsListInstancesWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupsListInstancesWarning.php',
    'Google\\Service\\Compute\\RegionInstanceGroupsListInstancesWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupsListInstancesWarningData.php',
    'Google\\Service\\Compute\\RegionInstanceGroupsSetNamedPortsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionInstanceGroupsSetNamedPortsRequest.php',
    'Google\\Service\\Compute\\RegionList' => $vendorDir . '/google/apiclient-services/src/Compute/RegionList.php',
    'Google\\Service\\Compute\\RegionListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionListWarning.php',
    'Google\\Service\\Compute\\RegionListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionListWarningData.php',
    'Google\\Service\\Compute\\RegionNetworkEndpointGroupsAttachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionNetworkEndpointGroupsAttachEndpointsRequest.php',
    'Google\\Service\\Compute\\RegionNetworkEndpointGroupsDetachEndpointsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionNetworkEndpointGroupsDetachEndpointsRequest.php',
    'Google\\Service\\Compute\\RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.php',
    'Google\\Service\\Compute\\RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.php',
    'Google\\Service\\Compute\\RegionQuotaStatusWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RegionQuotaStatusWarning.php',
    'Google\\Service\\Compute\\RegionQuotaStatusWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RegionQuotaStatusWarningData.php',
    'Google\\Service\\Compute\\RegionSetLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionSetLabelsRequest.php',
    'Google\\Service\\Compute\\RegionSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionSetPolicyRequest.php',
    'Google\\Service\\Compute\\RegionTargetHttpsProxiesSetSslCertificatesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionTargetHttpsProxiesSetSslCertificatesRequest.php',
    'Google\\Service\\Compute\\RegionUrlMapsValidateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/RegionUrlMapsValidateRequest.php',
    'Google\\Service\\Compute\\RequestMirrorPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/RequestMirrorPolicy.php',
    'Google\\Service\\Compute\\Reservation' => $vendorDir . '/google/apiclient-services/src/Compute/Reservation.php',
    'Google\\Service\\Compute\\ReservationAffinity' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationAffinity.php',
    'Google\\Service\\Compute\\ReservationAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationAggregatedList.php',
    'Google\\Service\\Compute\\ReservationAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationAggregatedListWarning.php',
    'Google\\Service\\Compute\\ReservationAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationAggregatedListWarningData.php',
    'Google\\Service\\Compute\\ReservationList' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationList.php',
    'Google\\Service\\Compute\\ReservationListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationListWarning.php',
    'Google\\Service\\Compute\\ReservationListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationListWarningData.php',
    'Google\\Service\\Compute\\ReservationsResizeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationsResizeRequest.php',
    'Google\\Service\\Compute\\ReservationsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationsScopedList.php',
    'Google\\Service\\Compute\\ReservationsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationsScopedListWarning.php',
    'Google\\Service\\Compute\\ReservationsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ReservationsScopedListWarningData.php',
    'Google\\Service\\Compute\\ResourceCommitment' => $vendorDir . '/google/apiclient-services/src/Compute/ResourceCommitment.php',
    'Google\\Service\\Compute\\ResourceGroupReference' => $vendorDir . '/google/apiclient-services/src/Compute/ResourceGroupReference.php',
    'Google\\Service\\Compute\\ResourcePoliciesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePoliciesScopedList.php',
    'Google\\Service\\Compute\\ResourcePoliciesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePoliciesScopedListWarning.php',
    'Google\\Service\\Compute\\ResourcePoliciesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePoliciesScopedListWarningData.php',
    'Google\\Service\\Compute\\ResourcePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicy.php',
    'Google\\Service\\Compute\\ResourcePolicyAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyAggregatedList.php',
    'Google\\Service\\Compute\\ResourcePolicyAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyAggregatedListWarning.php',
    'Google\\Service\\Compute\\ResourcePolicyAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyAggregatedListWarningData.php',
    'Google\\Service\\Compute\\ResourcePolicyDailyCycle' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyDailyCycle.php',
    'Google\\Service\\Compute\\ResourcePolicyDiskConsistencyGroupPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyDiskConsistencyGroupPolicy.php',
    'Google\\Service\\Compute\\ResourcePolicyGroupPlacementPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyGroupPlacementPolicy.php',
    'Google\\Service\\Compute\\ResourcePolicyHourlyCycle' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyHourlyCycle.php',
    'Google\\Service\\Compute\\ResourcePolicyInstanceSchedulePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyInstanceSchedulePolicy.php',
    'Google\\Service\\Compute\\ResourcePolicyInstanceSchedulePolicySchedule' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyInstanceSchedulePolicySchedule.php',
    'Google\\Service\\Compute\\ResourcePolicyList' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyList.php',
    'Google\\Service\\Compute\\ResourcePolicyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyListWarning.php',
    'Google\\Service\\Compute\\ResourcePolicyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyListWarningData.php',
    'Google\\Service\\Compute\\ResourcePolicyResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyResourceStatus.php',
    'Google\\Service\\Compute\\ResourcePolicyResourceStatusInstanceSchedulePolicyStatus' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyResourceStatusInstanceSchedulePolicyStatus.php',
    'Google\\Service\\Compute\\ResourcePolicySnapshotSchedulePolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicySnapshotSchedulePolicy.php',
    'Google\\Service\\Compute\\ResourcePolicySnapshotSchedulePolicyRetentionPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicySnapshotSchedulePolicyRetentionPolicy.php',
    'Google\\Service\\Compute\\ResourcePolicySnapshotSchedulePolicySchedule' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicySnapshotSchedulePolicySchedule.php',
    'Google\\Service\\Compute\\ResourcePolicySnapshotSchedulePolicySnapshotProperties' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicySnapshotSchedulePolicySnapshotProperties.php',
    'Google\\Service\\Compute\\ResourcePolicyWeeklyCycle' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyWeeklyCycle.php',
    'Google\\Service\\Compute\\ResourcePolicyWeeklyCycleDayOfWeek' => $vendorDir . '/google/apiclient-services/src/Compute/ResourcePolicyWeeklyCycleDayOfWeek.php',
    'Google\\Service\\Compute\\ResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/ResourceStatus.php',
    'Google\\Service\\Compute\\ResourceStatusScheduling' => $vendorDir . '/google/apiclient-services/src/Compute/ResourceStatusScheduling.php',
    'Google\\Service\\Compute\\Resource\\AcceleratorTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/AcceleratorTypes.php',
    'Google\\Service\\Compute\\Resource\\Addresses' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Addresses.php',
    'Google\\Service\\Compute\\Resource\\Autoscalers' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Autoscalers.php',
    'Google\\Service\\Compute\\Resource\\BackendBuckets' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/BackendBuckets.php',
    'Google\\Service\\Compute\\Resource\\BackendServices' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/BackendServices.php',
    'Google\\Service\\Compute\\Resource\\DiskTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/DiskTypes.php',
    'Google\\Service\\Compute\\Resource\\Disks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Disks.php',
    'Google\\Service\\Compute\\Resource\\ExternalVpnGateways' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ExternalVpnGateways.php',
    'Google\\Service\\Compute\\Resource\\FirewallPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/FirewallPolicies.php',
    'Google\\Service\\Compute\\Resource\\Firewalls' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Firewalls.php',
    'Google\\Service\\Compute\\Resource\\ForwardingRules' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ForwardingRules.php',
    'Google\\Service\\Compute\\Resource\\FutureReservations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/FutureReservations.php',
    'Google\\Service\\Compute\\Resource\\GlobalAddresses' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalAddresses.php',
    'Google\\Service\\Compute\\Resource\\GlobalForwardingRules' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalForwardingRules.php',
    'Google\\Service\\Compute\\Resource\\GlobalNetworkEndpointGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalNetworkEndpointGroups.php',
    'Google\\Service\\Compute\\Resource\\GlobalOperations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalOperations.php',
    'Google\\Service\\Compute\\Resource\\GlobalOrganizationOperations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalOrganizationOperations.php',
    'Google\\Service\\Compute\\Resource\\GlobalPublicDelegatedPrefixes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/GlobalPublicDelegatedPrefixes.php',
    'Google\\Service\\Compute\\Resource\\HealthChecks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/HealthChecks.php',
    'Google\\Service\\Compute\\Resource\\HttpHealthChecks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/HttpHealthChecks.php',
    'Google\\Service\\Compute\\Resource\\HttpsHealthChecks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/HttpsHealthChecks.php',
    'Google\\Service\\Compute\\Resource\\ImageFamilyViews' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ImageFamilyViews.php',
    'Google\\Service\\Compute\\Resource\\Images' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Images.php',
    'Google\\Service\\Compute\\Resource\\InstanceGroupManagerResizeRequests' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstanceGroupManagerResizeRequests.php',
    'Google\\Service\\Compute\\Resource\\InstanceGroupManagers' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstanceGroupManagers.php',
    'Google\\Service\\Compute\\Resource\\InstanceGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstanceGroups.php',
    'Google\\Service\\Compute\\Resource\\InstanceSettings' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstanceSettings.php',
    'Google\\Service\\Compute\\Resource\\InstanceTemplates' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstanceTemplates.php',
    'Google\\Service\\Compute\\Resource\\Instances' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Instances.php',
    'Google\\Service\\Compute\\Resource\\InstantSnapshots' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InstantSnapshots.php',
    'Google\\Service\\Compute\\Resource\\InterconnectAttachments' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InterconnectAttachments.php',
    'Google\\Service\\Compute\\Resource\\InterconnectLocations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InterconnectLocations.php',
    'Google\\Service\\Compute\\Resource\\InterconnectRemoteLocations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/InterconnectRemoteLocations.php',
    'Google\\Service\\Compute\\Resource\\Interconnects' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Interconnects.php',
    'Google\\Service\\Compute\\Resource\\LicenseCodes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/LicenseCodes.php',
    'Google\\Service\\Compute\\Resource\\Licenses' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Licenses.php',
    'Google\\Service\\Compute\\Resource\\MachineImages' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/MachineImages.php',
    'Google\\Service\\Compute\\Resource\\MachineTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/MachineTypes.php',
    'Google\\Service\\Compute\\Resource\\NetworkAttachments' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NetworkAttachments.php',
    'Google\\Service\\Compute\\Resource\\NetworkEdgeSecurityServices' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NetworkEdgeSecurityServices.php',
    'Google\\Service\\Compute\\Resource\\NetworkEndpointGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NetworkEndpointGroups.php',
    'Google\\Service\\Compute\\Resource\\NetworkFirewallPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NetworkFirewallPolicies.php',
    'Google\\Service\\Compute\\Resource\\Networks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Networks.php',
    'Google\\Service\\Compute\\Resource\\NodeGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NodeGroups.php',
    'Google\\Service\\Compute\\Resource\\NodeTemplates' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NodeTemplates.php',
    'Google\\Service\\Compute\\Resource\\NodeTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/NodeTypes.php',
    'Google\\Service\\Compute\\Resource\\PacketMirrorings' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/PacketMirrorings.php',
    'Google\\Service\\Compute\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Projects.php',
    'Google\\Service\\Compute\\Resource\\PublicAdvertisedPrefixes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/PublicAdvertisedPrefixes.php',
    'Google\\Service\\Compute\\Resource\\PublicDelegatedPrefixes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/PublicDelegatedPrefixes.php',
    'Google\\Service\\Compute\\Resource\\RegionAutoscalers' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionAutoscalers.php',
    'Google\\Service\\Compute\\Resource\\RegionBackendServices' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionBackendServices.php',
    'Google\\Service\\Compute\\Resource\\RegionCommitments' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionCommitments.php',
    'Google\\Service\\Compute\\Resource\\RegionDiskTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionDiskTypes.php',
    'Google\\Service\\Compute\\Resource\\RegionDisks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionDisks.php',
    'Google\\Service\\Compute\\Resource\\RegionHealthCheckServices' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionHealthCheckServices.php',
    'Google\\Service\\Compute\\Resource\\RegionHealthChecks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionHealthChecks.php',
    'Google\\Service\\Compute\\Resource\\RegionInstanceGroupManagers' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionInstanceGroupManagers.php',
    'Google\\Service\\Compute\\Resource\\RegionInstanceGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionInstanceGroups.php',
    'Google\\Service\\Compute\\Resource\\RegionInstanceTemplates' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionInstanceTemplates.php',
    'Google\\Service\\Compute\\Resource\\RegionInstances' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionInstances.php',
    'Google\\Service\\Compute\\Resource\\RegionInstantSnapshots' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionInstantSnapshots.php',
    'Google\\Service\\Compute\\Resource\\RegionNetworkEndpointGroups' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionNetworkEndpointGroups.php',
    'Google\\Service\\Compute\\Resource\\RegionNetworkFirewallPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionNetworkFirewallPolicies.php',
    'Google\\Service\\Compute\\Resource\\RegionNotificationEndpoints' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionNotificationEndpoints.php',
    'Google\\Service\\Compute\\Resource\\RegionOperations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionOperations.php',
    'Google\\Service\\Compute\\Resource\\RegionSecurityPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionSecurityPolicies.php',
    'Google\\Service\\Compute\\Resource\\RegionSslCertificates' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionSslCertificates.php',
    'Google\\Service\\Compute\\Resource\\RegionSslPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionSslPolicies.php',
    'Google\\Service\\Compute\\Resource\\RegionTargetHttpProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionTargetHttpProxies.php',
    'Google\\Service\\Compute\\Resource\\RegionTargetHttpsProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionTargetHttpsProxies.php',
    'Google\\Service\\Compute\\Resource\\RegionTargetTcpProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionTargetTcpProxies.php',
    'Google\\Service\\Compute\\Resource\\RegionUrlMaps' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionUrlMaps.php',
    'Google\\Service\\Compute\\Resource\\RegionZones' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/RegionZones.php',
    'Google\\Service\\Compute\\Resource\\Regions' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Regions.php',
    'Google\\Service\\Compute\\Resource\\Reservations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Reservations.php',
    'Google\\Service\\Compute\\Resource\\ResourcePolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ResourcePolicies.php',
    'Google\\Service\\Compute\\Resource\\Routers' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Routers.php',
    'Google\\Service\\Compute\\Resource\\Routes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Routes.php',
    'Google\\Service\\Compute\\Resource\\SecurityPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/SecurityPolicies.php',
    'Google\\Service\\Compute\\Resource\\ServiceAttachments' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ServiceAttachments.php',
    'Google\\Service\\Compute\\Resource\\SnapshotSettings' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/SnapshotSettings.php',
    'Google\\Service\\Compute\\Resource\\Snapshots' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Snapshots.php',
    'Google\\Service\\Compute\\Resource\\SslCertificates' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/SslCertificates.php',
    'Google\\Service\\Compute\\Resource\\SslPolicies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/SslPolicies.php',
    'Google\\Service\\Compute\\Resource\\StoragePoolTypes' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/StoragePoolTypes.php',
    'Google\\Service\\Compute\\Resource\\StoragePools' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/StoragePools.php',
    'Google\\Service\\Compute\\Resource\\Subnetworks' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Subnetworks.php',
    'Google\\Service\\Compute\\Resource\\TargetGrpcProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetGrpcProxies.php',
    'Google\\Service\\Compute\\Resource\\TargetHttpProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetHttpProxies.php',
    'Google\\Service\\Compute\\Resource\\TargetHttpsProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetHttpsProxies.php',
    'Google\\Service\\Compute\\Resource\\TargetInstances' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetInstances.php',
    'Google\\Service\\Compute\\Resource\\TargetPools' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetPools.php',
    'Google\\Service\\Compute\\Resource\\TargetSslProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetSslProxies.php',
    'Google\\Service\\Compute\\Resource\\TargetTcpProxies' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetTcpProxies.php',
    'Google\\Service\\Compute\\Resource\\TargetVpnGateways' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/TargetVpnGateways.php',
    'Google\\Service\\Compute\\Resource\\UrlMaps' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/UrlMaps.php',
    'Google\\Service\\Compute\\Resource\\VpnGateways' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/VpnGateways.php',
    'Google\\Service\\Compute\\Resource\\VpnTunnels' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/VpnTunnels.php',
    'Google\\Service\\Compute\\Resource\\ZoneOperations' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/ZoneOperations.php',
    'Google\\Service\\Compute\\Resource\\Zones' => $vendorDir . '/google/apiclient-services/src/Compute/Resource/Zones.php',
    'Google\\Service\\Compute\\Route' => $vendorDir . '/google/apiclient-services/src/Compute/Route.php',
    'Google\\Service\\Compute\\RouteAsPath' => $vendorDir . '/google/apiclient-services/src/Compute/RouteAsPath.php',
    'Google\\Service\\Compute\\RouteList' => $vendorDir . '/google/apiclient-services/src/Compute/RouteList.php',
    'Google\\Service\\Compute\\RouteListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RouteListWarning.php',
    'Google\\Service\\Compute\\RouteListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RouteListWarningData.php',
    'Google\\Service\\Compute\\RouteWarnings' => $vendorDir . '/google/apiclient-services/src/Compute/RouteWarnings.php',
    'Google\\Service\\Compute\\RouteWarningsData' => $vendorDir . '/google/apiclient-services/src/Compute/RouteWarningsData.php',
    'Google\\Service\\Compute\\Router' => $vendorDir . '/google/apiclient-services/src/Compute/Router.php',
    'Google\\Service\\Compute\\RouterAdvertisedIpRange' => $vendorDir . '/google/apiclient-services/src/Compute/RouterAdvertisedIpRange.php',
    'Google\\Service\\Compute\\RouterAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/RouterAggregatedList.php',
    'Google\\Service\\Compute\\RouterAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RouterAggregatedListWarning.php',
    'Google\\Service\\Compute\\RouterAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RouterAggregatedListWarningData.php',
    'Google\\Service\\Compute\\RouterBgp' => $vendorDir . '/google/apiclient-services/src/Compute/RouterBgp.php',
    'Google\\Service\\Compute\\RouterBgpPeer' => $vendorDir . '/google/apiclient-services/src/Compute/RouterBgpPeer.php',
    'Google\\Service\\Compute\\RouterBgpPeerBfd' => $vendorDir . '/google/apiclient-services/src/Compute/RouterBgpPeerBfd.php',
    'Google\\Service\\Compute\\RouterBgpPeerCustomLearnedIpRange' => $vendorDir . '/google/apiclient-services/src/Compute/RouterBgpPeerCustomLearnedIpRange.php',
    'Google\\Service\\Compute\\RouterInterface' => $vendorDir . '/google/apiclient-services/src/Compute/RouterInterface.php',
    'Google\\Service\\Compute\\RouterList' => $vendorDir . '/google/apiclient-services/src/Compute/RouterList.php',
    'Google\\Service\\Compute\\RouterListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RouterListWarning.php',
    'Google\\Service\\Compute\\RouterListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RouterListWarningData.php',
    'Google\\Service\\Compute\\RouterMd5AuthenticationKey' => $vendorDir . '/google/apiclient-services/src/Compute/RouterMd5AuthenticationKey.php',
    'Google\\Service\\Compute\\RouterNat' => $vendorDir . '/google/apiclient-services/src/Compute/RouterNat.php',
    'Google\\Service\\Compute\\RouterNatLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/RouterNatLogConfig.php',
    'Google\\Service\\Compute\\RouterNatRule' => $vendorDir . '/google/apiclient-services/src/Compute/RouterNatRule.php',
    'Google\\Service\\Compute\\RouterNatRuleAction' => $vendorDir . '/google/apiclient-services/src/Compute/RouterNatRuleAction.php',
    'Google\\Service\\Compute\\RouterNatSubnetworkToNat' => $vendorDir . '/google/apiclient-services/src/Compute/RouterNatSubnetworkToNat.php',
    'Google\\Service\\Compute\\RouterStatus' => $vendorDir . '/google/apiclient-services/src/Compute/RouterStatus.php',
    'Google\\Service\\Compute\\RouterStatusBgpPeerStatus' => $vendorDir . '/google/apiclient-services/src/Compute/RouterStatusBgpPeerStatus.php',
    'Google\\Service\\Compute\\RouterStatusNatStatus' => $vendorDir . '/google/apiclient-services/src/Compute/RouterStatusNatStatus.php',
    'Google\\Service\\Compute\\RouterStatusNatStatusNatRuleStatus' => $vendorDir . '/google/apiclient-services/src/Compute/RouterStatusNatStatusNatRuleStatus.php',
    'Google\\Service\\Compute\\RouterStatusResponse' => $vendorDir . '/google/apiclient-services/src/Compute/RouterStatusResponse.php',
    'Google\\Service\\Compute\\RoutersPreviewResponse' => $vendorDir . '/google/apiclient-services/src/Compute/RoutersPreviewResponse.php',
    'Google\\Service\\Compute\\RoutersScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/RoutersScopedList.php',
    'Google\\Service\\Compute\\RoutersScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/RoutersScopedListWarning.php',
    'Google\\Service\\Compute\\RoutersScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/RoutersScopedListWarningData.php',
    'Google\\Service\\Compute\\Rule' => $vendorDir . '/google/apiclient-services/src/Compute/Rule.php',
    'Google\\Service\\Compute\\SSLHealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/SSLHealthCheck.php',
    'Google\\Service\\Compute\\SavedAttachedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/SavedAttachedDisk.php',
    'Google\\Service\\Compute\\SavedDisk' => $vendorDir . '/google/apiclient-services/src/Compute/SavedDisk.php',
    'Google\\Service\\Compute\\ScalingScheduleStatus' => $vendorDir . '/google/apiclient-services/src/Compute/ScalingScheduleStatus.php',
    'Google\\Service\\Compute\\Scheduling' => $vendorDir . '/google/apiclient-services/src/Compute/Scheduling.php',
    'Google\\Service\\Compute\\SchedulingNodeAffinity' => $vendorDir . '/google/apiclient-services/src/Compute/SchedulingNodeAffinity.php',
    'Google\\Service\\Compute\\SchedulingOnInstanceStopAction' => $vendorDir . '/google/apiclient-services/src/Compute/SchedulingOnInstanceStopAction.php',
    'Google\\Service\\Compute\\Screenshot' => $vendorDir . '/google/apiclient-services/src/Compute/Screenshot.php',
    'Google\\Service\\Compute\\SecurityPoliciesAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesAggregatedList.php',
    'Google\\Service\\Compute\\SecurityPoliciesAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesAggregatedListWarning.php',
    'Google\\Service\\Compute\\SecurityPoliciesAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesAggregatedListWarningData.php',
    'Google\\Service\\Compute\\SecurityPoliciesListPreconfiguredExpressionSetsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesListPreconfiguredExpressionSetsResponse.php',
    'Google\\Service\\Compute\\SecurityPoliciesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesScopedList.php',
    'Google\\Service\\Compute\\SecurityPoliciesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesScopedListWarning.php',
    'Google\\Service\\Compute\\SecurityPoliciesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesScopedListWarningData.php',
    'Google\\Service\\Compute\\SecurityPoliciesWafConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPoliciesWafConfig.php',
    'Google\\Service\\Compute\\SecurityPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicy.php',
    'Google\\Service\\Compute\\SecurityPolicyAdaptiveProtectionConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdaptiveProtectionConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyAdvancedOptionsConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdvancedOptionsConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyAdvancedOptionsConfigJsonCustomConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyAdvancedOptionsConfigJsonCustomConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyDdosProtectionConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyDdosProtectionConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyList' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyList.php',
    'Google\\Service\\Compute\\SecurityPolicyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyListWarning.php',
    'Google\\Service\\Compute\\SecurityPolicyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyListWarningData.php',
    'Google\\Service\\Compute\\SecurityPolicyRecaptchaOptionsConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRecaptchaOptionsConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyReference' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyReference.php',
    'Google\\Service\\Compute\\SecurityPolicyRule' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRule.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleHttpHeaderAction' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleHttpHeaderAction.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleHttpHeaderActionHttpHeaderOption' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleHttpHeaderActionHttpHeaderOption.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleMatcher' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleMatcher.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleMatcherConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleMatcherConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleMatcherExprOptions' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleMatcherExprOptions.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleNetworkMatcher' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleNetworkMatcher.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch.php',
    'Google\\Service\\Compute\\SecurityPolicyRulePreconfiguredWafConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRulePreconfiguredWafConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyRulePreconfiguredWafConfigExclusion' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRulePreconfiguredWafConfigExclusion.php',
    'Google\\Service\\Compute\\SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleRateLimitOptions' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleRateLimitOptions.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleRateLimitOptionsThreshold' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleRateLimitOptionsThreshold.php',
    'Google\\Service\\Compute\\SecurityPolicyRuleRedirectOptions' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyRuleRedirectOptions.php',
    'Google\\Service\\Compute\\SecurityPolicyUserDefinedField' => $vendorDir . '/google/apiclient-services/src/Compute/SecurityPolicyUserDefinedField.php',
    'Google\\Service\\Compute\\SecuritySettings' => $vendorDir . '/google/apiclient-services/src/Compute/SecuritySettings.php',
    'Google\\Service\\Compute\\SerialPortOutput' => $vendorDir . '/google/apiclient-services/src/Compute/SerialPortOutput.php',
    'Google\\Service\\Compute\\ServerBinding' => $vendorDir . '/google/apiclient-services/src/Compute/ServerBinding.php',
    'Google\\Service\\Compute\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAccount.php',
    'Google\\Service\\Compute\\ServiceAttachment' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachment.php',
    'Google\\Service\\Compute\\ServiceAttachmentAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentAggregatedList.php',
    'Google\\Service\\Compute\\ServiceAttachmentAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentAggregatedListWarning.php',
    'Google\\Service\\Compute\\ServiceAttachmentAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentAggregatedListWarningData.php',
    'Google\\Service\\Compute\\ServiceAttachmentConnectedEndpoint' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentConnectedEndpoint.php',
    'Google\\Service\\Compute\\ServiceAttachmentConsumerProjectLimit' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentConsumerProjectLimit.php',
    'Google\\Service\\Compute\\ServiceAttachmentList' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentList.php',
    'Google\\Service\\Compute\\ServiceAttachmentListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentListWarning.php',
    'Google\\Service\\Compute\\ServiceAttachmentListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentListWarningData.php',
    'Google\\Service\\Compute\\ServiceAttachmentsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentsScopedList.php',
    'Google\\Service\\Compute\\ServiceAttachmentsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentsScopedListWarning.php',
    'Google\\Service\\Compute\\ServiceAttachmentsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ServiceAttachmentsScopedListWarningData.php',
    'Google\\Service\\Compute\\SetCommonInstanceMetadataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Compute/SetCommonInstanceMetadataOperationMetadata.php',
    'Google\\Service\\Compute\\SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo' => $vendorDir . '/google/apiclient-services/src/Compute/SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.php',
    'Google\\Service\\Compute\\ShareSettings' => $vendorDir . '/google/apiclient-services/src/Compute/ShareSettings.php',
    'Google\\Service\\Compute\\ShareSettingsProjectConfig' => $vendorDir . '/google/apiclient-services/src/Compute/ShareSettingsProjectConfig.php',
    'Google\\Service\\Compute\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Compute/ShieldedInstanceConfig.php',
    'Google\\Service\\Compute\\ShieldedInstanceIdentity' => $vendorDir . '/google/apiclient-services/src/Compute/ShieldedInstanceIdentity.php',
    'Google\\Service\\Compute\\ShieldedInstanceIdentityEntry' => $vendorDir . '/google/apiclient-services/src/Compute/ShieldedInstanceIdentityEntry.php',
    'Google\\Service\\Compute\\ShieldedInstanceIntegrityPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/ShieldedInstanceIntegrityPolicy.php',
    'Google\\Service\\Compute\\SignedUrlKey' => $vendorDir . '/google/apiclient-services/src/Compute/SignedUrlKey.php',
    'Google\\Service\\Compute\\Snapshot' => $vendorDir . '/google/apiclient-services/src/Compute/Snapshot.php',
    'Google\\Service\\Compute\\SnapshotList' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotList.php',
    'Google\\Service\\Compute\\SnapshotListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotListWarning.php',
    'Google\\Service\\Compute\\SnapshotListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotListWarningData.php',
    'Google\\Service\\Compute\\SnapshotSettings' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotSettings.php',
    'Google\\Service\\Compute\\SnapshotSettingsStorageLocationSettings' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotSettingsStorageLocationSettings.php',
    'Google\\Service\\Compute\\SnapshotSettingsStorageLocationSettingsStorageLocationPreference' => $vendorDir . '/google/apiclient-services/src/Compute/SnapshotSettingsStorageLocationSettingsStorageLocationPreference.php',
    'Google\\Service\\Compute\\SourceDiskEncryptionKey' => $vendorDir . '/google/apiclient-services/src/Compute/SourceDiskEncryptionKey.php',
    'Google\\Service\\Compute\\SourceInstanceParams' => $vendorDir . '/google/apiclient-services/src/Compute/SourceInstanceParams.php',
    'Google\\Service\\Compute\\SourceInstanceProperties' => $vendorDir . '/google/apiclient-services/src/Compute/SourceInstanceProperties.php',
    'Google\\Service\\Compute\\SslCertificate' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificate.php',
    'Google\\Service\\Compute\\SslCertificateAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateAggregatedList.php',
    'Google\\Service\\Compute\\SslCertificateAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateAggregatedListWarning.php',
    'Google\\Service\\Compute\\SslCertificateAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateAggregatedListWarningData.php',
    'Google\\Service\\Compute\\SslCertificateList' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateList.php',
    'Google\\Service\\Compute\\SslCertificateListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateListWarning.php',
    'Google\\Service\\Compute\\SslCertificateListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateListWarningData.php',
    'Google\\Service\\Compute\\SslCertificateManagedSslCertificate' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateManagedSslCertificate.php',
    'Google\\Service\\Compute\\SslCertificateSelfManagedSslCertificate' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificateSelfManagedSslCertificate.php',
    'Google\\Service\\Compute\\SslCertificatesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificatesScopedList.php',
    'Google\\Service\\Compute\\SslCertificatesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificatesScopedListWarning.php',
    'Google\\Service\\Compute\\SslCertificatesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslCertificatesScopedListWarningData.php',
    'Google\\Service\\Compute\\SslPoliciesAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesAggregatedList.php',
    'Google\\Service\\Compute\\SslPoliciesAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesAggregatedListWarning.php',
    'Google\\Service\\Compute\\SslPoliciesAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesAggregatedListWarningData.php',
    'Google\\Service\\Compute\\SslPoliciesList' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesList.php',
    'Google\\Service\\Compute\\SslPoliciesListAvailableFeaturesResponse' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesListAvailableFeaturesResponse.php',
    'Google\\Service\\Compute\\SslPoliciesListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesListWarning.php',
    'Google\\Service\\Compute\\SslPoliciesListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesListWarningData.php',
    'Google\\Service\\Compute\\SslPoliciesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesScopedList.php',
    'Google\\Service\\Compute\\SslPoliciesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesScopedListWarning.php',
    'Google\\Service\\Compute\\SslPoliciesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SslPoliciesScopedListWarningData.php',
    'Google\\Service\\Compute\\SslPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/SslPolicy.php',
    'Google\\Service\\Compute\\SslPolicyReference' => $vendorDir . '/google/apiclient-services/src/Compute/SslPolicyReference.php',
    'Google\\Service\\Compute\\SslPolicyWarnings' => $vendorDir . '/google/apiclient-services/src/Compute/SslPolicyWarnings.php',
    'Google\\Service\\Compute\\SslPolicyWarningsData' => $vendorDir . '/google/apiclient-services/src/Compute/SslPolicyWarningsData.php',
    'Google\\Service\\Compute\\StatefulPolicy' => $vendorDir . '/google/apiclient-services/src/Compute/StatefulPolicy.php',
    'Google\\Service\\Compute\\StatefulPolicyPreservedState' => $vendorDir . '/google/apiclient-services/src/Compute/StatefulPolicyPreservedState.php',
    'Google\\Service\\Compute\\StatefulPolicyPreservedStateDiskDevice' => $vendorDir . '/google/apiclient-services/src/Compute/StatefulPolicyPreservedStateDiskDevice.php',
    'Google\\Service\\Compute\\StatefulPolicyPreservedStateNetworkIp' => $vendorDir . '/google/apiclient-services/src/Compute/StatefulPolicyPreservedStateNetworkIp.php',
    'Google\\Service\\Compute\\Status' => $vendorDir . '/google/apiclient-services/src/Compute/Status.php',
    'Google\\Service\\Compute\\StoragePool' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePool.php',
    'Google\\Service\\Compute\\StoragePoolAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolAggregatedList.php',
    'Google\\Service\\Compute\\StoragePoolAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolAggregatedListWarning.php',
    'Google\\Service\\Compute\\StoragePoolAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolAggregatedListWarningData.php',
    'Google\\Service\\Compute\\StoragePoolDisk' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolDisk.php',
    'Google\\Service\\Compute\\StoragePoolList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolList.php',
    'Google\\Service\\Compute\\StoragePoolListDisks' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolListDisks.php',
    'Google\\Service\\Compute\\StoragePoolListDisksWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolListDisksWarning.php',
    'Google\\Service\\Compute\\StoragePoolListDisksWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolListDisksWarningData.php',
    'Google\\Service\\Compute\\StoragePoolListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolListWarning.php',
    'Google\\Service\\Compute\\StoragePoolListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolListWarningData.php',
    'Google\\Service\\Compute\\StoragePoolResourceStatus' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolResourceStatus.php',
    'Google\\Service\\Compute\\StoragePoolType' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolType.php',
    'Google\\Service\\Compute\\StoragePoolTypeAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeAggregatedList.php',
    'Google\\Service\\Compute\\StoragePoolTypeAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeAggregatedListWarning.php',
    'Google\\Service\\Compute\\StoragePoolTypeAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeAggregatedListWarningData.php',
    'Google\\Service\\Compute\\StoragePoolTypeList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeList.php',
    'Google\\Service\\Compute\\StoragePoolTypeListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeListWarning.php',
    'Google\\Service\\Compute\\StoragePoolTypeListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypeListWarningData.php',
    'Google\\Service\\Compute\\StoragePoolTypesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypesScopedList.php',
    'Google\\Service\\Compute\\StoragePoolTypesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypesScopedListWarning.php',
    'Google\\Service\\Compute\\StoragePoolTypesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolTypesScopedListWarningData.php',
    'Google\\Service\\Compute\\StoragePoolsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolsScopedList.php',
    'Google\\Service\\Compute\\StoragePoolsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolsScopedListWarning.php',
    'Google\\Service\\Compute\\StoragePoolsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/StoragePoolsScopedListWarningData.php',
    'Google\\Service\\Compute\\Subnetwork' => $vendorDir . '/google/apiclient-services/src/Compute/Subnetwork.php',
    'Google\\Service\\Compute\\SubnetworkAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkAggregatedList.php',
    'Google\\Service\\Compute\\SubnetworkAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkAggregatedListWarning.php',
    'Google\\Service\\Compute\\SubnetworkAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkAggregatedListWarningData.php',
    'Google\\Service\\Compute\\SubnetworkList' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkList.php',
    'Google\\Service\\Compute\\SubnetworkListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkListWarning.php',
    'Google\\Service\\Compute\\SubnetworkListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkListWarningData.php',
    'Google\\Service\\Compute\\SubnetworkLogConfig' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkLogConfig.php',
    'Google\\Service\\Compute\\SubnetworkSecondaryRange' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworkSecondaryRange.php',
    'Google\\Service\\Compute\\SubnetworksExpandIpCidrRangeRequest' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworksExpandIpCidrRangeRequest.php',
    'Google\\Service\\Compute\\SubnetworksScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworksScopedList.php',
    'Google\\Service\\Compute\\SubnetworksScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworksScopedListWarning.php',
    'Google\\Service\\Compute\\SubnetworksScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworksScopedListWarningData.php',
    'Google\\Service\\Compute\\SubnetworksSetPrivateIpGoogleAccessRequest' => $vendorDir . '/google/apiclient-services/src/Compute/SubnetworksSetPrivateIpGoogleAccessRequest.php',
    'Google\\Service\\Compute\\Subsetting' => $vendorDir . '/google/apiclient-services/src/Compute/Subsetting.php',
    'Google\\Service\\Compute\\TCPHealthCheck' => $vendorDir . '/google/apiclient-services/src/Compute/TCPHealthCheck.php',
    'Google\\Service\\Compute\\Tags' => $vendorDir . '/google/apiclient-services/src/Compute/Tags.php',
    'Google\\Service\\Compute\\TargetGrpcProxy' => $vendorDir . '/google/apiclient-services/src/Compute/TargetGrpcProxy.php',
    'Google\\Service\\Compute\\TargetGrpcProxyList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetGrpcProxyList.php',
    'Google\\Service\\Compute\\TargetGrpcProxyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetGrpcProxyListWarning.php',
    'Google\\Service\\Compute\\TargetGrpcProxyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetGrpcProxyListWarningData.php',
    'Google\\Service\\Compute\\TargetHttpProxiesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxiesScopedList.php',
    'Google\\Service\\Compute\\TargetHttpProxiesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxiesScopedListWarning.php',
    'Google\\Service\\Compute\\TargetHttpProxiesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxiesScopedListWarningData.php',
    'Google\\Service\\Compute\\TargetHttpProxy' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxy.php',
    'Google\\Service\\Compute\\TargetHttpProxyAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxyAggregatedList.php',
    'Google\\Service\\Compute\\TargetHttpProxyList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxyList.php',
    'Google\\Service\\Compute\\TargetHttpProxyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxyListWarning.php',
    'Google\\Service\\Compute\\TargetHttpProxyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpProxyListWarningData.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesScopedList.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesScopedListWarning.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesScopedListWarningData.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesSetCertificateMapRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesSetCertificateMapRequest.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesSetQuicOverrideRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesSetQuicOverrideRequest.php',
    'Google\\Service\\Compute\\TargetHttpsProxiesSetSslCertificatesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxiesSetSslCertificatesRequest.php',
    'Google\\Service\\Compute\\TargetHttpsProxy' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxy.php',
    'Google\\Service\\Compute\\TargetHttpsProxyAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyAggregatedList.php',
    'Google\\Service\\Compute\\TargetHttpsProxyAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyAggregatedListWarning.php',
    'Google\\Service\\Compute\\TargetHttpsProxyAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyAggregatedListWarningData.php',
    'Google\\Service\\Compute\\TargetHttpsProxyList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyList.php',
    'Google\\Service\\Compute\\TargetHttpsProxyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyListWarning.php',
    'Google\\Service\\Compute\\TargetHttpsProxyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetHttpsProxyListWarningData.php',
    'Google\\Service\\Compute\\TargetInstance' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstance.php',
    'Google\\Service\\Compute\\TargetInstanceAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceAggregatedList.php',
    'Google\\Service\\Compute\\TargetInstanceAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceAggregatedListWarning.php',
    'Google\\Service\\Compute\\TargetInstanceAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceAggregatedListWarningData.php',
    'Google\\Service\\Compute\\TargetInstanceList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceList.php',
    'Google\\Service\\Compute\\TargetInstanceListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceListWarning.php',
    'Google\\Service\\Compute\\TargetInstanceListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstanceListWarningData.php',
    'Google\\Service\\Compute\\TargetInstancesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstancesScopedList.php',
    'Google\\Service\\Compute\\TargetInstancesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstancesScopedListWarning.php',
    'Google\\Service\\Compute\\TargetInstancesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetInstancesScopedListWarningData.php',
    'Google\\Service\\Compute\\TargetPool' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPool.php',
    'Google\\Service\\Compute\\TargetPoolAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolAggregatedList.php',
    'Google\\Service\\Compute\\TargetPoolAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolAggregatedListWarning.php',
    'Google\\Service\\Compute\\TargetPoolAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolAggregatedListWarningData.php',
    'Google\\Service\\Compute\\TargetPoolInstanceHealth' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolInstanceHealth.php',
    'Google\\Service\\Compute\\TargetPoolList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolList.php',
    'Google\\Service\\Compute\\TargetPoolListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolListWarning.php',
    'Google\\Service\\Compute\\TargetPoolListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolListWarningData.php',
    'Google\\Service\\Compute\\TargetPoolsAddHealthCheckRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsAddHealthCheckRequest.php',
    'Google\\Service\\Compute\\TargetPoolsAddInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsAddInstanceRequest.php',
    'Google\\Service\\Compute\\TargetPoolsRemoveHealthCheckRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsRemoveHealthCheckRequest.php',
    'Google\\Service\\Compute\\TargetPoolsRemoveInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsRemoveInstanceRequest.php',
    'Google\\Service\\Compute\\TargetPoolsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsScopedList.php',
    'Google\\Service\\Compute\\TargetPoolsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsScopedListWarning.php',
    'Google\\Service\\Compute\\TargetPoolsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetPoolsScopedListWarningData.php',
    'Google\\Service\\Compute\\TargetReference' => $vendorDir . '/google/apiclient-services/src/Compute/TargetReference.php',
    'Google\\Service\\Compute\\TargetSslProxiesSetBackendServiceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxiesSetBackendServiceRequest.php',
    'Google\\Service\\Compute\\TargetSslProxiesSetCertificateMapRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxiesSetCertificateMapRequest.php',
    'Google\\Service\\Compute\\TargetSslProxiesSetProxyHeaderRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxiesSetProxyHeaderRequest.php',
    'Google\\Service\\Compute\\TargetSslProxiesSetSslCertificatesRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxiesSetSslCertificatesRequest.php',
    'Google\\Service\\Compute\\TargetSslProxy' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxy.php',
    'Google\\Service\\Compute\\TargetSslProxyList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxyList.php',
    'Google\\Service\\Compute\\TargetSslProxyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxyListWarning.php',
    'Google\\Service\\Compute\\TargetSslProxyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetSslProxyListWarningData.php',
    'Google\\Service\\Compute\\TargetTcpProxiesScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxiesScopedList.php',
    'Google\\Service\\Compute\\TargetTcpProxiesScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxiesScopedListWarning.php',
    'Google\\Service\\Compute\\TargetTcpProxiesScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxiesScopedListWarningData.php',
    'Google\\Service\\Compute\\TargetTcpProxiesSetBackendServiceRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxiesSetBackendServiceRequest.php',
    'Google\\Service\\Compute\\TargetTcpProxiesSetProxyHeaderRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxiesSetProxyHeaderRequest.php',
    'Google\\Service\\Compute\\TargetTcpProxy' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxy.php',
    'Google\\Service\\Compute\\TargetTcpProxyAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyAggregatedList.php',
    'Google\\Service\\Compute\\TargetTcpProxyAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyAggregatedListWarning.php',
    'Google\\Service\\Compute\\TargetTcpProxyAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyAggregatedListWarningData.php',
    'Google\\Service\\Compute\\TargetTcpProxyList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyList.php',
    'Google\\Service\\Compute\\TargetTcpProxyListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyListWarning.php',
    'Google\\Service\\Compute\\TargetTcpProxyListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetTcpProxyListWarningData.php',
    'Google\\Service\\Compute\\TargetVpnGateway' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGateway.php',
    'Google\\Service\\Compute\\TargetVpnGatewayAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayAggregatedList.php',
    'Google\\Service\\Compute\\TargetVpnGatewayAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayAggregatedListWarning.php',
    'Google\\Service\\Compute\\TargetVpnGatewayAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayAggregatedListWarningData.php',
    'Google\\Service\\Compute\\TargetVpnGatewayList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayList.php',
    'Google\\Service\\Compute\\TargetVpnGatewayListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayListWarning.php',
    'Google\\Service\\Compute\\TargetVpnGatewayListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewayListWarningData.php',
    'Google\\Service\\Compute\\TargetVpnGatewaysScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewaysScopedList.php',
    'Google\\Service\\Compute\\TargetVpnGatewaysScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewaysScopedListWarning.php',
    'Google\\Service\\Compute\\TargetVpnGatewaysScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/TargetVpnGatewaysScopedListWarningData.php',
    'Google\\Service\\Compute\\TestFailure' => $vendorDir . '/google/apiclient-services/src/Compute/TestFailure.php',
    'Google\\Service\\Compute\\TestPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/TestPermissionsRequest.php',
    'Google\\Service\\Compute\\TestPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Compute/TestPermissionsResponse.php',
    'Google\\Service\\Compute\\Uint128' => $vendorDir . '/google/apiclient-services/src/Compute/Uint128.php',
    'Google\\Service\\Compute\\UpcomingMaintenance' => $vendorDir . '/google/apiclient-services/src/Compute/UpcomingMaintenance.php',
    'Google\\Service\\Compute\\UrlMap' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMap.php',
    'Google\\Service\\Compute\\UrlMapList' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapList.php',
    'Google\\Service\\Compute\\UrlMapListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapListWarning.php',
    'Google\\Service\\Compute\\UrlMapListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapListWarningData.php',
    'Google\\Service\\Compute\\UrlMapReference' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapReference.php',
    'Google\\Service\\Compute\\UrlMapTest' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapTest.php',
    'Google\\Service\\Compute\\UrlMapTestHeader' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapTestHeader.php',
    'Google\\Service\\Compute\\UrlMapValidationResult' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapValidationResult.php',
    'Google\\Service\\Compute\\UrlMapsAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsAggregatedList.php',
    'Google\\Service\\Compute\\UrlMapsAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsAggregatedListWarning.php',
    'Google\\Service\\Compute\\UrlMapsAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsAggregatedListWarningData.php',
    'Google\\Service\\Compute\\UrlMapsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsScopedList.php',
    'Google\\Service\\Compute\\UrlMapsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsScopedListWarning.php',
    'Google\\Service\\Compute\\UrlMapsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsScopedListWarningData.php',
    'Google\\Service\\Compute\\UrlMapsValidateRequest' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsValidateRequest.php',
    'Google\\Service\\Compute\\UrlMapsValidateResponse' => $vendorDir . '/google/apiclient-services/src/Compute/UrlMapsValidateResponse.php',
    'Google\\Service\\Compute\\UrlRewrite' => $vendorDir . '/google/apiclient-services/src/Compute/UrlRewrite.php',
    'Google\\Service\\Compute\\UsableSubnetwork' => $vendorDir . '/google/apiclient-services/src/Compute/UsableSubnetwork.php',
    'Google\\Service\\Compute\\UsableSubnetworkSecondaryRange' => $vendorDir . '/google/apiclient-services/src/Compute/UsableSubnetworkSecondaryRange.php',
    'Google\\Service\\Compute\\UsableSubnetworksAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/UsableSubnetworksAggregatedList.php',
    'Google\\Service\\Compute\\UsableSubnetworksAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/UsableSubnetworksAggregatedListWarning.php',
    'Google\\Service\\Compute\\UsableSubnetworksAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/UsableSubnetworksAggregatedListWarningData.php',
    'Google\\Service\\Compute\\UsageExportLocation' => $vendorDir . '/google/apiclient-services/src/Compute/UsageExportLocation.php',
    'Google\\Service\\Compute\\VmEndpointNatMappings' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappings.php',
    'Google\\Service\\Compute\\VmEndpointNatMappingsInterfaceNatMappings' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappingsInterfaceNatMappings.php',
    'Google\\Service\\Compute\\VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.php',
    'Google\\Service\\Compute\\VmEndpointNatMappingsList' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappingsList.php',
    'Google\\Service\\Compute\\VmEndpointNatMappingsListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappingsListWarning.php',
    'Google\\Service\\Compute\\VmEndpointNatMappingsListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VmEndpointNatMappingsListWarningData.php',
    'Google\\Service\\Compute\\VpnGateway' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGateway.php',
    'Google\\Service\\Compute\\VpnGatewayAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayAggregatedList.php',
    'Google\\Service\\Compute\\VpnGatewayAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayAggregatedListWarning.php',
    'Google\\Service\\Compute\\VpnGatewayAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayAggregatedListWarningData.php',
    'Google\\Service\\Compute\\VpnGatewayList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayList.php',
    'Google\\Service\\Compute\\VpnGatewayListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayListWarning.php',
    'Google\\Service\\Compute\\VpnGatewayListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayListWarningData.php',
    'Google\\Service\\Compute\\VpnGatewayStatus' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayStatus.php',
    'Google\\Service\\Compute\\VpnGatewayStatusHighAvailabilityRequirementState' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayStatusHighAvailabilityRequirementState.php',
    'Google\\Service\\Compute\\VpnGatewayStatusTunnel' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayStatusTunnel.php',
    'Google\\Service\\Compute\\VpnGatewayStatusVpnConnection' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayStatusVpnConnection.php',
    'Google\\Service\\Compute\\VpnGatewayVpnGatewayInterface' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewayVpnGatewayInterface.php',
    'Google\\Service\\Compute\\VpnGatewaysGetStatusResponse' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewaysGetStatusResponse.php',
    'Google\\Service\\Compute\\VpnGatewaysScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewaysScopedList.php',
    'Google\\Service\\Compute\\VpnGatewaysScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewaysScopedListWarning.php',
    'Google\\Service\\Compute\\VpnGatewaysScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnGatewaysScopedListWarningData.php',
    'Google\\Service\\Compute\\VpnTunnel' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnel.php',
    'Google\\Service\\Compute\\VpnTunnelAggregatedList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelAggregatedList.php',
    'Google\\Service\\Compute\\VpnTunnelAggregatedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelAggregatedListWarning.php',
    'Google\\Service\\Compute\\VpnTunnelAggregatedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelAggregatedListWarningData.php',
    'Google\\Service\\Compute\\VpnTunnelList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelList.php',
    'Google\\Service\\Compute\\VpnTunnelListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelListWarning.php',
    'Google\\Service\\Compute\\VpnTunnelListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelListWarningData.php',
    'Google\\Service\\Compute\\VpnTunnelsScopedList' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelsScopedList.php',
    'Google\\Service\\Compute\\VpnTunnelsScopedListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelsScopedListWarning.php',
    'Google\\Service\\Compute\\VpnTunnelsScopedListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/VpnTunnelsScopedListWarningData.php',
    'Google\\Service\\Compute\\WafExpressionSet' => $vendorDir . '/google/apiclient-services/src/Compute/WafExpressionSet.php',
    'Google\\Service\\Compute\\WafExpressionSetExpression' => $vendorDir . '/google/apiclient-services/src/Compute/WafExpressionSetExpression.php',
    'Google\\Service\\Compute\\WeightedBackendService' => $vendorDir . '/google/apiclient-services/src/Compute/WeightedBackendService.php',
    'Google\\Service\\Compute\\XpnHostList' => $vendorDir . '/google/apiclient-services/src/Compute/XpnHostList.php',
    'Google\\Service\\Compute\\XpnHostListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/XpnHostListWarning.php',
    'Google\\Service\\Compute\\XpnHostListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/XpnHostListWarningData.php',
    'Google\\Service\\Compute\\XpnResourceId' => $vendorDir . '/google/apiclient-services/src/Compute/XpnResourceId.php',
    'Google\\Service\\Compute\\Zone' => $vendorDir . '/google/apiclient-services/src/Compute/Zone.php',
    'Google\\Service\\Compute\\ZoneList' => $vendorDir . '/google/apiclient-services/src/Compute/ZoneList.php',
    'Google\\Service\\Compute\\ZoneListWarning' => $vendorDir . '/google/apiclient-services/src/Compute/ZoneListWarning.php',
    'Google\\Service\\Compute\\ZoneListWarningData' => $vendorDir . '/google/apiclient-services/src/Compute/ZoneListWarningData.php',
    'Google\\Service\\Compute\\ZoneSetLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ZoneSetLabelsRequest.php',
    'Google\\Service\\Compute\\ZoneSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Compute/ZoneSetPolicyRequest.php',
    'Google\\Service\\Config' => $vendorDir . '/google/apiclient-services/src/Config.php',
    'Google\\Service\\Config\\ApplyResults' => $vendorDir . '/google/apiclient-services/src/Config/ApplyResults.php',
    'Google\\Service\\Config\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Config/AuditConfig.php',
    'Google\\Service\\Config\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Config/AuditLogConfig.php',
    'Google\\Service\\Config\\Binding' => $vendorDir . '/google/apiclient-services/src/Config/Binding.php',
    'Google\\Service\\Config\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Config/CancelOperationRequest.php',
    'Google\\Service\\Config\\ConfigEmpty' => $vendorDir . '/google/apiclient-services/src/Config/ConfigEmpty.php',
    'Google\\Service\\Config\\ConfigResource' => $vendorDir . '/google/apiclient-services/src/Config/ConfigResource.php',
    'Google\\Service\\Config\\DeleteStatefileRequest' => $vendorDir . '/google/apiclient-services/src/Config/DeleteStatefileRequest.php',
    'Google\\Service\\Config\\Deployment' => $vendorDir . '/google/apiclient-services/src/Config/Deployment.php',
    'Google\\Service\\Config\\DeploymentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Config/DeploymentOperationMetadata.php',
    'Google\\Service\\Config\\ExportDeploymentStatefileRequest' => $vendorDir . '/google/apiclient-services/src/Config/ExportDeploymentStatefileRequest.php',
    'Google\\Service\\Config\\ExportPreviewResultRequest' => $vendorDir . '/google/apiclient-services/src/Config/ExportPreviewResultRequest.php',
    'Google\\Service\\Config\\ExportPreviewResultResponse' => $vendorDir . '/google/apiclient-services/src/Config/ExportPreviewResultResponse.php',
    'Google\\Service\\Config\\ExportRevisionStatefileRequest' => $vendorDir . '/google/apiclient-services/src/Config/ExportRevisionStatefileRequest.php',
    'Google\\Service\\Config\\Expr' => $vendorDir . '/google/apiclient-services/src/Config/Expr.php',
    'Google\\Service\\Config\\GitSource' => $vendorDir . '/google/apiclient-services/src/Config/GitSource.php',
    'Google\\Service\\Config\\ImportStatefileRequest' => $vendorDir . '/google/apiclient-services/src/Config/ImportStatefileRequest.php',
    'Google\\Service\\Config\\ListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListDeploymentsResponse.php',
    'Google\\Service\\Config\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListLocationsResponse.php',
    'Google\\Service\\Config\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListOperationsResponse.php',
    'Google\\Service\\Config\\ListPreviewsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListPreviewsResponse.php',
    'Google\\Service\\Config\\ListResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListResourcesResponse.php',
    'Google\\Service\\Config\\ListRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListRevisionsResponse.php',
    'Google\\Service\\Config\\ListTerraformVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Config/ListTerraformVersionsResponse.php',
    'Google\\Service\\Config\\Location' => $vendorDir . '/google/apiclient-services/src/Config/Location.php',
    'Google\\Service\\Config\\LockDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/Config/LockDeploymentRequest.php',
    'Google\\Service\\Config\\LockInfo' => $vendorDir . '/google/apiclient-services/src/Config/LockInfo.php',
    'Google\\Service\\Config\\Operation' => $vendorDir . '/google/apiclient-services/src/Config/Operation.php',
    'Google\\Service\\Config\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Config/OperationMetadata.php',
    'Google\\Service\\Config\\Policy' => $vendorDir . '/google/apiclient-services/src/Config/Policy.php',
    'Google\\Service\\Config\\Preview' => $vendorDir . '/google/apiclient-services/src/Config/Preview.php',
    'Google\\Service\\Config\\PreviewArtifacts' => $vendorDir . '/google/apiclient-services/src/Config/PreviewArtifacts.php',
    'Google\\Service\\Config\\PreviewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Config/PreviewOperationMetadata.php',
    'Google\\Service\\Config\\PreviewResult' => $vendorDir . '/google/apiclient-services/src/Config/PreviewResult.php',
    'Google\\Service\\Config\\ResourceCAIInfo' => $vendorDir . '/google/apiclient-services/src/Config/ResourceCAIInfo.php',
    'Google\\Service\\Config\\ResourceTerraformInfo' => $vendorDir . '/google/apiclient-services/src/Config/ResourceTerraformInfo.php',
    'Google\\Service\\Config\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Config/Resource/Projects.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocations.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsDeployments' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsDeployments.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsDeploymentsRevisions' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsDeploymentsRevisions.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsDeploymentsRevisionsResources' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsDeploymentsRevisionsResources.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsPreviews' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsPreviews.php',
    'Google\\Service\\Config\\Resource\\ProjectsLocationsTerraformVersions' => $vendorDir . '/google/apiclient-services/src/Config/Resource/ProjectsLocationsTerraformVersions.php',
    'Google\\Service\\Config\\Revision' => $vendorDir . '/google/apiclient-services/src/Config/Revision.php',
    'Google\\Service\\Config\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Config/SetIamPolicyRequest.php',
    'Google\\Service\\Config\\Statefile' => $vendorDir . '/google/apiclient-services/src/Config/Statefile.php',
    'Google\\Service\\Config\\Status' => $vendorDir . '/google/apiclient-services/src/Config/Status.php',
    'Google\\Service\\Config\\TerraformBlueprint' => $vendorDir . '/google/apiclient-services/src/Config/TerraformBlueprint.php',
    'Google\\Service\\Config\\TerraformError' => $vendorDir . '/google/apiclient-services/src/Config/TerraformError.php',
    'Google\\Service\\Config\\TerraformOutput' => $vendorDir . '/google/apiclient-services/src/Config/TerraformOutput.php',
    'Google\\Service\\Config\\TerraformVariable' => $vendorDir . '/google/apiclient-services/src/Config/TerraformVariable.php',
    'Google\\Service\\Config\\TerraformVersion' => $vendorDir . '/google/apiclient-services/src/Config/TerraformVersion.php',
    'Google\\Service\\Config\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Config/TestIamPermissionsRequest.php',
    'Google\\Service\\Config\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Config/TestIamPermissionsResponse.php',
    'Google\\Service\\Config\\UnlockDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/Config/UnlockDeploymentRequest.php',
    'Google\\Service\\Connectors' => $vendorDir . '/google/apiclient-services/src/Connectors.php',
    'Google\\Service\\Connectors\\AccessCredentials' => $vendorDir . '/google/apiclient-services/src/Connectors/AccessCredentials.php',
    'Google\\Service\\Connectors\\AclInfo' => $vendorDir . '/google/apiclient-services/src/Connectors/AclInfo.php',
    'Google\\Service\\Connectors\\Action' => $vendorDir . '/google/apiclient-services/src/Connectors/Action.php',
    'Google\\Service\\Connectors\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/AuditConfig.php',
    'Google\\Service\\Connectors\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/AuditLogConfig.php',
    'Google\\Service\\Connectors\\AuthCodeData' => $vendorDir . '/google/apiclient-services/src/Connectors/AuthCodeData.php',
    'Google\\Service\\Connectors\\AuthConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/AuthConfig.php',
    'Google\\Service\\Connectors\\AuthConfigTemplate' => $vendorDir . '/google/apiclient-services/src/Connectors/AuthConfigTemplate.php',
    'Google\\Service\\Connectors\\AuthorizationCodeLink' => $vendorDir . '/google/apiclient-services/src/Connectors/AuthorizationCodeLink.php',
    'Google\\Service\\Connectors\\Binding' => $vendorDir . '/google/apiclient-services/src/Connectors/Binding.php',
    'Google\\Service\\Connectors\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/CancelOperationRequest.php',
    'Google\\Service\\Connectors\\CheckReadinessResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/CheckReadinessResponse.php',
    'Google\\Service\\Connectors\\CheckStatusResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/CheckStatusResponse.php',
    'Google\\Service\\Connectors\\ConfigVariable' => $vendorDir . '/google/apiclient-services/src/Connectors/ConfigVariable.php',
    'Google\\Service\\Connectors\\ConfigVariableTemplate' => $vendorDir . '/google/apiclient-services/src/Connectors/ConfigVariableTemplate.php',
    'Google\\Service\\Connectors\\Connection' => $vendorDir . '/google/apiclient-services/src/Connectors/Connection.php',
    'Google\\Service\\Connectors\\ConnectionSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/Connectors/ConnectionSchemaMetadata.php',
    'Google\\Service\\Connectors\\ConnectionStatus' => $vendorDir . '/google/apiclient-services/src/Connectors/ConnectionStatus.php',
    'Google\\Service\\Connectors\\Connector' => $vendorDir . '/google/apiclient-services/src/Connectors/Connector.php',
    'Google\\Service\\Connectors\\ConnectorVersion' => $vendorDir . '/google/apiclient-services/src/Connectors/ConnectorVersion.php',
    'Google\\Service\\Connectors\\ConnectorsEmpty' => $vendorDir . '/google/apiclient-services/src/Connectors/ConnectorsEmpty.php',
    'Google\\Service\\Connectors\\ConnectorsResource' => $vendorDir . '/google/apiclient-services/src/Connectors/ConnectorsResource.php',
    'Google\\Service\\Connectors\\DailyCycle' => $vendorDir . '/google/apiclient-services/src/Connectors/DailyCycle.php',
    'Google\\Service\\Connectors\\Date' => $vendorDir . '/google/apiclient-services/src/Connectors/Date.php',
    'Google\\Service\\Connectors\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/Connectors/DenyMaintenancePeriod.php',
    'Google\\Service\\Connectors\\EgressControlConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/EgressControlConfig.php',
    'Google\\Service\\Connectors\\Entity' => $vendorDir . '/google/apiclient-services/src/Connectors/Entity.php',
    'Google\\Service\\Connectors\\EntityType' => $vendorDir . '/google/apiclient-services/src/Connectors/EntityType.php',
    'Google\\Service\\Connectors\\EntityWithACL' => $vendorDir . '/google/apiclient-services/src/Connectors/EntityWithACL.php',
    'Google\\Service\\Connectors\\EnumOption' => $vendorDir . '/google/apiclient-services/src/Connectors/EnumOption.php',
    'Google\\Service\\Connectors\\ExchangeAuthCodeRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/ExchangeAuthCodeRequest.php',
    'Google\\Service\\Connectors\\ExchangeAuthCodeResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ExchangeAuthCodeResponse.php',
    'Google\\Service\\Connectors\\ExecuteActionRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/ExecuteActionRequest.php',
    'Google\\Service\\Connectors\\ExecuteActionResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ExecuteActionResponse.php',
    'Google\\Service\\Connectors\\ExecuteSqlQueryRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/ExecuteSqlQueryRequest.php',
    'Google\\Service\\Connectors\\ExecuteSqlQueryResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ExecuteSqlQueryResponse.php',
    'Google\\Service\\Connectors\\Expr' => $vendorDir . '/google/apiclient-services/src/Connectors/Expr.php',
    'Google\\Service\\Connectors\\ExtractionRule' => $vendorDir . '/google/apiclient-services/src/Connectors/ExtractionRule.php',
    'Google\\Service\\Connectors\\ExtractionRules' => $vendorDir . '/google/apiclient-services/src/Connectors/ExtractionRules.php',
    'Google\\Service\\Connectors\\Field' => $vendorDir . '/google/apiclient-services/src/Connectors/Field.php',
    'Google\\Service\\Connectors\\InputParameter' => $vendorDir . '/google/apiclient-services/src/Connectors/InputParameter.php',
    'Google\\Service\\Connectors\\Instance' => $vendorDir . '/google/apiclient-services/src/Connectors/Instance.php',
    'Google\\Service\\Connectors\\JsonSchema' => $vendorDir . '/google/apiclient-services/src/Connectors/JsonSchema.php',
    'Google\\Service\\Connectors\\JwtClaims' => $vendorDir . '/google/apiclient-services/src/Connectors/JwtClaims.php',
    'Google\\Service\\Connectors\\ListActionsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListActionsResponse.php',
    'Google\\Service\\Connectors\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListConnectionsResponse.php',
    'Google\\Service\\Connectors\\ListConnectorVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListConnectorVersionsResponse.php',
    'Google\\Service\\Connectors\\ListConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListConnectorsResponse.php',
    'Google\\Service\\Connectors\\ListEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListEntitiesResponse.php',
    'Google\\Service\\Connectors\\ListEntitiesWithACLsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListEntitiesWithACLsResponse.php',
    'Google\\Service\\Connectors\\ListEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListEntityTypesResponse.php',
    'Google\\Service\\Connectors\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListLocationsResponse.php',
    'Google\\Service\\Connectors\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListOperationsResponse.php',
    'Google\\Service\\Connectors\\ListProvidersResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListProvidersResponse.php',
    'Google\\Service\\Connectors\\ListRuntimeActionSchemasResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListRuntimeActionSchemasResponse.php',
    'Google\\Service\\Connectors\\ListRuntimeEntitySchemasResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/ListRuntimeEntitySchemasResponse.php',
    'Google\\Service\\Connectors\\Location' => $vendorDir . '/google/apiclient-services/src/Connectors/Location.php',
    'Google\\Service\\Connectors\\LockConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/LockConfig.php',
    'Google\\Service\\Connectors\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/Connectors/MaintenancePolicy.php',
    'Google\\Service\\Connectors\\MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/Connectors/MaintenanceSchedule.php',
    'Google\\Service\\Connectors\\MaintenanceSettings' => $vendorDir . '/google/apiclient-services/src/Connectors/MaintenanceSettings.php',
    'Google\\Service\\Connectors\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/Connectors/MaintenanceWindow.php',
    'Google\\Service\\Connectors\\NodeSloMetadata' => $vendorDir . '/google/apiclient-services/src/Connectors/NodeSloMetadata.php',
    'Google\\Service\\Connectors\\NotificationParameter' => $vendorDir . '/google/apiclient-services/src/Connectors/NotificationParameter.php',
    'Google\\Service\\Connectors\\Oauth2ClientCredentials' => $vendorDir . '/google/apiclient-services/src/Connectors/Oauth2ClientCredentials.php',
    'Google\\Service\\Connectors\\Oauth2JwtBearer' => $vendorDir . '/google/apiclient-services/src/Connectors/Oauth2JwtBearer.php',
    'Google\\Service\\Connectors\\Operation' => $vendorDir . '/google/apiclient-services/src/Connectors/Operation.php',
    'Google\\Service\\Connectors\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Connectors/OperationMetadata.php',
    'Google\\Service\\Connectors\\PerSliSloEligibility' => $vendorDir . '/google/apiclient-services/src/Connectors/PerSliSloEligibility.php',
    'Google\\Service\\Connectors\\Policy' => $vendorDir . '/google/apiclient-services/src/Connectors/Policy.php',
    'Google\\Service\\Connectors\\Principal' => $vendorDir . '/google/apiclient-services/src/Connectors/Principal.php',
    'Google\\Service\\Connectors\\Provider' => $vendorDir . '/google/apiclient-services/src/Connectors/Provider.php',
    'Google\\Service\\Connectors\\ProvisionedResource' => $vendorDir . '/google/apiclient-services/src/Connectors/ProvisionedResource.php',
    'Google\\Service\\Connectors\\Query' => $vendorDir . '/google/apiclient-services/src/Connectors/Query.php',
    'Google\\Service\\Connectors\\QueryParameter' => $vendorDir . '/google/apiclient-services/src/Connectors/QueryParameter.php',
    'Google\\Service\\Connectors\\Readers' => $vendorDir . '/google/apiclient-services/src/Connectors/Readers.php',
    'Google\\Service\\Connectors\\Reference' => $vendorDir . '/google/apiclient-services/src/Connectors/Reference.php',
    'Google\\Service\\Connectors\\RefreshAccessTokenRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/RefreshAccessTokenRequest.php',
    'Google\\Service\\Connectors\\RefreshAccessTokenResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/RefreshAccessTokenResponse.php',
    'Google\\Service\\Connectors\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/Projects.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocations.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsActions' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsActions.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsEntityTypes' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsEntityTypes.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsEntityTypesEntities' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsEntityTypesEntities.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsEntityTypesEntitieswithacls' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsEntityTypesEntitieswithacls.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsRuntimeActionSchemas' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsRuntimeActionSchemas.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectionsRuntimeEntitySchemas' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectionsRuntimeEntitySchemas.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectorsGlobal' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectorsGlobal.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectorsGlobalProviders' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectorsGlobalProviders.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectorsGlobalProvidersConnectors' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectorsGlobalProvidersConnectors.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsConnectorsGlobalProvidersConnectorsVersions' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsConnectorsGlobalProvidersConnectorsVersions.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Connectors\\Resource\\ProjectsLocationsProviders' => $vendorDir . '/google/apiclient-services/src/Connectors/Resource/ProjectsLocationsProviders.php',
    'Google\\Service\\Connectors\\ResultMetadata' => $vendorDir . '/google/apiclient-services/src/Connectors/ResultMetadata.php',
    'Google\\Service\\Connectors\\RoleGrant' => $vendorDir . '/google/apiclient-services/src/Connectors/RoleGrant.php',
    'Google\\Service\\Connectors\\RuntimeActionSchema' => $vendorDir . '/google/apiclient-services/src/Connectors/RuntimeActionSchema.php',
    'Google\\Service\\Connectors\\RuntimeConfig' => $vendorDir . '/google/apiclient-services/src/Connectors/RuntimeConfig.php',
    'Google\\Service\\Connectors\\RuntimeEntitySchema' => $vendorDir . '/google/apiclient-services/src/Connectors/RuntimeEntitySchema.php',
    'Google\\Service\\Connectors\\Schedule' => $vendorDir . '/google/apiclient-services/src/Connectors/Schedule.php',
    'Google\\Service\\Connectors\\Secret' => $vendorDir . '/google/apiclient-services/src/Connectors/Secret.php',
    'Google\\Service\\Connectors\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/SetIamPolicyRequest.php',
    'Google\\Service\\Connectors\\SloEligibility' => $vendorDir . '/google/apiclient-services/src/Connectors/SloEligibility.php',
    'Google\\Service\\Connectors\\SloMetadata' => $vendorDir . '/google/apiclient-services/src/Connectors/SloMetadata.php',
    'Google\\Service\\Connectors\\Source' => $vendorDir . '/google/apiclient-services/src/Connectors/Source.php',
    'Google\\Service\\Connectors\\SshPublicKey' => $vendorDir . '/google/apiclient-services/src/Connectors/SshPublicKey.php',
    'Google\\Service\\Connectors\\Status' => $vendorDir . '/google/apiclient-services/src/Connectors/Status.php',
    'Google\\Service\\Connectors\\SupportedRuntimeFeatures' => $vendorDir . '/google/apiclient-services/src/Connectors/SupportedRuntimeFeatures.php',
    'Google\\Service\\Connectors\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Connectors/TestIamPermissionsRequest.php',
    'Google\\Service\\Connectors\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/TestIamPermissionsResponse.php',
    'Google\\Service\\Connectors\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Connectors/TimeOfDay.php',
    'Google\\Service\\Connectors\\UpdateEntitiesWithConditionsResponse' => $vendorDir . '/google/apiclient-services/src/Connectors/UpdateEntitiesWithConditionsResponse.php',
    'Google\\Service\\Connectors\\UpdatePolicy' => $vendorDir . '/google/apiclient-services/src/Connectors/UpdatePolicy.php',
    'Google\\Service\\Connectors\\UserPassword' => $vendorDir . '/google/apiclient-services/src/Connectors/UserPassword.php',
    'Google\\Service\\Connectors\\WeeklyCycle' => $vendorDir . '/google/apiclient-services/src/Connectors/WeeklyCycle.php',
    'Google\\Service\\Contactcenterinsights' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingInstruction' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingInstruction.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentActionSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentActionSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentCoachingSuggestionEval' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentCoachingSuggestionEval.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentCoachingSuggestionReasoning' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionAgentCoachingSuggestionReasoning.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionSampleResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AgentCoachingSuggestionSampleResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Analysis' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Analysis.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnalysisResult' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnalysisResult.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnnotationBoundary' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnnotationBoundary.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnnotatorSelector' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnnotatorSelector.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnnotatorSelectorSummarizationConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnnotatorSelectorSummarizationConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1AnswerFeedback' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1AnswerFeedback.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ArticleSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ArticleSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1BulkDeleteConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1BulkDeleteConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CalculateStatsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CalculateStatsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CallAnnotation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CallAnnotation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Conversation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Conversation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationCallMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationCallMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationDataSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationDataSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationLevelSentiment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationLevelSentiment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationLevelSilence' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationLevelSilence.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationParticipant' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationParticipant.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationQualityMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationQualityMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationTranscript' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationTranscript.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CreateAnalysisOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CreateAnalysisOperationMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CreateIssueMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CreateIssueMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CreateIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CreateIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CreateIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CreateIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1CreateIssueRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1CreateIssueRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DeleteIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DeleteIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DeleteIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DeleteIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DeployIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DeployIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DeployIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DeployIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DeployIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DeployIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DialogflowIntent' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DialogflowIntent.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DialogflowInteractionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DialogflowInteractionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1DialogflowSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1DialogflowSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1EncryptionSpec.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Entity' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Entity.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1EntityMentionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1EntityMentionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExactMatchConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExactMatchConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportInsightsDataResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportInsightsDataResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportIssueModelRequestGcsDestination' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportIssueModelRequestGcsDestination.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ExportIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ExportIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1FaqAnswerData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1FaqAnswerData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1FreeFormSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1FreeFormSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GeneratorSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GeneratorSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetGeneratorSuggestionResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetGeneratorSuggestionResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswer.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerFaqSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerFaqSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSourceSnippet' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSourceSnippet.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerIntentMatchingSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseKnowledgeAnswerIntentMatchingSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseSuggestedQuery' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1GetKnowledgeAssistResponseSuggestedQuery.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1HoldData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1HoldData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ImportIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ImportIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ImportIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ImportIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ImportIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ImportIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsMetadataIngestConversationsStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsMetadataIngestConversationsStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsRequestConversationConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsRequestConversationConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsRequestTranscriptObjectConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsRequestTranscriptObjectConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IngestConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IngestConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Intent' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Intent.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IntentMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IntentMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1InterruptionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1InterruptionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Issue' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Issue.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueAssignment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueAssignment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueModel' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueModel.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueModelLabelStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueModelLabelStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1IssueModelResult' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1IssueModelResult.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListAnalysesResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListAnalysesResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListIssueModelsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListIssueModelsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListIssuesResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListIssuesResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1ListViewsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1ListViewsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1PhraseMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1PhraseMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1PhraseMatchRule' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1PhraseMatchRule.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1PhraseMatcher' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1PhraseMatcher.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1RedactionConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1RedactionConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1RuntimeAnnotation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1RuntimeAnnotation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SearchKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SearchKnowledgeAnswer.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SearchKnowledgeAnswerAnswerSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SearchKnowledgeAnswerAnswerSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SentimentData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SentimentData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1Settings' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1Settings.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SilenceData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SilenceData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SmartReplyData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SmartReplyData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SpeechConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SpeechConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SummarySuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SummarySuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1SummarySuggestionSummarySection' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1SummarySuggestionSummarySection.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1UndeployIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1UndeployIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1UndeployIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1UndeployIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1UploadConversationMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1UploadConversationMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1UploadConversationRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1UploadConversationRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1View' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1View.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingInstruction' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingInstruction.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentActionSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentActionSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentCoachingSuggestionEval' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentCoachingSuggestionEval.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentCoachingSuggestionReasoning' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionAgentCoachingSuggestionReasoning.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionSampleResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AgentCoachingSuggestionSampleResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1Analysis' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1Analysis.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnalysisResult' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnalysisResult.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1CallAnnotation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1CallAnnotation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1Conversation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1Conversation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSentiment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSentiment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSilence' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSilence.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1DialogflowSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1DialogflowSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1EncryptionSpec.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1Entity' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1Entity.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1EntityMentionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1EntityMentionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelRequestGcsDestination' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelRequestGcsDestination.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ExportIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1FreeFormSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1FreeFormSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GeneratorSuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GeneratorSuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetGeneratorSuggestionResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetGeneratorSuggestionResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswer.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerFaqSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerFaqSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSourceSnippet' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerGenerativeSourceSnippet.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerIntentMatchingSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseKnowledgeAnswerIntentMatchingSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseSuggestedQuery' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1GetKnowledgeAssistResponseSuggestedQuery.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1HoldData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1HoldData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequestGcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequestGcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestGcsSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestGcsSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestTranscriptObjectConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestTranscriptObjectConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IngestConversationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IngestConversationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1Intent' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1Intent.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IntentMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IntentMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1InterruptionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1InterruptionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueAssignment' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueAssignment.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueModel' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueModel.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1IssueModelResult' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1IssueModelResult.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1RedactionConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1RedactionConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SearchKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SearchKnowledgeAnswer.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SearchKnowledgeAnswerAnswerSource' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SearchKnowledgeAnswerAnswerSource.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SentimentData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SentimentData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SilenceData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SilenceData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SmartReplyData' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SmartReplyData.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SpeechConfig' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SpeechConfig.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SummarySuggestion' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SummarySuggestion.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1SummarySuggestionSummarySection' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1SummarySuggestionSummarySection.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata.php',
    'Google\\Service\\Contactcenterinsights\\GoogleCloudContactcenterinsightsV1alpha1UploadConversationRequest' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleCloudContactcenterinsightsV1alpha1UploadConversationRequest.php',
    'Google\\Service\\Contactcenterinsights\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Contactcenterinsights\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleLongrunningOperation.php',
    'Google\\Service\\Contactcenterinsights\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleProtobufEmpty.php',
    'Google\\Service\\Contactcenterinsights\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/GoogleRpcStatus.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/Projects.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocations.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsConversations' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsConversations.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsConversationsAnalyses' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsConversationsAnalyses.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsEncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsEncryptionSpec.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsInsightsdata' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsInsightsdata.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsIssueModels' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsIssueModels.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsIssueModelsIssues' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsIssueModelsIssues.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsPhraseMatchers' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsPhraseMatchers.php',
    'Google\\Service\\Contactcenterinsights\\Resource\\ProjectsLocationsViews' => $vendorDir . '/google/apiclient-services/src/Contactcenterinsights/Resource/ProjectsLocationsViews.php',
    'Google\\Service\\Container' => $vendorDir . '/google/apiclient-services/src/Container.php',
    'Google\\Service\\ContainerAnalysis' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis.php',
    'Google\\Service\\ContainerAnalysis\\AliasContext' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/AliasContext.php',
    'Google\\Service\\ContainerAnalysis\\AnalysisCompleted' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/AnalysisCompleted.php',
    'Google\\Service\\ContainerAnalysis\\Artifact' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Artifact.php',
    'Google\\Service\\ContainerAnalysis\\ArtifactHashes' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ArtifactHashes.php',
    'Google\\Service\\ContainerAnalysis\\ArtifactRule' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ArtifactRule.php',
    'Google\\Service\\ContainerAnalysis\\Assessment' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Assessment.php',
    'Google\\Service\\ContainerAnalysis\\Attestation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Attestation.php',
    'Google\\Service\\ContainerAnalysis\\AttestationNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/AttestationNote.php',
    'Google\\Service\\ContainerAnalysis\\AttestationOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/AttestationOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Authority' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Authority.php',
    'Google\\Service\\ContainerAnalysis\\Basis' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Basis.php',
    'Google\\Service\\ContainerAnalysis\\BatchCreateNotesRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BatchCreateNotesRequest.php',
    'Google\\Service\\ContainerAnalysis\\BatchCreateNotesResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BatchCreateNotesResponse.php',
    'Google\\Service\\ContainerAnalysis\\BatchCreateOccurrencesRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BatchCreateOccurrencesRequest.php',
    'Google\\Service\\ContainerAnalysis\\BatchCreateOccurrencesResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BatchCreateOccurrencesResponse.php',
    'Google\\Service\\ContainerAnalysis\\Binding' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Binding.php',
    'Google\\Service\\ContainerAnalysis\\Build' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Build.php',
    'Google\\Service\\ContainerAnalysis\\BuildDefinition' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildDefinition.php',
    'Google\\Service\\ContainerAnalysis\\BuildMetadata' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildMetadata.php',
    'Google\\Service\\ContainerAnalysis\\BuildNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildNote.php',
    'Google\\Service\\ContainerAnalysis\\BuildOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\BuildProvenance' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildProvenance.php',
    'Google\\Service\\ContainerAnalysis\\BuildSignature' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildSignature.php',
    'Google\\Service\\ContainerAnalysis\\BuildStep' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuildStep.php',
    'Google\\Service\\ContainerAnalysis\\BuilderConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/BuilderConfig.php',
    'Google\\Service\\ContainerAnalysis\\ByProducts' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ByProducts.php',
    'Google\\Service\\ContainerAnalysis\\CVSS' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CVSS.php',
    'Google\\Service\\ContainerAnalysis\\CVSSv3' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CVSSv3.php',
    'Google\\Service\\ContainerAnalysis\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CancelOperationRequest.php',
    'Google\\Service\\ContainerAnalysis\\Category' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Category.php',
    'Google\\Service\\ContainerAnalysis\\CisBenchmark' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CisBenchmark.php',
    'Google\\Service\\ContainerAnalysis\\CloudRepoSourceContext' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CloudRepoSourceContext.php',
    'Google\\Service\\ContainerAnalysis\\CloudStorageLocation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/CloudStorageLocation.php',
    'Google\\Service\\ContainerAnalysis\\Command' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Command.php',
    'Google\\Service\\ContainerAnalysis\\Completeness' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Completeness.php',
    'Google\\Service\\ContainerAnalysis\\ComplianceNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ComplianceNote.php',
    'Google\\Service\\ContainerAnalysis\\ComplianceOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ComplianceOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\ComplianceVersion' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ComplianceVersion.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisEmpty' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisEmpty.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalConfig.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Build' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Build.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildApproval' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildApproval.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOptionWorkerConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOptionWorkerConfig.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuildWarning' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuildWarning.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1GCSLocation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1GCSLocation.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfig.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfigHttpConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfigHttpConfig.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Hash' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Hash.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1InlineSecret' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1InlineSecret.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Results' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Results.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Secret' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Secret.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1SecretManagerSecret' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1SecretManagerSecret.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Secrets' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Secrets.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Source' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Source.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisGoogleDevtoolsCloudbuildV1Volume' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.php',
    'Google\\Service\\ContainerAnalysis\\ContaineranalysisResource' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ContaineranalysisResource.php',
    'Google\\Service\\ContainerAnalysis\\DSSEAttestationNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DSSEAttestationNote.php',
    'Google\\Service\\ContainerAnalysis\\DSSEAttestationOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DSSEAttestationOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\DSSEHint' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DSSEHint.php',
    'Google\\Service\\ContainerAnalysis\\Deployable' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Deployable.php',
    'Google\\Service\\ContainerAnalysis\\Deployment' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Deployment.php',
    'Google\\Service\\ContainerAnalysis\\DeploymentNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DeploymentNote.php',
    'Google\\Service\\ContainerAnalysis\\DeploymentOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DeploymentOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Derived' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Derived.php',
    'Google\\Service\\ContainerAnalysis\\Detail' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Detail.php',
    'Google\\Service\\ContainerAnalysis\\Details' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Details.php',
    'Google\\Service\\ContainerAnalysis\\Digest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Digest.php',
    'Google\\Service\\ContainerAnalysis\\Discovered' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Discovered.php',
    'Google\\Service\\ContainerAnalysis\\Discovery' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Discovery.php',
    'Google\\Service\\ContainerAnalysis\\DiscoveryNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DiscoveryNote.php',
    'Google\\Service\\ContainerAnalysis\\DiscoveryOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DiscoveryOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Distribution' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Distribution.php',
    'Google\\Service\\ContainerAnalysis\\DocumentNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DocumentNote.php',
    'Google\\Service\\ContainerAnalysis\\DocumentOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/DocumentOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Envelope' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Envelope.php',
    'Google\\Service\\ContainerAnalysis\\EnvelopeSignature' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/EnvelopeSignature.php',
    'Google\\Service\\ContainerAnalysis\\Environment' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Environment.php',
    'Google\\Service\\ContainerAnalysis\\ExportSBOMRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ExportSBOMRequest.php',
    'Google\\Service\\ContainerAnalysis\\ExportSBOMResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ExportSBOMResponse.php',
    'Google\\Service\\ContainerAnalysis\\Expr' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Expr.php',
    'Google\\Service\\ContainerAnalysis\\ExternalRef' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ExternalRef.php',
    'Google\\Service\\ContainerAnalysis\\FileHashes' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/FileHashes.php',
    'Google\\Service\\ContainerAnalysis\\FileNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/FileNote.php',
    'Google\\Service\\ContainerAnalysis\\FileOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/FileOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Fingerprint' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Fingerprint.php',
    'Google\\Service\\ContainerAnalysis\\FixableTotalByDigest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/FixableTotalByDigest.php',
    'Google\\Service\\ContainerAnalysis\\GeneratePackagesSummaryRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GeneratePackagesSummaryRequest.php',
    'Google\\Service\\ContainerAnalysis\\GenericSignedAttestation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GenericSignedAttestation.php',
    'Google\\Service\\ContainerAnalysis\\GerritSourceContext' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GerritSourceContext.php',
    'Google\\Service\\ContainerAnalysis\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GetIamPolicyRequest.php',
    'Google\\Service\\ContainerAnalysis\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GetPolicyOptions.php',
    'Google\\Service\\ContainerAnalysis\\GitSourceContext' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GitSourceContext.php',
    'Google\\Service\\ContainerAnalysis\\GoogleDevtoolsContaineranalysisV1alpha1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GoogleDevtoolsContaineranalysisV1alpha1OperationMetadata.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1FileLocation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1FileLocation.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1BuildDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1BuildDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1DeploymentDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1DeploymentDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1DiscoveryDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1DiscoveryDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1ImageDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1ImageDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1IntotoArtifact' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1IntotoArtifact.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1IntotoDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1IntotoDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1IntotoSignature' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1IntotoSignature.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1PackageDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1PackageDetails.php',
    'Google\\Service\\ContainerAnalysis\\GrafeasV1beta1VulnerabilityDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/GrafeasV1beta1VulnerabilityDetails.php',
    'Google\\Service\\ContainerAnalysis\\Hash' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Hash.php',
    'Google\\Service\\ContainerAnalysis\\Hint' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Hint.php',
    'Google\\Service\\ContainerAnalysis\\Identity' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Identity.php',
    'Google\\Service\\ContainerAnalysis\\ImageNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ImageNote.php',
    'Google\\Service\\ContainerAnalysis\\ImageOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ImageOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\InToto' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/InToto.php',
    'Google\\Service\\ContainerAnalysis\\InTotoProvenance' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/InTotoProvenance.php',
    'Google\\Service\\ContainerAnalysis\\InTotoSlsaProvenanceV1' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/InTotoSlsaProvenanceV1.php',
    'Google\\Service\\ContainerAnalysis\\InTotoStatement' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/InTotoStatement.php',
    'Google\\Service\\ContainerAnalysis\\Installation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Installation.php',
    'Google\\Service\\ContainerAnalysis\\Justification' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Justification.php',
    'Google\\Service\\ContainerAnalysis\\Jwt' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Jwt.php',
    'Google\\Service\\ContainerAnalysis\\KnowledgeBase' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/KnowledgeBase.php',
    'Google\\Service\\ContainerAnalysis\\Layer' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Layer.php',
    'Google\\Service\\ContainerAnalysis\\License' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/License.php',
    'Google\\Service\\ContainerAnalysis\\LicensesSummary' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/LicensesSummary.php',
    'Google\\Service\\ContainerAnalysis\\Link' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Link.php',
    'Google\\Service\\ContainerAnalysis\\ListNoteOccurrencesResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ListNoteOccurrencesResponse.php',
    'Google\\Service\\ContainerAnalysis\\ListNotesResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ListNotesResponse.php',
    'Google\\Service\\ContainerAnalysis\\ListOccurrencesResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ListOccurrencesResponse.php',
    'Google\\Service\\ContainerAnalysis\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ListOperationsResponse.php',
    'Google\\Service\\ContainerAnalysis\\ListScanConfigsResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ListScanConfigsResponse.php',
    'Google\\Service\\ContainerAnalysis\\Location' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Location.php',
    'Google\\Service\\ContainerAnalysis\\Material' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Material.php',
    'Google\\Service\\ContainerAnalysis\\Metadata' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Metadata.php',
    'Google\\Service\\ContainerAnalysis\\NonCompliantFile' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/NonCompliantFile.php',
    'Google\\Service\\ContainerAnalysis\\Note' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Note.php',
    'Google\\Service\\ContainerAnalysis\\Occurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Occurrence.php',
    'Google\\Service\\ContainerAnalysis\\Operation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Operation.php',
    'Google\\Service\\ContainerAnalysis\\Package' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Package.php',
    'Google\\Service\\ContainerAnalysis\\PackageIssue' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/PackageIssue.php',
    'Google\\Service\\ContainerAnalysis\\PackageNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/PackageNote.php',
    'Google\\Service\\ContainerAnalysis\\PackageOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/PackageOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\PackagesSummaryResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/PackagesSummaryResponse.php',
    'Google\\Service\\ContainerAnalysis\\PgpSignedAttestation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/PgpSignedAttestation.php',
    'Google\\Service\\ContainerAnalysis\\Policy' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Policy.php',
    'Google\\Service\\ContainerAnalysis\\Product' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Product.php',
    'Google\\Service\\ContainerAnalysis\\ProjectRepoId' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ProjectRepoId.php',
    'Google\\Service\\ContainerAnalysis\\ProvenanceBuilder' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ProvenanceBuilder.php',
    'Google\\Service\\ContainerAnalysis\\Publisher' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Publisher.php',
    'Google\\Service\\ContainerAnalysis\\Recipe' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Recipe.php',
    'Google\\Service\\ContainerAnalysis\\RelatedUrl' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/RelatedUrl.php',
    'Google\\Service\\ContainerAnalysis\\RelationshipNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/RelationshipNote.php',
    'Google\\Service\\ContainerAnalysis\\RelationshipOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/RelationshipOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Remediation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Remediation.php',
    'Google\\Service\\ContainerAnalysis\\RepoId' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/RepoId.php',
    'Google\\Service\\ContainerAnalysis\\ResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ResourceDescriptor.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/Operations.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/Projects.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsLocations.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsLocationsNotes' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsLocationsNotes.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsLocationsNotesOccurrences' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsLocationsNotesOccurrences.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsLocationsOccurrences' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsLocationsOccurrences.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsLocationsResources' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsLocationsResources.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsNotes' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsNotes.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsNotesOccurrences' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsNotesOccurrences.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsOccurrences' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsOccurrences.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsResources' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsResources.php',
    'Google\\Service\\ContainerAnalysis\\Resource\\ProjectsScanConfigs' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Resource/ProjectsScanConfigs.php',
    'Google\\Service\\ContainerAnalysis\\RunDetails' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/RunDetails.php',
    'Google\\Service\\ContainerAnalysis\\SBOMReferenceNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SBOMReferenceNote.php',
    'Google\\Service\\ContainerAnalysis\\SBOMReferenceOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SBOMReferenceOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\SBOMStatus' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SBOMStatus.php',
    'Google\\Service\\ContainerAnalysis\\SbomReferenceIntotoPayload' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SbomReferenceIntotoPayload.php',
    'Google\\Service\\ContainerAnalysis\\SbomReferenceIntotoPredicate' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SbomReferenceIntotoPredicate.php',
    'Google\\Service\\ContainerAnalysis\\ScanConfig' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/ScanConfig.php',
    'Google\\Service\\ContainerAnalysis\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SetIamPolicyRequest.php',
    'Google\\Service\\ContainerAnalysis\\Signature' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Signature.php',
    'Google\\Service\\ContainerAnalysis\\SigningKey' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SigningKey.php',
    'Google\\Service\\ContainerAnalysis\\SlsaBuilder' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaBuilder.php',
    'Google\\Service\\ContainerAnalysis\\SlsaCompleteness' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaCompleteness.php',
    'Google\\Service\\ContainerAnalysis\\SlsaMetadata' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaMetadata.php',
    'Google\\Service\\ContainerAnalysis\\SlsaProvenance' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaProvenance.php',
    'Google\\Service\\ContainerAnalysis\\SlsaProvenanceV1' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaProvenanceV1.php',
    'Google\\Service\\ContainerAnalysis\\SlsaProvenanceZeroTwo' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaProvenanceZeroTwo.php',
    'Google\\Service\\ContainerAnalysis\\SlsaRecipe' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SlsaRecipe.php',
    'Google\\Service\\ContainerAnalysis\\Source' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Source.php',
    'Google\\Service\\ContainerAnalysis\\SourceContext' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/SourceContext.php',
    'Google\\Service\\ContainerAnalysis\\Status' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Status.php',
    'Google\\Service\\ContainerAnalysis\\Subject' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Subject.php',
    'Google\\Service\\ContainerAnalysis\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/TestIamPermissionsRequest.php',
    'Google\\Service\\ContainerAnalysis\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/TestIamPermissionsResponse.php',
    'Google\\Service\\ContainerAnalysis\\TimeSpan' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/TimeSpan.php',
    'Google\\Service\\ContainerAnalysis\\UpgradeDistribution' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/UpgradeDistribution.php',
    'Google\\Service\\ContainerAnalysis\\UpgradeNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/UpgradeNote.php',
    'Google\\Service\\ContainerAnalysis\\UpgradeOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/UpgradeOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\Version' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Version.php',
    'Google\\Service\\ContainerAnalysis\\VexAssessment' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VexAssessment.php',
    'Google\\Service\\ContainerAnalysis\\Volume' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Volume.php',
    'Google\\Service\\ContainerAnalysis\\Vulnerability' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/Vulnerability.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityAssessmentNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityAssessmentNote.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityAttestation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityAttestation.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityLocation' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityLocation.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityNote' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityNote.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityOccurrence' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityOccurrence.php',
    'Google\\Service\\ContainerAnalysis\\VulnerabilityOccurrencesSummary' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/VulnerabilityOccurrencesSummary.php',
    'Google\\Service\\ContainerAnalysis\\WindowsDetail' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/WindowsDetail.php',
    'Google\\Service\\ContainerAnalysis\\WindowsUpdate' => $vendorDir . '/google/apiclient-services/src/ContainerAnalysis/WindowsUpdate.php',
    'Google\\Service\\Container\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/Container/AcceleratorConfig.php',
    'Google\\Service\\Container\\AdditionalNodeNetworkConfig' => $vendorDir . '/google/apiclient-services/src/Container/AdditionalNodeNetworkConfig.php',
    'Google\\Service\\Container\\AdditionalPodNetworkConfig' => $vendorDir . '/google/apiclient-services/src/Container/AdditionalPodNetworkConfig.php',
    'Google\\Service\\Container\\AdditionalPodRangesConfig' => $vendorDir . '/google/apiclient-services/src/Container/AdditionalPodRangesConfig.php',
    'Google\\Service\\Container\\AddonsConfig' => $vendorDir . '/google/apiclient-services/src/Container/AddonsConfig.php',
    'Google\\Service\\Container\\AdvancedDatapathObservabilityConfig' => $vendorDir . '/google/apiclient-services/src/Container/AdvancedDatapathObservabilityConfig.php',
    'Google\\Service\\Container\\AdvancedMachineFeatures' => $vendorDir . '/google/apiclient-services/src/Container/AdvancedMachineFeatures.php',
    'Google\\Service\\Container\\AuthenticatorGroupsConfig' => $vendorDir . '/google/apiclient-services/src/Container/AuthenticatorGroupsConfig.php',
    'Google\\Service\\Container\\AutoUpgradeOptions' => $vendorDir . '/google/apiclient-services/src/Container/AutoUpgradeOptions.php',
    'Google\\Service\\Container\\Autopilot' => $vendorDir . '/google/apiclient-services/src/Container/Autopilot.php',
    'Google\\Service\\Container\\AutopilotCompatibilityIssue' => $vendorDir . '/google/apiclient-services/src/Container/AutopilotCompatibilityIssue.php',
    'Google\\Service\\Container\\AutoprovisioningNodePoolDefaults' => $vendorDir . '/google/apiclient-services/src/Container/AutoprovisioningNodePoolDefaults.php',
    'Google\\Service\\Container\\BestEffortProvisioning' => $vendorDir . '/google/apiclient-services/src/Container/BestEffortProvisioning.php',
    'Google\\Service\\Container\\BigQueryDestination' => $vendorDir . '/google/apiclient-services/src/Container/BigQueryDestination.php',
    'Google\\Service\\Container\\BinaryAuthorization' => $vendorDir . '/google/apiclient-services/src/Container/BinaryAuthorization.php',
    'Google\\Service\\Container\\BlueGreenInfo' => $vendorDir . '/google/apiclient-services/src/Container/BlueGreenInfo.php',
    'Google\\Service\\Container\\BlueGreenSettings' => $vendorDir . '/google/apiclient-services/src/Container/BlueGreenSettings.php',
    'Google\\Service\\Container\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Container/CancelOperationRequest.php',
    'Google\\Service\\Container\\CertificateAuthorityDomainConfig' => $vendorDir . '/google/apiclient-services/src/Container/CertificateAuthorityDomainConfig.php',
    'Google\\Service\\Container\\CheckAutopilotCompatibilityResponse' => $vendorDir . '/google/apiclient-services/src/Container/CheckAutopilotCompatibilityResponse.php',
    'Google\\Service\\Container\\CidrBlock' => $vendorDir . '/google/apiclient-services/src/Container/CidrBlock.php',
    'Google\\Service\\Container\\ClientCertificateConfig' => $vendorDir . '/google/apiclient-services/src/Container/ClientCertificateConfig.php',
    'Google\\Service\\Container\\CloudRunConfig' => $vendorDir . '/google/apiclient-services/src/Container/CloudRunConfig.php',
    'Google\\Service\\Container\\Cluster' => $vendorDir . '/google/apiclient-services/src/Container/Cluster.php',
    'Google\\Service\\Container\\ClusterAutoscaling' => $vendorDir . '/google/apiclient-services/src/Container/ClusterAutoscaling.php',
    'Google\\Service\\Container\\ClusterNetworkPerformanceConfig' => $vendorDir . '/google/apiclient-services/src/Container/ClusterNetworkPerformanceConfig.php',
    'Google\\Service\\Container\\ClusterUpdate' => $vendorDir . '/google/apiclient-services/src/Container/ClusterUpdate.php',
    'Google\\Service\\Container\\CompleteIPRotationRequest' => $vendorDir . '/google/apiclient-services/src/Container/CompleteIPRotationRequest.php',
    'Google\\Service\\Container\\CompleteNodePoolUpgradeRequest' => $vendorDir . '/google/apiclient-services/src/Container/CompleteNodePoolUpgradeRequest.php',
    'Google\\Service\\Container\\ConfidentialNodes' => $vendorDir . '/google/apiclient-services/src/Container/ConfidentialNodes.php',
    'Google\\Service\\Container\\ConfigConnectorConfig' => $vendorDir . '/google/apiclient-services/src/Container/ConfigConnectorConfig.php',
    'Google\\Service\\Container\\ConsumptionMeteringConfig' => $vendorDir . '/google/apiclient-services/src/Container/ConsumptionMeteringConfig.php',
    'Google\\Service\\Container\\ContainerEmpty' => $vendorDir . '/google/apiclient-services/src/Container/ContainerEmpty.php',
    'Google\\Service\\Container\\ContainerdConfig' => $vendorDir . '/google/apiclient-services/src/Container/ContainerdConfig.php',
    'Google\\Service\\Container\\CostManagementConfig' => $vendorDir . '/google/apiclient-services/src/Container/CostManagementConfig.php',
    'Google\\Service\\Container\\CreateClusterRequest' => $vendorDir . '/google/apiclient-services/src/Container/CreateClusterRequest.php',
    'Google\\Service\\Container\\CreateNodePoolRequest' => $vendorDir . '/google/apiclient-services/src/Container/CreateNodePoolRequest.php',
    'Google\\Service\\Container\\DNSConfig' => $vendorDir . '/google/apiclient-services/src/Container/DNSConfig.php',
    'Google\\Service\\Container\\DailyMaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/Container/DailyMaintenanceWindow.php',
    'Google\\Service\\Container\\DatabaseEncryption' => $vendorDir . '/google/apiclient-services/src/Container/DatabaseEncryption.php',
    'Google\\Service\\Container\\DefaultSnatStatus' => $vendorDir . '/google/apiclient-services/src/Container/DefaultSnatStatus.php',
    'Google\\Service\\Container\\DnsCacheConfig' => $vendorDir . '/google/apiclient-services/src/Container/DnsCacheConfig.php',
    'Google\\Service\\Container\\EnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/Container/EnterpriseConfig.php',
    'Google\\Service\\Container\\EphemeralStorageLocalSsdConfig' => $vendorDir . '/google/apiclient-services/src/Container/EphemeralStorageLocalSsdConfig.php',
    'Google\\Service\\Container\\FastSocket' => $vendorDir . '/google/apiclient-services/src/Container/FastSocket.php',
    'Google\\Service\\Container\\Filter' => $vendorDir . '/google/apiclient-services/src/Container/Filter.php',
    'Google\\Service\\Container\\Fleet' => $vendorDir . '/google/apiclient-services/src/Container/Fleet.php',
    'Google\\Service\\Container\\GCPSecretManagerCertificateConfig' => $vendorDir . '/google/apiclient-services/src/Container/GCPSecretManagerCertificateConfig.php',
    'Google\\Service\\Container\\GPUDriverInstallationConfig' => $vendorDir . '/google/apiclient-services/src/Container/GPUDriverInstallationConfig.php',
    'Google\\Service\\Container\\GPUSharingConfig' => $vendorDir . '/google/apiclient-services/src/Container/GPUSharingConfig.php',
    'Google\\Service\\Container\\GatewayAPIConfig' => $vendorDir . '/google/apiclient-services/src/Container/GatewayAPIConfig.php',
    'Google\\Service\\Container\\GcePersistentDiskCsiDriverConfig' => $vendorDir . '/google/apiclient-services/src/Container/GcePersistentDiskCsiDriverConfig.php',
    'Google\\Service\\Container\\GcfsConfig' => $vendorDir . '/google/apiclient-services/src/Container/GcfsConfig.php',
    'Google\\Service\\Container\\GcpFilestoreCsiDriverConfig' => $vendorDir . '/google/apiclient-services/src/Container/GcpFilestoreCsiDriverConfig.php',
    'Google\\Service\\Container\\GcsFuseCsiDriverConfig' => $vendorDir . '/google/apiclient-services/src/Container/GcsFuseCsiDriverConfig.php',
    'Google\\Service\\Container\\GetJSONWebKeysResponse' => $vendorDir . '/google/apiclient-services/src/Container/GetJSONWebKeysResponse.php',
    'Google\\Service\\Container\\GetOpenIDConfigResponse' => $vendorDir . '/google/apiclient-services/src/Container/GetOpenIDConfigResponse.php',
    'Google\\Service\\Container\\GkeBackupAgentConfig' => $vendorDir . '/google/apiclient-services/src/Container/GkeBackupAgentConfig.php',
    'Google\\Service\\Container\\HorizontalPodAutoscaling' => $vendorDir . '/google/apiclient-services/src/Container/HorizontalPodAutoscaling.php',
    'Google\\Service\\Container\\HttpCacheControlResponseHeader' => $vendorDir . '/google/apiclient-services/src/Container/HttpCacheControlResponseHeader.php',
    'Google\\Service\\Container\\HttpLoadBalancing' => $vendorDir . '/google/apiclient-services/src/Container/HttpLoadBalancing.php',
    'Google\\Service\\Container\\HugepagesConfig' => $vendorDir . '/google/apiclient-services/src/Container/HugepagesConfig.php',
    'Google\\Service\\Container\\ILBSubsettingConfig' => $vendorDir . '/google/apiclient-services/src/Container/ILBSubsettingConfig.php',
    'Google\\Service\\Container\\IPAllocationPolicy' => $vendorDir . '/google/apiclient-services/src/Container/IPAllocationPolicy.php',
    'Google\\Service\\Container\\IdentityServiceConfig' => $vendorDir . '/google/apiclient-services/src/Container/IdentityServiceConfig.php',
    'Google\\Service\\Container\\IntraNodeVisibilityConfig' => $vendorDir . '/google/apiclient-services/src/Container/IntraNodeVisibilityConfig.php',
    'Google\\Service\\Container\\Jwk' => $vendorDir . '/google/apiclient-services/src/Container/Jwk.php',
    'Google\\Service\\Container\\K8sBetaAPIConfig' => $vendorDir . '/google/apiclient-services/src/Container/K8sBetaAPIConfig.php',
    'Google\\Service\\Container\\KubernetesDashboard' => $vendorDir . '/google/apiclient-services/src/Container/KubernetesDashboard.php',
    'Google\\Service\\Container\\LegacyAbac' => $vendorDir . '/google/apiclient-services/src/Container/LegacyAbac.php',
    'Google\\Service\\Container\\LinuxNodeConfig' => $vendorDir . '/google/apiclient-services/src/Container/LinuxNodeConfig.php',
    'Google\\Service\\Container\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/Container/ListClustersResponse.php',
    'Google\\Service\\Container\\ListNodePoolsResponse' => $vendorDir . '/google/apiclient-services/src/Container/ListNodePoolsResponse.php',
    'Google\\Service\\Container\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Container/ListOperationsResponse.php',
    'Google\\Service\\Container\\ListUsableSubnetworksResponse' => $vendorDir . '/google/apiclient-services/src/Container/ListUsableSubnetworksResponse.php',
    'Google\\Service\\Container\\LocalNvmeSsdBlockConfig' => $vendorDir . '/google/apiclient-services/src/Container/LocalNvmeSsdBlockConfig.php',
    'Google\\Service\\Container\\LoggingComponentConfig' => $vendorDir . '/google/apiclient-services/src/Container/LoggingComponentConfig.php',
    'Google\\Service\\Container\\LoggingConfig' => $vendorDir . '/google/apiclient-services/src/Container/LoggingConfig.php',
    'Google\\Service\\Container\\LoggingVariantConfig' => $vendorDir . '/google/apiclient-services/src/Container/LoggingVariantConfig.php',
    'Google\\Service\\Container\\MaintenanceExclusionOptions' => $vendorDir . '/google/apiclient-services/src/Container/MaintenanceExclusionOptions.php',
    'Google\\Service\\Container\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/Container/MaintenancePolicy.php',
    'Google\\Service\\Container\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/Container/MaintenanceWindow.php',
    'Google\\Service\\Container\\ManagedPrometheusConfig' => $vendorDir . '/google/apiclient-services/src/Container/ManagedPrometheusConfig.php',
    'Google\\Service\\Container\\MasterAuth' => $vendorDir . '/google/apiclient-services/src/Container/MasterAuth.php',
    'Google\\Service\\Container\\MasterAuthorizedNetworksConfig' => $vendorDir . '/google/apiclient-services/src/Container/MasterAuthorizedNetworksConfig.php',
    'Google\\Service\\Container\\MaxPodsConstraint' => $vendorDir . '/google/apiclient-services/src/Container/MaxPodsConstraint.php',
    'Google\\Service\\Container\\MeshCertificates' => $vendorDir . '/google/apiclient-services/src/Container/MeshCertificates.php',
    'Google\\Service\\Container\\Metric' => $vendorDir . '/google/apiclient-services/src/Container/Metric.php',
    'Google\\Service\\Container\\MonitoringComponentConfig' => $vendorDir . '/google/apiclient-services/src/Container/MonitoringComponentConfig.php',
    'Google\\Service\\Container\\MonitoringConfig' => $vendorDir . '/google/apiclient-services/src/Container/MonitoringConfig.php',
    'Google\\Service\\Container\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/Container/NetworkConfig.php',
    'Google\\Service\\Container\\NetworkPerformanceConfig' => $vendorDir . '/google/apiclient-services/src/Container/NetworkPerformanceConfig.php',
    'Google\\Service\\Container\\NetworkPolicy' => $vendorDir . '/google/apiclient-services/src/Container/NetworkPolicy.php',
    'Google\\Service\\Container\\NetworkPolicyConfig' => $vendorDir . '/google/apiclient-services/src/Container/NetworkPolicyConfig.php',
    'Google\\Service\\Container\\NetworkTags' => $vendorDir . '/google/apiclient-services/src/Container/NetworkTags.php',
    'Google\\Service\\Container\\NodeAffinity' => $vendorDir . '/google/apiclient-services/src/Container/NodeAffinity.php',
    'Google\\Service\\Container\\NodeConfig' => $vendorDir . '/google/apiclient-services/src/Container/NodeConfig.php',
    'Google\\Service\\Container\\NodeConfigDefaults' => $vendorDir . '/google/apiclient-services/src/Container/NodeConfigDefaults.php',
    'Google\\Service\\Container\\NodeKubeletConfig' => $vendorDir . '/google/apiclient-services/src/Container/NodeKubeletConfig.php',
    'Google\\Service\\Container\\NodeLabels' => $vendorDir . '/google/apiclient-services/src/Container/NodeLabels.php',
    'Google\\Service\\Container\\NodeManagement' => $vendorDir . '/google/apiclient-services/src/Container/NodeManagement.php',
    'Google\\Service\\Container\\NodeNetworkConfig' => $vendorDir . '/google/apiclient-services/src/Container/NodeNetworkConfig.php',
    'Google\\Service\\Container\\NodePool' => $vendorDir . '/google/apiclient-services/src/Container/NodePool.php',
    'Google\\Service\\Container\\NodePoolAutoConfig' => $vendorDir . '/google/apiclient-services/src/Container/NodePoolAutoConfig.php',
    'Google\\Service\\Container\\NodePoolAutoscaling' => $vendorDir . '/google/apiclient-services/src/Container/NodePoolAutoscaling.php',
    'Google\\Service\\Container\\NodePoolDefaults' => $vendorDir . '/google/apiclient-services/src/Container/NodePoolDefaults.php',
    'Google\\Service\\Container\\NodePoolLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Container/NodePoolLoggingConfig.php',
    'Google\\Service\\Container\\NodeTaint' => $vendorDir . '/google/apiclient-services/src/Container/NodeTaint.php',
    'Google\\Service\\Container\\NodeTaints' => $vendorDir . '/google/apiclient-services/src/Container/NodeTaints.php',
    'Google\\Service\\Container\\NotificationConfig' => $vendorDir . '/google/apiclient-services/src/Container/NotificationConfig.php',
    'Google\\Service\\Container\\Operation' => $vendorDir . '/google/apiclient-services/src/Container/Operation.php',
    'Google\\Service\\Container\\OperationError' => $vendorDir . '/google/apiclient-services/src/Container/OperationError.php',
    'Google\\Service\\Container\\OperationProgress' => $vendorDir . '/google/apiclient-services/src/Container/OperationProgress.php',
    'Google\\Service\\Container\\ParentProductConfig' => $vendorDir . '/google/apiclient-services/src/Container/ParentProductConfig.php',
    'Google\\Service\\Container\\PlacementPolicy' => $vendorDir . '/google/apiclient-services/src/Container/PlacementPolicy.php',
    'Google\\Service\\Container\\PodCIDROverprovisionConfig' => $vendorDir . '/google/apiclient-services/src/Container/PodCIDROverprovisionConfig.php',
    'Google\\Service\\Container\\PrivateClusterConfig' => $vendorDir . '/google/apiclient-services/src/Container/PrivateClusterConfig.php',
    'Google\\Service\\Container\\PrivateClusterMasterGlobalAccessConfig' => $vendorDir . '/google/apiclient-services/src/Container/PrivateClusterMasterGlobalAccessConfig.php',
    'Google\\Service\\Container\\PrivateRegistryAccessConfig' => $vendorDir . '/google/apiclient-services/src/Container/PrivateRegistryAccessConfig.php',
    'Google\\Service\\Container\\PubSub' => $vendorDir . '/google/apiclient-services/src/Container/PubSub.php',
    'Google\\Service\\Container\\QueuedProvisioning' => $vendorDir . '/google/apiclient-services/src/Container/QueuedProvisioning.php',
    'Google\\Service\\Container\\RBACBindingConfig' => $vendorDir . '/google/apiclient-services/src/Container/RBACBindingConfig.php',
    'Google\\Service\\Container\\RangeInfo' => $vendorDir . '/google/apiclient-services/src/Container/RangeInfo.php',
    'Google\\Service\\Container\\RayClusterLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Container/RayClusterLoggingConfig.php',
    'Google\\Service\\Container\\RayClusterMonitoringConfig' => $vendorDir . '/google/apiclient-services/src/Container/RayClusterMonitoringConfig.php',
    'Google\\Service\\Container\\RayOperatorConfig' => $vendorDir . '/google/apiclient-services/src/Container/RayOperatorConfig.php',
    'Google\\Service\\Container\\RecurringTimeWindow' => $vendorDir . '/google/apiclient-services/src/Container/RecurringTimeWindow.php',
    'Google\\Service\\Container\\ReleaseChannel' => $vendorDir . '/google/apiclient-services/src/Container/ReleaseChannel.php',
    'Google\\Service\\Container\\ReleaseChannelConfig' => $vendorDir . '/google/apiclient-services/src/Container/ReleaseChannelConfig.php',
    'Google\\Service\\Container\\ReservationAffinity' => $vendorDir . '/google/apiclient-services/src/Container/ReservationAffinity.php',
    'Google\\Service\\Container\\ResourceLabels' => $vendorDir . '/google/apiclient-services/src/Container/ResourceLabels.php',
    'Google\\Service\\Container\\ResourceLimit' => $vendorDir . '/google/apiclient-services/src/Container/ResourceLimit.php',
    'Google\\Service\\Container\\ResourceManagerTags' => $vendorDir . '/google/apiclient-services/src/Container/ResourceManagerTags.php',
    'Google\\Service\\Container\\ResourceUsageExportConfig' => $vendorDir . '/google/apiclient-services/src/Container/ResourceUsageExportConfig.php',
    'Google\\Service\\Container\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Container/Resource/Projects.php',
    'Google\\Service\\Container\\Resource\\ProjectsAggregated' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsAggregated.php',
    'Google\\Service\\Container\\Resource\\ProjectsAggregatedUsableSubnetworks' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsAggregatedUsableSubnetworks.php',
    'Google\\Service\\Container\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsLocations.php',
    'Google\\Service\\Container\\Resource\\ProjectsLocationsClusters' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsLocationsClusters.php',
    'Google\\Service\\Container\\Resource\\ProjectsLocationsClustersNodePools' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsLocationsClustersNodePools.php',
    'Google\\Service\\Container\\Resource\\ProjectsLocationsClustersWellKnown' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsLocationsClustersWellKnown.php',
    'Google\\Service\\Container\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Container\\Resource\\ProjectsZones' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsZones.php',
    'Google\\Service\\Container\\Resource\\ProjectsZonesClusters' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsZonesClusters.php',
    'Google\\Service\\Container\\Resource\\ProjectsZonesClustersNodePools' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsZonesClustersNodePools.php',
    'Google\\Service\\Container\\Resource\\ProjectsZonesOperations' => $vendorDir . '/google/apiclient-services/src/Container/Resource/ProjectsZonesOperations.php',
    'Google\\Service\\Container\\RollbackNodePoolUpgradeRequest' => $vendorDir . '/google/apiclient-services/src/Container/RollbackNodePoolUpgradeRequest.php',
    'Google\\Service\\Container\\SandboxConfig' => $vendorDir . '/google/apiclient-services/src/Container/SandboxConfig.php',
    'Google\\Service\\Container\\SecondaryBootDisk' => $vendorDir . '/google/apiclient-services/src/Container/SecondaryBootDisk.php',
    'Google\\Service\\Container\\SecondaryBootDiskUpdateStrategy' => $vendorDir . '/google/apiclient-services/src/Container/SecondaryBootDiskUpdateStrategy.php',
    'Google\\Service\\Container\\SecretManagerConfig' => $vendorDir . '/google/apiclient-services/src/Container/SecretManagerConfig.php',
    'Google\\Service\\Container\\SecurityBulletinEvent' => $vendorDir . '/google/apiclient-services/src/Container/SecurityBulletinEvent.php',
    'Google\\Service\\Container\\SecurityPostureConfig' => $vendorDir . '/google/apiclient-services/src/Container/SecurityPostureConfig.php',
    'Google\\Service\\Container\\ServerConfig' => $vendorDir . '/google/apiclient-services/src/Container/ServerConfig.php',
    'Google\\Service\\Container\\ServiceExternalIPsConfig' => $vendorDir . '/google/apiclient-services/src/Container/ServiceExternalIPsConfig.php',
    'Google\\Service\\Container\\SetAddonsConfigRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetAddonsConfigRequest.php',
    'Google\\Service\\Container\\SetLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetLabelsRequest.php',
    'Google\\Service\\Container\\SetLegacyAbacRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetLegacyAbacRequest.php',
    'Google\\Service\\Container\\SetLocationsRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetLocationsRequest.php',
    'Google\\Service\\Container\\SetLoggingServiceRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetLoggingServiceRequest.php',
    'Google\\Service\\Container\\SetMaintenancePolicyRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetMaintenancePolicyRequest.php',
    'Google\\Service\\Container\\SetMasterAuthRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetMasterAuthRequest.php',
    'Google\\Service\\Container\\SetMonitoringServiceRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetMonitoringServiceRequest.php',
    'Google\\Service\\Container\\SetNetworkPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetNetworkPolicyRequest.php',
    'Google\\Service\\Container\\SetNodePoolAutoscalingRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetNodePoolAutoscalingRequest.php',
    'Google\\Service\\Container\\SetNodePoolManagementRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetNodePoolManagementRequest.php',
    'Google\\Service\\Container\\SetNodePoolSizeRequest' => $vendorDir . '/google/apiclient-services/src/Container/SetNodePoolSizeRequest.php',
    'Google\\Service\\Container\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Container/ShieldedInstanceConfig.php',
    'Google\\Service\\Container\\ShieldedNodes' => $vendorDir . '/google/apiclient-services/src/Container/ShieldedNodes.php',
    'Google\\Service\\Container\\SoleTenantConfig' => $vendorDir . '/google/apiclient-services/src/Container/SoleTenantConfig.php',
    'Google\\Service\\Container\\StandardRolloutPolicy' => $vendorDir . '/google/apiclient-services/src/Container/StandardRolloutPolicy.php',
    'Google\\Service\\Container\\StartIPRotationRequest' => $vendorDir . '/google/apiclient-services/src/Container/StartIPRotationRequest.php',
    'Google\\Service\\Container\\StatefulHAConfig' => $vendorDir . '/google/apiclient-services/src/Container/StatefulHAConfig.php',
    'Google\\Service\\Container\\Status' => $vendorDir . '/google/apiclient-services/src/Container/Status.php',
    'Google\\Service\\Container\\StatusCondition' => $vendorDir . '/google/apiclient-services/src/Container/StatusCondition.php',
    'Google\\Service\\Container\\TimeWindow' => $vendorDir . '/google/apiclient-services/src/Container/TimeWindow.php',
    'Google\\Service\\Container\\UpdateClusterRequest' => $vendorDir . '/google/apiclient-services/src/Container/UpdateClusterRequest.php',
    'Google\\Service\\Container\\UpdateInfo' => $vendorDir . '/google/apiclient-services/src/Container/UpdateInfo.php',
    'Google\\Service\\Container\\UpdateMasterRequest' => $vendorDir . '/google/apiclient-services/src/Container/UpdateMasterRequest.php',
    'Google\\Service\\Container\\UpdateNodePoolRequest' => $vendorDir . '/google/apiclient-services/src/Container/UpdateNodePoolRequest.php',
    'Google\\Service\\Container\\UpgradeAvailableEvent' => $vendorDir . '/google/apiclient-services/src/Container/UpgradeAvailableEvent.php',
    'Google\\Service\\Container\\UpgradeEvent' => $vendorDir . '/google/apiclient-services/src/Container/UpgradeEvent.php',
    'Google\\Service\\Container\\UpgradeSettings' => $vendorDir . '/google/apiclient-services/src/Container/UpgradeSettings.php',
    'Google\\Service\\Container\\UsableSubnetwork' => $vendorDir . '/google/apiclient-services/src/Container/UsableSubnetwork.php',
    'Google\\Service\\Container\\UsableSubnetworkSecondaryRange' => $vendorDir . '/google/apiclient-services/src/Container/UsableSubnetworkSecondaryRange.php',
    'Google\\Service\\Container\\VerticalPodAutoscaling' => $vendorDir . '/google/apiclient-services/src/Container/VerticalPodAutoscaling.php',
    'Google\\Service\\Container\\VirtualNIC' => $vendorDir . '/google/apiclient-services/src/Container/VirtualNIC.php',
    'Google\\Service\\Container\\WindowsNodeConfig' => $vendorDir . '/google/apiclient-services/src/Container/WindowsNodeConfig.php',
    'Google\\Service\\Container\\WorkloadIdentityConfig' => $vendorDir . '/google/apiclient-services/src/Container/WorkloadIdentityConfig.php',
    'Google\\Service\\Container\\WorkloadMetadataConfig' => $vendorDir . '/google/apiclient-services/src/Container/WorkloadMetadataConfig.php',
    'Google\\Service\\Container\\WorkloadPolicyConfig' => $vendorDir . '/google/apiclient-services/src/Container/WorkloadPolicyConfig.php',
    'Google\\Service\\Contentwarehouse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceCloudSqlInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceCloudSqlInstanceConfig.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceGcsBucketConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceGcsBucketConfig.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceIamPolicyBinding' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceIamPolicyBinding.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceInfraSpannerConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceInfraSpannerConfig.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceServiceAccountIdentity' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceServiceAccountIdentity.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceTenantProjectConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceTenantProjectConfig.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceTenantProjectResource' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceTenantProjectResource.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceTenantResource' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceTenantResource.php',
    'Google\\Service\\Contentwarehouse\\CloudAiPlatformTenantresourceTenantServiceAccountIdentity' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/CloudAiPlatformTenantresourceTenantServiceAccountIdentity.php',
    'Google\\Service\\Contentwarehouse\\GoogleApiServiceconsumermanagementV1BillingConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleApiServiceconsumermanagementV1BillingConfig.php',
    'Google\\Service\\Contentwarehouse\\GoogleApiServiceconsumermanagementV1PolicyBinding' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleApiServiceconsumermanagementV1PolicyBinding.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1AccessControlAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1AccessControlAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1Action' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1Action.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ActionExecutorOutput' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ActionExecutorOutput.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ActionOutput' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ActionOutput.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1AddToFolderAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1AddToFolderAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CloudAIDocumentOption' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CloudAIDocumentOption.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CreateDocumentLinkRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CreateDocumentLinkRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CreateDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CreateDocumentMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CreateDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CreateDocumentRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CreateDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CreateDocumentResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1CustomWeightsMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1CustomWeightsMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DataUpdateAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DataUpdateAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DataValidationAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DataValidationAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DateTimeArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DateTimeArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DateTimeTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DateTimeTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DeleteDocumentAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DeleteDocumentAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DeleteDocumentLinkRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DeleteDocumentLinkRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DeleteDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DeleteDocumentRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1Document' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1Document.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DocumentLink' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DocumentLink.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DocumentQuery' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DocumentQuery.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DocumentReference' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DocumentReference.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1DocumentSchema' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1DocumentSchema.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1EnumArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1EnumArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1EnumTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1EnumTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1EnumValue' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1EnumValue.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ExportToCdwPipeline' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ExportToCdwPipeline.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1FetchAclRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1FetchAclRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1FetchAclResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1FetchAclResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1FileTypeFilter' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1FileTypeFilter.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1FloatArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1FloatArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1FloatTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1FloatTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1GcsIngestPipeline' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1GcsIngestPipeline.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1GetDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1GetDocumentRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1HistogramQuery' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1HistogramQuery.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1HistogramQueryResult' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1HistogramQueryResult.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1IngestPipelineConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1IngestPipelineConfig.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1InitializeProjectRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1InitializeProjectRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1InitializeProjectResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1InitializeProjectResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1IntegerArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1IntegerArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1IntegerTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1IntegerTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1InvalidRule' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1InvalidRule.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListDocumentSchemasResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListDocumentSchemasResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListLinkedSourcesRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListLinkedSourcesRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListLinkedSourcesResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListLinkedSourcesResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListLinkedTargetsRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListLinkedTargetsRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListLinkedTargetsResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListLinkedTargetsResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListRuleSetsResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListRuleSetsResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ListSynonymSetsResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ListSynonymSetsResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1LockDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1LockDocumentRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1MapProperty' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1MapProperty.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1MapTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1MapTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1MergeFieldsOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1MergeFieldsOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ProcessorInfo' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ProcessorInfo.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ProjectStatus' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ProjectStatus.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1Property' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1Property.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PropertyArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PropertyArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PropertyDefinition' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PropertyDefinition.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PropertyDefinitionSchemaSource' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PropertyDefinitionSchemaSource.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PropertyFilter' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PropertyFilter.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PropertyTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PropertyTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1PublishAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1PublishAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1QAResult' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1QAResult.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1QAResultHighlight' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1QAResultHighlight.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RemoveFromFolderAction' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RemoveFromFolderAction.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RequestMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RequestMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1ResponseMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1ResponseMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1Rule' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1Rule.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RuleActionsPair' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RuleActionsPair.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RuleEngineOutput' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RuleEngineOutput.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RuleEvaluatorOutput' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RuleEvaluatorOutput.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RuleSet' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RuleSet.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineMetadataGcsIngestPipelineMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineMetadataGcsIngestPipelineMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1RunPipelineRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1RunPipelineRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SearchDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SearchDocumentsRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SearchDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SearchDocumentsResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SetAclRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SetAclRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SetAclResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SetAclResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SynonymSet' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SynonymSet.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1SynonymSetSynonym' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1SynonymSetSynonym.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TextArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TextArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TextTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TextTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TimeFilter' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TimeFilter.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TimestampArray' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TimestampArray.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TimestampTypeOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TimestampTypeOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1TimestampValue' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1TimestampValue.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateDocumentMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateDocumentRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateDocumentResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateDocumentSchemaRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateDocumentSchemaRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateOptions' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateOptions.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UpdateRuleSetRequest' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UpdateRuleSetRequest.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1UserInfo' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1UserInfo.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1Value' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1Value.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1WeightedSchemaProperty' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1WeightedSchemaProperty.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1beta1CreateDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1beta1CreateDocumentMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1beta1InitializeProjectResponse' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1beta1InitializeProjectResponse.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudContentwarehouseV1beta1UpdateDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudContentwarehouseV1beta1UpdateDocumentMetadata.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1Barcode' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1Barcode.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1BoundingPoly.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1Document' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1Document.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentChunkedDocument' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentChunkedDocument.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayout' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayout.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentEntity' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentEntity.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentEntityNormalizedValue' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentEntityNormalizedValue.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentEntityRelation' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentEntityRelation.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPage' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPage.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageAnchor' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageAnchor.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageAnchorPageRef' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageBlock' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageBlock.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageDetectedBarcode' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageDetectedBarcode.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageDetectedLanguage.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageDimension' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageDimension.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageFormField' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageFormField.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageImage' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageImage.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageImageQualityScores' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageImageQualityScores.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageImageQualityScoresDetectedDefect' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageImageQualityScoresDetectedDefect.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageLayout' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageLayout.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageLine' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageLine.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageMatrix' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageMatrix.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageParagraph' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageParagraph.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageSymbol' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageSymbol.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageTable' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageTable.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageTableTableCell' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageTableTableCell.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageTableTableRow' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageTableTableRow.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageToken' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageToken.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentPageVisualElement' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentPageVisualElement.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentProvenance' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentProvenance.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentProvenanceParent' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentProvenanceParent.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentRevision' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentRevision.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentRevisionHumanReview' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentRevisionHumanReview.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentShardInfo' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentShardInfo.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentStyle' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentStyle.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentStyleFontSize' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentStyleFontSize.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentTextAnchor' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentTextAnchor.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1DocumentTextChange' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1DocumentTextChange.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1NormalizedVertex.php',
    'Google\\Service\\Contentwarehouse\\GoogleCloudDocumentaiV1Vertex' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleCloudDocumentaiV1Vertex.php',
    'Google\\Service\\Contentwarehouse\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleIamV1AuditConfig.php',
    'Google\\Service\\Contentwarehouse\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\Contentwarehouse\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleIamV1Binding.php',
    'Google\\Service\\Contentwarehouse\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleIamV1Policy.php',
    'Google\\Service\\Contentwarehouse\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleLongrunningOperation.php',
    'Google\\Service\\Contentwarehouse\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleProtobufEmpty.php',
    'Google\\Service\\Contentwarehouse\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleRpcStatus.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeColor' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeColor.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeDate.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeDateTime' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeDateTime.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeExpr.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeInterval' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeInterval.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeMoney.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypePostalAddress' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypePostalAddress.php',
    'Google\\Service\\Contentwarehouse\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/GoogleTypeTimeZone.php',
    'Google\\Service\\Contentwarehouse\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/Projects.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocations.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsDocumentSchemas' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsDocumentSchemas.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsDocuments' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsDocuments.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsDocumentsDocumentLinks' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsDocumentsDocumentLinks.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsDocumentsReferenceId' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsDocumentsReferenceId.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsRuleSets' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsRuleSets.php',
    'Google\\Service\\Contentwarehouse\\Resource\\ProjectsLocationsSynonymSets' => $vendorDir . '/google/apiclient-services/src/Contentwarehouse/Resource/ProjectsLocationsSynonymSets.php',
    'Google\\Service\\Css' => $vendorDir . '/google/apiclient-services/src/Css.php',
    'Google\\Service\\Css\\Account' => $vendorDir . '/google/apiclient-services/src/Css/Account.php',
    'Google\\Service\\Css\\AccountLabel' => $vendorDir . '/google/apiclient-services/src/Css/AccountLabel.php',
    'Google\\Service\\Css\\Attributes' => $vendorDir . '/google/apiclient-services/src/Css/Attributes.php',
    'Google\\Service\\Css\\Certification' => $vendorDir . '/google/apiclient-services/src/Css/Certification.php',
    'Google\\Service\\Css\\CssEmpty' => $vendorDir . '/google/apiclient-services/src/Css/CssEmpty.php',
    'Google\\Service\\Css\\CssProduct' => $vendorDir . '/google/apiclient-services/src/Css/CssProduct.php',
    'Google\\Service\\Css\\CssProductInput' => $vendorDir . '/google/apiclient-services/src/Css/CssProductInput.php',
    'Google\\Service\\Css\\CssProductStatus' => $vendorDir . '/google/apiclient-services/src/Css/CssProductStatus.php',
    'Google\\Service\\Css\\CustomAttribute' => $vendorDir . '/google/apiclient-services/src/Css/CustomAttribute.php',
    'Google\\Service\\Css\\DestinationStatus' => $vendorDir . '/google/apiclient-services/src/Css/DestinationStatus.php',
    'Google\\Service\\Css\\ItemLevelIssue' => $vendorDir . '/google/apiclient-services/src/Css/ItemLevelIssue.php',
    'Google\\Service\\Css\\ListAccountLabelsResponse' => $vendorDir . '/google/apiclient-services/src/Css/ListAccountLabelsResponse.php',
    'Google\\Service\\Css\\ListChildAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Css/ListChildAccountsResponse.php',
    'Google\\Service\\Css\\ListCssProductsResponse' => $vendorDir . '/google/apiclient-services/src/Css/ListCssProductsResponse.php',
    'Google\\Service\\Css\\Price' => $vendorDir . '/google/apiclient-services/src/Css/Price.php',
    'Google\\Service\\Css\\ProductDetail' => $vendorDir . '/google/apiclient-services/src/Css/ProductDetail.php',
    'Google\\Service\\Css\\ProductDimension' => $vendorDir . '/google/apiclient-services/src/Css/ProductDimension.php',
    'Google\\Service\\Css\\ProductWeight' => $vendorDir . '/google/apiclient-services/src/Css/ProductWeight.php',
    'Google\\Service\\Css\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Css/Resource/Accounts.php',
    'Google\\Service\\Css\\Resource\\AccountsCssProductInputs' => $vendorDir . '/google/apiclient-services/src/Css/Resource/AccountsCssProductInputs.php',
    'Google\\Service\\Css\\Resource\\AccountsCssProducts' => $vendorDir . '/google/apiclient-services/src/Css/Resource/AccountsCssProducts.php',
    'Google\\Service\\Css\\Resource\\AccountsLabels' => $vendorDir . '/google/apiclient-services/src/Css/Resource/AccountsLabels.php',
    'Google\\Service\\Css\\UpdateAccountLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Css/UpdateAccountLabelsRequest.php',
    'Google\\Service\\CustomSearchAPI' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI.php',
    'Google\\Service\\CustomSearchAPI\\Promotion' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/Promotion.php',
    'Google\\Service\\CustomSearchAPI\\PromotionBodyLines' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/PromotionBodyLines.php',
    'Google\\Service\\CustomSearchAPI\\PromotionImage' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/PromotionImage.php',
    'Google\\Service\\CustomSearchAPI\\Resource\\Cse' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/Resource/Cse.php',
    'Google\\Service\\CustomSearchAPI\\Resource\\CseSiterestrict' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/Resource/CseSiterestrict.php',
    'Google\\Service\\CustomSearchAPI\\Result' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/Result.php',
    'Google\\Service\\CustomSearchAPI\\ResultImage' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/ResultImage.php',
    'Google\\Service\\CustomSearchAPI\\ResultLabels' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/ResultLabels.php',
    'Google\\Service\\CustomSearchAPI\\Search' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/Search.php',
    'Google\\Service\\CustomSearchAPI\\SearchQueries' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchQueries.php',
    'Google\\Service\\CustomSearchAPI\\SearchQueriesNextPage' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchQueriesNextPage.php',
    'Google\\Service\\CustomSearchAPI\\SearchQueriesPreviousPage' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchQueriesPreviousPage.php',
    'Google\\Service\\CustomSearchAPI\\SearchQueriesRequest' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchQueriesRequest.php',
    'Google\\Service\\CustomSearchAPI\\SearchSearchInformation' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchSearchInformation.php',
    'Google\\Service\\CustomSearchAPI\\SearchSpelling' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchSpelling.php',
    'Google\\Service\\CustomSearchAPI\\SearchUrl' => $vendorDir . '/google/apiclient-services/src/CustomSearchAPI/SearchUrl.php',
    'Google\\Service\\DLP' => $vendorDir . '/google/apiclient-services/src/DLP.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Action' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Action.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ActionDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ActionDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ActivateJobTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ActivateJobTriggerRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AllInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AllInfoTypes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AllOtherBigQueryTables' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AllOtherBigQueryTables.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AllOtherDatabaseResources' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AllOtherDatabaseResources.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AllOtherResources' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AllOtherResources.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AllText' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AllText.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AnalyzeDataSourceRiskDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AnalyzeDataSourceRiskDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2AuxiliaryTable' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2AuxiliaryTable.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryDiscoveryTarget' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryDiscoveryTarget.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryField' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryField.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryRegex' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryRegex.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryRegexes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryRegexes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryTable' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryTable.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryTableCollection' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryTableCollection.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BigQueryTableTypes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BigQueryTableTypes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BoundingBox' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BoundingBox.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Bucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Bucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2BucketingConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2BucketingConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ByteContentItem' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ByteContentItem.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CancelDlpJobRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CancelDlpJobRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CategoricalStatsConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CategoricalStatsConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CategoricalStatsHistogramBucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CategoricalStatsHistogramBucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CategoricalStatsResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CategoricalStatsResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CharacterMaskConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CharacterMaskConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CharsToIgnore' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CharsToIgnore.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudSqlDiscoveryTarget' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudSqlDiscoveryTarget.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudSqlIamCredential' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudSqlIamCredential.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudSqlProperties' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudSqlProperties.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageDiscoveryTarget' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageDiscoveryTarget.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageFileSet' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageFileSet.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStoragePath' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStoragePath.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageRegex' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageRegex.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageRegexFileSet' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageRegexFileSet.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CloudStorageResourceReference' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CloudStorageResourceReference.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Color' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Color.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ColumnDataProfile' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ColumnDataProfile.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Condition' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Condition.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Conditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Conditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Connection' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Connection.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Container' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Container.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ContentItem' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ContentItem.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ContentLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ContentLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateConnectionRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateConnectionRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateDeidentifyTemplateRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateDeidentifyTemplateRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateDiscoveryConfigRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateDiscoveryConfigRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateDlpJobRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateDlpJobRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateInspectTemplateRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateInspectTemplateRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateJobTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateJobTriggerRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CreateStoredInfoTypeRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CreateStoredInfoTypeRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CryptoDeterministicConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CryptoDeterministicConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CryptoHashConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CryptoHashConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CryptoKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CryptoKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CryptoReplaceFfxFpeConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CryptoReplaceFfxFpeConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2CustomInfoType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2CustomInfoType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfileAction' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfileAction.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfileBigQueryRowSchema' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfileBigQueryRowSchema.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfileConfigSnapshot' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfileConfigSnapshot.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfileJobConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfileJobConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfileLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfileLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfilePubSubCondition' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfilePubSubCondition.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataProfilePubSubMessage' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataProfilePubSubMessage.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataRiskLevel' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataRiskLevel.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DataSourceType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DataSourceType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatabaseResourceCollection' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatabaseResourceCollection.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatabaseResourceReference' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatabaseResourceReference.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatabaseResourceRegex' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatabaseResourceRegex.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatabaseResourceRegexes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatabaseResourceRegexes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatastoreKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatastoreKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DatastoreOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DatastoreOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DateShiftConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DateShiftConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DateTime' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DateTime.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Deidentify' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Deidentify.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyContentRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyContentRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyContentResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyContentResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyDataSourceDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyDataSourceDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyDataSourceStats' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyDataSourceStats.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeidentifyTemplate' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeidentifyTemplate.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeltaPresenceEstimationConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeltaPresenceEstimationConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeltaPresenceEstimationHistogramBucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeltaPresenceEstimationHistogramBucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeltaPresenceEstimationQuasiIdValues' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeltaPresenceEstimationQuasiIdValues.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DeltaPresenceEstimationResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DeltaPresenceEstimationResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DetectionRule' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DetectionRule.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Dictionary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Dictionary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Disabled' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Disabled.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryBigQueryConditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryBigQueryConditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryBigQueryFilter' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryBigQueryFilter.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudSqlConditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudSqlConditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudSqlFilter' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudSqlFilter.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudStorageConditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudStorageConditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudStorageFilter' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudStorageFilter.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryFileStoreConditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryFileStoreConditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryGenerationCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryGenerationCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoverySchemaModifiedCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoverySchemaModifiedCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryStartingLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryStartingLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryTableModifiedCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryTableModifiedCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DiscoveryTarget' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DiscoveryTarget.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DlpJob' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DlpJob.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2DocumentLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2DocumentLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2EntityId' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2EntityId.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Error' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Error.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ExcludeByHotword' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ExcludeByHotword.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ExcludeInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ExcludeInfoTypes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ExclusionRule' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ExclusionRule.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Export' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Export.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Expressions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Expressions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FieldId' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FieldId.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FieldTransformation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FieldTransformation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileClusterSummary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileClusterSummary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileClusterType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileClusterType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileExtensionInfo' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileExtensionInfo.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileSet' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileSet.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileStoreCollection' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileStoreCollection.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileStoreDataProfile' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileStoreDataProfile.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileStoreInfoTypeSummary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileStoreInfoTypeSummary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileStoreRegex' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileStoreRegex.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FileStoreRegexes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FileStoreRegexes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Finding' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Finding.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FindingLimits' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FindingLimits.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FinishDlpJobRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FinishDlpJobRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2FixedSizeBucketingConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2FixedSizeBucketingConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HotwordRule' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HotwordRule.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridContentItem' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridContentItem.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridFindingDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridFindingDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridInspectDlpJobRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridInspectDlpJobRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridInspectJobTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridInspectJobTriggerRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridInspectResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridInspectResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridInspectStatistics' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridInspectStatistics.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2HybridOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2HybridOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ImageLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ImageLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ImageRedactionConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ImageRedactionConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ImageTransformation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ImageTransformation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ImageTransformations' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ImageTransformations.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeCategory' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeCategory.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeDescription' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeDescription.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeLikelihood' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeLikelihood.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeLimit' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeLimit.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeStats' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeStats.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeSummary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeSummary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeTransformation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeTransformation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InfoTypeTransformations' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InfoTypeTransformations.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectContentRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectContentRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectContentResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectContentResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectDataSourceDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectDataSourceDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectJobConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectJobConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectTemplate' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectTemplate.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectionRule' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectionRule.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2InspectionRuleSet' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2InspectionRuleSet.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2JobNotificationEmails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2JobNotificationEmails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2JobTrigger' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2JobTrigger.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KAnonymityConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KAnonymityConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KAnonymityEquivalenceClass' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KAnonymityEquivalenceClass.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KAnonymityHistogramBucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KAnonymityHistogramBucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KAnonymityResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KAnonymityResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KMapEstimationConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KMapEstimationConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KMapEstimationHistogramBucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KMapEstimationHistogramBucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KMapEstimationQuasiIdValues' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KMapEstimationQuasiIdValues.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KMapEstimationResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KMapEstimationResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Key' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Key.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KindExpression' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KindExpression.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2KmsWrappedCryptoKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2KmsWrappedCryptoKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LDiversityConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LDiversityConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LDiversityEquivalenceClass' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LDiversityEquivalenceClass.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LDiversityHistogramBucket' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LDiversityHistogramBucket.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LDiversityResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LDiversityResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LargeCustomDictionaryConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LargeCustomDictionaryConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LargeCustomDictionaryStats' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LargeCustomDictionaryStats.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LeaveUntransformed' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LeaveUntransformed.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2LikelihoodAdjustment' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2LikelihoodAdjustment.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListColumnDataProfilesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListColumnDataProfilesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListConnectionsResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListDeidentifyTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListDeidentifyTemplatesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListDiscoveryConfigsResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListDiscoveryConfigsResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListDlpJobsResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListDlpJobsResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListFileStoreDataProfilesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListFileStoreDataProfilesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListInfoTypesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListInfoTypesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListInspectTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListInspectTemplatesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListJobTriggersResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListJobTriggersResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListProjectDataProfilesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListProjectDataProfilesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListStoredInfoTypesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListStoredInfoTypesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ListTableDataProfilesResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ListTableDataProfilesResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Location' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Location.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Manual' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Manual.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2MetadataLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2MetadataLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2NumericalStatsConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2NumericalStatsConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2NumericalStatsResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2NumericalStatsResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2OrConditions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2OrConditions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2OrgConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2OrgConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2OtherInfoTypeSummary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2OtherInfoTypeSummary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2OutputStorageConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2OutputStorageConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PartitionId' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PartitionId.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PathElement' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PathElement.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PrimitiveTransformation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PrimitiveTransformation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PrivacyMetric' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PrivacyMetric.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ProfileStatus' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ProfileStatus.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ProjectDataProfile' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ProjectDataProfile.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Proximity' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Proximity.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PubSubCondition' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PubSubCondition.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PubSubExpressions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PubSubExpressions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PubSubNotification' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PubSubNotification.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishSummaryToCscc' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishSummaryToCscc.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishToChronicle' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishToChronicle.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishToPubSub' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishToPubSub.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishToSecurityCommandCenter' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishToSecurityCommandCenter.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2PublishToStackdriver' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2PublishToStackdriver.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2QuasiId' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2QuasiId.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2QuasiIdField' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2QuasiIdField.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2QuasiIdentifierField' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2QuasiIdentifierField.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2QuoteInfo' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2QuoteInfo.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Range' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Range.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordCondition' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordCondition.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordSuppression' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordSuppression.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordTransformation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordTransformation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RecordTransformations' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RecordTransformations.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RedactConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RedactConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RedactImageRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RedactImageRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RedactImageResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RedactImageResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Regex' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Regex.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ReidentifyContentRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ReidentifyContentRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ReidentifyContentResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ReidentifyContentResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ReplaceDictionaryConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ReplaceDictionaryConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ReplaceValueConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ReplaceValueConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ReplaceWithInfoTypeConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ReplaceWithInfoTypeConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RequestedDeidentifyOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RequestedDeidentifyOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RequestedOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RequestedOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RequestedRiskAnalysisOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RequestedRiskAnalysisOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Result' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Result.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2RiskAnalysisJobConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2RiskAnalysisJobConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Row' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Row.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SaveFindings' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SaveFindings.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Schedule' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Schedule.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SchemaModifiedCadence' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SchemaModifiedCadence.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SearchConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SearchConnectionsResponse.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SecretManagerCredential' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SecretManagerCredential.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SecretsDiscoveryTarget' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SecretsDiscoveryTarget.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SelectedInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SelectedInfoTypes.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SensitivityScore' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SensitivityScore.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StatisticalTable' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StatisticalTable.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StorageConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StorageConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StorageMetadataLabel' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StorageMetadataLabel.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StoredInfoType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StoredInfoType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StoredInfoTypeConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StoredInfoTypeConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StoredInfoTypeStats' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StoredInfoTypeStats.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StoredInfoTypeVersion' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StoredInfoTypeVersion.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2StoredType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2StoredType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SummaryResult' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SummaryResult.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2SurrogateType' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2SurrogateType.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Table' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Table.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TableDataProfile' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TableDataProfile.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TableLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TableLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TableOptions' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TableOptions.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TableReference' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TableReference.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TagCondition' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TagCondition.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TagResources' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TagResources.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TagValue' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TagValue.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TaggedField' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TaggedField.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ThrowError' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ThrowError.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TimePartConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TimePartConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TimeZone' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TimeZone.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TimespanConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TimespanConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationDescription' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationDescription.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationDetails' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationDetails.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationDetailsStorageConfig' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationDetailsStorageConfig.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationErrorHandling' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationErrorHandling.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationLocation' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationLocation.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationOverview' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationOverview.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationResultStatus' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationResultStatus.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransformationSummary' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransformationSummary.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2TransientCryptoKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2TransientCryptoKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Trigger' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Trigger.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UnwrappedCryptoKey' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UnwrappedCryptoKey.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateConnectionRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateConnectionRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateDiscoveryConfigRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateInspectTemplateRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateInspectTemplateRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateJobTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateJobTriggerRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2UpdateStoredInfoTypeRequest' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2UpdateStoredInfoTypeRequest.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2Value' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2Value.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2ValueFrequency' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2ValueFrequency.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2VersionDescription' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2VersionDescription.php',
    'Google\\Service\\DLP\\GooglePrivacyDlpV2WordList' => $vendorDir . '/google/apiclient-services/src/DLP/GooglePrivacyDlpV2WordList.php',
    'Google\\Service\\DLP\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/DLP/GoogleProtobufEmpty.php',
    'Google\\Service\\DLP\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/DLP/GoogleRpcStatus.php',
    'Google\\Service\\DLP\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/DLP/GoogleTypeDate.php',
    'Google\\Service\\DLP\\GoogleTypeTimeOfDay' => $vendorDir . '/google/apiclient-services/src/DLP/GoogleTypeTimeOfDay.php',
    'Google\\Service\\DLP\\Resource\\InfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/InfoTypes.php',
    'Google\\Service\\DLP\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/Locations.php',
    'Google\\Service\\DLP\\Resource\\LocationsInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/LocationsInfoTypes.php',
    'Google\\Service\\DLP\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/Organizations.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsDeidentifyTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsDeidentifyTemplates.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsInspectTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsInspectTemplates.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocations.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsColumnDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsColumnDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsConnections.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsDeidentifyTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsDeidentifyTemplates.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsDiscoveryConfigs' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsDiscoveryConfigs.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsDlpJobs' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsDlpJobs.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsFileStoreDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsFileStoreDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsInspectTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsInspectTemplates.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsJobTriggers' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsJobTriggers.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsProjectDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsProjectDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsStoredInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsStoredInfoTypes.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsLocationsTableDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsLocationsTableDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\OrganizationsStoredInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/OrganizationsStoredInfoTypes.php',
    'Google\\Service\\DLP\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/Projects.php',
    'Google\\Service\\DLP\\Resource\\ProjectsContent' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsContent.php',
    'Google\\Service\\DLP\\Resource\\ProjectsDeidentifyTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsDeidentifyTemplates.php',
    'Google\\Service\\DLP\\Resource\\ProjectsDlpJobs' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsDlpJobs.php',
    'Google\\Service\\DLP\\Resource\\ProjectsImage' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsImage.php',
    'Google\\Service\\DLP\\Resource\\ProjectsInspectTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsInspectTemplates.php',
    'Google\\Service\\DLP\\Resource\\ProjectsJobTriggers' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsJobTriggers.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocations.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsColumnDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsColumnDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsContent' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsContent.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsDeidentifyTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsDeidentifyTemplates.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsDiscoveryConfigs' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsDiscoveryConfigs.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsDlpJobs' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsDlpJobs.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsFileStoreDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsFileStoreDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsImage' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsImage.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsInspectTemplates' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsInspectTemplates.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsJobTriggers' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsJobTriggers.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsProjectDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsProjectDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsStoredInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsStoredInfoTypes.php',
    'Google\\Service\\DLP\\Resource\\ProjectsLocationsTableDataProfiles' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsLocationsTableDataProfiles.php',
    'Google\\Service\\DLP\\Resource\\ProjectsStoredInfoTypes' => $vendorDir . '/google/apiclient-services/src/DLP/Resource/ProjectsStoredInfoTypes.php',
    'Google\\Service\\DataCatalog' => $vendorDir . '/google/apiclient-services/src/DataCatalog.php',
    'Google\\Service\\DataCatalog\\Binding' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Binding.php',
    'Google\\Service\\DataCatalog\\DatacatalogEmpty' => $vendorDir . '/google/apiclient-services/src/DataCatalog/DatacatalogEmpty.php',
    'Google\\Service\\DataCatalog\\Expr' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Expr.php',
    'Google\\Service\\DataCatalog\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GetIamPolicyRequest.php',
    'Google\\Service\\DataCatalog\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GetPolicyOptions.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1BigQueryConnectionSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1BigQueryConnectionSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1BigQueryDateShardedSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1BigQueryDateShardedSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1BigQueryRoutineSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1BigQueryRoutineSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1BigQueryTableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1BigQueryTableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1BusinessContext' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1BusinessContext.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CloudBigtableInstanceSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CloudBigtableInstanceSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CloudBigtableInstanceSpecCloudBigtableClusterSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CloudBigtableInstanceSpecCloudBigtableClusterSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CloudBigtableSystemSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CloudBigtableSystemSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CloudSqlBigQueryConnectionSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CloudSqlBigQueryConnectionSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ColumnSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ColumnSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ColumnSchemaFieldElementType' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ColumnSchemaFieldElementType.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ColumnSchemaLookerColumnSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ColumnSchemaLookerColumnSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CommonUsageStats' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CommonUsageStats.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1Contacts' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1Contacts.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ContactsPerson' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ContactsPerson.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1CrossRegionalSource' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1CrossRegionalSource.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataSource' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataSource.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataSourceConnectionSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataSourceConnectionSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DatabaseTableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DatabaseTableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DatabaseTableSpecDatabaseViewSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DatabaseTableSpecDatabaseViewSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataplexExternalTable' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataplexExternalTable.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataplexFilesetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataplexFilesetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataplexSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataplexSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DataplexTableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DataplexTableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DatasetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DatasetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1DumpItem' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1DumpItem.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1Entry' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1Entry.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1EntryGroup' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1EntryGroup.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1EntryOverview' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1EntryOverview.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ExportTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ExportTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1FeatureOnlineStoreSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1FeatureOnlineStoreSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1FieldType' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1FieldType.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1FieldTypeEnumType' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1FieldTypeEnumType.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1FieldTypeEnumTypeEnumValue' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1FieldTypeEnumTypeEnumValue.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1FilesetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1FilesetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1GcsFileSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1GcsFileSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1GcsFilesetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1GcsFilesetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ImportEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ImportEntriesMetadata.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ImportEntriesRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ImportEntriesRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ImportEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ImportEntriesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ImportTaxonomiesRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ImportTaxonomiesRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ImportTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ImportTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1InlineSource' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1InlineSource.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ListEntriesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ListEntryGroupsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ListEntryGroupsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ListPolicyTagsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ListPolicyTagsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ListTagsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ListTagsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ListTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ListTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1LookerSystemSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1LookerSystemSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ModelSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ModelSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ModifyEntryContactsRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ModifyEntryContactsRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ModifyEntryOverviewRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ModifyEntryOverviewRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PersonalDetails' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PersonalDetails.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1PolicyTag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1PolicyTag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ReconcileTagsMetadata' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ReconcileTagsMetadata.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ReconcileTagsRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ReconcileTagsRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ReconcileTagsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ReconcileTagsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1RenameTagTemplateFieldEnumValueRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1RenameTagTemplateFieldEnumValueRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1RenameTagTemplateFieldRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1RenameTagTemplateFieldRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ReplaceTaxonomyRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ReplaceTaxonomyRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1RoutineSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1RoutineSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1RoutineSpecArgument' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1RoutineSpecArgument.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1Schema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1Schema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SearchCatalogRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SearchCatalogRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SearchCatalogRequestScope' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SearchCatalogRequestScope.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SearchCatalogResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SearchCatalogResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SearchCatalogResult' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SearchCatalogResult.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SerializedPolicyTag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SerializedPolicyTag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SerializedTaxonomy' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SerializedTaxonomy.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ServiceSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ServiceSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SqlDatabaseSystemSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SqlDatabaseSystemSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1StarEntryRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1StarEntryRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1StarEntryResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1StarEntryResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1StorageProperties' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1StorageProperties.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1SystemTimestamps' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1SystemTimestamps.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1Tag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1Tag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TagField' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TagField.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TagFieldEnumValue' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TagFieldEnumValue.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TagTemplate' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TagTemplate.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TagTemplateField' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TagTemplateField.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TaggedEntry' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TaggedEntry.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1Taxonomy' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1Taxonomy.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1TaxonomyService' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1TaxonomyService.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1UnstarEntryRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1UnstarEntryRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1UnstarEntryResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1UnstarEntryResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1UsageSignal' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1UsageSignal.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1UsageStats' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1UsageStats.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1VertexDatasetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1VertexDatasetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1VertexModelSourceInfo' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1VertexModelSourceInfo.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1VertexModelSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1VertexModelSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1ViewSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1ViewSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1BigQueryDateShardedSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1BigQueryDateShardedSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1BigQueryTableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1BigQueryTableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ColumnSchema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ColumnSchema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1Entry' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1Entry.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1EntryGroup' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1EntryGroup.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ExportTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ExportTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1FieldType' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1FieldType.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1FieldTypeEnumType' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1FieldTypeEnumType.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1FieldTypeEnumTypeEnumValue' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1FieldTypeEnumTypeEnumValue.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1GcsFileSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1GcsFileSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1GcsFilesetSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1GcsFilesetSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ImportTaxonomiesRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ImportTaxonomiesRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ImportTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ImportTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1InlineSource' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1InlineSource.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ListEntriesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ListEntryGroupsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ListEntryGroupsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ListPolicyTagsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ListPolicyTagsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ListTagsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ListTagsResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ListTaxonomiesResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ListTaxonomiesResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1PolicyTag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1PolicyTag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1RenameTagTemplateFieldEnumValueRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1RenameTagTemplateFieldEnumValueRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1RenameTagTemplateFieldRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1RenameTagTemplateFieldRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1Schema' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1Schema.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SearchCatalogRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SearchCatalogRequest.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SearchCatalogRequestScope' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SearchCatalogRequestScope.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SearchCatalogResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SearchCatalogResponse.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SearchCatalogResult' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SearchCatalogResult.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SerializedPolicyTag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SerializedPolicyTag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SerializedTaxonomy' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SerializedTaxonomy.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1SystemTimestamps' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1SystemTimestamps.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1TableSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1TableSpec.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1Tag' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1Tag.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1TagField' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1TagField.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1TagFieldEnumValue' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1TagFieldEnumValue.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1TagTemplate' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1TagTemplate.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1TagTemplateField' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1TagTemplateField.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1Taxonomy' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1Taxonomy.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1UsageSignal' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1UsageSignal.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1UsageStats' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1UsageStats.php',
    'Google\\Service\\DataCatalog\\GoogleCloudDatacatalogV1beta1ViewSpec' => $vendorDir . '/google/apiclient-services/src/DataCatalog/GoogleCloudDatacatalogV1beta1ViewSpec.php',
    'Google\\Service\\DataCatalog\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/ListOperationsResponse.php',
    'Google\\Service\\DataCatalog\\Operation' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Operation.php',
    'Google\\Service\\DataCatalog\\Policy' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Policy.php',
    'Google\\Service\\DataCatalog\\Resource\\Catalog' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/Catalog.php',
    'Google\\Service\\DataCatalog\\Resource\\Entries' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/Entries.php',
    'Google\\Service\\DataCatalog\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/Projects.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocations.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsEntryGroups' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsEntryGroups.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsEntryGroupsEntries' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsEntryGroupsEntries.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsEntryGroupsEntriesTags' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsEntryGroupsEntriesTags.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsEntryGroupsTags' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsEntryGroupsTags.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsTagTemplates' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsTagTemplates.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsTagTemplatesFields' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsTagTemplatesFields.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsTagTemplatesFieldsEnumValues' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsTagTemplatesFieldsEnumValues.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsTaxonomies' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsTaxonomies.php',
    'Google\\Service\\DataCatalog\\Resource\\ProjectsLocationsTaxonomiesPolicyTags' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Resource/ProjectsLocationsTaxonomiesPolicyTags.php',
    'Google\\Service\\DataCatalog\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/SetIamPolicyRequest.php',
    'Google\\Service\\DataCatalog\\Status' => $vendorDir . '/google/apiclient-services/src/DataCatalog/Status.php',
    'Google\\Service\\DataCatalog\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DataCatalog/TestIamPermissionsRequest.php',
    'Google\\Service\\DataCatalog\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DataCatalog/TestIamPermissionsResponse.php',
    'Google\\Service\\DataFusion' => $vendorDir . '/google/apiclient-services/src/DataFusion.php',
    'Google\\Service\\DataFusion\\Accelerator' => $vendorDir . '/google/apiclient-services/src/DataFusion/Accelerator.php',
    'Google\\Service\\DataFusion\\AssetLocation' => $vendorDir . '/google/apiclient-services/src/DataFusion/AssetLocation.php',
    'Google\\Service\\DataFusion\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/AuditConfig.php',
    'Google\\Service\\DataFusion\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/AuditLogConfig.php',
    'Google\\Service\\DataFusion\\Binding' => $vendorDir . '/google/apiclient-services/src/DataFusion/Binding.php',
    'Google\\Service\\DataFusion\\BlobstoreLocation' => $vendorDir . '/google/apiclient-services/src/DataFusion/BlobstoreLocation.php',
    'Google\\Service\\DataFusion\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/DataFusion/CancelOperationRequest.php',
    'Google\\Service\\DataFusion\\CloudAsset' => $vendorDir . '/google/apiclient-services/src/DataFusion/CloudAsset.php',
    'Google\\Service\\DataFusion\\CloudAssetComposition' => $vendorDir . '/google/apiclient-services/src/DataFusion/CloudAssetComposition.php',
    'Google\\Service\\DataFusion\\CryptoKeyConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/CryptoKeyConfig.php',
    'Google\\Service\\DataFusion\\DataResidencyAugmentedView' => $vendorDir . '/google/apiclient-services/src/DataFusion/DataResidencyAugmentedView.php',
    'Google\\Service\\DataFusion\\DatafusionEmpty' => $vendorDir . '/google/apiclient-services/src/DataFusion/DatafusionEmpty.php',
    'Google\\Service\\DataFusion\\DirectLocationAssignment' => $vendorDir . '/google/apiclient-services/src/DataFusion/DirectLocationAssignment.php',
    'Google\\Service\\DataFusion\\DnsPeering' => $vendorDir . '/google/apiclient-services/src/DataFusion/DnsPeering.php',
    'Google\\Service\\DataFusion\\EventPublishConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/EventPublishConfig.php',
    'Google\\Service\\DataFusion\\Expr' => $vendorDir . '/google/apiclient-services/src/DataFusion/Expr.php',
    'Google\\Service\\DataFusion\\ExtraParameter' => $vendorDir . '/google/apiclient-services/src/DataFusion/ExtraParameter.php',
    'Google\\Service\\DataFusion\\Instance' => $vendorDir . '/google/apiclient-services/src/DataFusion/Instance.php',
    'Google\\Service\\DataFusion\\IsolationExpectations' => $vendorDir . '/google/apiclient-services/src/DataFusion/IsolationExpectations.php',
    'Google\\Service\\DataFusion\\ListAvailableVersionsResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/ListAvailableVersionsResponse.php',
    'Google\\Service\\DataFusion\\ListDnsPeeringsResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/ListDnsPeeringsResponse.php',
    'Google\\Service\\DataFusion\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/ListInstancesResponse.php',
    'Google\\Service\\DataFusion\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/ListLocationsResponse.php',
    'Google\\Service\\DataFusion\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/ListOperationsResponse.php',
    'Google\\Service\\DataFusion\\Location' => $vendorDir . '/google/apiclient-services/src/DataFusion/Location.php',
    'Google\\Service\\DataFusion\\LocationAssignment' => $vendorDir . '/google/apiclient-services/src/DataFusion/LocationAssignment.php',
    'Google\\Service\\DataFusion\\LocationData' => $vendorDir . '/google/apiclient-services/src/DataFusion/LocationData.php',
    'Google\\Service\\DataFusion\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/DataFusion/MaintenancePolicy.php',
    'Google\\Service\\DataFusion\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/DataFusion/MaintenanceWindow.php',
    'Google\\Service\\DataFusion\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/NetworkConfig.php',
    'Google\\Service\\DataFusion\\Operation' => $vendorDir . '/google/apiclient-services/src/DataFusion/Operation.php',
    'Google\\Service\\DataFusion\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataFusion/OperationMetadata.php',
    'Google\\Service\\DataFusion\\PersistentDiskData' => $vendorDir . '/google/apiclient-services/src/DataFusion/PersistentDiskData.php',
    'Google\\Service\\DataFusion\\PlacerLocation' => $vendorDir . '/google/apiclient-services/src/DataFusion/PlacerLocation.php',
    'Google\\Service\\DataFusion\\Policy' => $vendorDir . '/google/apiclient-services/src/DataFusion/Policy.php',
    'Google\\Service\\DataFusion\\PrivateServiceConnectConfig' => $vendorDir . '/google/apiclient-services/src/DataFusion/PrivateServiceConnectConfig.php',
    'Google\\Service\\DataFusion\\RecurringTimeWindow' => $vendorDir . '/google/apiclient-services/src/DataFusion/RecurringTimeWindow.php',
    'Google\\Service\\DataFusion\\RegionalMigDistributionPolicy' => $vendorDir . '/google/apiclient-services/src/DataFusion/RegionalMigDistributionPolicy.php',
    'Google\\Service\\DataFusion\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/Projects.php',
    'Google\\Service\\DataFusion\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/ProjectsLocations.php',
    'Google\\Service\\DataFusion\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\DataFusion\\Resource\\ProjectsLocationsInstancesDnsPeerings' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/ProjectsLocationsInstancesDnsPeerings.php',
    'Google\\Service\\DataFusion\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DataFusion\\Resource\\ProjectsLocationsVersions' => $vendorDir . '/google/apiclient-services/src/DataFusion/Resource/ProjectsLocationsVersions.php',
    'Google\\Service\\DataFusion\\RestartInstanceRequest' => $vendorDir . '/google/apiclient-services/src/DataFusion/RestartInstanceRequest.php',
    'Google\\Service\\DataFusion\\ServiceData' => $vendorDir . '/google/apiclient-services/src/DataFusion/ServiceData.php',
    'Google\\Service\\DataFusion\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DataFusion/SetIamPolicyRequest.php',
    'Google\\Service\\DataFusion\\SpannerLocation' => $vendorDir . '/google/apiclient-services/src/DataFusion/SpannerLocation.php',
    'Google\\Service\\DataFusion\\Status' => $vendorDir . '/google/apiclient-services/src/DataFusion/Status.php',
    'Google\\Service\\DataFusion\\TenantProjectProxy' => $vendorDir . '/google/apiclient-services/src/DataFusion/TenantProjectProxy.php',
    'Google\\Service\\DataFusion\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DataFusion/TestIamPermissionsRequest.php',
    'Google\\Service\\DataFusion\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DataFusion/TestIamPermissionsResponse.php',
    'Google\\Service\\DataFusion\\TimeWindow' => $vendorDir . '/google/apiclient-services/src/DataFusion/TimeWindow.php',
    'Google\\Service\\DataFusion\\Version' => $vendorDir . '/google/apiclient-services/src/DataFusion/Version.php',
    'Google\\Service\\DataFusion\\ZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/DataFusion/ZoneConfiguration.php',
    'Google\\Service\\DataLabeling' => $vendorDir . '/google/apiclient-services/src/DataLabeling.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1CreateInstructionMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1CreateInstructionMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1ExportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1ExportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1ExportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1ExportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1GcsDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1GcsDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1GcsFolderDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1GcsFolderDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1ImportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1ImportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1ImportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1ImportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImageBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImageBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImageBoundingPolyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImageBoundingPolyOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImageClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImageClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImageOrientedBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImageOrientedBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImagePolylineOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImagePolylineOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelImageSegmentationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelImageSegmentationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelStats' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelStats.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelTextClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelTextClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelTextEntityExtractionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelTextEntityExtractionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelVideoClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelVideoClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelVideoEventOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelVideoEventOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelVideoObjectDetectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelVideoObjectDetectionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1LabelVideoObjectTrackingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1LabelVideoObjectTrackingOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1alpha1OutputConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1alpha1OutputConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotatedDataset' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotatedDataset.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotatedDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotatedDatasetMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Annotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Annotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotationSpec' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotationSpec.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotationSpecSet' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotationSpecSet.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotationSpecSetConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotationSpecSetConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1AnnotationValue' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1AnnotationValue.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Attempt' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Attempt.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1BigQuerySource' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1BigQuerySource.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1BoundingBoxEvaluationOptions' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1BoundingBoxEvaluationOptions.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1BoundingPoly.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1BoundingPolyConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1BoundingPolyConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ClassificationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ClassificationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ClassificationMetrics' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ClassificationMetrics.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ConfidenceMetricsEntry' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ConfidenceMetricsEntry.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ConfusionMatrix' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ConfusionMatrix.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ConfusionMatrixEntry' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ConfusionMatrixEntry.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CreateAnnotationSpecSetRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CreateAnnotationSpecSetRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CreateDatasetRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CreateDatasetRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CreateEvaluationJobRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CreateEvaluationJobRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CreateInstructionMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CreateInstructionMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CreateInstructionRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CreateInstructionRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1CsvInstruction' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1CsvInstruction.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1DataItem' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1DataItem.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Dataset' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Dataset.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Evaluation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Evaluation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EvaluationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EvaluationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EvaluationJob' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EvaluationJob.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EvaluationJobAlertConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EvaluationJobAlertConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EvaluationJobConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EvaluationJobConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EvaluationMetrics.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1EventConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1EventConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Example' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Example.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ExampleComparison' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ExampleComparison.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ExportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ExportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ExportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ExportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ExportDataRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ExportDataRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1FeedbackMessage' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1FeedbackMessage.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1FeedbackThread' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1FeedbackThread.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1FeedbackThreadMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1FeedbackThreadMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1GcsDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1GcsFolderDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1GcsFolderDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1GcsSource.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1HumanAnnotationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1HumanAnnotationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImageBoundingPolyAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImageBoundingPolyAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImageClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImageClassificationAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImageClassificationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImageClassificationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImagePayload' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImagePayload.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImagePolylineAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImagePolylineAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImageSegmentationAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImageSegmentationAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ImportDataRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ImportDataRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1InputConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Instruction' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Instruction.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageBoundingPolyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageBoundingPolyOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageOrientedBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageOrientedBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImagePolylineOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImagePolylineOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelImageSegmentationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelImageSegmentationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelStats' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelStats.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelTextClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelTextClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelTextEntityExtractionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelTextEntityExtractionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelTextRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelTextRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelVideoClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelVideoClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelVideoEventOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelVideoEventOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelVideoObjectDetectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelVideoObjectDetectionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelVideoObjectTrackingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelVideoObjectTrackingOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1LabelVideoRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1LabelVideoRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListAnnotatedDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListAnnotatedDatasetsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListAnnotationSpecSetsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListAnnotationSpecSetsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListDataItemsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListDataItemsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListDatasetsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListEvaluationJobsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListEvaluationJobsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListExamplesResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListExamplesResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListFeedbackMessagesResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListFeedbackMessagesResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListFeedbackThreadsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListFeedbackThreadsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ListInstructionsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ListInstructionsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1NormalizedBoundingPoly' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1NormalizedBoundingPoly.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1NormalizedPolyline' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1NormalizedPolyline.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1NormalizedVertex.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ObjectDetectionConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ObjectDetectionConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ObjectDetectionMetrics' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ObjectDetectionMetrics.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ObjectTrackingConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ObjectTrackingConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ObjectTrackingFrame' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ObjectTrackingFrame.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1OperatorFeedbackMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1OperatorFeedbackMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1OperatorMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1OperatorMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1OutputConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1PauseEvaluationJobRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1PauseEvaluationJobRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1PdfInstruction' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1PdfInstruction.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Polyline' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Polyline.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1PolylineConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1PolylineConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1PrCurve' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1PrCurve.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1RequesterFeedbackMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1RequesterFeedbackMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1ResumeEvaluationJobRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1ResumeEvaluationJobRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Row' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Row.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SearchEvaluationsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SearchEvaluationsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SearchExampleComparisonsRequest' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SearchExampleComparisonsRequest.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SearchExampleComparisonsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SearchExampleComparisonsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SegmentationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SegmentationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SentimentConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SentimentConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1SequentialSegment' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1SequentialSegment.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextClassificationAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextClassificationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextClassificationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextEntityExtractionAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextEntityExtractionAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextEntityExtractionConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextEntityExtractionConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TextPayload' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TextPayload.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1TimeSegment' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1TimeSegment.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1Vertex' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1Vertex.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoClassificationAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoClassificationAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoClassificationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoClassificationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoEventAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoEventAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoObjectTrackingAnnotation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoObjectTrackingAnnotation.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoPayload' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoPayload.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1beta1VideoThumbnail' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1beta1VideoThumbnail.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1CreateInstructionMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1CreateInstructionMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1ExportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1ExportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1ExportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1ExportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1GcsDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1GcsDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1GcsFolderDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1GcsFolderDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1GenerateAnalysisReportOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1GenerateAnalysisReportOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1ImportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1ImportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1ImportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1ImportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingPolyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingPolyOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImageClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImageClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImageOrientedBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImageOrientedBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImagePolylineOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImagePolylineOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelImageSegmentationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelImageSegmentationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelStats' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelStats.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelTextClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelTextClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelTextEntityExtractionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelTextEntityExtractionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelVideoClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelVideoClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelVideoEventOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelVideoEventOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectDetectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectDetectionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectTrackingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectTrackingOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p1alpha1OutputConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p1alpha1OutputConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1CreateInstructionMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1CreateInstructionMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1ExportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1ExportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1ExportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1ExportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1GcsDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1GcsDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1GcsFolderDestination' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1GcsFolderDestination.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1ImportDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1ImportDataOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1ImportDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1ImportDataOperationResponse.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingPolyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingPolyOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImageClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImageClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImageOrientedBoundingBoxOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImageOrientedBoundingBoxOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImagePolylineOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImagePolylineOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelImageSegmentationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelImageSegmentationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelStats' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelStats.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelTextClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelTextClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelTextEntityExtractionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelTextEntityExtractionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelVideoClassificationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelVideoClassificationOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelVideoEventOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelVideoEventOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectDetectionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectDetectionOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectTrackingOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectTrackingOperationMetadata.php',
    'Google\\Service\\DataLabeling\\GoogleCloudDatalabelingV1p2alpha1OutputConfig' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleCloudDatalabelingV1p2alpha1OutputConfig.php',
    'Google\\Service\\DataLabeling\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\DataLabeling\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleLongrunningOperation.php',
    'Google\\Service\\DataLabeling\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleProtobufEmpty.php',
    'Google\\Service\\DataLabeling\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/DataLabeling/GoogleRpcStatus.php',
    'Google\\Service\\DataLabeling\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/Projects.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsAnnotationSpecSets' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsAnnotationSpecSets.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasets' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasets.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsAnnotatedDatasets' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsAnnotatedDatasets.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsAnnotatedDatasetsDataItems' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsAnnotatedDatasetsDataItems.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsAnnotatedDatasetsExamples' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsAnnotatedDatasetsExamples.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsAnnotatedDatasetsFeedbackThreads' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsAnnotatedDatasetsFeedbackThreads.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsAnnotatedDatasetsFeedbackThreadsFeedbackMessages' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsAnnotatedDatasetsFeedbackThreadsFeedbackMessages.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsDataItems' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsDataItems.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsEvaluations' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsEvaluations.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsEvaluationsExampleComparisons' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsEvaluationsExampleComparisons.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsImage' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsImage.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsText' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsText.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsDatasetsVideo' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsDatasetsVideo.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsEvaluationJobs' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsEvaluationJobs.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsEvaluations' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsEvaluations.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsInstructions' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsInstructions.php',
    'Google\\Service\\DataLabeling\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/DataLabeling/Resource/ProjectsOperations.php',
    'Google\\Service\\DataPortability' => $vendorDir . '/google/apiclient-services/src/DataPortability.php',
    'Google\\Service\\DataPortability\\DataportabilityEmpty' => $vendorDir . '/google/apiclient-services/src/DataPortability/DataportabilityEmpty.php',
    'Google\\Service\\DataPortability\\InitiatePortabilityArchiveRequest' => $vendorDir . '/google/apiclient-services/src/DataPortability/InitiatePortabilityArchiveRequest.php',
    'Google\\Service\\DataPortability\\InitiatePortabilityArchiveResponse' => $vendorDir . '/google/apiclient-services/src/DataPortability/InitiatePortabilityArchiveResponse.php',
    'Google\\Service\\DataPortability\\PortabilityArchiveState' => $vendorDir . '/google/apiclient-services/src/DataPortability/PortabilityArchiveState.php',
    'Google\\Service\\DataPortability\\ResetAuthorizationRequest' => $vendorDir . '/google/apiclient-services/src/DataPortability/ResetAuthorizationRequest.php',
    'Google\\Service\\DataPortability\\Resource\\ArchiveJobs' => $vendorDir . '/google/apiclient-services/src/DataPortability/Resource/ArchiveJobs.php',
    'Google\\Service\\DataPortability\\Resource\\Authorization' => $vendorDir . '/google/apiclient-services/src/DataPortability/Resource/Authorization.php',
    'Google\\Service\\DataPortability\\Resource\\PortabilityArchive' => $vendorDir . '/google/apiclient-services/src/DataPortability/Resource/PortabilityArchive.php',
    'Google\\Service\\DataPortability\\RetryPortabilityArchiveRequest' => $vendorDir . '/google/apiclient-services/src/DataPortability/RetryPortabilityArchiveRequest.php',
    'Google\\Service\\DataPortability\\RetryPortabilityArchiveResponse' => $vendorDir . '/google/apiclient-services/src/DataPortability/RetryPortabilityArchiveResponse.php',
    'Google\\Service\\DataTransfer' => $vendorDir . '/google/apiclient-services/src/DataTransfer.php',
    'Google\\Service\\DataTransfer\\Application' => $vendorDir . '/google/apiclient-services/src/DataTransfer/Application.php',
    'Google\\Service\\DataTransfer\\ApplicationDataTransfer' => $vendorDir . '/google/apiclient-services/src/DataTransfer/ApplicationDataTransfer.php',
    'Google\\Service\\DataTransfer\\ApplicationTransferParam' => $vendorDir . '/google/apiclient-services/src/DataTransfer/ApplicationTransferParam.php',
    'Google\\Service\\DataTransfer\\ApplicationsListResponse' => $vendorDir . '/google/apiclient-services/src/DataTransfer/ApplicationsListResponse.php',
    'Google\\Service\\DataTransfer\\DataTransfer' => $vendorDir . '/google/apiclient-services/src/DataTransfer/DataTransfer.php',
    'Google\\Service\\DataTransfer\\DataTransfersListResponse' => $vendorDir . '/google/apiclient-services/src/DataTransfer/DataTransfersListResponse.php',
    'Google\\Service\\DataTransfer\\Resource\\Applications' => $vendorDir . '/google/apiclient-services/src/DataTransfer/Resource/Applications.php',
    'Google\\Service\\DataTransfer\\Resource\\Transfers' => $vendorDir . '/google/apiclient-services/src/DataTransfer/Resource/Transfers.php',
    'Google\\Service\\DatabaseMigrationService' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService.php',
    'Google\\Service\\DatabaseMigrationService\\AlloyDbConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/AlloyDbConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\AlloyDbSettings' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/AlloyDbSettings.php',
    'Google\\Service\\DatabaseMigrationService\\ApplyConversionWorkspaceRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ApplyConversionWorkspaceRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ApplyHash' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ApplyHash.php',
    'Google\\Service\\DatabaseMigrationService\\ApplyJobDetails' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ApplyJobDetails.php',
    'Google\\Service\\DatabaseMigrationService\\AssignSpecificValue' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/AssignSpecificValue.php',
    'Google\\Service\\DatabaseMigrationService\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/AuditConfig.php',
    'Google\\Service\\DatabaseMigrationService\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/AuditLogConfig.php',
    'Google\\Service\\DatabaseMigrationService\\BackgroundJobLogEntry' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/BackgroundJobLogEntry.php',
    'Google\\Service\\DatabaseMigrationService\\Binding' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Binding.php',
    'Google\\Service\\DatabaseMigrationService\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/CancelOperationRequest.php',
    'Google\\Service\\DatabaseMigrationService\\CloudSqlConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/CloudSqlConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\CloudSqlSettings' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/CloudSqlSettings.php',
    'Google\\Service\\DatabaseMigrationService\\ColumnEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ColumnEntity.php',
    'Google\\Service\\DatabaseMigrationService\\CommitConversionWorkspaceRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/CommitConversionWorkspaceRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ConditionalColumnSetValue' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConditionalColumnSetValue.php',
    'Google\\Service\\DatabaseMigrationService\\ConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\ConstraintEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConstraintEntity.php',
    'Google\\Service\\DatabaseMigrationService\\ConversionWorkspace' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConversionWorkspace.php',
    'Google\\Service\\DatabaseMigrationService\\ConversionWorkspaceInfo' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConversionWorkspaceInfo.php',
    'Google\\Service\\DatabaseMigrationService\\ConvertConversionWorkspaceRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConvertConversionWorkspaceRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ConvertJobDetails' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConvertJobDetails.php',
    'Google\\Service\\DatabaseMigrationService\\ConvertRowIdToColumn' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ConvertRowIdToColumn.php',
    'Google\\Service\\DatabaseMigrationService\\DataCacheConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DataCacheConfig.php',
    'Google\\Service\\DatabaseMigrationService\\DatabaseEngineInfo' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DatabaseEngineInfo.php',
    'Google\\Service\\DatabaseMigrationService\\DatabaseEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DatabaseEntity.php',
    'Google\\Service\\DatabaseMigrationService\\DatabaseInstanceEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DatabaseInstanceEntity.php',
    'Google\\Service\\DatabaseMigrationService\\DatabaseType' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DatabaseType.php',
    'Google\\Service\\DatabaseMigrationService\\DatamigrationEmpty' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DatamigrationEmpty.php',
    'Google\\Service\\DatabaseMigrationService\\DemoteDestinationRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DemoteDestinationRequest.php',
    'Google\\Service\\DatabaseMigrationService\\DescribeConversionWorkspaceRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DescribeConversionWorkspaceRevisionsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\DescribeDatabaseEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DescribeDatabaseEntitiesResponse.php',
    'Google\\Service\\DatabaseMigrationService\\DoubleComparisonFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DoubleComparisonFilter.php',
    'Google\\Service\\DatabaseMigrationService\\DumpFlag' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DumpFlag.php',
    'Google\\Service\\DatabaseMigrationService\\DumpFlags' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/DumpFlags.php',
    'Google\\Service\\DatabaseMigrationService\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EncryptionConfig.php',
    'Google\\Service\\DatabaseMigrationService\\EntityDdl' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EntityDdl.php',
    'Google\\Service\\DatabaseMigrationService\\EntityIssue' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EntityIssue.php',
    'Google\\Service\\DatabaseMigrationService\\EntityMapping' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EntityMapping.php',
    'Google\\Service\\DatabaseMigrationService\\EntityMappingLogEntry' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EntityMappingLogEntry.php',
    'Google\\Service\\DatabaseMigrationService\\EntityMove' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/EntityMove.php',
    'Google\\Service\\DatabaseMigrationService\\Expr' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Expr.php',
    'Google\\Service\\DatabaseMigrationService\\FetchStaticIpsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/FetchStaticIpsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\FilterTableColumns' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/FilterTableColumns.php',
    'Google\\Service\\DatabaseMigrationService\\ForwardSshTunnelConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ForwardSshTunnelConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\FunctionEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/FunctionEntity.php',
    'Google\\Service\\DatabaseMigrationService\\GenerateSshScriptRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/GenerateSshScriptRequest.php',
    'Google\\Service\\DatabaseMigrationService\\GenerateTcpProxyScriptRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/GenerateTcpProxyScriptRequest.php',
    'Google\\Service\\DatabaseMigrationService\\GoogleCloudClouddmsV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/GoogleCloudClouddmsV1OperationMetadata.php',
    'Google\\Service\\DatabaseMigrationService\\ImportMappingRulesRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ImportMappingRulesRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ImportRulesJobDetails' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ImportRulesJobDetails.php',
    'Google\\Service\\DatabaseMigrationService\\IndexEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/IndexEntity.php',
    'Google\\Service\\DatabaseMigrationService\\IntComparisonFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/IntComparisonFilter.php',
    'Google\\Service\\DatabaseMigrationService\\ListConnectionProfilesResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListConnectionProfilesResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListConversionWorkspacesResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListConversionWorkspacesResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListLocationsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListMappingRulesResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListMappingRulesResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListMigrationJobsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListMigrationJobsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListOperationsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\ListPrivateConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ListPrivateConnectionsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\Location' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Location.php',
    'Google\\Service\\DatabaseMigrationService\\MachineConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MachineConfig.php',
    'Google\\Service\\DatabaseMigrationService\\MappingRule' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MappingRule.php',
    'Google\\Service\\DatabaseMigrationService\\MappingRuleFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MappingRuleFilter.php',
    'Google\\Service\\DatabaseMigrationService\\MaterializedViewEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MaterializedViewEntity.php',
    'Google\\Service\\DatabaseMigrationService\\MigrationJob' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MigrationJob.php',
    'Google\\Service\\DatabaseMigrationService\\MigrationJobVerificationError' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MigrationJobVerificationError.php',
    'Google\\Service\\DatabaseMigrationService\\MultiColumnDatatypeChange' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MultiColumnDatatypeChange.php',
    'Google\\Service\\DatabaseMigrationService\\MultiEntityRename' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MultiEntityRename.php',
    'Google\\Service\\DatabaseMigrationService\\MySqlConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/MySqlConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\Operation' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Operation.php',
    'Google\\Service\\DatabaseMigrationService\\OracleAsmConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/OracleAsmConfig.php',
    'Google\\Service\\DatabaseMigrationService\\OracleConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/OracleConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\PackageEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PackageEntity.php',
    'Google\\Service\\DatabaseMigrationService\\PerformanceConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PerformanceConfig.php',
    'Google\\Service\\DatabaseMigrationService\\Policy' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Policy.php',
    'Google\\Service\\DatabaseMigrationService\\Position' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Position.php',
    'Google\\Service\\DatabaseMigrationService\\PostgreSqlConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PostgreSqlConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\PrimaryInstanceSettings' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PrimaryInstanceSettings.php',
    'Google\\Service\\DatabaseMigrationService\\PrivateConnection' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PrivateConnection.php',
    'Google\\Service\\DatabaseMigrationService\\PrivateConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PrivateConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\PrivateServiceConnectConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PrivateServiceConnectConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\PromoteMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/PromoteMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/Projects.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocations.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsConnectionProfiles' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsConnectionProfiles.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsConversionWorkspaces' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsConversionWorkspaces.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsConversionWorkspacesMappingRules' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsConversionWorkspacesMappingRules.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsMigrationJobs' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsMigrationJobs.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsMigrationJobsObjects' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsMigrationJobsObjects.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DatabaseMigrationService\\Resource\\ProjectsLocationsPrivateConnections' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Resource/ProjectsLocationsPrivateConnections.php',
    'Google\\Service\\DatabaseMigrationService\\RestartMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/RestartMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ResumeMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ResumeMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ReverseSshConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ReverseSshConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\RollbackConversionWorkspaceRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/RollbackConversionWorkspaceRequest.php',
    'Google\\Service\\DatabaseMigrationService\\RoundToScale' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/RoundToScale.php',
    'Google\\Service\\DatabaseMigrationService\\RulesFile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/RulesFile.php',
    'Google\\Service\\DatabaseMigrationService\\SchemaEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SchemaEntity.php',
    'Google\\Service\\DatabaseMigrationService\\SearchBackgroundJobsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SearchBackgroundJobsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\SeedConversionWorkspaceRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SeedConversionWorkspaceRequest.php',
    'Google\\Service\\DatabaseMigrationService\\SeedJobDetails' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SeedJobDetails.php',
    'Google\\Service\\DatabaseMigrationService\\SequenceEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SequenceEntity.php',
    'Google\\Service\\DatabaseMigrationService\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SetIamPolicyRequest.php',
    'Google\\Service\\DatabaseMigrationService\\SetTablePrimaryKey' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SetTablePrimaryKey.php',
    'Google\\Service\\DatabaseMigrationService\\SingleColumnChange' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SingleColumnChange.php',
    'Google\\Service\\DatabaseMigrationService\\SingleEntityRename' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SingleEntityRename.php',
    'Google\\Service\\DatabaseMigrationService\\SinglePackageChange' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SinglePackageChange.php',
    'Google\\Service\\DatabaseMigrationService\\SourceNumericFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SourceNumericFilter.php',
    'Google\\Service\\DatabaseMigrationService\\SourceSqlChange' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SourceSqlChange.php',
    'Google\\Service\\DatabaseMigrationService\\SourceTextFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SourceTextFilter.php',
    'Google\\Service\\DatabaseMigrationService\\SqlAclEntry' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlAclEntry.php',
    'Google\\Service\\DatabaseMigrationService\\SqlIpConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlIpConfig.php',
    'Google\\Service\\DatabaseMigrationService\\SqlServerBackups' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlServerBackups.php',
    'Google\\Service\\DatabaseMigrationService\\SqlServerConnectionProfile' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlServerConnectionProfile.php',
    'Google\\Service\\DatabaseMigrationService\\SqlServerDatabaseBackup' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlServerDatabaseBackup.php',
    'Google\\Service\\DatabaseMigrationService\\SqlServerEncryptionOptions' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlServerEncryptionOptions.php',
    'Google\\Service\\DatabaseMigrationService\\SqlServerHomogeneousMigrationJobConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SqlServerHomogeneousMigrationJobConfig.php',
    'Google\\Service\\DatabaseMigrationService\\SshScript' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SshScript.php',
    'Google\\Service\\DatabaseMigrationService\\SslConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SslConfig.php',
    'Google\\Service\\DatabaseMigrationService\\StartMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/StartMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\StaticIpConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/StaticIpConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\StaticServiceIpConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/StaticServiceIpConnectivity.php',
    'Google\\Service\\DatabaseMigrationService\\Status' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/Status.php',
    'Google\\Service\\DatabaseMigrationService\\StopMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/StopMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\StoredProcedureEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/StoredProcedureEntity.php',
    'Google\\Service\\DatabaseMigrationService\\SynonymEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/SynonymEntity.php',
    'Google\\Service\\DatabaseMigrationService\\TableEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/TableEntity.php',
    'Google\\Service\\DatabaseMigrationService\\TcpProxyScript' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/TcpProxyScript.php',
    'Google\\Service\\DatabaseMigrationService\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/TestIamPermissionsRequest.php',
    'Google\\Service\\DatabaseMigrationService\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/TestIamPermissionsResponse.php',
    'Google\\Service\\DatabaseMigrationService\\TriggerEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/TriggerEntity.php',
    'Google\\Service\\DatabaseMigrationService\\UDTEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/UDTEntity.php',
    'Google\\Service\\DatabaseMigrationService\\UserPassword' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/UserPassword.php',
    'Google\\Service\\DatabaseMigrationService\\ValueListFilter' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ValueListFilter.php',
    'Google\\Service\\DatabaseMigrationService\\ValueTransformation' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ValueTransformation.php',
    'Google\\Service\\DatabaseMigrationService\\VerifyMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/VerifyMigrationJobRequest.php',
    'Google\\Service\\DatabaseMigrationService\\ViewEntity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/ViewEntity.php',
    'Google\\Service\\DatabaseMigrationService\\VmCreationConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/VmCreationConfig.php',
    'Google\\Service\\DatabaseMigrationService\\VmSelectionConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/VmSelectionConfig.php',
    'Google\\Service\\DatabaseMigrationService\\VpcPeeringConfig' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/VpcPeeringConfig.php',
    'Google\\Service\\DatabaseMigrationService\\VpcPeeringConnectivity' => $vendorDir . '/google/apiclient-services/src/DatabaseMigrationService/VpcPeeringConnectivity.php',
    'Google\\Service\\Dataflow' => $vendorDir . '/google/apiclient-services/src/Dataflow.php',
    'Google\\Service\\Dataflow\\ApproximateProgress' => $vendorDir . '/google/apiclient-services/src/Dataflow/ApproximateProgress.php',
    'Google\\Service\\Dataflow\\ApproximateReportedProgress' => $vendorDir . '/google/apiclient-services/src/Dataflow/ApproximateReportedProgress.php',
    'Google\\Service\\Dataflow\\ApproximateSplitRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/ApproximateSplitRequest.php',
    'Google\\Service\\Dataflow\\AutoscalingEvent' => $vendorDir . '/google/apiclient-services/src/Dataflow/AutoscalingEvent.php',
    'Google\\Service\\Dataflow\\AutoscalingSettings' => $vendorDir . '/google/apiclient-services/src/Dataflow/AutoscalingSettings.php',
    'Google\\Service\\Dataflow\\Base2Exponent' => $vendorDir . '/google/apiclient-services/src/Dataflow/Base2Exponent.php',
    'Google\\Service\\Dataflow\\BigQueryIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/BigQueryIODetails.php',
    'Google\\Service\\Dataflow\\BigTableIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/BigTableIODetails.php',
    'Google\\Service\\Dataflow\\BucketOptions' => $vendorDir . '/google/apiclient-services/src/Dataflow/BucketOptions.php',
    'Google\\Service\\Dataflow\\CPUTime' => $vendorDir . '/google/apiclient-services/src/Dataflow/CPUTime.php',
    'Google\\Service\\Dataflow\\ComponentSource' => $vendorDir . '/google/apiclient-services/src/Dataflow/ComponentSource.php',
    'Google\\Service\\Dataflow\\ComponentTransform' => $vendorDir . '/google/apiclient-services/src/Dataflow/ComponentTransform.php',
    'Google\\Service\\Dataflow\\ComputationTopology' => $vendorDir . '/google/apiclient-services/src/Dataflow/ComputationTopology.php',
    'Google\\Service\\Dataflow\\ConcatPosition' => $vendorDir . '/google/apiclient-services/src/Dataflow/ConcatPosition.php',
    'Google\\Service\\Dataflow\\ContainerSpec' => $vendorDir . '/google/apiclient-services/src/Dataflow/ContainerSpec.php',
    'Google\\Service\\Dataflow\\CounterMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/CounterMetadata.php',
    'Google\\Service\\Dataflow\\CounterStructuredName' => $vendorDir . '/google/apiclient-services/src/Dataflow/CounterStructuredName.php',
    'Google\\Service\\Dataflow\\CounterStructuredNameAndMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/CounterStructuredNameAndMetadata.php',
    'Google\\Service\\Dataflow\\CounterUpdate' => $vendorDir . '/google/apiclient-services/src/Dataflow/CounterUpdate.php',
    'Google\\Service\\Dataflow\\CreateJobFromTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/CreateJobFromTemplateRequest.php',
    'Google\\Service\\Dataflow\\CustomSourceLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/CustomSourceLocation.php',
    'Google\\Service\\Dataflow\\DataDiskAssignment' => $vendorDir . '/google/apiclient-services/src/Dataflow/DataDiskAssignment.php',
    'Google\\Service\\Dataflow\\DataSamplingConfig' => $vendorDir . '/google/apiclient-services/src/Dataflow/DataSamplingConfig.php',
    'Google\\Service\\Dataflow\\DataSamplingReport' => $vendorDir . '/google/apiclient-services/src/Dataflow/DataSamplingReport.php',
    'Google\\Service\\Dataflow\\DataflowHistogramValue' => $vendorDir . '/google/apiclient-services/src/Dataflow/DataflowHistogramValue.php',
    'Google\\Service\\Dataflow\\DatastoreIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/DatastoreIODetails.php',
    'Google\\Service\\Dataflow\\DebugOptions' => $vendorDir . '/google/apiclient-services/src/Dataflow/DebugOptions.php',
    'Google\\Service\\Dataflow\\DeleteSnapshotResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/DeleteSnapshotResponse.php',
    'Google\\Service\\Dataflow\\DerivedSource' => $vendorDir . '/google/apiclient-services/src/Dataflow/DerivedSource.php',
    'Google\\Service\\Dataflow\\Disk' => $vendorDir . '/google/apiclient-services/src/Dataflow/Disk.php',
    'Google\\Service\\Dataflow\\DisplayData' => $vendorDir . '/google/apiclient-services/src/Dataflow/DisplayData.php',
    'Google\\Service\\Dataflow\\DistributionUpdate' => $vendorDir . '/google/apiclient-services/src/Dataflow/DistributionUpdate.php',
    'Google\\Service\\Dataflow\\DynamicSourceSplit' => $vendorDir . '/google/apiclient-services/src/Dataflow/DynamicSourceSplit.php',
    'Google\\Service\\Dataflow\\Environment' => $vendorDir . '/google/apiclient-services/src/Dataflow/Environment.php',
    'Google\\Service\\Dataflow\\ExecutionStageState' => $vendorDir . '/google/apiclient-services/src/Dataflow/ExecutionStageState.php',
    'Google\\Service\\Dataflow\\ExecutionStageSummary' => $vendorDir . '/google/apiclient-services/src/Dataflow/ExecutionStageSummary.php',
    'Google\\Service\\Dataflow\\FailedLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/FailedLocation.php',
    'Google\\Service\\Dataflow\\FileIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/FileIODetails.php',
    'Google\\Service\\Dataflow\\FlattenInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/FlattenInstruction.php',
    'Google\\Service\\Dataflow\\FlexTemplateRuntimeEnvironment' => $vendorDir . '/google/apiclient-services/src/Dataflow/FlexTemplateRuntimeEnvironment.php',
    'Google\\Service\\Dataflow\\FloatingPointList' => $vendorDir . '/google/apiclient-services/src/Dataflow/FloatingPointList.php',
    'Google\\Service\\Dataflow\\FloatingPointMean' => $vendorDir . '/google/apiclient-services/src/Dataflow/FloatingPointMean.php',
    'Google\\Service\\Dataflow\\GetDebugConfigRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/GetDebugConfigRequest.php',
    'Google\\Service\\Dataflow\\GetDebugConfigResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/GetDebugConfigResponse.php',
    'Google\\Service\\Dataflow\\GetTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/GetTemplateResponse.php',
    'Google\\Service\\Dataflow\\Histogram' => $vendorDir . '/google/apiclient-services/src/Dataflow/Histogram.php',
    'Google\\Service\\Dataflow\\HotKeyDebuggingInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/HotKeyDebuggingInfo.php',
    'Google\\Service\\Dataflow\\HotKeyDetection' => $vendorDir . '/google/apiclient-services/src/Dataflow/HotKeyDetection.php',
    'Google\\Service\\Dataflow\\HotKeyInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/HotKeyInfo.php',
    'Google\\Service\\Dataflow\\InstructionInput' => $vendorDir . '/google/apiclient-services/src/Dataflow/InstructionInput.php',
    'Google\\Service\\Dataflow\\InstructionOutput' => $vendorDir . '/google/apiclient-services/src/Dataflow/InstructionOutput.php',
    'Google\\Service\\Dataflow\\IntegerGauge' => $vendorDir . '/google/apiclient-services/src/Dataflow/IntegerGauge.php',
    'Google\\Service\\Dataflow\\IntegerList' => $vendorDir . '/google/apiclient-services/src/Dataflow/IntegerList.php',
    'Google\\Service\\Dataflow\\IntegerMean' => $vendorDir . '/google/apiclient-services/src/Dataflow/IntegerMean.php',
    'Google\\Service\\Dataflow\\Job' => $vendorDir . '/google/apiclient-services/src/Dataflow/Job.php',
    'Google\\Service\\Dataflow\\JobExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobExecutionDetails.php',
    'Google\\Service\\Dataflow\\JobExecutionInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobExecutionInfo.php',
    'Google\\Service\\Dataflow\\JobExecutionStageInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobExecutionStageInfo.php',
    'Google\\Service\\Dataflow\\JobMessage' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobMessage.php',
    'Google\\Service\\Dataflow\\JobMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobMetadata.php',
    'Google\\Service\\Dataflow\\JobMetrics' => $vendorDir . '/google/apiclient-services/src/Dataflow/JobMetrics.php',
    'Google\\Service\\Dataflow\\KeyRangeDataDiskAssignment' => $vendorDir . '/google/apiclient-services/src/Dataflow/KeyRangeDataDiskAssignment.php',
    'Google\\Service\\Dataflow\\KeyRangeLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/KeyRangeLocation.php',
    'Google\\Service\\Dataflow\\LaunchFlexTemplateParameter' => $vendorDir . '/google/apiclient-services/src/Dataflow/LaunchFlexTemplateParameter.php',
    'Google\\Service\\Dataflow\\LaunchFlexTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/LaunchFlexTemplateRequest.php',
    'Google\\Service\\Dataflow\\LaunchFlexTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/LaunchFlexTemplateResponse.php',
    'Google\\Service\\Dataflow\\LaunchTemplateParameters' => $vendorDir . '/google/apiclient-services/src/Dataflow/LaunchTemplateParameters.php',
    'Google\\Service\\Dataflow\\LaunchTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/LaunchTemplateResponse.php',
    'Google\\Service\\Dataflow\\LeaseWorkItemRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/LeaseWorkItemRequest.php',
    'Google\\Service\\Dataflow\\LeaseWorkItemResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/LeaseWorkItemResponse.php',
    'Google\\Service\\Dataflow\\Linear' => $vendorDir . '/google/apiclient-services/src/Dataflow/Linear.php',
    'Google\\Service\\Dataflow\\ListJobMessagesResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ListJobMessagesResponse.php',
    'Google\\Service\\Dataflow\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ListJobsResponse.php',
    'Google\\Service\\Dataflow\\ListSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ListSnapshotsResponse.php',
    'Google\\Service\\Dataflow\\MapTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/MapTask.php',
    'Google\\Service\\Dataflow\\MemInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/MemInfo.php',
    'Google\\Service\\Dataflow\\MetricShortId' => $vendorDir . '/google/apiclient-services/src/Dataflow/MetricShortId.php',
    'Google\\Service\\Dataflow\\MetricStructuredName' => $vendorDir . '/google/apiclient-services/src/Dataflow/MetricStructuredName.php',
    'Google\\Service\\Dataflow\\MetricUpdate' => $vendorDir . '/google/apiclient-services/src/Dataflow/MetricUpdate.php',
    'Google\\Service\\Dataflow\\MetricValue' => $vendorDir . '/google/apiclient-services/src/Dataflow/MetricValue.php',
    'Google\\Service\\Dataflow\\MountedDataDisk' => $vendorDir . '/google/apiclient-services/src/Dataflow/MountedDataDisk.php',
    'Google\\Service\\Dataflow\\MultiOutputInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/MultiOutputInfo.php',
    'Google\\Service\\Dataflow\\NameAndKind' => $vendorDir . '/google/apiclient-services/src/Dataflow/NameAndKind.php',
    'Google\\Service\\Dataflow\\OutlierStats' => $vendorDir . '/google/apiclient-services/src/Dataflow/OutlierStats.php',
    'Google\\Service\\Dataflow\\Package' => $vendorDir . '/google/apiclient-services/src/Dataflow/Package.php',
    'Google\\Service\\Dataflow\\ParDoInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/ParDoInstruction.php',
    'Google\\Service\\Dataflow\\ParallelInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/ParallelInstruction.php',
    'Google\\Service\\Dataflow\\Parameter' => $vendorDir . '/google/apiclient-services/src/Dataflow/Parameter.php',
    'Google\\Service\\Dataflow\\ParameterMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/ParameterMetadata.php',
    'Google\\Service\\Dataflow\\ParameterMetadataEnumOption' => $vendorDir . '/google/apiclient-services/src/Dataflow/ParameterMetadataEnumOption.php',
    'Google\\Service\\Dataflow\\PartialGroupByKeyInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/PartialGroupByKeyInstruction.php',
    'Google\\Service\\Dataflow\\PerStepNamespaceMetrics' => $vendorDir . '/google/apiclient-services/src/Dataflow/PerStepNamespaceMetrics.php',
    'Google\\Service\\Dataflow\\PerWorkerMetrics' => $vendorDir . '/google/apiclient-services/src/Dataflow/PerWorkerMetrics.php',
    'Google\\Service\\Dataflow\\PipelineDescription' => $vendorDir . '/google/apiclient-services/src/Dataflow/PipelineDescription.php',
    'Google\\Service\\Dataflow\\Point' => $vendorDir . '/google/apiclient-services/src/Dataflow/Point.php',
    'Google\\Service\\Dataflow\\Position' => $vendorDir . '/google/apiclient-services/src/Dataflow/Position.php',
    'Google\\Service\\Dataflow\\ProgressTimeseries' => $vendorDir . '/google/apiclient-services/src/Dataflow/ProgressTimeseries.php',
    'Google\\Service\\Dataflow\\PubSubIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/PubSubIODetails.php',
    'Google\\Service\\Dataflow\\PubsubLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/PubsubLocation.php',
    'Google\\Service\\Dataflow\\PubsubSnapshotMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/PubsubSnapshotMetadata.php',
    'Google\\Service\\Dataflow\\QueryInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/QueryInfo.php',
    'Google\\Service\\Dataflow\\ReadInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/ReadInstruction.php',
    'Google\\Service\\Dataflow\\ReportWorkItemStatusRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/ReportWorkItemStatusRequest.php',
    'Google\\Service\\Dataflow\\ReportWorkItemStatusResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ReportWorkItemStatusResponse.php',
    'Google\\Service\\Dataflow\\ReportedParallelism' => $vendorDir . '/google/apiclient-services/src/Dataflow/ReportedParallelism.php',
    'Google\\Service\\Dataflow\\ResourceUtilizationReport' => $vendorDir . '/google/apiclient-services/src/Dataflow/ResourceUtilizationReport.php',
    'Google\\Service\\Dataflow\\ResourceUtilizationReportResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ResourceUtilizationReportResponse.php',
    'Google\\Service\\Dataflow\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/Projects.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsJobs' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsJobs.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsJobsDebug' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsJobsDebug.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsJobsMessages' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsJobsMessages.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsJobsWorkItems' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsJobsWorkItems.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocations.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsFlexTemplates' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsFlexTemplates.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobs' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobs.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobsDebug' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobsDebug.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobsMessages' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobsMessages.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobsSnapshots' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobsSnapshots.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobsStages' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobsStages.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsJobsWorkItems' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsJobsWorkItems.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsSnapshots' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsSnapshots.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsSql' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsSql.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsLocationsTemplates' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsLocationsTemplates.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsSnapshots' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsSnapshots.php',
    'Google\\Service\\Dataflow\\Resource\\ProjectsTemplates' => $vendorDir . '/google/apiclient-services/src/Dataflow/Resource/ProjectsTemplates.php',
    'Google\\Service\\Dataflow\\RuntimeEnvironment' => $vendorDir . '/google/apiclient-services/src/Dataflow/RuntimeEnvironment.php',
    'Google\\Service\\Dataflow\\RuntimeMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/RuntimeMetadata.php',
    'Google\\Service\\Dataflow\\RuntimeUpdatableParams' => $vendorDir . '/google/apiclient-services/src/Dataflow/RuntimeUpdatableParams.php',
    'Google\\Service\\Dataflow\\SDKInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/SDKInfo.php',
    'Google\\Service\\Dataflow\\SdkBug' => $vendorDir . '/google/apiclient-services/src/Dataflow/SdkBug.php',
    'Google\\Service\\Dataflow\\SdkHarnessContainerImage' => $vendorDir . '/google/apiclient-services/src/Dataflow/SdkHarnessContainerImage.php',
    'Google\\Service\\Dataflow\\SdkVersion' => $vendorDir . '/google/apiclient-services/src/Dataflow/SdkVersion.php',
    'Google\\Service\\Dataflow\\SendDebugCaptureRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SendDebugCaptureRequest.php',
    'Google\\Service\\Dataflow\\SendDebugCaptureResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/SendDebugCaptureResponse.php',
    'Google\\Service\\Dataflow\\SendWorkerMessagesRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SendWorkerMessagesRequest.php',
    'Google\\Service\\Dataflow\\SendWorkerMessagesResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/SendWorkerMessagesResponse.php',
    'Google\\Service\\Dataflow\\SeqMapTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/SeqMapTask.php',
    'Google\\Service\\Dataflow\\SeqMapTaskOutputInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/SeqMapTaskOutputInfo.php',
    'Google\\Service\\Dataflow\\ServiceResources' => $vendorDir . '/google/apiclient-services/src/Dataflow/ServiceResources.php',
    'Google\\Service\\Dataflow\\ShellTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/ShellTask.php',
    'Google\\Service\\Dataflow\\SideInputInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/SideInputInfo.php',
    'Google\\Service\\Dataflow\\Sink' => $vendorDir . '/google/apiclient-services/src/Dataflow/Sink.php',
    'Google\\Service\\Dataflow\\Snapshot' => $vendorDir . '/google/apiclient-services/src/Dataflow/Snapshot.php',
    'Google\\Service\\Dataflow\\SnapshotJobRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SnapshotJobRequest.php',
    'Google\\Service\\Dataflow\\Source' => $vendorDir . '/google/apiclient-services/src/Dataflow/Source.php',
    'Google\\Service\\Dataflow\\SourceFork' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceFork.php',
    'Google\\Service\\Dataflow\\SourceGetMetadataRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceGetMetadataRequest.php',
    'Google\\Service\\Dataflow\\SourceGetMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceGetMetadataResponse.php',
    'Google\\Service\\Dataflow\\SourceMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceMetadata.php',
    'Google\\Service\\Dataflow\\SourceOperationRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceOperationRequest.php',
    'Google\\Service\\Dataflow\\SourceOperationResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceOperationResponse.php',
    'Google\\Service\\Dataflow\\SourceSplitOptions' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceSplitOptions.php',
    'Google\\Service\\Dataflow\\SourceSplitRequest' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceSplitRequest.php',
    'Google\\Service\\Dataflow\\SourceSplitResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceSplitResponse.php',
    'Google\\Service\\Dataflow\\SourceSplitShard' => $vendorDir . '/google/apiclient-services/src/Dataflow/SourceSplitShard.php',
    'Google\\Service\\Dataflow\\SpannerIODetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/SpannerIODetails.php',
    'Google\\Service\\Dataflow\\SplitInt64' => $vendorDir . '/google/apiclient-services/src/Dataflow/SplitInt64.php',
    'Google\\Service\\Dataflow\\StageExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/StageExecutionDetails.php',
    'Google\\Service\\Dataflow\\StageSource' => $vendorDir . '/google/apiclient-services/src/Dataflow/StageSource.php',
    'Google\\Service\\Dataflow\\StageSummary' => $vendorDir . '/google/apiclient-services/src/Dataflow/StageSummary.php',
    'Google\\Service\\Dataflow\\StateFamilyConfig' => $vendorDir . '/google/apiclient-services/src/Dataflow/StateFamilyConfig.php',
    'Google\\Service\\Dataflow\\Status' => $vendorDir . '/google/apiclient-services/src/Dataflow/Status.php',
    'Google\\Service\\Dataflow\\Step' => $vendorDir . '/google/apiclient-services/src/Dataflow/Step.php',
    'Google\\Service\\Dataflow\\Straggler' => $vendorDir . '/google/apiclient-services/src/Dataflow/Straggler.php',
    'Google\\Service\\Dataflow\\StragglerDebuggingInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/StragglerDebuggingInfo.php',
    'Google\\Service\\Dataflow\\StragglerInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/StragglerInfo.php',
    'Google\\Service\\Dataflow\\StragglerSummary' => $vendorDir . '/google/apiclient-services/src/Dataflow/StragglerSummary.php',
    'Google\\Service\\Dataflow\\StreamLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamLocation.php',
    'Google\\Service\\Dataflow\\StreamingApplianceSnapshotConfig' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingApplianceSnapshotConfig.php',
    'Google\\Service\\Dataflow\\StreamingComputationConfig' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingComputationConfig.php',
    'Google\\Service\\Dataflow\\StreamingComputationRanges' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingComputationRanges.php',
    'Google\\Service\\Dataflow\\StreamingComputationTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingComputationTask.php',
    'Google\\Service\\Dataflow\\StreamingConfigTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingConfigTask.php',
    'Google\\Service\\Dataflow\\StreamingOperationalLimits' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingOperationalLimits.php',
    'Google\\Service\\Dataflow\\StreamingScalingReport' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingScalingReport.php',
    'Google\\Service\\Dataflow\\StreamingScalingReportResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingScalingReportResponse.php',
    'Google\\Service\\Dataflow\\StreamingSetupTask' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingSetupTask.php',
    'Google\\Service\\Dataflow\\StreamingSideInputLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingSideInputLocation.php',
    'Google\\Service\\Dataflow\\StreamingStageLocation' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingStageLocation.php',
    'Google\\Service\\Dataflow\\StreamingStragglerInfo' => $vendorDir . '/google/apiclient-services/src/Dataflow/StreamingStragglerInfo.php',
    'Google\\Service\\Dataflow\\StringList' => $vendorDir . '/google/apiclient-services/src/Dataflow/StringList.php',
    'Google\\Service\\Dataflow\\StructuredMessage' => $vendorDir . '/google/apiclient-services/src/Dataflow/StructuredMessage.php',
    'Google\\Service\\Dataflow\\TaskRunnerSettings' => $vendorDir . '/google/apiclient-services/src/Dataflow/TaskRunnerSettings.php',
    'Google\\Service\\Dataflow\\TemplateMetadata' => $vendorDir . '/google/apiclient-services/src/Dataflow/TemplateMetadata.php',
    'Google\\Service\\Dataflow\\TopologyConfig' => $vendorDir . '/google/apiclient-services/src/Dataflow/TopologyConfig.php',
    'Google\\Service\\Dataflow\\TransformSummary' => $vendorDir . '/google/apiclient-services/src/Dataflow/TransformSummary.php',
    'Google\\Service\\Dataflow\\ValidateResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/ValidateResponse.php',
    'Google\\Service\\Dataflow\\WorkItem' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkItem.php',
    'Google\\Service\\Dataflow\\WorkItemDetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkItemDetails.php',
    'Google\\Service\\Dataflow\\WorkItemServiceState' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkItemServiceState.php',
    'Google\\Service\\Dataflow\\WorkItemStatus' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkItemStatus.php',
    'Google\\Service\\Dataflow\\WorkerDetails' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerDetails.php',
    'Google\\Service\\Dataflow\\WorkerHealthReport' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerHealthReport.php',
    'Google\\Service\\Dataflow\\WorkerHealthReportResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerHealthReportResponse.php',
    'Google\\Service\\Dataflow\\WorkerLifecycleEvent' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerLifecycleEvent.php',
    'Google\\Service\\Dataflow\\WorkerMessage' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerMessage.php',
    'Google\\Service\\Dataflow\\WorkerMessageCode' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerMessageCode.php',
    'Google\\Service\\Dataflow\\WorkerMessageResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerMessageResponse.php',
    'Google\\Service\\Dataflow\\WorkerPool' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerPool.php',
    'Google\\Service\\Dataflow\\WorkerSettings' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerSettings.php',
    'Google\\Service\\Dataflow\\WorkerShutdownNotice' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerShutdownNotice.php',
    'Google\\Service\\Dataflow\\WorkerShutdownNoticeResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerShutdownNoticeResponse.php',
    'Google\\Service\\Dataflow\\WorkerThreadScalingReport' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerThreadScalingReport.php',
    'Google\\Service\\Dataflow\\WorkerThreadScalingReportResponse' => $vendorDir . '/google/apiclient-services/src/Dataflow/WorkerThreadScalingReportResponse.php',
    'Google\\Service\\Dataflow\\WriteInstruction' => $vendorDir . '/google/apiclient-services/src/Dataflow/WriteInstruction.php',
    'Google\\Service\\Dataform' => $vendorDir . '/google/apiclient-services/src/Dataform.php',
    'Google\\Service\\Dataform\\Assertion' => $vendorDir . '/google/apiclient-services/src/Dataform/Assertion.php',
    'Google\\Service\\Dataform\\BigQueryAction' => $vendorDir . '/google/apiclient-services/src/Dataform/BigQueryAction.php',
    'Google\\Service\\Dataform\\Binding' => $vendorDir . '/google/apiclient-services/src/Dataform/Binding.php',
    'Google\\Service\\Dataform\\CancelWorkflowInvocationRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/CancelWorkflowInvocationRequest.php',
    'Google\\Service\\Dataform\\CodeCompilationConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/CodeCompilationConfig.php',
    'Google\\Service\\Dataform\\ColumnDescriptor' => $vendorDir . '/google/apiclient-services/src/Dataform/ColumnDescriptor.php',
    'Google\\Service\\Dataform\\CommitAuthor' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitAuthor.php',
    'Google\\Service\\Dataform\\CommitLogEntry' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitLogEntry.php',
    'Google\\Service\\Dataform\\CommitMetadata' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitMetadata.php',
    'Google\\Service\\Dataform\\CommitRepositoryChangesRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitRepositoryChangesRequest.php',
    'Google\\Service\\Dataform\\CommitRepositoryChangesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitRepositoryChangesResponse.php',
    'Google\\Service\\Dataform\\CommitWorkspaceChangesRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/CommitWorkspaceChangesRequest.php',
    'Google\\Service\\Dataform\\CompilationError' => $vendorDir . '/google/apiclient-services/src/Dataform/CompilationError.php',
    'Google\\Service\\Dataform\\CompilationResult' => $vendorDir . '/google/apiclient-services/src/Dataform/CompilationResult.php',
    'Google\\Service\\Dataform\\CompilationResultAction' => $vendorDir . '/google/apiclient-services/src/Dataform/CompilationResultAction.php',
    'Google\\Service\\Dataform\\ComputeRepositoryAccessTokenStatusResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ComputeRepositoryAccessTokenStatusResponse.php',
    'Google\\Service\\Dataform\\Config' => $vendorDir . '/google/apiclient-services/src/Dataform/Config.php',
    'Google\\Service\\Dataform\\DataEncryptionState' => $vendorDir . '/google/apiclient-services/src/Dataform/DataEncryptionState.php',
    'Google\\Service\\Dataform\\DataPreparation' => $vendorDir . '/google/apiclient-services/src/Dataform/DataPreparation.php',
    'Google\\Service\\Dataform\\DataformEmpty' => $vendorDir . '/google/apiclient-services/src/Dataform/DataformEmpty.php',
    'Google\\Service\\Dataform\\Declaration' => $vendorDir . '/google/apiclient-services/src/Dataform/Declaration.php',
    'Google\\Service\\Dataform\\DeleteFile' => $vendorDir . '/google/apiclient-services/src/Dataform/DeleteFile.php',
    'Google\\Service\\Dataform\\DirectoryEntry' => $vendorDir . '/google/apiclient-services/src/Dataform/DirectoryEntry.php',
    'Google\\Service\\Dataform\\DirectorySearchResult' => $vendorDir . '/google/apiclient-services/src/Dataform/DirectorySearchResult.php',
    'Google\\Service\\Dataform\\Expr' => $vendorDir . '/google/apiclient-services/src/Dataform/Expr.php',
    'Google\\Service\\Dataform\\FetchFileDiffResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/FetchFileDiffResponse.php',
    'Google\\Service\\Dataform\\FetchFileGitStatusesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/FetchFileGitStatusesResponse.php',
    'Google\\Service\\Dataform\\FetchGitAheadBehindResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/FetchGitAheadBehindResponse.php',
    'Google\\Service\\Dataform\\FetchRemoteBranchesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/FetchRemoteBranchesResponse.php',
    'Google\\Service\\Dataform\\FetchRepositoryHistoryResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/FetchRepositoryHistoryResponse.php',
    'Google\\Service\\Dataform\\FileOperation' => $vendorDir . '/google/apiclient-services/src/Dataform/FileOperation.php',
    'Google\\Service\\Dataform\\FileSearchResult' => $vendorDir . '/google/apiclient-services/src/Dataform/FileSearchResult.php',
    'Google\\Service\\Dataform\\GitRemoteSettings' => $vendorDir . '/google/apiclient-services/src/Dataform/GitRemoteSettings.php',
    'Google\\Service\\Dataform\\IncrementalTableConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/IncrementalTableConfig.php',
    'Google\\Service\\Dataform\\InstallNpmPackagesRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/InstallNpmPackagesRequest.php',
    'Google\\Service\\Dataform\\InstallNpmPackagesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/InstallNpmPackagesResponse.php',
    'Google\\Service\\Dataform\\Interval' => $vendorDir . '/google/apiclient-services/src/Dataform/Interval.php',
    'Google\\Service\\Dataform\\InvocationConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/InvocationConfig.php',
    'Google\\Service\\Dataform\\ListCompilationResultsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListCompilationResultsResponse.php',
    'Google\\Service\\Dataform\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListLocationsResponse.php',
    'Google\\Service\\Dataform\\ListReleaseConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListReleaseConfigsResponse.php',
    'Google\\Service\\Dataform\\ListRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListRepositoriesResponse.php',
    'Google\\Service\\Dataform\\ListWorkflowConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListWorkflowConfigsResponse.php',
    'Google\\Service\\Dataform\\ListWorkflowInvocationsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListWorkflowInvocationsResponse.php',
    'Google\\Service\\Dataform\\ListWorkspacesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ListWorkspacesResponse.php',
    'Google\\Service\\Dataform\\Location' => $vendorDir . '/google/apiclient-services/src/Dataform/Location.php',
    'Google\\Service\\Dataform\\MakeDirectoryRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/MakeDirectoryRequest.php',
    'Google\\Service\\Dataform\\MakeDirectoryResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/MakeDirectoryResponse.php',
    'Google\\Service\\Dataform\\MoveDirectoryRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/MoveDirectoryRequest.php',
    'Google\\Service\\Dataform\\MoveDirectoryResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/MoveDirectoryResponse.php',
    'Google\\Service\\Dataform\\MoveFileRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/MoveFileRequest.php',
    'Google\\Service\\Dataform\\MoveFileResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/MoveFileResponse.php',
    'Google\\Service\\Dataform\\Notebook' => $vendorDir . '/google/apiclient-services/src/Dataform/Notebook.php',
    'Google\\Service\\Dataform\\NotebookAction' => $vendorDir . '/google/apiclient-services/src/Dataform/NotebookAction.php',
    'Google\\Service\\Dataform\\NotebookRuntimeOptions' => $vendorDir . '/google/apiclient-services/src/Dataform/NotebookRuntimeOptions.php',
    'Google\\Service\\Dataform\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataform/OperationMetadata.php',
    'Google\\Service\\Dataform\\Operations' => $vendorDir . '/google/apiclient-services/src/Dataform/Operations.php',
    'Google\\Service\\Dataform\\Policy' => $vendorDir . '/google/apiclient-services/src/Dataform/Policy.php',
    'Google\\Service\\Dataform\\PullGitCommitsRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/PullGitCommitsRequest.php',
    'Google\\Service\\Dataform\\PushGitCommitsRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/PushGitCommitsRequest.php',
    'Google\\Service\\Dataform\\QueryCompilationResultActionsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/QueryCompilationResultActionsResponse.php',
    'Google\\Service\\Dataform\\QueryDirectoryContentsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/QueryDirectoryContentsResponse.php',
    'Google\\Service\\Dataform\\QueryRepositoryDirectoryContentsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/QueryRepositoryDirectoryContentsResponse.php',
    'Google\\Service\\Dataform\\QueryWorkflowInvocationActionsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/QueryWorkflowInvocationActionsResponse.php',
    'Google\\Service\\Dataform\\ReadFileResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ReadFileResponse.php',
    'Google\\Service\\Dataform\\ReadRepositoryFileResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/ReadRepositoryFileResponse.php',
    'Google\\Service\\Dataform\\Relation' => $vendorDir . '/google/apiclient-services/src/Dataform/Relation.php',
    'Google\\Service\\Dataform\\RelationDescriptor' => $vendorDir . '/google/apiclient-services/src/Dataform/RelationDescriptor.php',
    'Google\\Service\\Dataform\\ReleaseConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/ReleaseConfig.php',
    'Google\\Service\\Dataform\\RemoveDirectoryRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/RemoveDirectoryRequest.php',
    'Google\\Service\\Dataform\\RemoveFileRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/RemoveFileRequest.php',
    'Google\\Service\\Dataform\\Repository' => $vendorDir . '/google/apiclient-services/src/Dataform/Repository.php',
    'Google\\Service\\Dataform\\ResetWorkspaceChangesRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/ResetWorkspaceChangesRequest.php',
    'Google\\Service\\Dataform\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/Projects.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocations.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsCollections' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsCollections.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositories' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositories.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesCommentThreads' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesCommentThreads.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesCommentThreadsComments' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesCommentThreadsComments.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesCompilationResults' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesCompilationResults.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesReleaseConfigs' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesReleaseConfigs.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesWorkflowConfigs' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesWorkflowConfigs.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesWorkflowInvocations' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesWorkflowInvocations.php',
    'Google\\Service\\Dataform\\Resource\\ProjectsLocationsRepositoriesWorkspaces' => $vendorDir . '/google/apiclient-services/src/Dataform/Resource/ProjectsLocationsRepositoriesWorkspaces.php',
    'Google\\Service\\Dataform\\ScheduledExecutionRecord' => $vendorDir . '/google/apiclient-services/src/Dataform/ScheduledExecutionRecord.php',
    'Google\\Service\\Dataform\\ScheduledReleaseRecord' => $vendorDir . '/google/apiclient-services/src/Dataform/ScheduledReleaseRecord.php',
    'Google\\Service\\Dataform\\SearchFilesResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/SearchFilesResponse.php',
    'Google\\Service\\Dataform\\SearchResult' => $vendorDir . '/google/apiclient-services/src/Dataform/SearchResult.php',
    'Google\\Service\\Dataform\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/SetIamPolicyRequest.php',
    'Google\\Service\\Dataform\\SshAuthenticationConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/SshAuthenticationConfig.php',
    'Google\\Service\\Dataform\\Status' => $vendorDir . '/google/apiclient-services/src/Dataform/Status.php',
    'Google\\Service\\Dataform\\Target' => $vendorDir . '/google/apiclient-services/src/Dataform/Target.php',
    'Google\\Service\\Dataform\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/TestIamPermissionsRequest.php',
    'Google\\Service\\Dataform\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/TestIamPermissionsResponse.php',
    'Google\\Service\\Dataform\\UncommittedFileChange' => $vendorDir . '/google/apiclient-services/src/Dataform/UncommittedFileChange.php',
    'Google\\Service\\Dataform\\WorkflowConfig' => $vendorDir . '/google/apiclient-services/src/Dataform/WorkflowConfig.php',
    'Google\\Service\\Dataform\\WorkflowInvocation' => $vendorDir . '/google/apiclient-services/src/Dataform/WorkflowInvocation.php',
    'Google\\Service\\Dataform\\WorkflowInvocationAction' => $vendorDir . '/google/apiclient-services/src/Dataform/WorkflowInvocationAction.php',
    'Google\\Service\\Dataform\\Workspace' => $vendorDir . '/google/apiclient-services/src/Dataform/Workspace.php',
    'Google\\Service\\Dataform\\WorkspaceCompilationOverrides' => $vendorDir . '/google/apiclient-services/src/Dataform/WorkspaceCompilationOverrides.php',
    'Google\\Service\\Dataform\\WriteFile' => $vendorDir . '/google/apiclient-services/src/Dataform/WriteFile.php',
    'Google\\Service\\Dataform\\WriteFileRequest' => $vendorDir . '/google/apiclient-services/src/Dataform/WriteFileRequest.php',
    'Google\\Service\\Dataform\\WriteFileResponse' => $vendorDir . '/google/apiclient-services/src/Dataform/WriteFileResponse.php',
    'Google\\Service\\Datalineage' => $vendorDir . '/google/apiclient-services/src/Datalineage.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1EntityReference' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1EntityReference.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1EventLink' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1EventLink.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1LineageEvent' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1LineageEvent.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1Link' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1Link.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ListLineageEventsResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ListLineageEventsResponse.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ListProcessesResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ListProcessesResponse.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ListRunsResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ListRunsResponse.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1OperationMetadata.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1Origin' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1Origin.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1Process' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1Process.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ProcessLinkInfo' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ProcessLinkInfo.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ProcessLinks' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ProcessLinks.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1Run' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1Run.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1SearchLinksRequest' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1SearchLinksRequest.php',
    'Google\\Service\\Datalineage\\GoogleCloudDatacatalogLineageV1SearchLinksResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleCloudDatacatalogLineageV1SearchLinksResponse.php',
    'Google\\Service\\Datalineage\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\Datalineage\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Datalineage\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleLongrunningOperation.php',
    'Google\\Service\\Datalineage\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleProtobufEmpty.php',
    'Google\\Service\\Datalineage\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Datalineage/GoogleRpcStatus.php',
    'Google\\Service\\Datalineage\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/Projects.php',
    'Google\\Service\\Datalineage\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/ProjectsLocations.php',
    'Google\\Service\\Datalineage\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Datalineage\\Resource\\ProjectsLocationsProcesses' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/ProjectsLocationsProcesses.php',
    'Google\\Service\\Datalineage\\Resource\\ProjectsLocationsProcessesRuns' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/ProjectsLocationsProcessesRuns.php',
    'Google\\Service\\Datalineage\\Resource\\ProjectsLocationsProcessesRunsLineageEvents' => $vendorDir . '/google/apiclient-services/src/Datalineage/Resource/ProjectsLocationsProcessesRunsLineageEvents.php',
    'Google\\Service\\Datapipelines' => $vendorDir . '/google/apiclient-services/src/Datapipelines.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ArrayValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ArrayValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1AtomicValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1AtomicValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1BatchGetTransformDescriptionsResponse' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1BatchGetTransformDescriptionsResponse.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ComputeSchemaRequest' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ComputeSchemaRequest.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ConfiguredTransform' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ConfiguredTransform.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1DataflowJobDetails' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1DataflowJobDetails.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1EnumerationValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1EnumerationValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Field' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Field.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1FieldType' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1FieldType.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1FieldValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1FieldValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1FixedBytesValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1FixedBytesValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1FlexTemplateRuntimeEnvironment' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1FlexTemplateRuntimeEnvironment.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1IterableValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1IterableValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Job' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Job.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LaunchFlexTemplateParameter' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LaunchFlexTemplateParameter.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LaunchFlexTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LaunchFlexTemplateRequest.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LaunchTemplateParameters' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LaunchTemplateParameters.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LaunchTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LaunchTemplateRequest.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ListJobsResponse.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ListPipelinesResponse' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ListPipelinesResponse.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LogicalType' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LogicalType.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LogicalTypeEnumerationType' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LogicalTypeEnumerationType.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1LogicalTypeFixedBytes' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1LogicalTypeFixedBytes.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1MapType' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1MapType.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1MapValue' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1MapValue.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1MapValueEntry' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1MapValueEntry.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Pipeline' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Pipeline.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1RawSchemaInfo' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1RawSchemaInfo.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Row' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Row.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1RunPipelineRequest' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1RunPipelineRequest.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1RunPipelineResponse' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1RunPipelineResponse.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1RuntimeEnvironment' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1RuntimeEnvironment.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1ScheduleSpec' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1ScheduleSpec.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Schema' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Schema.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1SchemaSource' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1SchemaSource.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1SdkVersion' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1SdkVersion.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1StopPipelineRequest' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1StopPipelineRequest.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1TransformDescription' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1TransformDescription.php',
    'Google\\Service\\Datapipelines\\GoogleCloudDatapipelinesV1Workload' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleCloudDatapipelinesV1Workload.php',
    'Google\\Service\\Datapipelines\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleProtobufEmpty.php',
    'Google\\Service\\Datapipelines\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleRpcStatus.php',
    'Google\\Service\\Datapipelines\\GoogleTypeDateTime' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleTypeDateTime.php',
    'Google\\Service\\Datapipelines\\GoogleTypeDecimal' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleTypeDecimal.php',
    'Google\\Service\\Datapipelines\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Datapipelines/GoogleTypeTimeZone.php',
    'Google\\Service\\Datapipelines\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Datapipelines/Resource/Projects.php',
    'Google\\Service\\Datapipelines\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Datapipelines/Resource/ProjectsLocations.php',
    'Google\\Service\\Datapipelines\\Resource\\ProjectsLocationsPipelines' => $vendorDir . '/google/apiclient-services/src/Datapipelines/Resource/ProjectsLocationsPipelines.php',
    'Google\\Service\\Datapipelines\\Resource\\ProjectsLocationsPipelinesJobs' => $vendorDir . '/google/apiclient-services/src/Datapipelines/Resource/ProjectsLocationsPipelinesJobs.php',
    'Google\\Service\\Datapipelines\\Resource\\ProjectsLocationsTransformDescriptions' => $vendorDir . '/google/apiclient-services/src/Datapipelines/Resource/ProjectsLocationsTransformDescriptions.php',
    'Google\\Service\\Dataproc' => $vendorDir . '/google/apiclient-services/src/Dataproc.php',
    'Google\\Service\\DataprocMetastore' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore.php',
    'Google\\Service\\DataprocMetastore\\AlterMetadataResourceLocationRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AlterMetadataResourceLocationRequest.php',
    'Google\\Service\\DataprocMetastore\\AlterMetadataResourceLocationResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AlterMetadataResourceLocationResponse.php',
    'Google\\Service\\DataprocMetastore\\AlterTablePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AlterTablePropertiesRequest.php',
    'Google\\Service\\DataprocMetastore\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AuditConfig.php',
    'Google\\Service\\DataprocMetastore\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AuditLogConfig.php',
    'Google\\Service\\DataprocMetastore\\AutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AutoscalingConfig.php',
    'Google\\Service\\DataprocMetastore\\AuxiliaryVersionConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/AuxiliaryVersionConfig.php',
    'Google\\Service\\DataprocMetastore\\BackendMetastore' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/BackendMetastore.php',
    'Google\\Service\\DataprocMetastore\\Backup' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Backup.php',
    'Google\\Service\\DataprocMetastore\\Binding' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Binding.php',
    'Google\\Service\\DataprocMetastore\\CancelMigrationRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CancelMigrationRequest.php',
    'Google\\Service\\DataprocMetastore\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CancelOperationRequest.php',
    'Google\\Service\\DataprocMetastore\\CdcConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CdcConfig.php',
    'Google\\Service\\DataprocMetastore\\CloudSQLConnectionConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CloudSQLConnectionConfig.php',
    'Google\\Service\\DataprocMetastore\\CloudSQLMigrationConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CloudSQLMigrationConfig.php',
    'Google\\Service\\DataprocMetastore\\CompleteMigrationRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CompleteMigrationRequest.php',
    'Google\\Service\\DataprocMetastore\\Consumer' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Consumer.php',
    'Google\\Service\\DataprocMetastore\\CustomRegionMetadata' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/CustomRegionMetadata.php',
    'Google\\Service\\DataprocMetastore\\DataCatalogConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/DataCatalogConfig.php',
    'Google\\Service\\DataprocMetastore\\DatabaseDump' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/DatabaseDump.php',
    'Google\\Service\\DataprocMetastore\\DataplexConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/DataplexConfig.php',
    'Google\\Service\\DataprocMetastore\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/EncryptionConfig.php',
    'Google\\Service\\DataprocMetastore\\ErrorDetails' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ErrorDetails.php',
    'Google\\Service\\DataprocMetastore\\ExportMetadataRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ExportMetadataRequest.php',
    'Google\\Service\\DataprocMetastore\\Expr' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Expr.php',
    'Google\\Service\\DataprocMetastore\\Federation' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Federation.php',
    'Google\\Service\\DataprocMetastore\\HiveMetastoreConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/HiveMetastoreConfig.php',
    'Google\\Service\\DataprocMetastore\\HiveMetastoreVersion' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/HiveMetastoreVersion.php',
    'Google\\Service\\DataprocMetastore\\KerberosConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/KerberosConfig.php',
    'Google\\Service\\DataprocMetastore\\Lake' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Lake.php',
    'Google\\Service\\DataprocMetastore\\LatestBackup' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/LatestBackup.php',
    'Google\\Service\\DataprocMetastore\\LimitConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/LimitConfig.php',
    'Google\\Service\\DataprocMetastore\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListBackupsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListFederationsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListFederationsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListLocationsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListMetadataImportsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListMetadataImportsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListMigrationExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListMigrationExecutionsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListOperationsResponse.php',
    'Google\\Service\\DataprocMetastore\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ListServicesResponse.php',
    'Google\\Service\\DataprocMetastore\\Location' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Location.php',
    'Google\\Service\\DataprocMetastore\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/LocationMetadata.php',
    'Google\\Service\\DataprocMetastore\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MaintenanceWindow.php',
    'Google\\Service\\DataprocMetastore\\MetadataExport' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MetadataExport.php',
    'Google\\Service\\DataprocMetastore\\MetadataImport' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MetadataImport.php',
    'Google\\Service\\DataprocMetastore\\MetadataIntegration' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MetadataIntegration.php',
    'Google\\Service\\DataprocMetastore\\MetadataManagementActivity' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MetadataManagementActivity.php',
    'Google\\Service\\DataprocMetastore\\MetastoreEmpty' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MetastoreEmpty.php',
    'Google\\Service\\DataprocMetastore\\MigrationExecution' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MigrationExecution.php',
    'Google\\Service\\DataprocMetastore\\MoveTableToDatabaseRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MoveTableToDatabaseRequest.php',
    'Google\\Service\\DataprocMetastore\\MoveTableToDatabaseResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MoveTableToDatabaseResponse.php',
    'Google\\Service\\DataprocMetastore\\MultiRegionMetadata' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/MultiRegionMetadata.php',
    'Google\\Service\\DataprocMetastore\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/NetworkConfig.php',
    'Google\\Service\\DataprocMetastore\\Operation' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Operation.php',
    'Google\\Service\\DataprocMetastore\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/OperationMetadata.php',
    'Google\\Service\\DataprocMetastore\\Policy' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Policy.php',
    'Google\\Service\\DataprocMetastore\\QueryMetadataRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/QueryMetadataRequest.php',
    'Google\\Service\\DataprocMetastore\\QueryMetadataResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/QueryMetadataResponse.php',
    'Google\\Service\\DataprocMetastore\\RemoveIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/RemoveIamPolicyRequest.php',
    'Google\\Service\\DataprocMetastore\\RemoveIamPolicyResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/RemoveIamPolicyResponse.php',
    'Google\\Service\\DataprocMetastore\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/Operations.php',
    'Google\\Service\\DataprocMetastore\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/Projects.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocations.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsFederations' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsFederations.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServices' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServices.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServicesBackups' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServicesBackups.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServicesDatabases' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServicesDatabases.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServicesDatabasesTables' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServicesDatabasesTables.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServicesMetadataImports' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServicesMetadataImports.php',
    'Google\\Service\\DataprocMetastore\\Resource\\ProjectsLocationsServicesMigrationExecutions' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Resource/ProjectsLocationsServicesMigrationExecutions.php',
    'Google\\Service\\DataprocMetastore\\Restore' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Restore.php',
    'Google\\Service\\DataprocMetastore\\RestoreServiceRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/RestoreServiceRequest.php',
    'Google\\Service\\DataprocMetastore\\ScalingConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ScalingConfig.php',
    'Google\\Service\\DataprocMetastore\\ScheduledBackup' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/ScheduledBackup.php',
    'Google\\Service\\DataprocMetastore\\Secret' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Secret.php',
    'Google\\Service\\DataprocMetastore\\Service' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Service.php',
    'Google\\Service\\DataprocMetastore\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/SetIamPolicyRequest.php',
    'Google\\Service\\DataprocMetastore\\StartMigrationRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/StartMigrationRequest.php',
    'Google\\Service\\DataprocMetastore\\Status' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/Status.php',
    'Google\\Service\\DataprocMetastore\\TelemetryConfig' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/TelemetryConfig.php',
    'Google\\Service\\DataprocMetastore\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/TestIamPermissionsRequest.php',
    'Google\\Service\\DataprocMetastore\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DataprocMetastore/TestIamPermissionsResponse.php',
    'Google\\Service\\Dataproc\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/AcceleratorConfig.php',
    'Google\\Service\\Dataproc\\AnalyzeBatchRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/AnalyzeBatchRequest.php',
    'Google\\Service\\Dataproc\\AnalyzeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/AnalyzeOperationMetadata.php',
    'Google\\Service\\Dataproc\\AuthenticationConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/AuthenticationConfig.php',
    'Google\\Service\\Dataproc\\AutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/AutoscalingConfig.php',
    'Google\\Service\\Dataproc\\AutoscalingPolicy' => $vendorDir . '/google/apiclient-services/src/Dataproc/AutoscalingPolicy.php',
    'Google\\Service\\Dataproc\\AutotuningConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/AutotuningConfig.php',
    'Google\\Service\\Dataproc\\AuxiliaryNodeGroup' => $vendorDir . '/google/apiclient-services/src/Dataproc/AuxiliaryNodeGroup.php',
    'Google\\Service\\Dataproc\\AuxiliaryServicesConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/AuxiliaryServicesConfig.php',
    'Google\\Service\\Dataproc\\BasicAutoscalingAlgorithm' => $vendorDir . '/google/apiclient-services/src/Dataproc/BasicAutoscalingAlgorithm.php',
    'Google\\Service\\Dataproc\\BasicYarnAutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/BasicYarnAutoscalingConfig.php',
    'Google\\Service\\Dataproc\\Batch' => $vendorDir . '/google/apiclient-services/src/Dataproc/Batch.php',
    'Google\\Service\\Dataproc\\BatchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/BatchOperationMetadata.php',
    'Google\\Service\\Dataproc\\Binding' => $vendorDir . '/google/apiclient-services/src/Dataproc/Binding.php',
    'Google\\Service\\Dataproc\\CancelJobRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/CancelJobRequest.php',
    'Google\\Service\\Dataproc\\Cluster' => $vendorDir . '/google/apiclient-services/src/Dataproc/Cluster.php',
    'Google\\Service\\Dataproc\\ClusterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterConfig.php',
    'Google\\Service\\Dataproc\\ClusterMetrics' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterMetrics.php',
    'Google\\Service\\Dataproc\\ClusterOperation' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterOperation.php',
    'Google\\Service\\Dataproc\\ClusterOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterOperationMetadata.php',
    'Google\\Service\\Dataproc\\ClusterOperationStatus' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterOperationStatus.php',
    'Google\\Service\\Dataproc\\ClusterSelector' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterSelector.php',
    'Google\\Service\\Dataproc\\ClusterStatus' => $vendorDir . '/google/apiclient-services/src/Dataproc/ClusterStatus.php',
    'Google\\Service\\Dataproc\\ConfidentialInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/ConfidentialInstanceConfig.php',
    'Google\\Service\\Dataproc\\DataprocEmpty' => $vendorDir . '/google/apiclient-services/src/Dataproc/DataprocEmpty.php',
    'Google\\Service\\Dataproc\\DataprocMetricConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/DataprocMetricConfig.php',
    'Google\\Service\\Dataproc\\DiagnoseClusterRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/DiagnoseClusterRequest.php',
    'Google\\Service\\Dataproc\\DiagnoseClusterResults' => $vendorDir . '/google/apiclient-services/src/Dataproc/DiagnoseClusterResults.php',
    'Google\\Service\\Dataproc\\DiskConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/DiskConfig.php',
    'Google\\Service\\Dataproc\\DriverSchedulingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/DriverSchedulingConfig.php',
    'Google\\Service\\Dataproc\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/EncryptionConfig.php',
    'Google\\Service\\Dataproc\\EndpointConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/EndpointConfig.php',
    'Google\\Service\\Dataproc\\EnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/EnvironmentConfig.php',
    'Google\\Service\\Dataproc\\ExecutionConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/ExecutionConfig.php',
    'Google\\Service\\Dataproc\\Expr' => $vendorDir . '/google/apiclient-services/src/Dataproc/Expr.php',
    'Google\\Service\\Dataproc\\FlinkJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/FlinkJob.php',
    'Google\\Service\\Dataproc\\GceClusterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GceClusterConfig.php',
    'Google\\Service\\Dataproc\\GceNodePoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/GceNodePoolOperationMetadata.php',
    'Google\\Service\\Dataproc\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/GetIamPolicyRequest.php',
    'Google\\Service\\Dataproc\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/Dataproc/GetPolicyOptions.php',
    'Google\\Service\\Dataproc\\GkeClusterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeClusterConfig.php',
    'Google\\Service\\Dataproc\\GkeNodeConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeNodeConfig.php',
    'Google\\Service\\Dataproc\\GkeNodePoolAcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeNodePoolAcceleratorConfig.php',
    'Google\\Service\\Dataproc\\GkeNodePoolAutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeNodePoolAutoscalingConfig.php',
    'Google\\Service\\Dataproc\\GkeNodePoolConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeNodePoolConfig.php',
    'Google\\Service\\Dataproc\\GkeNodePoolTarget' => $vendorDir . '/google/apiclient-services/src/Dataproc/GkeNodePoolTarget.php',
    'Google\\Service\\Dataproc\\GoogleCloudDataprocV1WorkflowTemplateEncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/GoogleCloudDataprocV1WorkflowTemplateEncryptionConfig.php',
    'Google\\Service\\Dataproc\\HadoopJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/HadoopJob.php',
    'Google\\Service\\Dataproc\\HiveJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/HiveJob.php',
    'Google\\Service\\Dataproc\\IdentityConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/IdentityConfig.php',
    'Google\\Service\\Dataproc\\InjectCredentialsRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/InjectCredentialsRequest.php',
    'Google\\Service\\Dataproc\\InjectSessionCredentialsRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/InjectSessionCredentialsRequest.php',
    'Google\\Service\\Dataproc\\InjectableCredentialsConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/InjectableCredentialsConfig.php',
    'Google\\Service\\Dataproc\\InstanceFlexibilityPolicy' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceFlexibilityPolicy.php',
    'Google\\Service\\Dataproc\\InstanceGroupAutoscalingPolicyConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceGroupAutoscalingPolicyConfig.php',
    'Google\\Service\\Dataproc\\InstanceGroupConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceGroupConfig.php',
    'Google\\Service\\Dataproc\\InstanceReference' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceReference.php',
    'Google\\Service\\Dataproc\\InstanceSelection' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceSelection.php',
    'Google\\Service\\Dataproc\\InstanceSelectionResult' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstanceSelectionResult.php',
    'Google\\Service\\Dataproc\\InstantiateWorkflowTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/InstantiateWorkflowTemplateRequest.php',
    'Google\\Service\\Dataproc\\Interval' => $vendorDir . '/google/apiclient-services/src/Dataproc/Interval.php',
    'Google\\Service\\Dataproc\\Job' => $vendorDir . '/google/apiclient-services/src/Dataproc/Job.php',
    'Google\\Service\\Dataproc\\JobMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/JobMetadata.php',
    'Google\\Service\\Dataproc\\JobPlacement' => $vendorDir . '/google/apiclient-services/src/Dataproc/JobPlacement.php',
    'Google\\Service\\Dataproc\\JobReference' => $vendorDir . '/google/apiclient-services/src/Dataproc/JobReference.php',
    'Google\\Service\\Dataproc\\JobScheduling' => $vendorDir . '/google/apiclient-services/src/Dataproc/JobScheduling.php',
    'Google\\Service\\Dataproc\\JobStatus' => $vendorDir . '/google/apiclient-services/src/Dataproc/JobStatus.php',
    'Google\\Service\\Dataproc\\JupyterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/JupyterConfig.php',
    'Google\\Service\\Dataproc\\KerberosConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/KerberosConfig.php',
    'Google\\Service\\Dataproc\\KubernetesClusterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/KubernetesClusterConfig.php',
    'Google\\Service\\Dataproc\\KubernetesSoftwareConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/KubernetesSoftwareConfig.php',
    'Google\\Service\\Dataproc\\LifecycleConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/LifecycleConfig.php',
    'Google\\Service\\Dataproc\\ListAutoscalingPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListAutoscalingPoliciesResponse.php',
    'Google\\Service\\Dataproc\\ListBatchesResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListBatchesResponse.php',
    'Google\\Service\\Dataproc\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListClustersResponse.php',
    'Google\\Service\\Dataproc\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListJobsResponse.php',
    'Google\\Service\\Dataproc\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListOperationsResponse.php',
    'Google\\Service\\Dataproc\\ListSessionTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListSessionTemplatesResponse.php',
    'Google\\Service\\Dataproc\\ListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListSessionsResponse.php',
    'Google\\Service\\Dataproc\\ListWorkflowTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/ListWorkflowTemplatesResponse.php',
    'Google\\Service\\Dataproc\\LoggingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/LoggingConfig.php',
    'Google\\Service\\Dataproc\\ManagedCluster' => $vendorDir . '/google/apiclient-services/src/Dataproc/ManagedCluster.php',
    'Google\\Service\\Dataproc\\ManagedGroupConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/ManagedGroupConfig.php',
    'Google\\Service\\Dataproc\\MetastoreConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/MetastoreConfig.php',
    'Google\\Service\\Dataproc\\Metric' => $vendorDir . '/google/apiclient-services/src/Dataproc/Metric.php',
    'Google\\Service\\Dataproc\\NamespacedGkeDeploymentTarget' => $vendorDir . '/google/apiclient-services/src/Dataproc/NamespacedGkeDeploymentTarget.php',
    'Google\\Service\\Dataproc\\NodeGroup' => $vendorDir . '/google/apiclient-services/src/Dataproc/NodeGroup.php',
    'Google\\Service\\Dataproc\\NodeGroupAffinity' => $vendorDir . '/google/apiclient-services/src/Dataproc/NodeGroupAffinity.php',
    'Google\\Service\\Dataproc\\NodeGroupOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/NodeGroupOperationMetadata.php',
    'Google\\Service\\Dataproc\\NodeInitializationAction' => $vendorDir . '/google/apiclient-services/src/Dataproc/NodeInitializationAction.php',
    'Google\\Service\\Dataproc\\NodePool' => $vendorDir . '/google/apiclient-services/src/Dataproc/NodePool.php',
    'Google\\Service\\Dataproc\\Operation' => $vendorDir . '/google/apiclient-services/src/Dataproc/Operation.php',
    'Google\\Service\\Dataproc\\OrderedJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/OrderedJob.php',
    'Google\\Service\\Dataproc\\ParameterValidation' => $vendorDir . '/google/apiclient-services/src/Dataproc/ParameterValidation.php',
    'Google\\Service\\Dataproc\\PeripheralsConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/PeripheralsConfig.php',
    'Google\\Service\\Dataproc\\PigJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/PigJob.php',
    'Google\\Service\\Dataproc\\Policy' => $vendorDir . '/google/apiclient-services/src/Dataproc/Policy.php',
    'Google\\Service\\Dataproc\\PrestoJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/PrestoJob.php',
    'Google\\Service\\Dataproc\\PyPiRepositoryConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/PyPiRepositoryConfig.php',
    'Google\\Service\\Dataproc\\PySparkBatch' => $vendorDir . '/google/apiclient-services/src/Dataproc/PySparkBatch.php',
    'Google\\Service\\Dataproc\\PySparkJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/PySparkJob.php',
    'Google\\Service\\Dataproc\\QueryList' => $vendorDir . '/google/apiclient-services/src/Dataproc/QueryList.php',
    'Google\\Service\\Dataproc\\RegexValidation' => $vendorDir . '/google/apiclient-services/src/Dataproc/RegexValidation.php',
    'Google\\Service\\Dataproc\\RepairClusterRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/RepairClusterRequest.php',
    'Google\\Service\\Dataproc\\RepairNodeGroupRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/RepairNodeGroupRequest.php',
    'Google\\Service\\Dataproc\\RepositoryConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/RepositoryConfig.php',
    'Google\\Service\\Dataproc\\ReservationAffinity' => $vendorDir . '/google/apiclient-services/src/Dataproc/ReservationAffinity.php',
    'Google\\Service\\Dataproc\\ResizeNodeGroupRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/ResizeNodeGroupRequest.php',
    'Google\\Service\\Dataproc\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/Projects.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocations.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsAutoscalingPolicies' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsAutoscalingPolicies.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsBatches' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsBatches.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsSessionTemplates' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsSessionTemplates.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsSessions' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsSessions.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsLocationsWorkflowTemplates' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsLocationsWorkflowTemplates.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegions' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegions.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsAutoscalingPolicies' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsAutoscalingPolicies.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsClusters' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsClusters.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsClustersNodeGroups' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsClustersNodeGroups.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsJobs' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsJobs.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsOperations' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsOperations.php',
    'Google\\Service\\Dataproc\\Resource\\ProjectsRegionsWorkflowTemplates' => $vendorDir . '/google/apiclient-services/src/Dataproc/Resource/ProjectsRegionsWorkflowTemplates.php',
    'Google\\Service\\Dataproc\\RuntimeConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/RuntimeConfig.php',
    'Google\\Service\\Dataproc\\RuntimeInfo' => $vendorDir . '/google/apiclient-services/src/Dataproc/RuntimeInfo.php',
    'Google\\Service\\Dataproc\\SecurityConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/SecurityConfig.php',
    'Google\\Service\\Dataproc\\Session' => $vendorDir . '/google/apiclient-services/src/Dataproc/Session.php',
    'Google\\Service\\Dataproc\\SessionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/SessionOperationMetadata.php',
    'Google\\Service\\Dataproc\\SessionStateHistory' => $vendorDir . '/google/apiclient-services/src/Dataproc/SessionStateHistory.php',
    'Google\\Service\\Dataproc\\SessionTemplate' => $vendorDir . '/google/apiclient-services/src/Dataproc/SessionTemplate.php',
    'Google\\Service\\Dataproc\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/SetIamPolicyRequest.php',
    'Google\\Service\\Dataproc\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/ShieldedInstanceConfig.php',
    'Google\\Service\\Dataproc\\SoftwareConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/SoftwareConfig.php',
    'Google\\Service\\Dataproc\\SparkBatch' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkBatch.php',
    'Google\\Service\\Dataproc\\SparkConnectConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkConnectConfig.php',
    'Google\\Service\\Dataproc\\SparkHistoryServerConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkHistoryServerConfig.php',
    'Google\\Service\\Dataproc\\SparkJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkJob.php',
    'Google\\Service\\Dataproc\\SparkRBatch' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkRBatch.php',
    'Google\\Service\\Dataproc\\SparkRJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkRJob.php',
    'Google\\Service\\Dataproc\\SparkSqlBatch' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkSqlBatch.php',
    'Google\\Service\\Dataproc\\SparkSqlJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkSqlJob.php',
    'Google\\Service\\Dataproc\\SparkStandaloneAutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/SparkStandaloneAutoscalingConfig.php',
    'Google\\Service\\Dataproc\\StartClusterRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/StartClusterRequest.php',
    'Google\\Service\\Dataproc\\StartupConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/StartupConfig.php',
    'Google\\Service\\Dataproc\\StateHistory' => $vendorDir . '/google/apiclient-services/src/Dataproc/StateHistory.php',
    'Google\\Service\\Dataproc\\Status' => $vendorDir . '/google/apiclient-services/src/Dataproc/Status.php',
    'Google\\Service\\Dataproc\\StopClusterRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/StopClusterRequest.php',
    'Google\\Service\\Dataproc\\SubmitJobRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/SubmitJobRequest.php',
    'Google\\Service\\Dataproc\\TemplateParameter' => $vendorDir . '/google/apiclient-services/src/Dataproc/TemplateParameter.php',
    'Google\\Service\\Dataproc\\TerminateSessionRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/TerminateSessionRequest.php',
    'Google\\Service\\Dataproc\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Dataproc/TestIamPermissionsRequest.php',
    'Google\\Service\\Dataproc\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Dataproc/TestIamPermissionsResponse.php',
    'Google\\Service\\Dataproc\\TrinoJob' => $vendorDir . '/google/apiclient-services/src/Dataproc/TrinoJob.php',
    'Google\\Service\\Dataproc\\UsageMetrics' => $vendorDir . '/google/apiclient-services/src/Dataproc/UsageMetrics.php',
    'Google\\Service\\Dataproc\\UsageSnapshot' => $vendorDir . '/google/apiclient-services/src/Dataproc/UsageSnapshot.php',
    'Google\\Service\\Dataproc\\ValueValidation' => $vendorDir . '/google/apiclient-services/src/Dataproc/ValueValidation.php',
    'Google\\Service\\Dataproc\\VirtualClusterConfig' => $vendorDir . '/google/apiclient-services/src/Dataproc/VirtualClusterConfig.php',
    'Google\\Service\\Dataproc\\WorkflowGraph' => $vendorDir . '/google/apiclient-services/src/Dataproc/WorkflowGraph.php',
    'Google\\Service\\Dataproc\\WorkflowMetadata' => $vendorDir . '/google/apiclient-services/src/Dataproc/WorkflowMetadata.php',
    'Google\\Service\\Dataproc\\WorkflowNode' => $vendorDir . '/google/apiclient-services/src/Dataproc/WorkflowNode.php',
    'Google\\Service\\Dataproc\\WorkflowTemplate' => $vendorDir . '/google/apiclient-services/src/Dataproc/WorkflowTemplate.php',
    'Google\\Service\\Dataproc\\WorkflowTemplatePlacement' => $vendorDir . '/google/apiclient-services/src/Dataproc/WorkflowTemplatePlacement.php',
    'Google\\Service\\Dataproc\\YarnApplication' => $vendorDir . '/google/apiclient-services/src/Dataproc/YarnApplication.php',
    'Google\\Service\\Datastore' => $vendorDir . '/google/apiclient-services/src/Datastore.php',
    'Google\\Service\\Datastore\\Aggregation' => $vendorDir . '/google/apiclient-services/src/Datastore/Aggregation.php',
    'Google\\Service\\Datastore\\AggregationQuery' => $vendorDir . '/google/apiclient-services/src/Datastore/AggregationQuery.php',
    'Google\\Service\\Datastore\\AggregationResult' => $vendorDir . '/google/apiclient-services/src/Datastore/AggregationResult.php',
    'Google\\Service\\Datastore\\AggregationResultBatch' => $vendorDir . '/google/apiclient-services/src/Datastore/AggregationResultBatch.php',
    'Google\\Service\\Datastore\\AllocateIdsRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/AllocateIdsRequest.php',
    'Google\\Service\\Datastore\\AllocateIdsResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/AllocateIdsResponse.php',
    'Google\\Service\\Datastore\\ArrayValue' => $vendorDir . '/google/apiclient-services/src/Datastore/ArrayValue.php',
    'Google\\Service\\Datastore\\Avg' => $vendorDir . '/google/apiclient-services/src/Datastore/Avg.php',
    'Google\\Service\\Datastore\\BeginTransactionRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/BeginTransactionRequest.php',
    'Google\\Service\\Datastore\\BeginTransactionResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/BeginTransactionResponse.php',
    'Google\\Service\\Datastore\\CommitRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/CommitRequest.php',
    'Google\\Service\\Datastore\\CommitResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/CommitResponse.php',
    'Google\\Service\\Datastore\\CompositeFilter' => $vendorDir . '/google/apiclient-services/src/Datastore/CompositeFilter.php',
    'Google\\Service\\Datastore\\Count' => $vendorDir . '/google/apiclient-services/src/Datastore/Count.php',
    'Google\\Service\\Datastore\\DatastoreEmpty' => $vendorDir . '/google/apiclient-services/src/Datastore/DatastoreEmpty.php',
    'Google\\Service\\Datastore\\DatastoreReadOnly' => $vendorDir . '/google/apiclient-services/src/Datastore/DatastoreReadOnly.php',
    'Google\\Service\\Datastore\\Entity' => $vendorDir . '/google/apiclient-services/src/Datastore/Entity.php',
    'Google\\Service\\Datastore\\EntityResult' => $vendorDir . '/google/apiclient-services/src/Datastore/EntityResult.php',
    'Google\\Service\\Datastore\\ExecutionStats' => $vendorDir . '/google/apiclient-services/src/Datastore/ExecutionStats.php',
    'Google\\Service\\Datastore\\ExplainMetrics' => $vendorDir . '/google/apiclient-services/src/Datastore/ExplainMetrics.php',
    'Google\\Service\\Datastore\\ExplainOptions' => $vendorDir . '/google/apiclient-services/src/Datastore/ExplainOptions.php',
    'Google\\Service\\Datastore\\Filter' => $vendorDir . '/google/apiclient-services/src/Datastore/Filter.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1CommonMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1CommonMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1DatastoreFirestoreMigrationMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1DatastoreFirestoreMigrationMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1EntityFilter' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1EntityFilter.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ExportEntitiesMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ExportEntitiesMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ExportEntitiesRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ExportEntitiesRequest.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ExportEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ExportEntitiesResponse.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ImportEntitiesMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ImportEntitiesMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ImportEntitiesRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ImportEntitiesRequest.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1Index' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1Index.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1IndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1IndexOperationMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1IndexedProperty' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1IndexedProperty.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1ListIndexesResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1ListIndexesResponse.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1MigrationProgressEvent' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1MigrationProgressEvent.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1MigrationStateEvent' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1MigrationStateEvent.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1PrepareStepDetails' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1PrepareStepDetails.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1Progress' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1Progress.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1RedirectWritesStepDetails' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1RedirectWritesStepDetails.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1CommonMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1CommonMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1EntityFilter' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1EntityFilter.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1ExportEntitiesMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1ExportEntitiesMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1ExportEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1ExportEntitiesResponse.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1ImportEntitiesMetadata' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1ImportEntitiesMetadata.php',
    'Google\\Service\\Datastore\\GoogleDatastoreAdminV1beta1Progress' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleDatastoreAdminV1beta1Progress.php',
    'Google\\Service\\Datastore\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Datastore\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Datastore/GoogleLongrunningOperation.php',
    'Google\\Service\\Datastore\\GqlQuery' => $vendorDir . '/google/apiclient-services/src/Datastore/GqlQuery.php',
    'Google\\Service\\Datastore\\GqlQueryParameter' => $vendorDir . '/google/apiclient-services/src/Datastore/GqlQueryParameter.php',
    'Google\\Service\\Datastore\\Key' => $vendorDir . '/google/apiclient-services/src/Datastore/Key.php',
    'Google\\Service\\Datastore\\KindExpression' => $vendorDir . '/google/apiclient-services/src/Datastore/KindExpression.php',
    'Google\\Service\\Datastore\\LatLng' => $vendorDir . '/google/apiclient-services/src/Datastore/LatLng.php',
    'Google\\Service\\Datastore\\LookupRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/LookupRequest.php',
    'Google\\Service\\Datastore\\LookupResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/LookupResponse.php',
    'Google\\Service\\Datastore\\Mutation' => $vendorDir . '/google/apiclient-services/src/Datastore/Mutation.php',
    'Google\\Service\\Datastore\\MutationResult' => $vendorDir . '/google/apiclient-services/src/Datastore/MutationResult.php',
    'Google\\Service\\Datastore\\PartitionId' => $vendorDir . '/google/apiclient-services/src/Datastore/PartitionId.php',
    'Google\\Service\\Datastore\\PathElement' => $vendorDir . '/google/apiclient-services/src/Datastore/PathElement.php',
    'Google\\Service\\Datastore\\PlanSummary' => $vendorDir . '/google/apiclient-services/src/Datastore/PlanSummary.php',
    'Google\\Service\\Datastore\\Projection' => $vendorDir . '/google/apiclient-services/src/Datastore/Projection.php',
    'Google\\Service\\Datastore\\PropertyFilter' => $vendorDir . '/google/apiclient-services/src/Datastore/PropertyFilter.php',
    'Google\\Service\\Datastore\\PropertyMask' => $vendorDir . '/google/apiclient-services/src/Datastore/PropertyMask.php',
    'Google\\Service\\Datastore\\PropertyOrder' => $vendorDir . '/google/apiclient-services/src/Datastore/PropertyOrder.php',
    'Google\\Service\\Datastore\\PropertyReference' => $vendorDir . '/google/apiclient-services/src/Datastore/PropertyReference.php',
    'Google\\Service\\Datastore\\Query' => $vendorDir . '/google/apiclient-services/src/Datastore/Query.php',
    'Google\\Service\\Datastore\\QueryPlan' => $vendorDir . '/google/apiclient-services/src/Datastore/QueryPlan.php',
    'Google\\Service\\Datastore\\QueryResultBatch' => $vendorDir . '/google/apiclient-services/src/Datastore/QueryResultBatch.php',
    'Google\\Service\\Datastore\\ReadOptions' => $vendorDir . '/google/apiclient-services/src/Datastore/ReadOptions.php',
    'Google\\Service\\Datastore\\ReadWrite' => $vendorDir . '/google/apiclient-services/src/Datastore/ReadWrite.php',
    'Google\\Service\\Datastore\\ReserveIdsRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/ReserveIdsRequest.php',
    'Google\\Service\\Datastore\\ReserveIdsResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/ReserveIdsResponse.php',
    'Google\\Service\\Datastore\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Datastore/Resource/Projects.php',
    'Google\\Service\\Datastore\\Resource\\ProjectsIndexes' => $vendorDir . '/google/apiclient-services/src/Datastore/Resource/ProjectsIndexes.php',
    'Google\\Service\\Datastore\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/Datastore/Resource/ProjectsOperations.php',
    'Google\\Service\\Datastore\\ResultSetStats' => $vendorDir . '/google/apiclient-services/src/Datastore/ResultSetStats.php',
    'Google\\Service\\Datastore\\RollbackRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/RollbackRequest.php',
    'Google\\Service\\Datastore\\RollbackResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/RollbackResponse.php',
    'Google\\Service\\Datastore\\RunAggregationQueryRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/RunAggregationQueryRequest.php',
    'Google\\Service\\Datastore\\RunAggregationQueryResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/RunAggregationQueryResponse.php',
    'Google\\Service\\Datastore\\RunQueryRequest' => $vendorDir . '/google/apiclient-services/src/Datastore/RunQueryRequest.php',
    'Google\\Service\\Datastore\\RunQueryResponse' => $vendorDir . '/google/apiclient-services/src/Datastore/RunQueryResponse.php',
    'Google\\Service\\Datastore\\Status' => $vendorDir . '/google/apiclient-services/src/Datastore/Status.php',
    'Google\\Service\\Datastore\\Sum' => $vendorDir . '/google/apiclient-services/src/Datastore/Sum.php',
    'Google\\Service\\Datastore\\TransactionOptions' => $vendorDir . '/google/apiclient-services/src/Datastore/TransactionOptions.php',
    'Google\\Service\\Datastore\\Value' => $vendorDir . '/google/apiclient-services/src/Datastore/Value.php',
    'Google\\Service\\Datastream' => $vendorDir . '/google/apiclient-services/src/Datastream.php',
    'Google\\Service\\Datastream\\AppendOnly' => $vendorDir . '/google/apiclient-services/src/Datastream/AppendOnly.php',
    'Google\\Service\\Datastream\\AvroFileFormat' => $vendorDir . '/google/apiclient-services/src/Datastream/AvroFileFormat.php',
    'Google\\Service\\Datastream\\BackfillAllStrategy' => $vendorDir . '/google/apiclient-services/src/Datastream/BackfillAllStrategy.php',
    'Google\\Service\\Datastream\\BackfillJob' => $vendorDir . '/google/apiclient-services/src/Datastream/BackfillJob.php',
    'Google\\Service\\Datastream\\BackfillNoneStrategy' => $vendorDir . '/google/apiclient-services/src/Datastream/BackfillNoneStrategy.php',
    'Google\\Service\\Datastream\\BigQueryDestinationConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/BigQueryDestinationConfig.php',
    'Google\\Service\\Datastream\\BigQueryProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/BigQueryProfile.php',
    'Google\\Service\\Datastream\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/CancelOperationRequest.php',
    'Google\\Service\\Datastream\\CdcStrategy' => $vendorDir . '/google/apiclient-services/src/Datastream/CdcStrategy.php',
    'Google\\Service\\Datastream\\ConnectionProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/ConnectionProfile.php',
    'Google\\Service\\Datastream\\DatasetTemplate' => $vendorDir . '/google/apiclient-services/src/Datastream/DatasetTemplate.php',
    'Google\\Service\\Datastream\\DatastreamEmpty' => $vendorDir . '/google/apiclient-services/src/Datastream/DatastreamEmpty.php',
    'Google\\Service\\Datastream\\DestinationConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/DestinationConfig.php',
    'Google\\Service\\Datastream\\DiscoverConnectionProfileRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/DiscoverConnectionProfileRequest.php',
    'Google\\Service\\Datastream\\DiscoverConnectionProfileResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/DiscoverConnectionProfileResponse.php',
    'Google\\Service\\Datastream\\DropLargeObjects' => $vendorDir . '/google/apiclient-services/src/Datastream/DropLargeObjects.php',
    'Google\\Service\\Datastream\\Error' => $vendorDir . '/google/apiclient-services/src/Datastream/Error.php',
    'Google\\Service\\Datastream\\FetchErrorsRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/FetchErrorsRequest.php',
    'Google\\Service\\Datastream\\FetchErrorsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/FetchErrorsResponse.php',
    'Google\\Service\\Datastream\\FetchStaticIpsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/FetchStaticIpsResponse.php',
    'Google\\Service\\Datastream\\ForwardSshTunnelConnectivity' => $vendorDir . '/google/apiclient-services/src/Datastream/ForwardSshTunnelConnectivity.php',
    'Google\\Service\\Datastream\\GcsDestinationConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/GcsDestinationConfig.php',
    'Google\\Service\\Datastream\\GcsProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/GcsProfile.php',
    'Google\\Service\\Datastream\\JsonFileFormat' => $vendorDir . '/google/apiclient-services/src/Datastream/JsonFileFormat.php',
    'Google\\Service\\Datastream\\ListConnectionProfilesResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListConnectionProfilesResponse.php',
    'Google\\Service\\Datastream\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListLocationsResponse.php',
    'Google\\Service\\Datastream\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListOperationsResponse.php',
    'Google\\Service\\Datastream\\ListPrivateConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListPrivateConnectionsResponse.php',
    'Google\\Service\\Datastream\\ListRoutesResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListRoutesResponse.php',
    'Google\\Service\\Datastream\\ListStreamObjectsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListStreamObjectsResponse.php',
    'Google\\Service\\Datastream\\ListStreamsResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/ListStreamsResponse.php',
    'Google\\Service\\Datastream\\Location' => $vendorDir . '/google/apiclient-services/src/Datastream/Location.php',
    'Google\\Service\\Datastream\\LookupStreamObjectRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/LookupStreamObjectRequest.php',
    'Google\\Service\\Datastream\\Merge' => $vendorDir . '/google/apiclient-services/src/Datastream/Merge.php',
    'Google\\Service\\Datastream\\MostRecentStartPosition' => $vendorDir . '/google/apiclient-services/src/Datastream/MostRecentStartPosition.php',
    'Google\\Service\\Datastream\\MysqlColumn' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlColumn.php',
    'Google\\Service\\Datastream\\MysqlDatabase' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlDatabase.php',
    'Google\\Service\\Datastream\\MysqlLogPosition' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlLogPosition.php',
    'Google\\Service\\Datastream\\MysqlObjectIdentifier' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlObjectIdentifier.php',
    'Google\\Service\\Datastream\\MysqlProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlProfile.php',
    'Google\\Service\\Datastream\\MysqlRdbms' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlRdbms.php',
    'Google\\Service\\Datastream\\MysqlSourceConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlSourceConfig.php',
    'Google\\Service\\Datastream\\MysqlSslConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlSslConfig.php',
    'Google\\Service\\Datastream\\MysqlTable' => $vendorDir . '/google/apiclient-services/src/Datastream/MysqlTable.php',
    'Google\\Service\\Datastream\\NextAvailableStartPosition' => $vendorDir . '/google/apiclient-services/src/Datastream/NextAvailableStartPosition.php',
    'Google\\Service\\Datastream\\NoConnectivitySettings' => $vendorDir . '/google/apiclient-services/src/Datastream/NoConnectivitySettings.php',
    'Google\\Service\\Datastream\\Operation' => $vendorDir . '/google/apiclient-services/src/Datastream/Operation.php',
    'Google\\Service\\Datastream\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Datastream/OperationMetadata.php',
    'Google\\Service\\Datastream\\OracleColumn' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleColumn.php',
    'Google\\Service\\Datastream\\OracleDropLargeObjects' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleDropLargeObjects.php',
    'Google\\Service\\Datastream\\OracleObjectIdentifier' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleObjectIdentifier.php',
    'Google\\Service\\Datastream\\OracleProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleProfile.php',
    'Google\\Service\\Datastream\\OracleRdbms' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleRdbms.php',
    'Google\\Service\\Datastream\\OracleSchema' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleSchema.php',
    'Google\\Service\\Datastream\\OracleScnPosition' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleScnPosition.php',
    'Google\\Service\\Datastream\\OracleSourceConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleSourceConfig.php',
    'Google\\Service\\Datastream\\OracleSslConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleSslConfig.php',
    'Google\\Service\\Datastream\\OracleTable' => $vendorDir . '/google/apiclient-services/src/Datastream/OracleTable.php',
    'Google\\Service\\Datastream\\PostgresqlColumn' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlColumn.php',
    'Google\\Service\\Datastream\\PostgresqlObjectIdentifier' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlObjectIdentifier.php',
    'Google\\Service\\Datastream\\PostgresqlProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlProfile.php',
    'Google\\Service\\Datastream\\PostgresqlRdbms' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlRdbms.php',
    'Google\\Service\\Datastream\\PostgresqlSchema' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlSchema.php',
    'Google\\Service\\Datastream\\PostgresqlSourceConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlSourceConfig.php',
    'Google\\Service\\Datastream\\PostgresqlTable' => $vendorDir . '/google/apiclient-services/src/Datastream/PostgresqlTable.php',
    'Google\\Service\\Datastream\\PrivateConnection' => $vendorDir . '/google/apiclient-services/src/Datastream/PrivateConnection.php',
    'Google\\Service\\Datastream\\PrivateConnectivity' => $vendorDir . '/google/apiclient-services/src/Datastream/PrivateConnectivity.php',
    'Google\\Service\\Datastream\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/Projects.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocations.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsConnectionProfiles' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsConnectionProfiles.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsPrivateConnections' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsPrivateConnections.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsPrivateConnectionsRoutes' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsPrivateConnectionsRoutes.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsStreams' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsStreams.php',
    'Google\\Service\\Datastream\\Resource\\ProjectsLocationsStreamsObjects' => $vendorDir . '/google/apiclient-services/src/Datastream/Resource/ProjectsLocationsStreamsObjects.php',
    'Google\\Service\\Datastream\\Route' => $vendorDir . '/google/apiclient-services/src/Datastream/Route.php',
    'Google\\Service\\Datastream\\RunStreamRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/RunStreamRequest.php',
    'Google\\Service\\Datastream\\SingleTargetDataset' => $vendorDir . '/google/apiclient-services/src/Datastream/SingleTargetDataset.php',
    'Google\\Service\\Datastream\\SourceConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/SourceConfig.php',
    'Google\\Service\\Datastream\\SourceHierarchyDatasets' => $vendorDir . '/google/apiclient-services/src/Datastream/SourceHierarchyDatasets.php',
    'Google\\Service\\Datastream\\SourceObjectIdentifier' => $vendorDir . '/google/apiclient-services/src/Datastream/SourceObjectIdentifier.php',
    'Google\\Service\\Datastream\\SpecificStartPosition' => $vendorDir . '/google/apiclient-services/src/Datastream/SpecificStartPosition.php',
    'Google\\Service\\Datastream\\SqlServerChangeTables' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerChangeTables.php',
    'Google\\Service\\Datastream\\SqlServerColumn' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerColumn.php',
    'Google\\Service\\Datastream\\SqlServerObjectIdentifier' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerObjectIdentifier.php',
    'Google\\Service\\Datastream\\SqlServerProfile' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerProfile.php',
    'Google\\Service\\Datastream\\SqlServerRdbms' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerRdbms.php',
    'Google\\Service\\Datastream\\SqlServerSchema' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerSchema.php',
    'Google\\Service\\Datastream\\SqlServerSourceConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerSourceConfig.php',
    'Google\\Service\\Datastream\\SqlServerTable' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerTable.php',
    'Google\\Service\\Datastream\\SqlServerTransactionLogs' => $vendorDir . '/google/apiclient-services/src/Datastream/SqlServerTransactionLogs.php',
    'Google\\Service\\Datastream\\StartBackfillJobRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/StartBackfillJobRequest.php',
    'Google\\Service\\Datastream\\StartBackfillJobResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/StartBackfillJobResponse.php',
    'Google\\Service\\Datastream\\StaticServiceIpConnectivity' => $vendorDir . '/google/apiclient-services/src/Datastream/StaticServiceIpConnectivity.php',
    'Google\\Service\\Datastream\\Status' => $vendorDir . '/google/apiclient-services/src/Datastream/Status.php',
    'Google\\Service\\Datastream\\StopBackfillJobRequest' => $vendorDir . '/google/apiclient-services/src/Datastream/StopBackfillJobRequest.php',
    'Google\\Service\\Datastream\\StopBackfillJobResponse' => $vendorDir . '/google/apiclient-services/src/Datastream/StopBackfillJobResponse.php',
    'Google\\Service\\Datastream\\Stream' => $vendorDir . '/google/apiclient-services/src/Datastream/Stream.php',
    'Google\\Service\\Datastream\\StreamLargeObjects' => $vendorDir . '/google/apiclient-services/src/Datastream/StreamLargeObjects.php',
    'Google\\Service\\Datastream\\StreamObject' => $vendorDir . '/google/apiclient-services/src/Datastream/StreamObject.php',
    'Google\\Service\\Datastream\\Validation' => $vendorDir . '/google/apiclient-services/src/Datastream/Validation.php',
    'Google\\Service\\Datastream\\ValidationMessage' => $vendorDir . '/google/apiclient-services/src/Datastream/ValidationMessage.php',
    'Google\\Service\\Datastream\\ValidationResult' => $vendorDir . '/google/apiclient-services/src/Datastream/ValidationResult.php',
    'Google\\Service\\Datastream\\VpcPeeringConfig' => $vendorDir . '/google/apiclient-services/src/Datastream/VpcPeeringConfig.php',
    'Google\\Service\\DeploymentManager' => $vendorDir . '/google/apiclient-services/src/DeploymentManager.php',
    'Google\\Service\\DeploymentManager\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/AuditConfig.php',
    'Google\\Service\\DeploymentManager\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/AuditLogConfig.php',
    'Google\\Service\\DeploymentManager\\Binding' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Binding.php',
    'Google\\Service\\DeploymentManager\\BulkInsertOperationStatus' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/BulkInsertOperationStatus.php',
    'Google\\Service\\DeploymentManager\\ConfigFile' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ConfigFile.php',
    'Google\\Service\\DeploymentManager\\Deployment' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Deployment.php',
    'Google\\Service\\DeploymentManager\\DeploymentLabelEntry' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentLabelEntry.php',
    'Google\\Service\\DeploymentManager\\DeploymentUpdate' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentUpdate.php',
    'Google\\Service\\DeploymentManager\\DeploymentUpdateLabelEntry' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentUpdateLabelEntry.php',
    'Google\\Service\\DeploymentManager\\DeploymentmanagerResource' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentmanagerResource.php',
    'Google\\Service\\DeploymentManager\\DeploymentmanagerResourceWarnings' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentmanagerResourceWarnings.php',
    'Google\\Service\\DeploymentManager\\DeploymentmanagerResourceWarningsData' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentmanagerResourceWarningsData.php',
    'Google\\Service\\DeploymentManager\\DeploymentsCancelPreviewRequest' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentsCancelPreviewRequest.php',
    'Google\\Service\\DeploymentManager\\DeploymentsListResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentsListResponse.php',
    'Google\\Service\\DeploymentManager\\DeploymentsStopRequest' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/DeploymentsStopRequest.php',
    'Google\\Service\\DeploymentManager\\Expr' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Expr.php',
    'Google\\Service\\DeploymentManager\\GlobalSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/GlobalSetPolicyRequest.php',
    'Google\\Service\\DeploymentManager\\ImportFile' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ImportFile.php',
    'Google\\Service\\DeploymentManager\\InstancesBulkInsertOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/InstancesBulkInsertOperationMetadata.php',
    'Google\\Service\\DeploymentManager\\Manifest' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Manifest.php',
    'Google\\Service\\DeploymentManager\\ManifestsListResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ManifestsListResponse.php',
    'Google\\Service\\DeploymentManager\\Operation' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Operation.php',
    'Google\\Service\\DeploymentManager\\OperationError' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/OperationError.php',
    'Google\\Service\\DeploymentManager\\OperationErrorErrors' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/OperationErrorErrors.php',
    'Google\\Service\\DeploymentManager\\OperationWarnings' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/OperationWarnings.php',
    'Google\\Service\\DeploymentManager\\OperationWarningsData' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/OperationWarningsData.php',
    'Google\\Service\\DeploymentManager\\OperationsListResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/OperationsListResponse.php',
    'Google\\Service\\DeploymentManager\\Policy' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Policy.php',
    'Google\\Service\\DeploymentManager\\ResourceAccessControl' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceAccessControl.php',
    'Google\\Service\\DeploymentManager\\ResourceUpdate' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceUpdate.php',
    'Google\\Service\\DeploymentManager\\ResourceUpdateError' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceUpdateError.php',
    'Google\\Service\\DeploymentManager\\ResourceUpdateErrorErrors' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceUpdateErrorErrors.php',
    'Google\\Service\\DeploymentManager\\ResourceUpdateWarnings' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceUpdateWarnings.php',
    'Google\\Service\\DeploymentManager\\ResourceUpdateWarningsData' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourceUpdateWarningsData.php',
    'Google\\Service\\DeploymentManager\\Resource\\Deployments' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Resource/Deployments.php',
    'Google\\Service\\DeploymentManager\\Resource\\Manifests' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Resource/Manifests.php',
    'Google\\Service\\DeploymentManager\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Resource/Operations.php',
    'Google\\Service\\DeploymentManager\\Resource\\Resources' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Resource/Resources.php',
    'Google\\Service\\DeploymentManager\\Resource\\Types' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Resource/Types.php',
    'Google\\Service\\DeploymentManager\\ResourcesListResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/ResourcesListResponse.php',
    'Google\\Service\\DeploymentManager\\SetCommonInstanceMetadataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/SetCommonInstanceMetadataOperationMetadata.php',
    'Google\\Service\\DeploymentManager\\SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.php',
    'Google\\Service\\DeploymentManager\\Status' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Status.php',
    'Google\\Service\\DeploymentManager\\TargetConfiguration' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/TargetConfiguration.php',
    'Google\\Service\\DeploymentManager\\TestPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/TestPermissionsRequest.php',
    'Google\\Service\\DeploymentManager\\TestPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/TestPermissionsResponse.php',
    'Google\\Service\\DeploymentManager\\Type' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/Type.php',
    'Google\\Service\\DeploymentManager\\TypesListResponse' => $vendorDir . '/google/apiclient-services/src/DeploymentManager/TypesListResponse.php',
    'Google\\Service\\DeveloperConnect' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect.php',
    'Google\\Service\\DeveloperConnect\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/CancelOperationRequest.php',
    'Google\\Service\\DeveloperConnect\\Connection' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Connection.php',
    'Google\\Service\\DeveloperConnect\\DeveloperconnectEmpty' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/DeveloperconnectEmpty.php',
    'Google\\Service\\DeveloperConnect\\FetchGitHubInstallationsResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchGitHubInstallationsResponse.php',
    'Google\\Service\\DeveloperConnect\\FetchGitRefsResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchGitRefsResponse.php',
    'Google\\Service\\DeveloperConnect\\FetchLinkableGitRepositoriesResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchLinkableGitRepositoriesResponse.php',
    'Google\\Service\\DeveloperConnect\\FetchReadTokenRequest' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchReadTokenRequest.php',
    'Google\\Service\\DeveloperConnect\\FetchReadTokenResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchReadTokenResponse.php',
    'Google\\Service\\DeveloperConnect\\FetchReadWriteTokenRequest' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchReadWriteTokenRequest.php',
    'Google\\Service\\DeveloperConnect\\FetchReadWriteTokenResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/FetchReadWriteTokenResponse.php',
    'Google\\Service\\DeveloperConnect\\GitHubConfig' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/GitHubConfig.php',
    'Google\\Service\\DeveloperConnect\\GitRepositoryLink' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/GitRepositoryLink.php',
    'Google\\Service\\DeveloperConnect\\Installation' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Installation.php',
    'Google\\Service\\DeveloperConnect\\InstallationState' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/InstallationState.php',
    'Google\\Service\\DeveloperConnect\\LinkableGitRepository' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/LinkableGitRepository.php',
    'Google\\Service\\DeveloperConnect\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/ListConnectionsResponse.php',
    'Google\\Service\\DeveloperConnect\\ListGitRepositoryLinksResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/ListGitRepositoryLinksResponse.php',
    'Google\\Service\\DeveloperConnect\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/ListLocationsResponse.php',
    'Google\\Service\\DeveloperConnect\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/ListOperationsResponse.php',
    'Google\\Service\\DeveloperConnect\\Location' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Location.php',
    'Google\\Service\\DeveloperConnect\\OAuthCredential' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/OAuthCredential.php',
    'Google\\Service\\DeveloperConnect\\Operation' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Operation.php',
    'Google\\Service\\DeveloperConnect\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/OperationMetadata.php',
    'Google\\Service\\DeveloperConnect\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Resource/Projects.php',
    'Google\\Service\\DeveloperConnect\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Resource/ProjectsLocations.php',
    'Google\\Service\\DeveloperConnect\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\DeveloperConnect\\Resource\\ProjectsLocationsConnectionsGitRepositoryLinks' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Resource/ProjectsLocationsConnectionsGitRepositoryLinks.php',
    'Google\\Service\\DeveloperConnect\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DeveloperConnect\\Status' => $vendorDir . '/google/apiclient-services/src/DeveloperConnect/Status.php',
    'Google\\Service\\Dfareporting' => $vendorDir . '/google/apiclient-services/src/Dfareporting.php',
    'Google\\Service\\Dfareporting\\Account' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Account.php',
    'Google\\Service\\Dfareporting\\AccountActiveAdSummary' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountActiveAdSummary.php',
    'Google\\Service\\Dfareporting\\AccountPermission' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountPermission.php',
    'Google\\Service\\Dfareporting\\AccountPermissionGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountPermissionGroup.php',
    'Google\\Service\\Dfareporting\\AccountPermissionGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountPermissionGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\AccountPermissionsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountPermissionsListResponse.php',
    'Google\\Service\\Dfareporting\\AccountUserProfile' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountUserProfile.php',
    'Google\\Service\\Dfareporting\\AccountUserProfilesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountUserProfilesListResponse.php',
    'Google\\Service\\Dfareporting\\AccountsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AccountsListResponse.php',
    'Google\\Service\\Dfareporting\\Activities' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Activities.php',
    'Google\\Service\\Dfareporting\\Ad' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Ad.php',
    'Google\\Service\\Dfareporting\\AdBlockingConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdBlockingConfiguration.php',
    'Google\\Service\\Dfareporting\\AdSlot' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdSlot.php',
    'Google\\Service\\Dfareporting\\AdsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdsListResponse.php',
    'Google\\Service\\Dfareporting\\Advertiser' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Advertiser.php',
    'Google\\Service\\Dfareporting\\AdvertiserGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdvertiserGroup.php',
    'Google\\Service\\Dfareporting\\AdvertiserGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdvertiserGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\AdvertiserInvoicesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdvertiserInvoicesListResponse.php',
    'Google\\Service\\Dfareporting\\AdvertiserLandingPagesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdvertiserLandingPagesListResponse.php',
    'Google\\Service\\Dfareporting\\AdvertisersListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AdvertisersListResponse.php',
    'Google\\Service\\Dfareporting\\AudienceSegment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AudienceSegment.php',
    'Google\\Service\\Dfareporting\\AudienceSegmentGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/AudienceSegmentGroup.php',
    'Google\\Service\\Dfareporting\\BillingAssignment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingAssignment.php',
    'Google\\Service\\Dfareporting\\BillingAssignmentsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingAssignmentsListResponse.php',
    'Google\\Service\\Dfareporting\\BillingProfile' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingProfile.php',
    'Google\\Service\\Dfareporting\\BillingProfilesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingProfilesListResponse.php',
    'Google\\Service\\Dfareporting\\BillingRate' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingRate.php',
    'Google\\Service\\Dfareporting\\BillingRateTieredRate' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingRateTieredRate.php',
    'Google\\Service\\Dfareporting\\BillingRatesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BillingRatesListResponse.php',
    'Google\\Service\\Dfareporting\\Browser' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Browser.php',
    'Google\\Service\\Dfareporting\\BrowsersListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/BrowsersListResponse.php',
    'Google\\Service\\Dfareporting\\Campaign' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Campaign.php',
    'Google\\Service\\Dfareporting\\CampaignCreativeAssociation' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CampaignCreativeAssociation.php',
    'Google\\Service\\Dfareporting\\CampaignCreativeAssociationsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CampaignCreativeAssociationsListResponse.php',
    'Google\\Service\\Dfareporting\\CampaignSummary' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CampaignSummary.php',
    'Google\\Service\\Dfareporting\\CampaignsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CampaignsListResponse.php',
    'Google\\Service\\Dfareporting\\CartData' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CartData.php',
    'Google\\Service\\Dfareporting\\CartDataItem' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CartDataItem.php',
    'Google\\Service\\Dfareporting\\ChangeLog' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ChangeLog.php',
    'Google\\Service\\Dfareporting\\ChangeLogsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ChangeLogsListResponse.php',
    'Google\\Service\\Dfareporting\\ChannelGrouping' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ChannelGrouping.php',
    'Google\\Service\\Dfareporting\\ChannelGroupingRule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ChannelGroupingRule.php',
    'Google\\Service\\Dfareporting\\CitiesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CitiesListResponse.php',
    'Google\\Service\\Dfareporting\\City' => $vendorDir . '/google/apiclient-services/src/Dfareporting/City.php',
    'Google\\Service\\Dfareporting\\ClickTag' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ClickTag.php',
    'Google\\Service\\Dfareporting\\ClickThroughUrl' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ClickThroughUrl.php',
    'Google\\Service\\Dfareporting\\ClickThroughUrlSuffixProperties' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ClickThroughUrlSuffixProperties.php',
    'Google\\Service\\Dfareporting\\CompanionClickThroughOverride' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CompanionClickThroughOverride.php',
    'Google\\Service\\Dfareporting\\CompanionSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CompanionSetting.php',
    'Google\\Service\\Dfareporting\\CompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CompatibleFields.php',
    'Google\\Service\\Dfareporting\\ConnectionType' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConnectionType.php',
    'Google\\Service\\Dfareporting\\ConnectionTypesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConnectionTypesListResponse.php',
    'Google\\Service\\Dfareporting\\ContentCategoriesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ContentCategoriesListResponse.php',
    'Google\\Service\\Dfareporting\\ContentCategory' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ContentCategory.php',
    'Google\\Service\\Dfareporting\\Conversion' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Conversion.php',
    'Google\\Service\\Dfareporting\\ConversionError' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionError.php',
    'Google\\Service\\Dfareporting\\ConversionStatus' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionStatus.php',
    'Google\\Service\\Dfareporting\\ConversionsBatchInsertRequest' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionsBatchInsertRequest.php',
    'Google\\Service\\Dfareporting\\ConversionsBatchInsertResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionsBatchInsertResponse.php',
    'Google\\Service\\Dfareporting\\ConversionsBatchUpdateRequest' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionsBatchUpdateRequest.php',
    'Google\\Service\\Dfareporting\\ConversionsBatchUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ConversionsBatchUpdateResponse.php',
    'Google\\Service\\Dfareporting\\CountriesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CountriesListResponse.php',
    'Google\\Service\\Dfareporting\\Country' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Country.php',
    'Google\\Service\\Dfareporting\\Creative' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Creative.php',
    'Google\\Service\\Dfareporting\\CreativeAsset' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeAsset.php',
    'Google\\Service\\Dfareporting\\CreativeAssetId' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeAssetId.php',
    'Google\\Service\\Dfareporting\\CreativeAssetMetadata' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeAssetMetadata.php',
    'Google\\Service\\Dfareporting\\CreativeAssetSelection' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeAssetSelection.php',
    'Google\\Service\\Dfareporting\\CreativeAssignment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeAssignment.php',
    'Google\\Service\\Dfareporting\\CreativeClickThroughUrl' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeClickThroughUrl.php',
    'Google\\Service\\Dfareporting\\CreativeCustomEvent' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeCustomEvent.php',
    'Google\\Service\\Dfareporting\\CreativeField' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeField.php',
    'Google\\Service\\Dfareporting\\CreativeFieldAssignment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeFieldAssignment.php',
    'Google\\Service\\Dfareporting\\CreativeFieldValue' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeFieldValue.php',
    'Google\\Service\\Dfareporting\\CreativeFieldValuesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeFieldValuesListResponse.php',
    'Google\\Service\\Dfareporting\\CreativeFieldsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeFieldsListResponse.php',
    'Google\\Service\\Dfareporting\\CreativeGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeGroup.php',
    'Google\\Service\\Dfareporting\\CreativeGroupAssignment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeGroupAssignment.php',
    'Google\\Service\\Dfareporting\\CreativeGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\CreativeOptimizationConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeOptimizationConfiguration.php',
    'Google\\Service\\Dfareporting\\CreativeRotation' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativeRotation.php',
    'Google\\Service\\Dfareporting\\CreativesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CreativesListResponse.php',
    'Google\\Service\\Dfareporting\\CrossDimensionReachReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CrossDimensionReachReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\CustomFloodlightVariable' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CustomFloodlightVariable.php',
    'Google\\Service\\Dfareporting\\CustomRichMediaEvents' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CustomRichMediaEvents.php',
    'Google\\Service\\Dfareporting\\CustomViewabilityMetric' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CustomViewabilityMetric.php',
    'Google\\Service\\Dfareporting\\CustomViewabilityMetricConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/CustomViewabilityMetricConfiguration.php',
    'Google\\Service\\Dfareporting\\DateRange' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DateRange.php',
    'Google\\Service\\Dfareporting\\DayPartTargeting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DayPartTargeting.php',
    'Google\\Service\\Dfareporting\\DeepLink' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DeepLink.php',
    'Google\\Service\\Dfareporting\\DefaultClickThroughEventTagProperties' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DefaultClickThroughEventTagProperties.php',
    'Google\\Service\\Dfareporting\\DeliverySchedule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DeliverySchedule.php',
    'Google\\Service\\Dfareporting\\DfareportingFile' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DfareportingFile.php',
    'Google\\Service\\Dfareporting\\DfareportingFileUrls' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DfareportingFileUrls.php',
    'Google\\Service\\Dfareporting\\DfpSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DfpSettings.php',
    'Google\\Service\\Dfareporting\\Dimension' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Dimension.php',
    'Google\\Service\\Dfareporting\\DimensionFilter' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DimensionFilter.php',
    'Google\\Service\\Dfareporting\\DimensionValue' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DimensionValue.php',
    'Google\\Service\\Dfareporting\\DimensionValueList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DimensionValueList.php',
    'Google\\Service\\Dfareporting\\DimensionValueRequest' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DimensionValueRequest.php',
    'Google\\Service\\Dfareporting\\DirectorySite' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DirectorySite.php',
    'Google\\Service\\Dfareporting\\DirectorySiteSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DirectorySiteSettings.php',
    'Google\\Service\\Dfareporting\\DirectorySitesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DirectorySitesListResponse.php',
    'Google\\Service\\Dfareporting\\DisjunctiveMatchStatement' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DisjunctiveMatchStatement.php',
    'Google\\Service\\Dfareporting\\DynamicTargetingKey' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DynamicTargetingKey.php',
    'Google\\Service\\Dfareporting\\DynamicTargetingKeysListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/DynamicTargetingKeysListResponse.php',
    'Google\\Service\\Dfareporting\\EncryptionInfo' => $vendorDir . '/google/apiclient-services/src/Dfareporting/EncryptionInfo.php',
    'Google\\Service\\Dfareporting\\EventFilter' => $vendorDir . '/google/apiclient-services/src/Dfareporting/EventFilter.php',
    'Google\\Service\\Dfareporting\\EventTag' => $vendorDir . '/google/apiclient-services/src/Dfareporting/EventTag.php',
    'Google\\Service\\Dfareporting\\EventTagOverride' => $vendorDir . '/google/apiclient-services/src/Dfareporting/EventTagOverride.php',
    'Google\\Service\\Dfareporting\\EventTagsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/EventTagsListResponse.php',
    'Google\\Service\\Dfareporting\\FileList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FileList.php',
    'Google\\Service\\Dfareporting\\Flight' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Flight.php',
    'Google\\Service\\Dfareporting\\FloodlightActivitiesGenerateTagResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivitiesGenerateTagResponse.php',
    'Google\\Service\\Dfareporting\\FloodlightActivitiesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivitiesListResponse.php',
    'Google\\Service\\Dfareporting\\FloodlightActivity' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivity.php',
    'Google\\Service\\Dfareporting\\FloodlightActivityDynamicTag' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivityDynamicTag.php',
    'Google\\Service\\Dfareporting\\FloodlightActivityGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivityGroup.php',
    'Google\\Service\\Dfareporting\\FloodlightActivityGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivityGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\FloodlightActivityPublisherDynamicTag' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightActivityPublisherDynamicTag.php',
    'Google\\Service\\Dfareporting\\FloodlightConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightConfiguration.php',
    'Google\\Service\\Dfareporting\\FloodlightConfigurationsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightConfigurationsListResponse.php',
    'Google\\Service\\Dfareporting\\FloodlightReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FloodlightReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\FrequencyCap' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FrequencyCap.php',
    'Google\\Service\\Dfareporting\\FsCommand' => $vendorDir . '/google/apiclient-services/src/Dfareporting/FsCommand.php',
    'Google\\Service\\Dfareporting\\GeoTargeting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/GeoTargeting.php',
    'Google\\Service\\Dfareporting\\InventoryItem' => $vendorDir . '/google/apiclient-services/src/Dfareporting/InventoryItem.php',
    'Google\\Service\\Dfareporting\\InventoryItemsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/InventoryItemsListResponse.php',
    'Google\\Service\\Dfareporting\\Invoice' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Invoice.php',
    'Google\\Service\\Dfareporting\\KeyValueTargetingExpression' => $vendorDir . '/google/apiclient-services/src/Dfareporting/KeyValueTargetingExpression.php',
    'Google\\Service\\Dfareporting\\LandingPage' => $vendorDir . '/google/apiclient-services/src/Dfareporting/LandingPage.php',
    'Google\\Service\\Dfareporting\\Language' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Language.php',
    'Google\\Service\\Dfareporting\\LanguageTargeting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/LanguageTargeting.php',
    'Google\\Service\\Dfareporting\\LanguagesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/LanguagesListResponse.php',
    'Google\\Service\\Dfareporting\\LastModifiedInfo' => $vendorDir . '/google/apiclient-services/src/Dfareporting/LastModifiedInfo.php',
    'Google\\Service\\Dfareporting\\ListPopulationClause' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ListPopulationClause.php',
    'Google\\Service\\Dfareporting\\ListPopulationRule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ListPopulationRule.php',
    'Google\\Service\\Dfareporting\\ListPopulationTerm' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ListPopulationTerm.php',
    'Google\\Service\\Dfareporting\\ListTargetingExpression' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ListTargetingExpression.php',
    'Google\\Service\\Dfareporting\\LookbackConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/LookbackConfiguration.php',
    'Google\\Service\\Dfareporting\\MeasurementPartnerAdvertiserLink' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MeasurementPartnerAdvertiserLink.php',
    'Google\\Service\\Dfareporting\\MeasurementPartnerCampaignLink' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MeasurementPartnerCampaignLink.php',
    'Google\\Service\\Dfareporting\\MeasurementPartnerWrappingData' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MeasurementPartnerWrappingData.php',
    'Google\\Service\\Dfareporting\\Metric' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Metric.php',
    'Google\\Service\\Dfareporting\\Metro' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Metro.php',
    'Google\\Service\\Dfareporting\\MetrosListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MetrosListResponse.php',
    'Google\\Service\\Dfareporting\\MobileApp' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MobileApp.php',
    'Google\\Service\\Dfareporting\\MobileAppsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MobileAppsListResponse.php',
    'Google\\Service\\Dfareporting\\MobileCarrier' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MobileCarrier.php',
    'Google\\Service\\Dfareporting\\MobileCarriersListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/MobileCarriersListResponse.php',
    'Google\\Service\\Dfareporting\\ObaIcon' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ObaIcon.php',
    'Google\\Service\\Dfareporting\\ObjectFilter' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ObjectFilter.php',
    'Google\\Service\\Dfareporting\\OfflineUserAddressInfo' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OfflineUserAddressInfo.php',
    'Google\\Service\\Dfareporting\\OffsetPosition' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OffsetPosition.php',
    'Google\\Service\\Dfareporting\\OmnitureSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OmnitureSettings.php',
    'Google\\Service\\Dfareporting\\OperatingSystem' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OperatingSystem.php',
    'Google\\Service\\Dfareporting\\OperatingSystemVersion' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OperatingSystemVersion.php',
    'Google\\Service\\Dfareporting\\OperatingSystemVersionsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OperatingSystemVersionsListResponse.php',
    'Google\\Service\\Dfareporting\\OperatingSystemsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OperatingSystemsListResponse.php',
    'Google\\Service\\Dfareporting\\OptimizationActivity' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OptimizationActivity.php',
    'Google\\Service\\Dfareporting\\Order' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Order.php',
    'Google\\Service\\Dfareporting\\OrderContact' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OrderContact.php',
    'Google\\Service\\Dfareporting\\OrderDocument' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OrderDocument.php',
    'Google\\Service\\Dfareporting\\OrderDocumentsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OrderDocumentsListResponse.php',
    'Google\\Service\\Dfareporting\\OrdersListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/OrdersListResponse.php',
    'Google\\Service\\Dfareporting\\PathFilter' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PathFilter.php',
    'Google\\Service\\Dfareporting\\PathReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PathReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\PathReportDimensionValue' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PathReportDimensionValue.php',
    'Google\\Service\\Dfareporting\\PathToConversionReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PathToConversionReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\Placement' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Placement.php',
    'Google\\Service\\Dfareporting\\PlacementAssignment' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementAssignment.php',
    'Google\\Service\\Dfareporting\\PlacementConversionDomainOverride' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementConversionDomainOverride.php',
    'Google\\Service\\Dfareporting\\PlacementGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementGroup.php',
    'Google\\Service\\Dfareporting\\PlacementGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\PlacementSingleConversionDomain' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementSingleConversionDomain.php',
    'Google\\Service\\Dfareporting\\PlacementStrategiesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementStrategiesListResponse.php',
    'Google\\Service\\Dfareporting\\PlacementStrategy' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementStrategy.php',
    'Google\\Service\\Dfareporting\\PlacementTag' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementTag.php',
    'Google\\Service\\Dfareporting\\PlacementsGenerateTagsResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementsGenerateTagsResponse.php',
    'Google\\Service\\Dfareporting\\PlacementsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlacementsListResponse.php',
    'Google\\Service\\Dfareporting\\PlatformType' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlatformType.php',
    'Google\\Service\\Dfareporting\\PlatformTypesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PlatformTypesListResponse.php',
    'Google\\Service\\Dfareporting\\PopupWindowProperties' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PopupWindowProperties.php',
    'Google\\Service\\Dfareporting\\PostalCode' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PostalCode.php',
    'Google\\Service\\Dfareporting\\PostalCodesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PostalCodesListResponse.php',
    'Google\\Service\\Dfareporting\\Pricing' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Pricing.php',
    'Google\\Service\\Dfareporting\\PricingSchedule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PricingSchedule.php',
    'Google\\Service\\Dfareporting\\PricingSchedulePricingPeriod' => $vendorDir . '/google/apiclient-services/src/Dfareporting/PricingSchedulePricingPeriod.php',
    'Google\\Service\\Dfareporting\\Project' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Project.php',
    'Google\\Service\\Dfareporting\\ProjectsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ProjectsListResponse.php',
    'Google\\Service\\Dfareporting\\ReachReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReachReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\Recipient' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Recipient.php',
    'Google\\Service\\Dfareporting\\Region' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Region.php',
    'Google\\Service\\Dfareporting\\RegionsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/RegionsListResponse.php',
    'Google\\Service\\Dfareporting\\RemarketingList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/RemarketingList.php',
    'Google\\Service\\Dfareporting\\RemarketingListShare' => $vendorDir . '/google/apiclient-services/src/Dfareporting/RemarketingListShare.php',
    'Google\\Service\\Dfareporting\\RemarketingListsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/RemarketingListsListResponse.php',
    'Google\\Service\\Dfareporting\\Report' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Report.php',
    'Google\\Service\\Dfareporting\\ReportCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportCompatibleFields.php',
    'Google\\Service\\Dfareporting\\ReportCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportCriteria.php',
    'Google\\Service\\Dfareporting\\ReportCrossDimensionReachCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportCrossDimensionReachCriteria.php',
    'Google\\Service\\Dfareporting\\ReportDelivery' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportDelivery.php',
    'Google\\Service\\Dfareporting\\ReportFloodlightCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportFloodlightCriteria.php',
    'Google\\Service\\Dfareporting\\ReportFloodlightCriteriaReportProperties' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportFloodlightCriteriaReportProperties.php',
    'Google\\Service\\Dfareporting\\ReportList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportList.php',
    'Google\\Service\\Dfareporting\\ReportPathAttributionCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportPathAttributionCriteria.php',
    'Google\\Service\\Dfareporting\\ReportPathCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportPathCriteria.php',
    'Google\\Service\\Dfareporting\\ReportPathToConversionCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportPathToConversionCriteria.php',
    'Google\\Service\\Dfareporting\\ReportPathToConversionCriteriaReportProperties' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportPathToConversionCriteriaReportProperties.php',
    'Google\\Service\\Dfareporting\\ReportReachCriteria' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportReachCriteria.php',
    'Google\\Service\\Dfareporting\\ReportSchedule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportSchedule.php',
    'Google\\Service\\Dfareporting\\ReportsConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ReportsConfiguration.php',
    'Google\\Service\\Dfareporting\\Resource\\AccountActiveAdSummaries' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AccountActiveAdSummaries.php',
    'Google\\Service\\Dfareporting\\Resource\\AccountPermissionGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AccountPermissionGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\AccountPermissions' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AccountPermissions.php',
    'Google\\Service\\Dfareporting\\Resource\\AccountUserProfiles' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AccountUserProfiles.php',
    'Google\\Service\\Dfareporting\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Accounts.php',
    'Google\\Service\\Dfareporting\\Resource\\Ads' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Ads.php',
    'Google\\Service\\Dfareporting\\Resource\\AdvertiserGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AdvertiserGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\AdvertiserInvoices' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AdvertiserInvoices.php',
    'Google\\Service\\Dfareporting\\Resource\\AdvertiserLandingPages' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/AdvertiserLandingPages.php',
    'Google\\Service\\Dfareporting\\Resource\\Advertisers' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Advertisers.php',
    'Google\\Service\\Dfareporting\\Resource\\BillingAssignments' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/BillingAssignments.php',
    'Google\\Service\\Dfareporting\\Resource\\BillingProfiles' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/BillingProfiles.php',
    'Google\\Service\\Dfareporting\\Resource\\BillingRates' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/BillingRates.php',
    'Google\\Service\\Dfareporting\\Resource\\Browsers' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Browsers.php',
    'Google\\Service\\Dfareporting\\Resource\\CampaignCreativeAssociations' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/CampaignCreativeAssociations.php',
    'Google\\Service\\Dfareporting\\Resource\\Campaigns' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Campaigns.php',
    'Google\\Service\\Dfareporting\\Resource\\ChangeLogs' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/ChangeLogs.php',
    'Google\\Service\\Dfareporting\\Resource\\Cities' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Cities.php',
    'Google\\Service\\Dfareporting\\Resource\\ConnectionTypes' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/ConnectionTypes.php',
    'Google\\Service\\Dfareporting\\Resource\\ContentCategories' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/ContentCategories.php',
    'Google\\Service\\Dfareporting\\Resource\\Conversions' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Conversions.php',
    'Google\\Service\\Dfareporting\\Resource\\Countries' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Countries.php',
    'Google\\Service\\Dfareporting\\Resource\\CreativeAssets' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/CreativeAssets.php',
    'Google\\Service\\Dfareporting\\Resource\\CreativeFieldValues' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/CreativeFieldValues.php',
    'Google\\Service\\Dfareporting\\Resource\\CreativeFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/CreativeFields.php',
    'Google\\Service\\Dfareporting\\Resource\\CreativeGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/CreativeGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\Creatives' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Creatives.php',
    'Google\\Service\\Dfareporting\\Resource\\DimensionValues' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/DimensionValues.php',
    'Google\\Service\\Dfareporting\\Resource\\DirectorySites' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/DirectorySites.php',
    'Google\\Service\\Dfareporting\\Resource\\DynamicTargetingKeys' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/DynamicTargetingKeys.php',
    'Google\\Service\\Dfareporting\\Resource\\EventTags' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/EventTags.php',
    'Google\\Service\\Dfareporting\\Resource\\Files' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Files.php',
    'Google\\Service\\Dfareporting\\Resource\\FloodlightActivities' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/FloodlightActivities.php',
    'Google\\Service\\Dfareporting\\Resource\\FloodlightActivityGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/FloodlightActivityGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\FloodlightConfigurations' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/FloodlightConfigurations.php',
    'Google\\Service\\Dfareporting\\Resource\\InventoryItems' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/InventoryItems.php',
    'Google\\Service\\Dfareporting\\Resource\\Languages' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Languages.php',
    'Google\\Service\\Dfareporting\\Resource\\Metros' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Metros.php',
    'Google\\Service\\Dfareporting\\Resource\\MobileApps' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/MobileApps.php',
    'Google\\Service\\Dfareporting\\Resource\\MobileCarriers' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/MobileCarriers.php',
    'Google\\Service\\Dfareporting\\Resource\\OperatingSystemVersions' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/OperatingSystemVersions.php',
    'Google\\Service\\Dfareporting\\Resource\\OperatingSystems' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/OperatingSystems.php',
    'Google\\Service\\Dfareporting\\Resource\\OrderDocuments' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/OrderDocuments.php',
    'Google\\Service\\Dfareporting\\Resource\\Orders' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Orders.php',
    'Google\\Service\\Dfareporting\\Resource\\PlacementGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/PlacementGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\PlacementStrategies' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/PlacementStrategies.php',
    'Google\\Service\\Dfareporting\\Resource\\Placements' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Placements.php',
    'Google\\Service\\Dfareporting\\Resource\\PlatformTypes' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/PlatformTypes.php',
    'Google\\Service\\Dfareporting\\Resource\\PostalCodes' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/PostalCodes.php',
    'Google\\Service\\Dfareporting\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Projects.php',
    'Google\\Service\\Dfareporting\\Resource\\Regions' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Regions.php',
    'Google\\Service\\Dfareporting\\Resource\\RemarketingListShares' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/RemarketingListShares.php',
    'Google\\Service\\Dfareporting\\Resource\\RemarketingLists' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/RemarketingLists.php',
    'Google\\Service\\Dfareporting\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Reports.php',
    'Google\\Service\\Dfareporting\\Resource\\ReportsCompatibleFields' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/ReportsCompatibleFields.php',
    'Google\\Service\\Dfareporting\\Resource\\ReportsFiles' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/ReportsFiles.php',
    'Google\\Service\\Dfareporting\\Resource\\Sites' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Sites.php',
    'Google\\Service\\Dfareporting\\Resource\\Sizes' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Sizes.php',
    'Google\\Service\\Dfareporting\\Resource\\Subaccounts' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/Subaccounts.php',
    'Google\\Service\\Dfareporting\\Resource\\TargetableRemarketingLists' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/TargetableRemarketingLists.php',
    'Google\\Service\\Dfareporting\\Resource\\TargetingTemplates' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/TargetingTemplates.php',
    'Google\\Service\\Dfareporting\\Resource\\UserProfiles' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/UserProfiles.php',
    'Google\\Service\\Dfareporting\\Resource\\UserRolePermissionGroups' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/UserRolePermissionGroups.php',
    'Google\\Service\\Dfareporting\\Resource\\UserRolePermissions' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/UserRolePermissions.php',
    'Google\\Service\\Dfareporting\\Resource\\UserRoles' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/UserRoles.php',
    'Google\\Service\\Dfareporting\\Resource\\VideoFormats' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Resource/VideoFormats.php',
    'Google\\Service\\Dfareporting\\RichMediaExitOverride' => $vendorDir . '/google/apiclient-services/src/Dfareporting/RichMediaExitOverride.php',
    'Google\\Service\\Dfareporting\\Rule' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Rule.php',
    'Google\\Service\\Dfareporting\\Site' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Site.php',
    'Google\\Service\\Dfareporting\\SiteCompanionSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteCompanionSetting.php',
    'Google\\Service\\Dfareporting\\SiteContact' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteContact.php',
    'Google\\Service\\Dfareporting\\SiteSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteSettings.php',
    'Google\\Service\\Dfareporting\\SiteSkippableSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteSkippableSetting.php',
    'Google\\Service\\Dfareporting\\SiteTranscodeSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteTranscodeSetting.php',
    'Google\\Service\\Dfareporting\\SiteVideoSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SiteVideoSettings.php',
    'Google\\Service\\Dfareporting\\SitesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SitesListResponse.php',
    'Google\\Service\\Dfareporting\\Size' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Size.php',
    'Google\\Service\\Dfareporting\\SizesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SizesListResponse.php',
    'Google\\Service\\Dfareporting\\SkippableSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SkippableSetting.php',
    'Google\\Service\\Dfareporting\\SortedDimension' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SortedDimension.php',
    'Google\\Service\\Dfareporting\\Subaccount' => $vendorDir . '/google/apiclient-services/src/Dfareporting/Subaccount.php',
    'Google\\Service\\Dfareporting\\SubaccountsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/SubaccountsListResponse.php',
    'Google\\Service\\Dfareporting\\TagData' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TagData.php',
    'Google\\Service\\Dfareporting\\TagSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TagSetting.php',
    'Google\\Service\\Dfareporting\\TagSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TagSettings.php',
    'Google\\Service\\Dfareporting\\TargetWindow' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TargetWindow.php',
    'Google\\Service\\Dfareporting\\TargetableRemarketingList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TargetableRemarketingList.php',
    'Google\\Service\\Dfareporting\\TargetableRemarketingListsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TargetableRemarketingListsListResponse.php',
    'Google\\Service\\Dfareporting\\TargetingTemplate' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TargetingTemplate.php',
    'Google\\Service\\Dfareporting\\TargetingTemplatesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TargetingTemplatesListResponse.php',
    'Google\\Service\\Dfareporting\\TechnologyTargeting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TechnologyTargeting.php',
    'Google\\Service\\Dfareporting\\ThirdPartyAuthenticationToken' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ThirdPartyAuthenticationToken.php',
    'Google\\Service\\Dfareporting\\ThirdPartyTrackingUrl' => $vendorDir . '/google/apiclient-services/src/Dfareporting/ThirdPartyTrackingUrl.php',
    'Google\\Service\\Dfareporting\\TranscodeSetting' => $vendorDir . '/google/apiclient-services/src/Dfareporting/TranscodeSetting.php',
    'Google\\Service\\Dfareporting\\UniversalAdId' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UniversalAdId.php',
    'Google\\Service\\Dfareporting\\UserDefinedVariableConfiguration' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserDefinedVariableConfiguration.php',
    'Google\\Service\\Dfareporting\\UserIdentifier' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserIdentifier.php',
    'Google\\Service\\Dfareporting\\UserProfile' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserProfile.php',
    'Google\\Service\\Dfareporting\\UserProfileList' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserProfileList.php',
    'Google\\Service\\Dfareporting\\UserRole' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRole.php',
    'Google\\Service\\Dfareporting\\UserRolePermission' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRolePermission.php',
    'Google\\Service\\Dfareporting\\UserRolePermissionGroup' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRolePermissionGroup.php',
    'Google\\Service\\Dfareporting\\UserRolePermissionGroupsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRolePermissionGroupsListResponse.php',
    'Google\\Service\\Dfareporting\\UserRolePermissionsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRolePermissionsListResponse.php',
    'Google\\Service\\Dfareporting\\UserRolesListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UserRolesListResponse.php',
    'Google\\Service\\Dfareporting\\UvarFilter' => $vendorDir . '/google/apiclient-services/src/Dfareporting/UvarFilter.php',
    'Google\\Service\\Dfareporting\\VideoFormat' => $vendorDir . '/google/apiclient-services/src/Dfareporting/VideoFormat.php',
    'Google\\Service\\Dfareporting\\VideoFormatsListResponse' => $vendorDir . '/google/apiclient-services/src/Dfareporting/VideoFormatsListResponse.php',
    'Google\\Service\\Dfareporting\\VideoOffset' => $vendorDir . '/google/apiclient-services/src/Dfareporting/VideoOffset.php',
    'Google\\Service\\Dfareporting\\VideoSettings' => $vendorDir . '/google/apiclient-services/src/Dfareporting/VideoSettings.php',
    'Google\\Service\\Dialogflow' => $vendorDir . '/google/apiclient-services/src/Dialogflow.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AdvancedSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AdvancedSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Agent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Agent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentClientCertificateSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentClientCertificateSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentGitIntegrationSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentGitIntegrationSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentGitIntegrationSettingsGithubSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentGitIntegrationSettingsGithubSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentPersonalizationSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentPersonalizationSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AgentValidationResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AgentValidationResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AnswerFeedback' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AnswerFeedback.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AnswerFeedbackRatingReason' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AnswerFeedbackRatingReason.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3AudioInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3AudioInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BargeInConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BargeInConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BatchDeleteTestCasesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BatchDeleteTestCasesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BatchRunTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BatchRunTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BatchRunTestCasesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BatchRunTestCasesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BatchRunTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BatchRunTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BoostSpec' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BoostSpec.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpec' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpec.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpecBoostControlSpec' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpecBoostControlSpec.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpecBoostControlSpecControlPoint' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpecBoostControlSpecControlPoint.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3BoostSpecs' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3BoostSpecs.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3CalculateCoverageResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3CalculateCoverageResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Changelog' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Changelog.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3CompareVersionsRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3CompareVersionsRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3CompareVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3CompareVersionsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ContinuousTestResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ContinuousTestResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ConversationSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ConversationSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ConversationTurn' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ConversationTurn.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ConversationTurnUserInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ConversationTurnUserInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3CreateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3CreateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3CreateVersionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3CreateVersionOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnection' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnection.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerPart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerPart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsGroundingSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsGroundingSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsRewriterModelCallSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsRewriterModelCallSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DeleteDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DeleteDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DeployFlowMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DeployFlowMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DeployFlowRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DeployFlowRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DeployFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DeployFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Deployment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Deployment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DeploymentResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DeploymentResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DetectIntentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DetectIntentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DetectIntentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DetectIntentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3DtmfInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3DtmfInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EntityTypeEntity' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EntityTypeEntity.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Environment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Environment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EnvironmentVersionConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EnvironmentVersionConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EnvironmentWebhookConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EnvironmentWebhookConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EventHandler' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EventHandler.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3EventInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3EventInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Experiment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Experiment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExperimentDefinition' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExperimentDefinition.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExperimentResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExperimentResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExperimentResultConfidenceInterval' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExperimentResultConfidenceInterval.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExperimentResultMetric' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExperimentResultMetric.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportAgentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportAgentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportAgentRequestGitDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportAgentRequestGitDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportAgentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportAgentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportEntityTypesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportEntityTypesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportEntityTypesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportEntityTypesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportFlowRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportFlowRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportIntentsMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportIntentsMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportIntentsRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportIntentsRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportTestCasesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportTestCasesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ExportTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ExportTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FilterSpecs' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FilterSpecs.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Flow' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Flow.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FlowImportStrategy' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FlowImportStrategy.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FlowMultiLanguageSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FlowMultiLanguageSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FlowValidationResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FlowValidationResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Form' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Form.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FormParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FormParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FormParameterFillBehavior' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FormParameterFillBehavior.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillIntentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillIntentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillIntentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillIntentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Fulfillment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Fulfillment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillmentConditionalCases' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillmentConditionalCases.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3FulfillmentSetParameterAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3FulfillmentSetParameterAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GcsDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GcsDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GenerativeSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GenerativeSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GenerativeSettingsFallbackSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GenerativeSettingsFallbackSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GenerativeSettingsFallbackSettingsPromptTemplate' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GenerativeSettingsFallbackSettingsPromptTemplate.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Generator' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Generator.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GeneratorPlaceholder' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GeneratorPlaceholder.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportDocumentsOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportDocumentsOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportDocumentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportEntityTypesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportEntityTypesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportEntityTypesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportEntityTypesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportEntityTypesResponseConflictingResources' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportEntityTypesResponseConflictingResources.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportFlowRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportFlowRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportIntentsMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportIntentsMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportIntentsRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportIntentsRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportIntentsResponseConflictingResources' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportIntentsResponseConflictingResources.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportTestCasesRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportTestCasesRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ImportTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ImportTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3InlineDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3InlineDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3InlineSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3InlineSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3InputAudioConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3InputAudioConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Intent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Intent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentCoverage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentCoverage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentCoverageIntent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentCoverageIntent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentTrainingPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentTrainingPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3IntentTrainingPhrasePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3IntentTrainingPhrasePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3KnowledgeConnectorSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3KnowledgeConnectorSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3LanguageInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3LanguageInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListAgentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListAgentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListChangelogsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListChangelogsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListContinuousTestResultsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListContinuousTestResultsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListDeploymentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListEnvironmentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListExperimentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListExperimentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListFlowsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListFlowsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListGeneratorsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListGeneratorsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListPagesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListPagesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListSecuritySettingsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListSecuritySettingsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListSessionEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListSessionEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListTestCaseResultsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListTestCaseResultsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListTransitionRouteGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListTransitionRouteGroupsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListVersionsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ListWebhooksResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ListWebhooksResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3LoadVersionRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3LoadVersionRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3LookupEnvironmentHistoryResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3LookupEnvironmentHistoryResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Match' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Match.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3MatchIntentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3MatchIntentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3MatchIntentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3MatchIntentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3NluSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3NluSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3OutputAudioConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3OutputAudioConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Page' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Page.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3PageInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3PageInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3PageInfoFormInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3PageInfoFormInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Phrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Phrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3QueryInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3QueryInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3QueryParameters' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3QueryParameters.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3QueryResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3QueryResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ReloadDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ReloadDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResourceName' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResourceName.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageEndInteraction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageEndInteraction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageKnowledgeInfoCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageKnowledgeInfoCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageMixedAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageMixedAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessagePlayAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessagePlayAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ResponseMessageText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ResponseMessageText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RestoreAgentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RestoreAgentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RestoreAgentRequestGitSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RestoreAgentRequestGitSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RolloutConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RolloutConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RolloutConfigRolloutStep' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RolloutConfigRolloutStep.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RolloutState' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RolloutState.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunContinuousTestMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunContinuousTestMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunContinuousTestRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunContinuousTestRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunContinuousTestResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunContinuousTestResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunTestCaseMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunTestCaseMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunTestCaseRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunTestCaseRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3RunTestCaseResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3RunTestCaseResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SafetySettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SafetySettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SafetySettingsPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SafetySettingsPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SearchConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SearchConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SecuritySettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SecuritySettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SecuritySettingsInsightsExportSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SecuritySettingsInsightsExportSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SentimentAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SentimentAnalysisResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SessionEntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SessionEntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SessionInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SessionInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SpeechToTextSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SpeechToTextSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3StartExperimentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3StartExperimentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3StopExperimentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3StopExperimentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SubmitAnswerFeedbackRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SubmitAnswerFeedbackRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3SynthesizeSpeechConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3SynthesizeSpeechConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestCase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestCase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestCaseError' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestCaseError.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestCaseResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestCaseResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestError' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestError.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TestRunDifference' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TestRunDifference.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TextInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TextInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TextToSpeechSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TextToSpeechSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ToolCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ToolCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TrainFlowRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TrainFlowRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionCoverage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionCoverage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionCoverageTransition' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionCoverageTransition.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionCoverageTransitionNode' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionCoverageTransitionNode.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionRoute' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionRoute.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionRouteGroup' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionRouteGroup.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionRouteGroupCoverage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionRouteGroupCoverage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionRouteGroupCoverageCoverage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionRouteGroupCoverageCoverage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TransitionRouteGroupCoverageCoverageTransition' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TransitionRouteGroupCoverageCoverageTransition.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3TurnSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3TurnSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3UpdateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3UpdateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ValidateAgentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ValidateAgentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ValidateFlowRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ValidateFlowRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3ValidationMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3ValidationMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3VariantsHistory' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3VariantsHistory.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Version' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Version.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3VersionVariants' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3VersionVariants.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3VersionVariantsVariant' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3VersionVariantsVariant.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3VoiceSelectionParams' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3VoiceSelectionParams.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3Webhook' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3Webhook.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookGenericWebService' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookGenericWebService.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookRequestIntentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookRequestIntentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1AdvancedSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1AdvancedSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1AdvancedSettingsLoggingSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1AdvancedSettingsLoggingSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1AdvancedSettingsSpeechSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1AdvancedSettingsSpeechSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1AudioInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1AudioInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1BargeInConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1BargeInConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1BatchRunTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1BatchRunTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1BatchRunTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1BatchRunTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ContinuousTestResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ContinuousTestResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ConversationSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ConversationSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ConversationTurn' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ConversationTurn.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1CreateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1CreateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1CreateVersionOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1CreateVersionOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1DataStoreConnection' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1DataStoreConnection.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1DeleteDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1DeleteDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1DeployFlowMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1DeployFlowMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1DeployFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1DeployFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1DtmfInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1DtmfInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Environment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Environment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1EventHandler' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1EventHandler.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1EventInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1EventInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportAgentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportAgentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportEntityTypesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportEntityTypesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportIntentsMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportIntentsMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ExportTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ExportTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Form' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Form.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FormParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FormParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Fulfillment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Fulfillment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1GcsDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportDocumentsOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportDocumentsOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportDocumentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportEntityTypesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportEntityTypesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportEntityTypesResponseConflictingResources' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportEntityTypesResponseConflictingResources.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportFlowResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportFlowResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportIntentsMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportIntentsMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportIntentsResponseConflictingResources' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportIntentsResponseConflictingResources.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportTestCasesMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportTestCasesMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ImportTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ImportTestCasesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1InlineDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1InlineDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1InputAudioConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1InputAudioConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Intent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Intent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1IntentInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1IntentInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1IntentParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1IntentParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1KnowledgeConnectorSettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1KnowledgeConnectorSettings.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1LanguageInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1LanguageInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Page' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Page.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1PageInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1PageInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1PageInfoFormInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1PageInfoFormInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1QueryInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1QueryInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ReloadDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ReloadDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageConversationSuccess' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageConversationSuccess.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageKnowledgeInfoCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageKnowledgeInfoCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageLiveAgentHandoff' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageLiveAgentHandoff.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageTelephonyTransferCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageTelephonyTransferCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ResponseMessageText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ResponseMessageText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1RunContinuousTestMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1RunContinuousTestMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1RunContinuousTestResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1RunContinuousTestResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1RunTestCaseMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1RunTestCaseMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1RunTestCaseResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1RunTestCaseResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1SessionInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1SessionInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestCase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestCase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestCaseError' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestCaseError.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestCaseResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestCaseResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestError' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestError.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TestRunDifference' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TestRunDifference.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TextInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TextInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ToolCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ToolCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ToolCallResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ToolCallResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1ToolCallResultError' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1ToolCallResultError.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TransitionRoute' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TransitionRoute.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1TurnSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1TurnSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1UpdateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1UpdateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1Webhook' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1Webhook.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookGenericWebService' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookGenericWebService.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceOAuthConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceOAuthConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2AnnotatedMessagePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2AnnotatedMessagePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ArticleAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ArticleAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ArticleSuggestionModelMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ArticleSuggestionModelMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2BatchUpdateIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2BatchUpdateIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ClearSuggestionFeatureConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ClearSuggestionFeatureConfigOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2Context' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2Context.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ConversationEvent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ConversationEvent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ConversationModel' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ConversationModel.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2CreateConversationDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2CreateConversationDatasetOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2CreateConversationModelEvaluationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2CreateConversationModelEvaluationOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2CreateConversationModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2CreateConversationModelOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2DeleteConversationDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2DeleteConversationDatasetOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2DeleteConversationModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2DeleteConversationModelOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2DeployConversationModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2DeployConversationModelOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2EncryptionSpec.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2EntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2EntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2EntityTypeEntity' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2EntityTypeEntity.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2EventInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2EventInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ExportAgentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ExportAgentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ExportOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ExportOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2FaqAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2FaqAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2GcsDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2GcsDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2HumanAgentAssistantEvent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2HumanAgentAssistantEvent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ImportConversationDataOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ImportConversationDataOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ImportConversationDataOperationResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ImportConversationDataOperationResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2ImportDocumentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2InitializeEncryptionSpecMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2InitializeEncryptionSpecMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2InitializeEncryptionSpecRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2InitializeEncryptionSpecRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2InputDataset' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2InputDataset.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2Intent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2Intent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentFollowupIntentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentFollowupIntentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBasicCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBasicCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBasicCardButton' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBasicCardButton.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageCardButton' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageCardButton.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageCarouselSelect' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageCarouselSelect.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageCarouselSelectItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageCarouselSelectItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageColumnProperties' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageColumnProperties.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageImage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageImage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageListSelect' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageListSelect.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageListSelectItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageListSelectItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageMediaContent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageMediaContent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageQuickReplies' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageQuickReplies.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageSelectItemInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageSelectItemInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageSimpleResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageSimpleResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageSimpleResponses' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageSimpleResponses.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageSuggestions' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageSuggestions.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageTableCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageTableCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageTableCardCell' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageTableCardCell.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageTableCardRow' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageTableCardRow.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentMessageText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentMessageText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentTrainingPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentTrainingPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2IntentTrainingPhrasePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2IntentTrainingPhrasePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerFaqSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerFaqSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerGenerativeSourceSnippet' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswerKnowledgeAnswerGenerativeSourceSnippet.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeAssistAnswerSuggestedQuery' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeAssistAnswerSuggestedQuery.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2KnowledgeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2KnowledgeOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2Message' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2Message.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2MessageAnnotation' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2MessageAnnotation.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2OriginalDetectIntentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2OriginalDetectIntentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2QueryResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2QueryResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2Sentiment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2Sentiment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SentimentAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SentimentAnalysisResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SessionEntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SessionEntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SetSuggestionFeatureConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SetSuggestionFeatureConfigOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SmartReplyAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SmartReplyAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SmartReplyModelMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SmartReplyModelMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SuggestArticlesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SuggestArticlesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SuggestFaqAnswersResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SuggestFaqAnswersResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SuggestKnowledgeAssistResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SuggestKnowledgeAssistResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SuggestSmartRepliesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SuggestSmartRepliesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2SuggestionResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2SuggestionResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2WebhookRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2WebhookRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2WebhookResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2WebhookResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1AnnotatedMessagePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1AnnotatedMessagePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ArticleAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ArticleAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ClearSuggestionFeatureConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ClearSuggestionFeatureConfigOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1Context' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1Context.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ConversationEvent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ConversationEvent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1DialogflowAssistAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1DialogflowAssistAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1EncryptionSpec' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1EncryptionSpec.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1EntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1EntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1EntityTypeEntity' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1EntityTypeEntity.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1EventInput' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1EventInput.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ExportAgentResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ExportAgentResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ExportOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ExportOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1FaqAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1FaqAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1GcsDestination.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ImportDocumentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1InitializeEncryptionSpecMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1InitializeEncryptionSpecMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1InitializeEncryptionSpecRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1InitializeEncryptionSpecRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1Intent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1Intent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBasicCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBasicCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageCardButton' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageCardButton.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageColumnProperties' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageColumnProperties.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageImage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageImage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageListSelect' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageListSelect.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageListSelectItem' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageListSelectItem.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageMediaContent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageMediaContent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageMediaContentResponseMediaObject' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageMediaContentResponseMediaObject.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageQuickReplies' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageQuickReplies.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmCardContentRbmMedia' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmCardContentRbmMedia.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageRbmText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageRbmText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageSuggestions' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageSuggestions.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTableCard' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTableCard.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTableCardCell' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTableCardCell.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTableCardRow' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTableCardRow.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentMessageText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentMessageText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentParameter' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentParameter.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentSuggestion' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentSuggestion.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentTrainingPhrase' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentTrainingPhrase.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAnswers' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAnswers.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerFaqSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerFaqSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSourceSnippet' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSourceSnippet.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerSuggestedQuery' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerSuggestedQuery.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1Message' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1Message.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1MessageAnnotation' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1MessageAnnotation.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1QueryResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1QueryResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessage' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessage.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageEndInteraction' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageEndInteraction.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageLiveAgentHandoff' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageLiveAgentHandoff.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageMixedAudio' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageMixedAudio.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageTelephonyTransferCall' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageTelephonyTransferCall.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1ResponseMessageText' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1ResponseMessageText.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1Sentiment' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1Sentiment.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SentimentAnalysisResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SentimentAnalysisResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SessionEntityType' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SessionEntityType.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SetSuggestionFeatureConfigOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SetSuggestionFeatureConfigOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SmartReplyAnswer' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SmartReplyAnswer.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestArticlesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestArticlesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestDialogflowAssistsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestDialogflowAssistsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestKnowledgeAssistResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestKnowledgeAssistResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1SuggestionResult' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1SuggestionResult.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1WebhookRequest' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1WebhookRequest.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV2beta1WebhookResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV2beta1WebhookResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1ConversationSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1ConversationSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1CreateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1CreateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1DeleteDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1DeleteDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1ImportDocumentsOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1ImportDocumentsOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1ImportDocumentsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1ReloadDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1ReloadDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1TurnSignals' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1TurnSignals.php',
    'Google\\Service\\Dialogflow\\GoogleCloudDialogflowV3alpha1UpdateDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudDialogflowV3alpha1UpdateDocumentOperationMetadata.php',
    'Google\\Service\\Dialogflow\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleCloudLocationLocation.php',
    'Google\\Service\\Dialogflow\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Dialogflow\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleLongrunningOperation.php',
    'Google\\Service\\Dialogflow\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleProtobufEmpty.php',
    'Google\\Service\\Dialogflow\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleRpcStatus.php',
    'Google\\Service\\Dialogflow\\GoogleTypeLatLng' => $vendorDir . '/google/apiclient-services/src/Dialogflow/GoogleTypeLatLng.php',
    'Google\\Service\\Dialogflow\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/Projects.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocations.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgents' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgents.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsChangelogs' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsChangelogs.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEntityTypes' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEntityTypes.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironments' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironments.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironmentsContinuousTestResults' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironmentsContinuousTestResults.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironmentsDeployments' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironmentsDeployments.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironmentsExperiments' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironmentsExperiments.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironmentsSessions' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironmentsSessions.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsEnvironmentsSessionsEntityTypes' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsEnvironmentsSessionsEntityTypes.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsFlows' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsFlows.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsFlowsPages' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsFlowsPages.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsFlowsTransitionRouteGroups' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsFlowsTransitionRouteGroups.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsFlowsVersions' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsFlowsVersions.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsGenerators' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsGenerators.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsIntents' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsIntents.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsSessions' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsSessions.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsSessionsEntityTypes' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsSessionsEntityTypes.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsTestCases' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsTestCases.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsTestCasesResults' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsTestCasesResults.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsTransitionRouteGroups' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsTransitionRouteGroups.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsAgentsWebhooks' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsAgentsWebhooks.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsLocationsSecuritySettings' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsLocationsSecuritySettings.php',
    'Google\\Service\\Dialogflow\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/Dialogflow/Resource/ProjectsOperations.php',
    'Google\\Service\\Digitalassetlinks' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks.php',
    'Google\\Service\\Digitalassetlinks\\AndroidAppAsset' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/AndroidAppAsset.php',
    'Google\\Service\\Digitalassetlinks\\Asset' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/Asset.php',
    'Google\\Service\\Digitalassetlinks\\BulkCheckRequest' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/BulkCheckRequest.php',
    'Google\\Service\\Digitalassetlinks\\BulkCheckResponse' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/BulkCheckResponse.php',
    'Google\\Service\\Digitalassetlinks\\CertificateInfo' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/CertificateInfo.php',
    'Google\\Service\\Digitalassetlinks\\CheckResponse' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/CheckResponse.php',
    'Google\\Service\\Digitalassetlinks\\ListResponse' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/ListResponse.php',
    'Google\\Service\\Digitalassetlinks\\Resource\\Assetlinks' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/Resource/Assetlinks.php',
    'Google\\Service\\Digitalassetlinks\\Resource\\Statements' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/Resource/Statements.php',
    'Google\\Service\\Digitalassetlinks\\Statement' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/Statement.php',
    'Google\\Service\\Digitalassetlinks\\StatementTemplate' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/StatementTemplate.php',
    'Google\\Service\\Digitalassetlinks\\WebAsset' => $vendorDir . '/google/apiclient-services/src/Digitalassetlinks/WebAsset.php',
    'Google\\Service\\Directory' => $vendorDir . '/google/apiclient-services/src/Directory.php',
    'Google\\Service\\Directory\\AdminEmpty' => $vendorDir . '/google/apiclient-services/src/Directory/AdminEmpty.php',
    'Google\\Service\\Directory\\Alias' => $vendorDir . '/google/apiclient-services/src/Directory/Alias.php',
    'Google\\Service\\Directory\\Aliases' => $vendorDir . '/google/apiclient-services/src/Directory/Aliases.php',
    'Google\\Service\\Directory\\Asp' => $vendorDir . '/google/apiclient-services/src/Directory/Asp.php',
    'Google\\Service\\Directory\\Asps' => $vendorDir . '/google/apiclient-services/src/Directory/Asps.php',
    'Google\\Service\\Directory\\AuxiliaryMessage' => $vendorDir . '/google/apiclient-services/src/Directory/AuxiliaryMessage.php',
    'Google\\Service\\Directory\\BacklightInfo' => $vendorDir . '/google/apiclient-services/src/Directory/BacklightInfo.php',
    'Google\\Service\\Directory\\BatchChangeChromeOsDeviceStatusRequest' => $vendorDir . '/google/apiclient-services/src/Directory/BatchChangeChromeOsDeviceStatusRequest.php',
    'Google\\Service\\Directory\\BatchChangeChromeOsDeviceStatusResponse' => $vendorDir . '/google/apiclient-services/src/Directory/BatchChangeChromeOsDeviceStatusResponse.php',
    'Google\\Service\\Directory\\BatchCreatePrintServersRequest' => $vendorDir . '/google/apiclient-services/src/Directory/BatchCreatePrintServersRequest.php',
    'Google\\Service\\Directory\\BatchCreatePrintServersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/BatchCreatePrintServersResponse.php',
    'Google\\Service\\Directory\\BatchCreatePrintersRequest' => $vendorDir . '/google/apiclient-services/src/Directory/BatchCreatePrintersRequest.php',
    'Google\\Service\\Directory\\BatchCreatePrintersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/BatchCreatePrintersResponse.php',
    'Google\\Service\\Directory\\BatchDeletePrintServersRequest' => $vendorDir . '/google/apiclient-services/src/Directory/BatchDeletePrintServersRequest.php',
    'Google\\Service\\Directory\\BatchDeletePrintServersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/BatchDeletePrintServersResponse.php',
    'Google\\Service\\Directory\\BatchDeletePrintersRequest' => $vendorDir . '/google/apiclient-services/src/Directory/BatchDeletePrintersRequest.php',
    'Google\\Service\\Directory\\BatchDeletePrintersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/BatchDeletePrintersResponse.php',
    'Google\\Service\\Directory\\Building' => $vendorDir . '/google/apiclient-services/src/Directory/Building.php',
    'Google\\Service\\Directory\\BuildingAddress' => $vendorDir . '/google/apiclient-services/src/Directory/BuildingAddress.php',
    'Google\\Service\\Directory\\BuildingCoordinates' => $vendorDir . '/google/apiclient-services/src/Directory/BuildingCoordinates.php',
    'Google\\Service\\Directory\\Buildings' => $vendorDir . '/google/apiclient-services/src/Directory/Buildings.php',
    'Google\\Service\\Directory\\CalendarResource' => $vendorDir . '/google/apiclient-services/src/Directory/CalendarResource.php',
    'Google\\Service\\Directory\\CalendarResources' => $vendorDir . '/google/apiclient-services/src/Directory/CalendarResources.php',
    'Google\\Service\\Directory\\ChangeChromeOsDeviceStatusResult' => $vendorDir . '/google/apiclient-services/src/Directory/ChangeChromeOsDeviceStatusResult.php',
    'Google\\Service\\Directory\\ChangeChromeOsDeviceStatusSucceeded' => $vendorDir . '/google/apiclient-services/src/Directory/ChangeChromeOsDeviceStatusSucceeded.php',
    'Google\\Service\\Directory\\Channel' => $vendorDir . '/google/apiclient-services/src/Directory/Channel.php',
    'Google\\Service\\Directory\\ChromeOsDevice' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDevice.php',
    'Google\\Service\\Directory\\ChromeOsDeviceAction' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceAction.php',
    'Google\\Service\\Directory\\ChromeOsDeviceActiveTimeRanges' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceActiveTimeRanges.php',
    'Google\\Service\\Directory\\ChromeOsDeviceCpuInfo' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceCpuInfo.php',
    'Google\\Service\\Directory\\ChromeOsDeviceCpuInfoLogicalCpus' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceCpuInfoLogicalCpus.php',
    'Google\\Service\\Directory\\ChromeOsDeviceCpuInfoLogicalCpusCStates' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceCpuInfoLogicalCpusCStates.php',
    'Google\\Service\\Directory\\ChromeOsDeviceCpuStatusReports' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceCpuStatusReports.php',
    'Google\\Service\\Directory\\ChromeOsDeviceCpuStatusReportsCpuTemperatureInfo' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceCpuStatusReportsCpuTemperatureInfo.php',
    'Google\\Service\\Directory\\ChromeOsDeviceDeviceFiles' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceDeviceFiles.php',
    'Google\\Service\\Directory\\ChromeOsDeviceDiskVolumeReports' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceDiskVolumeReports.php',
    'Google\\Service\\Directory\\ChromeOsDeviceDiskVolumeReportsVolumeInfo' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceDiskVolumeReportsVolumeInfo.php',
    'Google\\Service\\Directory\\ChromeOsDeviceLastKnownNetwork' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceLastKnownNetwork.php',
    'Google\\Service\\Directory\\ChromeOsDeviceRecentUsers' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceRecentUsers.php',
    'Google\\Service\\Directory\\ChromeOsDeviceScreenshotFiles' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceScreenshotFiles.php',
    'Google\\Service\\Directory\\ChromeOsDeviceSystemRamFreeReports' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceSystemRamFreeReports.php',
    'Google\\Service\\Directory\\ChromeOsDeviceTpmVersionInfo' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDeviceTpmVersionInfo.php',
    'Google\\Service\\Directory\\ChromeOsDevices' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsDevices.php',
    'Google\\Service\\Directory\\ChromeOsMoveDevicesToOu' => $vendorDir . '/google/apiclient-services/src/Directory/ChromeOsMoveDevicesToOu.php',
    'Google\\Service\\Directory\\CreatePrintServerRequest' => $vendorDir . '/google/apiclient-services/src/Directory/CreatePrintServerRequest.php',
    'Google\\Service\\Directory\\CreatePrinterRequest' => $vendorDir . '/google/apiclient-services/src/Directory/CreatePrinterRequest.php',
    'Google\\Service\\Directory\\Customer' => $vendorDir . '/google/apiclient-services/src/Directory/Customer.php',
    'Google\\Service\\Directory\\CustomerPostalAddress' => $vendorDir . '/google/apiclient-services/src/Directory/CustomerPostalAddress.php',
    'Google\\Service\\Directory\\DirectoryChromeosdevicesCommand' => $vendorDir . '/google/apiclient-services/src/Directory/DirectoryChromeosdevicesCommand.php',
    'Google\\Service\\Directory\\DirectoryChromeosdevicesCommandResult' => $vendorDir . '/google/apiclient-services/src/Directory/DirectoryChromeosdevicesCommandResult.php',
    'Google\\Service\\Directory\\DirectoryChromeosdevicesIssueCommandRequest' => $vendorDir . '/google/apiclient-services/src/Directory/DirectoryChromeosdevicesIssueCommandRequest.php',
    'Google\\Service\\Directory\\DirectoryChromeosdevicesIssueCommandResponse' => $vendorDir . '/google/apiclient-services/src/Directory/DirectoryChromeosdevicesIssueCommandResponse.php',
    'Google\\Service\\Directory\\DomainAlias' => $vendorDir . '/google/apiclient-services/src/Directory/DomainAlias.php',
    'Google\\Service\\Directory\\DomainAliases' => $vendorDir . '/google/apiclient-services/src/Directory/DomainAliases.php',
    'Google\\Service\\Directory\\Domains' => $vendorDir . '/google/apiclient-services/src/Directory/Domains.php',
    'Google\\Service\\Directory\\Domains2' => $vendorDir . '/google/apiclient-services/src/Directory/Domains2.php',
    'Google\\Service\\Directory\\FailureInfo' => $vendorDir . '/google/apiclient-services/src/Directory/FailureInfo.php',
    'Google\\Service\\Directory\\FanInfo' => $vendorDir . '/google/apiclient-services/src/Directory/FanInfo.php',
    'Google\\Service\\Directory\\Feature' => $vendorDir . '/google/apiclient-services/src/Directory/Feature.php',
    'Google\\Service\\Directory\\FeatureInstance' => $vendorDir . '/google/apiclient-services/src/Directory/FeatureInstance.php',
    'Google\\Service\\Directory\\FeatureRename' => $vendorDir . '/google/apiclient-services/src/Directory/FeatureRename.php',
    'Google\\Service\\Directory\\Features' => $vendorDir . '/google/apiclient-services/src/Directory/Features.php',
    'Google\\Service\\Directory\\Group' => $vendorDir . '/google/apiclient-services/src/Directory/Group.php',
    'Google\\Service\\Directory\\GroupAlias' => $vendorDir . '/google/apiclient-services/src/Directory/GroupAlias.php',
    'Google\\Service\\Directory\\Groups' => $vendorDir . '/google/apiclient-services/src/Directory/Groups.php',
    'Google\\Service\\Directory\\ListPrintServersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/ListPrintServersResponse.php',
    'Google\\Service\\Directory\\ListPrinterModelsResponse' => $vendorDir . '/google/apiclient-services/src/Directory/ListPrinterModelsResponse.php',
    'Google\\Service\\Directory\\ListPrintersResponse' => $vendorDir . '/google/apiclient-services/src/Directory/ListPrintersResponse.php',
    'Google\\Service\\Directory\\Member' => $vendorDir . '/google/apiclient-services/src/Directory/Member.php',
    'Google\\Service\\Directory\\Members' => $vendorDir . '/google/apiclient-services/src/Directory/Members.php',
    'Google\\Service\\Directory\\MembersHasMember' => $vendorDir . '/google/apiclient-services/src/Directory/MembersHasMember.php',
    'Google\\Service\\Directory\\MobileDevice' => $vendorDir . '/google/apiclient-services/src/Directory/MobileDevice.php',
    'Google\\Service\\Directory\\MobileDeviceAction' => $vendorDir . '/google/apiclient-services/src/Directory/MobileDeviceAction.php',
    'Google\\Service\\Directory\\MobileDeviceApplications' => $vendorDir . '/google/apiclient-services/src/Directory/MobileDeviceApplications.php',
    'Google\\Service\\Directory\\MobileDevices' => $vendorDir . '/google/apiclient-services/src/Directory/MobileDevices.php',
    'Google\\Service\\Directory\\OrgUnit' => $vendorDir . '/google/apiclient-services/src/Directory/OrgUnit.php',
    'Google\\Service\\Directory\\OrgUnits' => $vendorDir . '/google/apiclient-services/src/Directory/OrgUnits.php',
    'Google\\Service\\Directory\\OsUpdateStatus' => $vendorDir . '/google/apiclient-services/src/Directory/OsUpdateStatus.php',
    'Google\\Service\\Directory\\PrintServer' => $vendorDir . '/google/apiclient-services/src/Directory/PrintServer.php',
    'Google\\Service\\Directory\\PrintServerFailureInfo' => $vendorDir . '/google/apiclient-services/src/Directory/PrintServerFailureInfo.php',
    'Google\\Service\\Directory\\Printer' => $vendorDir . '/google/apiclient-services/src/Directory/Printer.php',
    'Google\\Service\\Directory\\PrinterModel' => $vendorDir . '/google/apiclient-services/src/Directory/PrinterModel.php',
    'Google\\Service\\Directory\\Privilege' => $vendorDir . '/google/apiclient-services/src/Directory/Privilege.php',
    'Google\\Service\\Directory\\Privileges' => $vendorDir . '/google/apiclient-services/src/Directory/Privileges.php',
    'Google\\Service\\Directory\\Resource\\Asps' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Asps.php',
    'Google\\Service\\Directory\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Channels.php',
    'Google\\Service\\Directory\\Resource\\Chromeosdevices' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Chromeosdevices.php',
    'Google\\Service\\Directory\\Resource\\Customer' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Customer.php',
    'Google\\Service\\Directory\\Resource\\CustomerDevices' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomerDevices.php',
    'Google\\Service\\Directory\\Resource\\CustomerDevicesChromeos' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomerDevicesChromeos.php',
    'Google\\Service\\Directory\\Resource\\CustomerDevicesChromeosCommands' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomerDevicesChromeosCommands.php',
    'Google\\Service\\Directory\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Customers.php',
    'Google\\Service\\Directory\\Resource\\CustomersChrome' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomersChrome.php',
    'Google\\Service\\Directory\\Resource\\CustomersChromePrintServers' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomersChromePrintServers.php',
    'Google\\Service\\Directory\\Resource\\CustomersChromePrinters' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/CustomersChromePrinters.php',
    'Google\\Service\\Directory\\Resource\\DomainAliases' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/DomainAliases.php',
    'Google\\Service\\Directory\\Resource\\Domains' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Domains.php',
    'Google\\Service\\Directory\\Resource\\Groups' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Groups.php',
    'Google\\Service\\Directory\\Resource\\GroupsAliases' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/GroupsAliases.php',
    'Google\\Service\\Directory\\Resource\\Members' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Members.php',
    'Google\\Service\\Directory\\Resource\\Mobiledevices' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Mobiledevices.php',
    'Google\\Service\\Directory\\Resource\\Orgunits' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Orgunits.php',
    'Google\\Service\\Directory\\Resource\\Privileges' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Privileges.php',
    'Google\\Service\\Directory\\Resource\\Resources' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Resources.php',
    'Google\\Service\\Directory\\Resource\\ResourcesBuildings' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/ResourcesBuildings.php',
    'Google\\Service\\Directory\\Resource\\ResourcesCalendars' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/ResourcesCalendars.php',
    'Google\\Service\\Directory\\Resource\\ResourcesFeatures' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/ResourcesFeatures.php',
    'Google\\Service\\Directory\\Resource\\RoleAssignments' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/RoleAssignments.php',
    'Google\\Service\\Directory\\Resource\\Roles' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Roles.php',
    'Google\\Service\\Directory\\Resource\\Schemas' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Schemas.php',
    'Google\\Service\\Directory\\Resource\\Tokens' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Tokens.php',
    'Google\\Service\\Directory\\Resource\\TwoStepVerification' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/TwoStepVerification.php',
    'Google\\Service\\Directory\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/Users.php',
    'Google\\Service\\Directory\\Resource\\UsersAliases' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/UsersAliases.php',
    'Google\\Service\\Directory\\Resource\\UsersPhotos' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/UsersPhotos.php',
    'Google\\Service\\Directory\\Resource\\VerificationCodes' => $vendorDir . '/google/apiclient-services/src/Directory/Resource/VerificationCodes.php',
    'Google\\Service\\Directory\\Role' => $vendorDir . '/google/apiclient-services/src/Directory/Role.php',
    'Google\\Service\\Directory\\RoleAssignment' => $vendorDir . '/google/apiclient-services/src/Directory/RoleAssignment.php',
    'Google\\Service\\Directory\\RoleAssignments' => $vendorDir . '/google/apiclient-services/src/Directory/RoleAssignments.php',
    'Google\\Service\\Directory\\RoleRolePrivileges' => $vendorDir . '/google/apiclient-services/src/Directory/RoleRolePrivileges.php',
    'Google\\Service\\Directory\\Roles' => $vendorDir . '/google/apiclient-services/src/Directory/Roles.php',
    'Google\\Service\\Directory\\Schema' => $vendorDir . '/google/apiclient-services/src/Directory/Schema.php',
    'Google\\Service\\Directory\\SchemaFieldSpec' => $vendorDir . '/google/apiclient-services/src/Directory/SchemaFieldSpec.php',
    'Google\\Service\\Directory\\SchemaFieldSpecNumericIndexingSpec' => $vendorDir . '/google/apiclient-services/src/Directory/SchemaFieldSpecNumericIndexingSpec.php',
    'Google\\Service\\Directory\\Schemas' => $vendorDir . '/google/apiclient-services/src/Directory/Schemas.php',
    'Google\\Service\\Directory\\Status' => $vendorDir . '/google/apiclient-services/src/Directory/Status.php',
    'Google\\Service\\Directory\\Token' => $vendorDir . '/google/apiclient-services/src/Directory/Token.php',
    'Google\\Service\\Directory\\Tokens' => $vendorDir . '/google/apiclient-services/src/Directory/Tokens.php',
    'Google\\Service\\Directory\\User' => $vendorDir . '/google/apiclient-services/src/Directory/User.php',
    'Google\\Service\\Directory\\UserAbout' => $vendorDir . '/google/apiclient-services/src/Directory/UserAbout.php',
    'Google\\Service\\Directory\\UserAddress' => $vendorDir . '/google/apiclient-services/src/Directory/UserAddress.php',
    'Google\\Service\\Directory\\UserAlias' => $vendorDir . '/google/apiclient-services/src/Directory/UserAlias.php',
    'Google\\Service\\Directory\\UserEmail' => $vendorDir . '/google/apiclient-services/src/Directory/UserEmail.php',
    'Google\\Service\\Directory\\UserEmailPublicKeyEncryptionCertificates' => $vendorDir . '/google/apiclient-services/src/Directory/UserEmailPublicKeyEncryptionCertificates.php',
    'Google\\Service\\Directory\\UserExternalId' => $vendorDir . '/google/apiclient-services/src/Directory/UserExternalId.php',
    'Google\\Service\\Directory\\UserGender' => $vendorDir . '/google/apiclient-services/src/Directory/UserGender.php',
    'Google\\Service\\Directory\\UserIm' => $vendorDir . '/google/apiclient-services/src/Directory/UserIm.php',
    'Google\\Service\\Directory\\UserKeyword' => $vendorDir . '/google/apiclient-services/src/Directory/UserKeyword.php',
    'Google\\Service\\Directory\\UserLanguage' => $vendorDir . '/google/apiclient-services/src/Directory/UserLanguage.php',
    'Google\\Service\\Directory\\UserLocation' => $vendorDir . '/google/apiclient-services/src/Directory/UserLocation.php',
    'Google\\Service\\Directory\\UserMakeAdmin' => $vendorDir . '/google/apiclient-services/src/Directory/UserMakeAdmin.php',
    'Google\\Service\\Directory\\UserName' => $vendorDir . '/google/apiclient-services/src/Directory/UserName.php',
    'Google\\Service\\Directory\\UserOrganization' => $vendorDir . '/google/apiclient-services/src/Directory/UserOrganization.php',
    'Google\\Service\\Directory\\UserPhone' => $vendorDir . '/google/apiclient-services/src/Directory/UserPhone.php',
    'Google\\Service\\Directory\\UserPhoto' => $vendorDir . '/google/apiclient-services/src/Directory/UserPhoto.php',
    'Google\\Service\\Directory\\UserPosixAccount' => $vendorDir . '/google/apiclient-services/src/Directory/UserPosixAccount.php',
    'Google\\Service\\Directory\\UserRelation' => $vendorDir . '/google/apiclient-services/src/Directory/UserRelation.php',
    'Google\\Service\\Directory\\UserSshPublicKey' => $vendorDir . '/google/apiclient-services/src/Directory/UserSshPublicKey.php',
    'Google\\Service\\Directory\\UserUndelete' => $vendorDir . '/google/apiclient-services/src/Directory/UserUndelete.php',
    'Google\\Service\\Directory\\UserWebsite' => $vendorDir . '/google/apiclient-services/src/Directory/UserWebsite.php',
    'Google\\Service\\Directory\\Users' => $vendorDir . '/google/apiclient-services/src/Directory/Users.php',
    'Google\\Service\\Directory\\VerificationCode' => $vendorDir . '/google/apiclient-services/src/Directory/VerificationCode.php',
    'Google\\Service\\Directory\\VerificationCodes' => $vendorDir . '/google/apiclient-services/src/Directory/VerificationCodes.php',
    'Google\\Service\\DiscoveryEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleApiHttpBody.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingErrorContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingErrorContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingErrorLog' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingErrorLog.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingHttpRequestContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingHttpRequestContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingImportErrorContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingImportErrorContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingServiceContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingServiceContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineLoggingSourceLocation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineLoggingSourceLocation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AlloyDbSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AlloyDbSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Answer' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Answer.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerCitation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerCitation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerCitationSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerCitationSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpecModelSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpecModelSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpecPromptSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestAnswerGenerationSpecPromptSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpecQueryClassificationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpecQueryClassificationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpecQueryRephraserSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestQueryUnderstandingSpecQueryRephraserSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestRelatedQuestionsSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestRelatedQuestionsSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSafetySpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSafetySpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchParams' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchParams.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultList' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultList.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryUnderstandingInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryUnderstandingInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerQueryUnderstandingInfoQueryClassificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerQueryUnderstandingInfoQueryClassificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReferenceChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReferenceChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReferenceChunkInfoDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReferenceChunkInfoDocumentMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReferenceStructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReferenceStructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReferenceUnstructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReferenceUnstructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerReferenceUnstructuredDocumentInfoChunkContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerReferenceUnstructuredDocumentInfoChunkContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStep' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStep.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepActionObservation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepActionObservation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResultChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResultChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResultSnippetInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepActionObservationSearchResultSnippetInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1AnswerStepActionSearchAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1AnswerStepActionSearchAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchCreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchCreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchCreateTargetSitesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchCreateTargetSitesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchCreateTargetSitesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchCreateTargetSitesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponseDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponseDocumentMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponseDocumentMetadataMatcherValue' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchGetDocumentsMetadataResponseDocumentMetadataMatcherValue.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BatchVerifyTargetSitesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BatchVerifyTargetSitesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BigQuerySource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BigQuerySource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BigtableOptions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BigtableOptions.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BigtableOptionsBigtableColumn' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BigtableOptionsBigtableColumn.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BigtableOptionsBigtableColumnFamily' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BigtableOptionsBigtableColumnFamily.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1BigtableSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1BigtableSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CheckGroundingRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CheckGroundingRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CheckGroundingResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CheckGroundingResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CheckGroundingResponseClaim' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CheckGroundingResponseClaim.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CheckGroundingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CheckGroundingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Chunk' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Chunk.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ChunkChunkMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ChunkChunkMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ChunkDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ChunkDocumentMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ChunkPageSpan' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ChunkPageSpan.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CloudSqlSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CloudSqlSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CompleteQueryResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CompleteQueryResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CompleteQueryResponseQuerySuggestion' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CompleteQueryResponseQuerySuggestion.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CompletionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CompletionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CompletionSuggestion' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CompletionSuggestion.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Condition' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Condition.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConditionQueryTerm' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConditionQueryTerm.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConditionTimeRange' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConditionTimeRange.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Control' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Control.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ControlBoostAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ControlBoostAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ControlFilterAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ControlFilterAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ControlRedirectAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ControlRedirectAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ControlSynonymsAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ControlSynonymsAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Conversation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Conversation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConversationContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConversationContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConversationMessage' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConversationMessage.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConverseConversationRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConverseConversationRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ConverseConversationResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ConverseConversationResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CreateDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CreateDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CreateEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CreateEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CreateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CreateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CreateTargetSiteRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CreateTargetSiteRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CustomAttribute' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CustomAttribute.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1CustomTuningModel' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1CustomTuningModel.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DataStore' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DataStore.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DeleteDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DeleteDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DeleteEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DeleteEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DeleteSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DeleteSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DeleteTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DeleteTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DisableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Document' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Document.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentIndexStatus' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentIndexStatus.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigDigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigDigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigLayoutParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigLayoutParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigOcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigOcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EnableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Engine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Engine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EngineChatEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EngineChatEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EngineChatEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EngineChatEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EngineCommonConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EngineCommonConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1EngineSearchEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1EngineSearchEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1FactChunk' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1FactChunk.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1FetchDomainVerificationStatusResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1FetchDomainVerificationStatusResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1FhirStoreSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1FhirStoreSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1FirestoreSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1FirestoreSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1GcsSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1GcsSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1GroundingFact' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1GroundingFact.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportDocumentsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportDocumentsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportDocumentsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportErrorConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportErrorConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportUserEventsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportUserEventsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportUserEventsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportUserEventsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ImportUserEventsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Interval' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Interval.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListControlsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListControlsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListConversationsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListConversationsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListCustomModelsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListCustomModelsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListDataStoresResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListDataStoresResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListEnginesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListEnginesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListSchemasResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListSchemasResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListSessionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ListTargetSitesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ListTargetSitesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1MediaInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1MediaInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1OcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1OcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PageInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PageInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PanelInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PanelInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Project' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Project.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ProjectServiceTerms' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ProjectServiceTerms.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ProvisionProjectMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ProvisionProjectMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1ProvisionProjectRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1ProvisionProjectRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeDocumentsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeDocumentsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeDocumentsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeErrorConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeErrorConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1PurgeUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1PurgeUserEventsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Query' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Query.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RankRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RankRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RankResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RankResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RankingRecord' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RankingRecord.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RecommendRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RecommendRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RecommendResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RecommendResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RecommendResponseRecommendationResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RecommendResponseRecommendationResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1RecrawlUrisRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1RecrawlUrisRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Reply' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Reply.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Schema' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Schema.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestBoostSpecConditionBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestBoostSpecConditionBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSnippetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSnippetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestDataStoreSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestDataStoreSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestFacetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestFacetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestFacetSpecFacetKey' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestFacetSpecFacetKey.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestImageQuery' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestImageQuery.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestQueryExpansionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestQueryExpansionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestSearchAsYouTypeSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestSearchAsYouTypeSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestSessionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestSessionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchRequestSpellCorrectionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchRequestSpellCorrectionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseFacet' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseFacet.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseFacetFacetValue' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseFacetFacetValue.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseQueryExpansionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseQueryExpansionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSessionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSessionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummary' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummary.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummaryCitation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummaryCitation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummaryCitationMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummaryCitationMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummaryCitationSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummaryCitationSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummaryReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummaryReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummaryReferenceChunkContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummaryReferenceChunkContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummarySafetyAttributes' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummarySafetyAttributes.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SearchResponseSummarySummaryWithMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SearchResponseSummarySummaryWithMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1Session' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1Session.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SessionTurn' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SessionTurn.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SiteSearchEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SiteSearchEngine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SiteVerificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SiteVerificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SpannerSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SpannerSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1SuggestionDenyListEntry' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1SuggestionDenyListEntry.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TargetSite' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TargetSite.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TargetSiteFailureReason' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TargetSiteFailureReason.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TargetSiteFailureReasonQuotaFailure' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TargetSiteFailureReasonQuotaFailure.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TextInput' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TextInput.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TrainCustomModelMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TrainCustomModelMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TrainCustomModelRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TrainCustomModelRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TrainCustomModelRequestGcsTrainingInput' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TrainCustomModelRequestGcsTrainingInput.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TrainCustomModelResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TrainCustomModelResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1TransactionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1TransactionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1UpdateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1UpdateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1UpdateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1UpdateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1UserEvent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1UserEvent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1UserInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1UserInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1WorkspaceConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1WorkspaceConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAclConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAclConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswer' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswer.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerCitation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerCitation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerCitationSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerCitationSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfoQueryClassificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfoQueryClassificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReferenceStructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReferenceStructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStep' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStep.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaAnswerStepActionSearchAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaAnswerStepActionSearchAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaBatchCreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaBatchCreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaBatchCreateTargetSitesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaBatchCreateTargetSitesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCondition' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCondition.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaConditionQueryTerm' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaConditionQueryTerm.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaConditionTimeRange' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaConditionTimeRange.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaControl' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaControl.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaControlBoostAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaControlBoostAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaControlFilterAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaControlFilterAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaControlRedirectAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaControlRedirectAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaControlSynonymsAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaControlSynonymsAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCreateDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCreateDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCreateEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCreateEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCreateEvaluationMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCreateEvaluationMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCreateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCreateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCustomFineTuningSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCustomFineTuningSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaCustomTuningModel' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaCustomTuningModel.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDataStore' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDataStore.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDeleteDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDeleteDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDeleteEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDeleteEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDeleteSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDeleteSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDeleteTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDeleteTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDisableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDisableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDisableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDisableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigDigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigDigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigOcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigOcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEnableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEnableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEnableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEnableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineChatEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineChatEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineCommonConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineCommonConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigOptimizationObjectiveConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigOptimizationObjectiveConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEngineSimilarDocumentsEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEngineSimilarDocumentsEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEstimateDataSizeMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEstimateDataSizeMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEstimateDataSizeResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEstimateDataSizeResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEvaluation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEvaluation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpecQuerySetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpecQuerySetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaExportUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaExportUserEventsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaExportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaExportUserEventsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaFieldConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaFieldConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaGetUriPatternDocumentDataResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaGetUriPatternDocumentDataResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaGroundingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaGroundingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaIdpConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaIdpConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaIdpConfigExternalIdpConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaIdpConfigExternalIdpConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportErrorConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportErrorConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportSampleQueriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportSampleQueriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportUserEventsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaImportUserEventsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaInterval' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaInterval.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaLanguageInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaLanguageInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaLayoutParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaLayoutParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaListCustomModelsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaListCustomModelsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaOcrConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaOcrConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaOcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaOcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaOutputResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaOutputResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaOutputResultBigQueryOutputResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaOutputResultBigQueryOutputResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaProject' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaProject.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaProjectServiceTerms' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaProjectServiceTerms.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaProvisionProjectMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaProvisionProjectMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeUserEventsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaQualityMetrics' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaQualityMetrics.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaQualityMetricsTopkMetrics' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaQualityMetricsTopkMetrics.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaQuery' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaQuery.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponseFailureInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponseFailureInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponseFailureInfoFailureReason' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaRecrawlUrisResponseFailureInfoFailureReason.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSchema' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSchema.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSnippetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSnippetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpecModelPromptSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpecModelPromptSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpecModelSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpecModelSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpecEmbeddingVector' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpecEmbeddingVector.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestImageQuery' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestImageQuery.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAsYouTypeSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAsYouTypeSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSearchRequestSpellCorrectionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSearchRequestSpellCorrectionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSession' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSession.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSessionTurn' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSessionTurn.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSetUriPatternDocumentDataMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSetUriPatternDocumentDataMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSetUriPatternDocumentDataResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSetUriPatternDocumentDataResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaSiteVerificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaSiteVerificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTargetSite' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTargetSite.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTargetSiteFailureReason' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTargetSiteFailureReason.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTargetSiteFailureReasonQuotaFailure' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTargetSiteFailureReasonQuotaFailure.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTrainCustomModelMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTrainCustomModelMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTrainCustomModelResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTrainCustomModelResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTuneEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTuneEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaTuneEngineResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaTuneEngineResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaUpdateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaUpdateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaUpdateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaUpdateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaUserInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaUserInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1alphaWorkspaceConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1alphaWorkspaceConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswer' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswer.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerCitation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerCitation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerCitationSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerCitationSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecModelSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecModelSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecPromptSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecPromptSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpecQueryClassificationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpecQueryClassificationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpecQueryRephraserSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpecQueryRephraserSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestRelatedQuestionsSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestRelatedQuestionsSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSafetySpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSafetySpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchParams' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchParams.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultList' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultList.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfoQueryClassificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfoQueryClassificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfoDocumentMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfoDocumentMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStep' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStep.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaAnswerStepActionSearchAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaAnswerStepActionSearchAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBatchCreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBatchCreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBatchCreateTargetSitesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBatchCreateTargetSitesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBatchCreateTargetSitesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBatchCreateTargetSitesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBatchVerifyTargetSitesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBatchVerifyTargetSitesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBigQuerySource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBigQuerySource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBigtableOptions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBigtableOptions.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaBigtableSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaBigtableSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCheckGroundingRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCheckGroundingRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCheckGroundingResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCheckGroundingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCheckGroundingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCloudSqlSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCloudSqlSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCompleteQueryResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCompleteQueryResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCompleteQueryResponseQuerySuggestion' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCompleteQueryResponseQuerySuggestion.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCompletionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCompletionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCondition' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCondition.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConditionQueryTerm' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConditionQueryTerm.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConditionTimeRange' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConditionTimeRange.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaControl' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaControl.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaControlBoostAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaControlBoostAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaControlFilterAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaControlFilterAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaControlRedirectAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaControlRedirectAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaControlSynonymsAction' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaControlSynonymsAction.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConversation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConversation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConversationContext' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConversationContext.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConversationMessage' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConversationMessage.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConverseConversationRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConverseConversationRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaConverseConversationResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaConverseConversationResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateEvaluationMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateEvaluationMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCreateTargetSiteRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCreateTargetSiteRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCustomAttribute' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCustomAttribute.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaCustomTuningModel' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaCustomTuningModel.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDataStore' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDataStore.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDeleteDataStoreMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDeleteDataStoreMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDeleteEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDeleteEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDeleteSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDeleteSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDeleteTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDeleteTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDisableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocument' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocument.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigDigitalParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigDigitalParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigLayoutParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigLayoutParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaDoubleList' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaDoubleList.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEmbeddingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEmbeddingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEnableAdvancedSiteSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngineChatEngineConfigAgentCreationConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngineChatEngineConfigAgentCreationConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngineChatEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngineChatEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngineCommonConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngineCommonConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEvaluation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEvaluation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpecQuerySetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpecQuerySetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaFactChunk' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaFactChunk.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaFetchDomainVerificationStatusResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaFetchDomainVerificationStatusResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaFhirStoreSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaFhirStoreSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaFirestoreSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaFirestoreSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaGcsSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaGcsSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaGroundingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaGroundingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaGroundingFact' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaGroundingFact.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportCompletionSuggestionsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportCompletionSuggestionsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportCompletionSuggestionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportCompletionSuggestionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportDocumentsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportDocumentsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportDocumentsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportErrorConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportErrorConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSampleQueriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSampleQueriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSampleQueriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSampleQueriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportUserEventsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportUserEventsRequestInlineSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportUserEventsRequestInlineSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaImportUserEventsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaInterval' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaInterval.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaLanguageInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaLanguageInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListConversationsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListConversationsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListCustomModelsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListCustomModelsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListDataStoresResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListDataStoresResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListEnginesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListEnginesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListSchemasResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListSchemasResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListServingConfigsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListServingConfigsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListSessionsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaListTargetSitesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaListTargetSitesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaMediaInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaMediaInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaOcrParsingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaOcrParsingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPageInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPageInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPanelInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPanelInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPauseEngineRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPauseEngineRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaProject' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaProject.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaProjectServiceTerms' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaProjectServiceTerms.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaProvisionProjectMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaProvisionProjectMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeDocumentsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaPurgeSuggestionDenyListEntriesResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaQualityMetrics' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaQualityMetrics.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaQualityMetricsTopkMetrics' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaQualityMetricsTopkMetrics.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaQuery' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaQuery.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRankRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRankRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRankResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRankResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRankingRecord' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRankingRecord.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRecommendRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRecommendRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRecommendResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRecommendResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaRecrawlUrisRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaRecrawlUrisRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaReply' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaReply.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaReplyReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaReplyReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaResumeEngineRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaResumeEngineRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSchema' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSchema.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSnippetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSnippetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestEmbeddingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestEmbeddingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestEmbeddingSpecEmbeddingVector' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestEmbeddingSpecEmbeddingVector.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestImageQuery' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestImageQuery.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestNaturalLanguageQueryUnderstandingSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestNaturalLanguageQueryUnderstandingSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestSearchAsYouTypeSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestSearchAsYouTypeSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestSessionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestSessionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchRequestSpellCorrectionSpec' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchRequestSpellCorrectionSpec.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseFacet' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseFacet.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseFacetFacetValue' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseFacetFacetValue.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResultRefinementAttribute' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResultRefinementAttribute.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummary' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummary.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitationMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitationMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitationSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummaryCitationSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSearchResponseSummarySummaryWithMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSearchResponseSummarySummaryWithMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaServingConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaServingConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaServingConfigGenericConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaServingConfigGenericConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSession' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSession.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSessionTurn' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSessionTurn.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSiteSearchEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSiteSearchEngine.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSiteVerificationInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSiteVerificationInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSpannerSource' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSpannerSource.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaSuggestionDenyListEntry' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaSuggestionDenyListEntry.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTargetSite' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTargetSite.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTargetSiteFailureReason' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTargetSiteFailureReason.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTargetSiteFailureReasonQuotaFailure' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTargetSiteFailureReasonQuotaFailure.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTextInput' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTextInput.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTrainCustomModelMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTrainCustomModelMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTrainCustomModelRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTrainCustomModelRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTrainCustomModelRequestGcsTrainingInput' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTrainCustomModelRequestGcsTrainingInput.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTrainCustomModelResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTrainCustomModelResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTransactionInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTransactionInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTuneEngineMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTuneEngineMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTuneEngineRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTuneEngineRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaTuneEngineResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaTuneEngineResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaUpdateSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaUpdateSchemaMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaUpdateTargetSiteMetadata' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaUpdateTargetSiteMetadata.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaUserEvent' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaUserEvent.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaUserInfo' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaUserInfo.php',
    'Google\\Service\\DiscoveryEngine\\GoogleCloudDiscoveryengineV1betaWorkspaceConfig' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleCloudDiscoveryengineV1betaWorkspaceConfig.php',
    'Google\\Service\\DiscoveryEngine\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\DiscoveryEngine\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\DiscoveryEngine\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleLongrunningOperation.php',
    'Google\\Service\\DiscoveryEngine\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleProtobufEmpty.php',
    'Google\\Service\\DiscoveryEngine\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleRpcStatus.php',
    'Google\\Service\\DiscoveryEngine\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/GoogleTypeDate.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/Projects.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollections' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollections.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataConnector' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataConnector.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataConnectorOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataConnectorOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStores' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStores.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresBranches' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresBranches.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresBranchesDocuments' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresBranchesDocuments.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresBranchesOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresBranchesOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresCompletionSuggestions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresCompletionSuggestions.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresControls' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresControls.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresConversations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresConversations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresCustomModels' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresCustomModels.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresModels' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresModels.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresModelsOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresModelsOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSchemas' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSchemas.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSchemasOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSchemasOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresServingConfigs' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresServingConfigs.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSessions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSessions.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSessionsAnswers' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSessionsAnswers.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSiteSearchEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSiteSearchEngine.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSiteSearchEngineOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSiteSearchEngineOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSiteSearchEngineTargetSites' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSiteSearchEngineTargetSites.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSiteSearchEngineTargetSitesOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSiteSearchEngineTargetSitesOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresSuggestionDenyListEntries' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresSuggestionDenyListEntries.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsDataStoresUserEvents' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsDataStoresUserEvents.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEngines' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEngines.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesControls' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesControls.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesConversations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesConversations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesServingConfigs' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesServingConfigs.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesSessions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesSessions.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsEnginesSessionsAnswers' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsEnginesSessionsAnswers.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsCollectionsOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsCollectionsOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStores' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStores.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresBranches' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresBranches.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresBranchesDocuments' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresBranchesDocuments.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresBranchesOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresBranchesOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresCompletionSuggestions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresCompletionSuggestions.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresControls' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresControls.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresConversations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresConversations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresModels' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresModels.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresModelsOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresModelsOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSchemas' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSchemas.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresServingConfigs' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresServingConfigs.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSessions' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSessions.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSessionsAnswers' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSessionsAnswers.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSiteSearchEngine' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSiteSearchEngine.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSiteSearchEngineTargetSites' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSiteSearchEngineTargetSites.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresSuggestionDenyListEntries' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresSuggestionDenyListEntries.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsDataStoresUserEvents' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsDataStoresUserEvents.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsGroundingConfigs' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsGroundingConfigs.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsIdentityMappingStores' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsIdentityMappingStores.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsIdentityMappingStoresOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsIdentityMappingStoresOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsRankingConfigs' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsRankingConfigs.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsLocationsUserEvents' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsLocationsUserEvents.php',
    'Google\\Service\\DiscoveryEngine\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/DiscoveryEngine/Resource/ProjectsOperations.php',
    'Google\\Service\\DisplayVideo' => $vendorDir . '/google/apiclient-services/src/DisplayVideo.php',
    'Google\\Service\\DisplayVideo\\ActivateManualTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ActivateManualTriggerRequest.php',
    'Google\\Service\\DisplayVideo\\ActiveViewVideoViewabilityMetricConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ActiveViewVideoViewabilityMetricConfig.php',
    'Google\\Service\\DisplayVideo\\AdGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdGroup.php',
    'Google\\Service\\DisplayVideo\\AdGroupAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdGroupAd.php',
    'Google\\Service\\DisplayVideo\\AdGroupAssignedTargetingOption' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdGroupAssignedTargetingOption.php',
    'Google\\Service\\DisplayVideo\\AdUrl' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdUrl.php',
    'Google\\Service\\DisplayVideo\\Adloox' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Adloox.php',
    'Google\\Service\\DisplayVideo\\Advertiser' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Advertiser.php',
    'Google\\Service\\DisplayVideo\\AdvertiserAdServerConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserAdServerConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserBillingConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserBillingConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserCreativeConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserCreativeConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserDataAccessConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserDataAccessConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserGeneralConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserGeneralConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserSdfConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserSdfConfig.php',
    'Google\\Service\\DisplayVideo\\AdvertiserTargetingConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AdvertiserTargetingConfig.php',
    'Google\\Service\\DisplayVideo\\AgeRangeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AgeRangeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AgeRangeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AgeRangeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRules' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRules.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesComparisonValue' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesComparisonValue.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesRule' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesRule.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesRuleCondition' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesRuleCondition.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesRuleset' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesRuleset.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesSignal' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesSignal.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesSignalComparison' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesSignalComparison.php',
    'Google\\Service\\DisplayVideo\\AlgorithmRulesSignalValue' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AlgorithmRulesSignalValue.php',
    'Google\\Service\\DisplayVideo\\AppAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AppAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AppCategoryAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AppCategoryAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AppCategoryTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AppCategoryTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Asset' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Asset.php',
    'Google\\Service\\DisplayVideo\\AssetAssociation' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AssetAssociation.php',
    'Google\\Service\\DisplayVideo\\AssignedInventorySource' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AssignedInventorySource.php',
    'Google\\Service\\DisplayVideo\\AssignedLocation' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AssignedLocation.php',
    'Google\\Service\\DisplayVideo\\AssignedTargetingOption' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AssignedTargetingOption.php',
    'Google\\Service\\DisplayVideo\\AssignedUserRole' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AssignedUserRole.php',
    'Google\\Service\\DisplayVideo\\AudienceGroupAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AudienceGroupAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AudioAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AudioAd.php',
    'Google\\Service\\DisplayVideo\\AudioContentTypeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AudioContentTypeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AudioContentTypeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AudioContentTypeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AudioVideoOffset' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AudioVideoOffset.php',
    'Google\\Service\\DisplayVideo\\AuditAdvertiserResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AuditAdvertiserResponse.php',
    'Google\\Service\\DisplayVideo\\AuthorizedSellerStatusAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AuthorizedSellerStatusAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\AuthorizedSellerStatusTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/AuthorizedSellerStatusTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\BiddingStrategy' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BiddingStrategy.php',
    'Google\\Service\\DisplayVideo\\BrowserAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BrowserAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\BrowserTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BrowserTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\BudgetSummary' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BudgetSummary.php',
    'Google\\Service\\DisplayVideo\\BulkEditAdvertiserAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAdvertiserAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditAdvertiserAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAdvertiserAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedInventorySourcesRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedInventorySourcesRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedInventorySourcesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedInventorySourcesResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedLocationsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedLocationsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedLocationsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedUserRolesRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedUserRolesRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditAssignedUserRolesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditAssignedUserRolesResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditLineItemAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditLineItemAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditLineItemAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditLineItemAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditNegativeKeywordsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditNegativeKeywordsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditNegativeKeywordsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditNegativeKeywordsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditPartnerAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditPartnerAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditPartnerAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditPartnerAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkEditSitesRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditSitesRequest.php',
    'Google\\Service\\DisplayVideo\\BulkEditSitesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkEditSitesResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListAdGroupAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListAdGroupAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListAdvertiserAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListAdvertiserAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListCampaignAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListCampaignAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListInsertionOrderAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListInsertionOrderAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkListLineItemAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkListLineItemAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\BulkUpdateLineItemsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkUpdateLineItemsRequest.php',
    'Google\\Service\\DisplayVideo\\BulkUpdateLineItemsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BulkUpdateLineItemsResponse.php',
    'Google\\Service\\DisplayVideo\\BumperAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BumperAd.php',
    'Google\\Service\\DisplayVideo\\BusinessChainAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BusinessChainAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\BusinessChainSearchTerms' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BusinessChainSearchTerms.php',
    'Google\\Service\\DisplayVideo\\BusinessChainTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/BusinessChainTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Campaign' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Campaign.php',
    'Google\\Service\\DisplayVideo\\CampaignBudget' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CampaignBudget.php',
    'Google\\Service\\DisplayVideo\\CampaignFlight' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CampaignFlight.php',
    'Google\\Service\\DisplayVideo\\CampaignGoal' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CampaignGoal.php',
    'Google\\Service\\DisplayVideo\\CarrierAndIspAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CarrierAndIspAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\CarrierAndIspTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CarrierAndIspTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\CategoryAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CategoryAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\CategoryTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CategoryTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Channel' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Channel.php',
    'Google\\Service\\DisplayVideo\\ChannelAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ChannelAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\CmHybridConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CmHybridConfig.php',
    'Google\\Service\\DisplayVideo\\CmTrackingAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CmTrackingAd.php',
    'Google\\Service\\DisplayVideo\\CombinedAudience' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CombinedAudience.php',
    'Google\\Service\\DisplayVideo\\CombinedAudienceGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CombinedAudienceGroup.php',
    'Google\\Service\\DisplayVideo\\CombinedAudienceTargetingSetting' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CombinedAudienceTargetingSetting.php',
    'Google\\Service\\DisplayVideo\\CommonInStreamAttribute' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CommonInStreamAttribute.php',
    'Google\\Service\\DisplayVideo\\Consent' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Consent.php',
    'Google\\Service\\DisplayVideo\\ContactInfo' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContactInfo.php',
    'Google\\Service\\DisplayVideo\\ContactInfoList' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContactInfoList.php',
    'Google\\Service\\DisplayVideo\\ContentDurationAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentDurationAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentDurationTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentDurationTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentGenreAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentGenreAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentGenreTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentGenreTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentInstreamPositionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentInstreamPositionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentInstreamPositionTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentInstreamPositionTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentOutstreamPositionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentOutstreamPositionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentOutstreamPositionTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentOutstreamPositionTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentStreamTypeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentStreamTypeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ContentStreamTypeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ContentStreamTypeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ConversionCountingConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ConversionCountingConfig.php',
    'Google\\Service\\DisplayVideo\\CounterEvent' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CounterEvent.php',
    'Google\\Service\\DisplayVideo\\CreateAssetRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CreateAssetRequest.php',
    'Google\\Service\\DisplayVideo\\CreateAssetResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CreateAssetResponse.php',
    'Google\\Service\\DisplayVideo\\CreateAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CreateAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\CreateSdfDownloadTaskRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CreateSdfDownloadTaskRequest.php',
    'Google\\Service\\DisplayVideo\\Creative' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Creative.php',
    'Google\\Service\\DisplayVideo\\CreativeConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CreativeConfig.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingAlgorithm' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingAlgorithm.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingAlgorithmRules' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingAlgorithmRules.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingAlgorithmRulesError' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingAlgorithmRulesError.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingAlgorithmRulesRef' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingAlgorithmRulesRef.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingModelDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingModelDetails.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingModelReadinessState' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingModelReadinessState.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingScript' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingScript.php',
    'Google\\Service\\DisplayVideo\\CustomBiddingScriptRef' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomBiddingScriptRef.php',
    'Google\\Service\\DisplayVideo\\CustomLabel' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomLabel.php',
    'Google\\Service\\DisplayVideo\\CustomList' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomList.php',
    'Google\\Service\\DisplayVideo\\CustomListGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomListGroup.php',
    'Google\\Service\\DisplayVideo\\CustomListTargetingSetting' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/CustomListTargetingSetting.php',
    'Google\\Service\\DisplayVideo\\Date' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Date.php',
    'Google\\Service\\DisplayVideo\\DateRange' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DateRange.php',
    'Google\\Service\\DisplayVideo\\DayAndTime' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DayAndTime.php',
    'Google\\Service\\DisplayVideo\\DayAndTimeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DayAndTimeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DeactivateManualTriggerRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeactivateManualTriggerRequest.php',
    'Google\\Service\\DisplayVideo\\DeleteAssignedTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeleteAssignedTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\DeviceMakeModelAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeviceMakeModelAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DeviceMakeModelTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeviceMakeModelTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DeviceTypeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeviceTypeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DeviceTypeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DeviceTypeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DigitalContentLabelAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DigitalContentLabelAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\DigitalContentLabelTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DigitalContentLabelTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Dimensions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Dimensions.php',
    'Google\\Service\\DisplayVideo\\DisplayVideoSourceAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DisplayVideoSourceAd.php',
    'Google\\Service\\DisplayVideo\\DisplayvideoEmpty' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DisplayvideoEmpty.php',
    'Google\\Service\\DisplayVideo\\DoubleVerify' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerify.php',
    'Google\\Service\\DisplayVideo\\DoubleVerifyAppStarRating' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerifyAppStarRating.php',
    'Google\\Service\\DisplayVideo\\DoubleVerifyBrandSafetyCategories' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerifyBrandSafetyCategories.php',
    'Google\\Service\\DisplayVideo\\DoubleVerifyDisplayViewability' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerifyDisplayViewability.php',
    'Google\\Service\\DisplayVideo\\DoubleVerifyFraudInvalidTraffic' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerifyFraudInvalidTraffic.php',
    'Google\\Service\\DisplayVideo\\DoubleVerifyVideoViewability' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DoubleVerifyVideoViewability.php',
    'Google\\Service\\DisplayVideo\\DuplicateLineItemRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DuplicateLineItemRequest.php',
    'Google\\Service\\DisplayVideo\\DuplicateLineItemResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/DuplicateLineItemResponse.php',
    'Google\\Service\\DisplayVideo\\EditCustomerMatchMembersRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditCustomerMatchMembersRequest.php',
    'Google\\Service\\DisplayVideo\\EditCustomerMatchMembersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditCustomerMatchMembersResponse.php',
    'Google\\Service\\DisplayVideo\\EditGuaranteedOrderReadAccessorsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditGuaranteedOrderReadAccessorsRequest.php',
    'Google\\Service\\DisplayVideo\\EditGuaranteedOrderReadAccessorsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditGuaranteedOrderReadAccessorsResponse.php',
    'Google\\Service\\DisplayVideo\\EditInventorySourceReadWriteAccessorsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditInventorySourceReadWriteAccessorsRequest.php',
    'Google\\Service\\DisplayVideo\\EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate.php',
    'Google\\Service\\DisplayVideo\\EnvironmentAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EnvironmentAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\EnvironmentTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/EnvironmentTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ExchangeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExchangeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ExchangeConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExchangeConfig.php',
    'Google\\Service\\DisplayVideo\\ExchangeConfigEnabledExchange' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExchangeConfigEnabledExchange.php',
    'Google\\Service\\DisplayVideo\\ExchangeReviewStatus' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExchangeReviewStatus.php',
    'Google\\Service\\DisplayVideo\\ExchangeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExchangeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ExitEvent' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ExitEvent.php',
    'Google\\Service\\DisplayVideo\\FirstAndThirdPartyAudience' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FirstAndThirdPartyAudience.php',
    'Google\\Service\\DisplayVideo\\FirstAndThirdPartyAudienceGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FirstAndThirdPartyAudienceGroup.php',
    'Google\\Service\\DisplayVideo\\FirstAndThirdPartyAudienceTargetingSetting' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FirstAndThirdPartyAudienceTargetingSetting.php',
    'Google\\Service\\DisplayVideo\\FixedBidStrategy' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FixedBidStrategy.php',
    'Google\\Service\\DisplayVideo\\FloodlightActivity' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FloodlightActivity.php',
    'Google\\Service\\DisplayVideo\\FloodlightGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FloodlightGroup.php',
    'Google\\Service\\DisplayVideo\\FrequencyCap' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/FrequencyCap.php',
    'Google\\Service\\DisplayVideo\\GenderAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GenderAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\GenderTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GenderTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\GenerateDefaultLineItemRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GenerateDefaultLineItemRequest.php',
    'Google\\Service\\DisplayVideo\\GeoRegionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GeoRegionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\GeoRegionSearchTerms' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GeoRegionSearchTerms.php',
    'Google\\Service\\DisplayVideo\\GeoRegionTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GeoRegionTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\GoogleAudience' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GoogleAudience.php',
    'Google\\Service\\DisplayVideo\\GoogleAudienceGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GoogleAudienceGroup.php',
    'Google\\Service\\DisplayVideo\\GoogleAudienceTargetingSetting' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GoogleAudienceTargetingSetting.php',
    'Google\\Service\\DisplayVideo\\GoogleBytestreamMedia' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GoogleBytestreamMedia.php',
    'Google\\Service\\DisplayVideo\\GuaranteedOrder' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GuaranteedOrder.php',
    'Google\\Service\\DisplayVideo\\GuaranteedOrderStatus' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/GuaranteedOrderStatus.php',
    'Google\\Service\\DisplayVideo\\HouseholdIncomeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/HouseholdIncomeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\HouseholdIncomeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/HouseholdIncomeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\IdFilter' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/IdFilter.php',
    'Google\\Service\\DisplayVideo\\ImageAsset' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ImageAsset.php',
    'Google\\Service\\DisplayVideo\\InStreamAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InStreamAd.php',
    'Google\\Service\\DisplayVideo\\InsertionOrder' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InsertionOrder.php',
    'Google\\Service\\DisplayVideo\\InsertionOrderBudget' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InsertionOrderBudget.php',
    'Google\\Service\\DisplayVideo\\InsertionOrderBudgetSegment' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InsertionOrderBudgetSegment.php',
    'Google\\Service\\DisplayVideo\\IntegralAdScience' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/IntegralAdScience.php',
    'Google\\Service\\DisplayVideo\\IntegrationDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/IntegrationDetails.php',
    'Google\\Service\\DisplayVideo\\InventorySource' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySource.php',
    'Google\\Service\\DisplayVideo\\InventorySourceAccessors' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceAccessors.php',
    'Google\\Service\\DisplayVideo\\InventorySourceAccessorsAdvertiserAccessors' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceAccessorsAdvertiserAccessors.php',
    'Google\\Service\\DisplayVideo\\InventorySourceAccessorsPartnerAccessor' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceAccessorsPartnerAccessor.php',
    'Google\\Service\\DisplayVideo\\InventorySourceAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\InventorySourceDisplayCreativeConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceDisplayCreativeConfig.php',
    'Google\\Service\\DisplayVideo\\InventorySourceFilter' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceFilter.php',
    'Google\\Service\\DisplayVideo\\InventorySourceGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceGroup.php',
    'Google\\Service\\DisplayVideo\\InventorySourceGroupAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceGroupAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\InventorySourceStatus' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceStatus.php',
    'Google\\Service\\DisplayVideo\\InventorySourceVideoCreativeConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/InventorySourceVideoCreativeConfig.php',
    'Google\\Service\\DisplayVideo\\Invoice' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Invoice.php',
    'Google\\Service\\DisplayVideo\\KeywordAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/KeywordAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Kpi' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Kpi.php',
    'Google\\Service\\DisplayVideo\\LanguageAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LanguageAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\LanguageTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LanguageTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\LineItem' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LineItem.php',
    'Google\\Service\\DisplayVideo\\LineItemAssignedTargetingOption' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LineItemAssignedTargetingOption.php',
    'Google\\Service\\DisplayVideo\\LineItemBudget' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LineItemBudget.php',
    'Google\\Service\\DisplayVideo\\LineItemFlight' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LineItemFlight.php',
    'Google\\Service\\DisplayVideo\\ListAdGroupAdsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAdGroupAdsResponse.php',
    'Google\\Service\\DisplayVideo\\ListAdGroupAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAdGroupAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListAdGroupsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAdGroupsResponse.php',
    'Google\\Service\\DisplayVideo\\ListAdvertiserAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAdvertiserAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListAdvertisersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAdvertisersResponse.php',
    'Google\\Service\\DisplayVideo\\ListAssignedInventorySourcesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAssignedInventorySourcesResponse.php',
    'Google\\Service\\DisplayVideo\\ListAssignedLocationsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListAssignedLocationsResponse.php',
    'Google\\Service\\DisplayVideo\\ListCampaignAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCampaignAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListCampaignsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCampaignsResponse.php',
    'Google\\Service\\DisplayVideo\\ListChannelsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListChannelsResponse.php',
    'Google\\Service\\DisplayVideo\\ListCombinedAudiencesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCombinedAudiencesResponse.php',
    'Google\\Service\\DisplayVideo\\ListCreativesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCreativesResponse.php',
    'Google\\Service\\DisplayVideo\\ListCustomBiddingAlgorithmRulesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCustomBiddingAlgorithmRulesResponse.php',
    'Google\\Service\\DisplayVideo\\ListCustomBiddingAlgorithmsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCustomBiddingAlgorithmsResponse.php',
    'Google\\Service\\DisplayVideo\\ListCustomBiddingScriptsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCustomBiddingScriptsResponse.php',
    'Google\\Service\\DisplayVideo\\ListCustomListsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListCustomListsResponse.php',
    'Google\\Service\\DisplayVideo\\ListFirstAndThirdPartyAudiencesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListFirstAndThirdPartyAudiencesResponse.php',
    'Google\\Service\\DisplayVideo\\ListFloodlightActivitiesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListFloodlightActivitiesResponse.php',
    'Google\\Service\\DisplayVideo\\ListGoogleAudiencesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListGoogleAudiencesResponse.php',
    'Google\\Service\\DisplayVideo\\ListGuaranteedOrdersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListGuaranteedOrdersResponse.php',
    'Google\\Service\\DisplayVideo\\ListInsertionOrderAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListInsertionOrderAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListInsertionOrdersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListInsertionOrdersResponse.php',
    'Google\\Service\\DisplayVideo\\ListInventorySourceGroupsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListInventorySourceGroupsResponse.php',
    'Google\\Service\\DisplayVideo\\ListInventorySourcesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListInventorySourcesResponse.php',
    'Google\\Service\\DisplayVideo\\ListInvoicesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListInvoicesResponse.php',
    'Google\\Service\\DisplayVideo\\ListLineItemAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListLineItemAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListLineItemsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListLineItemsResponse.php',
    'Google\\Service\\DisplayVideo\\ListLocationListsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListLocationListsResponse.php',
    'Google\\Service\\DisplayVideo\\ListManualTriggersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListManualTriggersResponse.php',
    'Google\\Service\\DisplayVideo\\ListNegativeKeywordListsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListNegativeKeywordListsResponse.php',
    'Google\\Service\\DisplayVideo\\ListNegativeKeywordsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListNegativeKeywordsResponse.php',
    'Google\\Service\\DisplayVideo\\ListPartnerAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListPartnerAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListPartnersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListPartnersResponse.php',
    'Google\\Service\\DisplayVideo\\ListSitesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListSitesResponse.php',
    'Google\\Service\\DisplayVideo\\ListTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListUsersResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListUsersResponse.php',
    'Google\\Service\\DisplayVideo\\ListYoutubeAdGroupAdsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListYoutubeAdGroupAdsResponse.php',
    'Google\\Service\\DisplayVideo\\ListYoutubeAdGroupAssignedTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListYoutubeAdGroupAssignedTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\ListYoutubeAdGroupsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ListYoutubeAdGroupsResponse.php',
    'Google\\Service\\DisplayVideo\\LocationList' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LocationList.php',
    'Google\\Service\\DisplayVideo\\LookbackWindow' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LookbackWindow.php',
    'Google\\Service\\DisplayVideo\\LookupInvoiceCurrencyResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/LookupInvoiceCurrencyResponse.php',
    'Google\\Service\\DisplayVideo\\ManualTrigger' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ManualTrigger.php',
    'Google\\Service\\DisplayVideo\\MastheadAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/MastheadAd.php',
    'Google\\Service\\DisplayVideo\\MaximizeSpendBidStrategy' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/MaximizeSpendBidStrategy.php',
    'Google\\Service\\DisplayVideo\\MeasurementConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/MeasurementConfig.php',
    'Google\\Service\\DisplayVideo\\MobileApp' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/MobileApp.php',
    'Google\\Service\\DisplayVideo\\MobileDeviceIdList' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/MobileDeviceIdList.php',
    'Google\\Service\\DisplayVideo\\Money' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Money.php',
    'Google\\Service\\DisplayVideo\\NativeContentPositionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NativeContentPositionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\NativeContentPositionTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NativeContentPositionTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\NegativeKeyword' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NegativeKeyword.php',
    'Google\\Service\\DisplayVideo\\NegativeKeywordList' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NegativeKeywordList.php',
    'Google\\Service\\DisplayVideo\\NegativeKeywordListAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NegativeKeywordListAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\NonSkippableAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/NonSkippableAd.php',
    'Google\\Service\\DisplayVideo\\ObaIcon' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ObaIcon.php',
    'Google\\Service\\DisplayVideo\\OmidAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OmidAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\OmidTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OmidTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\OnScreenPositionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OnScreenPositionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\OnScreenPositionTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OnScreenPositionTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\OperatingSystemAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OperatingSystemAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\OperatingSystemTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/OperatingSystemTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Operation' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Operation.php',
    'Google\\Service\\DisplayVideo\\Pacing' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Pacing.php',
    'Google\\Service\\DisplayVideo\\ParentEntityFilter' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ParentEntityFilter.php',
    'Google\\Service\\DisplayVideo\\ParentalStatusAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ParentalStatusAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ParentalStatusTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ParentalStatusTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Partner' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Partner.php',
    'Google\\Service\\DisplayVideo\\PartnerAdServerConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerAdServerConfig.php',
    'Google\\Service\\DisplayVideo\\PartnerBillingConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerBillingConfig.php',
    'Google\\Service\\DisplayVideo\\PartnerCost' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerCost.php',
    'Google\\Service\\DisplayVideo\\PartnerDataAccessConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerDataAccessConfig.php',
    'Google\\Service\\DisplayVideo\\PartnerGeneralConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerGeneralConfig.php',
    'Google\\Service\\DisplayVideo\\PartnerRevenueModel' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PartnerRevenueModel.php',
    'Google\\Service\\DisplayVideo\\PerformanceGoal' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PerformanceGoal.php',
    'Google\\Service\\DisplayVideo\\PerformanceGoalBidStrategy' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PerformanceGoalBidStrategy.php',
    'Google\\Service\\DisplayVideo\\PoiAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PoiAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\PoiSearchTerms' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PoiSearchTerms.php',
    'Google\\Service\\DisplayVideo\\PoiTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PoiTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\PrismaConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PrismaConfig.php',
    'Google\\Service\\DisplayVideo\\PrismaCpeCode' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PrismaCpeCode.php',
    'Google\\Service\\DisplayVideo\\ProductFeedData' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ProductFeedData.php',
    'Google\\Service\\DisplayVideo\\ProductMatchDimension' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ProductMatchDimension.php',
    'Google\\Service\\DisplayVideo\\ProximityLocationListAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ProximityLocationListAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\PublisherReviewStatus' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/PublisherReviewStatus.php',
    'Google\\Service\\DisplayVideo\\RateDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/RateDetails.php',
    'Google\\Service\\DisplayVideo\\RegionalLocationListAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/RegionalLocationListAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\RemarketingConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/RemarketingConfig.php',
    'Google\\Service\\DisplayVideo\\ReplaceNegativeKeywordsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ReplaceNegativeKeywordsRequest.php',
    'Google\\Service\\DisplayVideo\\ReplaceNegativeKeywordsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ReplaceNegativeKeywordsResponse.php',
    'Google\\Service\\DisplayVideo\\ReplaceSitesRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ReplaceSitesRequest.php',
    'Google\\Service\\DisplayVideo\\ReplaceSitesResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ReplaceSitesResponse.php',
    'Google\\Service\\DisplayVideo\\Resource\\Advertisers' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/Advertisers.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersAdGroupAds' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersAdGroupAds.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersAdGroups' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersAdGroups.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersAdGroupsTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersAdGroupsTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersAdGroupsTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersAdGroupsTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersAssets' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersAssets.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersCampaigns' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersCampaigns.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersCampaignsTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersCampaignsTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersCampaignsTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersCampaignsTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersChannels' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersChannels.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersChannelsSites' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersChannelsSites.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersCreatives' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersCreatives.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersInsertionOrders' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersInsertionOrders.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersInsertionOrdersTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersInsertionOrdersTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersInsertionOrdersTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersInsertionOrdersTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersInvoices' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersInvoices.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersLineItems' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersLineItems.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersLineItemsTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersLineItemsTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersLineItemsTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersLineItemsTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersLocationLists' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersLocationLists.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersLocationListsAssignedLocations' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersLocationListsAssignedLocations.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersManualTriggers' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersManualTriggers.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersNegativeKeywordLists' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersNegativeKeywordLists.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersNegativeKeywordListsNegativeKeywords' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersNegativeKeywordListsNegativeKeywords.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersYoutubeAdGroupAds' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersYoutubeAdGroupAds.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersYoutubeAdGroups' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersYoutubeAdGroups.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersYoutubeAdGroupsTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersYoutubeAdGroupsTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\AdvertisersYoutubeAdGroupsTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/AdvertisersYoutubeAdGroupsTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\CombinedAudiences' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/CombinedAudiences.php',
    'Google\\Service\\DisplayVideo\\Resource\\CustomBiddingAlgorithms' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/CustomBiddingAlgorithms.php',
    'Google\\Service\\DisplayVideo\\Resource\\CustomBiddingAlgorithmsRules' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/CustomBiddingAlgorithmsRules.php',
    'Google\\Service\\DisplayVideo\\Resource\\CustomBiddingAlgorithmsScripts' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/CustomBiddingAlgorithmsScripts.php',
    'Google\\Service\\DisplayVideo\\Resource\\CustomLists' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/CustomLists.php',
    'Google\\Service\\DisplayVideo\\Resource\\FirstAndThirdPartyAudiences' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/FirstAndThirdPartyAudiences.php',
    'Google\\Service\\DisplayVideo\\Resource\\FloodlightGroups' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/FloodlightGroups.php',
    'Google\\Service\\DisplayVideo\\Resource\\FloodlightGroupsFloodlightActivities' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/FloodlightGroupsFloodlightActivities.php',
    'Google\\Service\\DisplayVideo\\Resource\\GoogleAudiences' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/GoogleAudiences.php',
    'Google\\Service\\DisplayVideo\\Resource\\GuaranteedOrders' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/GuaranteedOrders.php',
    'Google\\Service\\DisplayVideo\\Resource\\InventorySourceGroups' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/InventorySourceGroups.php',
    'Google\\Service\\DisplayVideo\\Resource\\InventorySourceGroupsAssignedInventorySources' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/InventorySourceGroupsAssignedInventorySources.php',
    'Google\\Service\\DisplayVideo\\Resource\\InventorySources' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/InventorySources.php',
    'Google\\Service\\DisplayVideo\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/Media.php',
    'Google\\Service\\DisplayVideo\\Resource\\Partners' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/Partners.php',
    'Google\\Service\\DisplayVideo\\Resource\\PartnersChannels' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/PartnersChannels.php',
    'Google\\Service\\DisplayVideo\\Resource\\PartnersChannelsSites' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/PartnersChannelsSites.php',
    'Google\\Service\\DisplayVideo\\Resource\\PartnersTargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/PartnersTargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\PartnersTargetingTypesAssignedTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/PartnersTargetingTypesAssignedTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\Sdfdownloadtasks' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/Sdfdownloadtasks.php',
    'Google\\Service\\DisplayVideo\\Resource\\SdfdownloadtasksOperations' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/SdfdownloadtasksOperations.php',
    'Google\\Service\\DisplayVideo\\Resource\\TargetingTypes' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/TargetingTypes.php',
    'Google\\Service\\DisplayVideo\\Resource\\TargetingTypesTargetingOptions' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/TargetingTypesTargetingOptions.php',
    'Google\\Service\\DisplayVideo\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Resource/Users.php',
    'Google\\Service\\DisplayVideo\\ReviewStatusInfo' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ReviewStatusInfo.php',
    'Google\\Service\\DisplayVideo\\ScriptError' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ScriptError.php',
    'Google\\Service\\DisplayVideo\\SdfConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SdfConfig.php',
    'Google\\Service\\DisplayVideo\\SdfDownloadTask' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SdfDownloadTask.php',
    'Google\\Service\\DisplayVideo\\SdfDownloadTaskMetadata' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SdfDownloadTaskMetadata.php',
    'Google\\Service\\DisplayVideo\\SearchTargetingOptionsRequest' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SearchTargetingOptionsRequest.php',
    'Google\\Service\\DisplayVideo\\SearchTargetingOptionsResponse' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SearchTargetingOptionsResponse.php',
    'Google\\Service\\DisplayVideo\\SensitiveCategoryAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SensitiveCategoryAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\SensitiveCategoryTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SensitiveCategoryTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\SessionPositionAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SessionPositionAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\Site' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Site.php',
    'Google\\Service\\DisplayVideo\\Status' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Status.php',
    'Google\\Service\\DisplayVideo\\SubExchangeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SubExchangeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\SubExchangeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/SubExchangeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\TargetFrequency' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TargetFrequency.php',
    'Google\\Service\\DisplayVideo\\TargetingExpansionConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TargetingExpansionConfig.php',
    'Google\\Service\\DisplayVideo\\TargetingOption' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TargetingOption.php',
    'Google\\Service\\DisplayVideo\\ThirdPartyMeasurementConfigs' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ThirdPartyMeasurementConfigs.php',
    'Google\\Service\\DisplayVideo\\ThirdPartyOnlyConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ThirdPartyOnlyConfig.php',
    'Google\\Service\\DisplayVideo\\ThirdPartyUrl' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ThirdPartyUrl.php',
    'Google\\Service\\DisplayVideo\\ThirdPartyVendorConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ThirdPartyVendorConfig.php',
    'Google\\Service\\DisplayVideo\\ThirdPartyVerifierAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ThirdPartyVerifierAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\TimeRange' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TimeRange.php',
    'Google\\Service\\DisplayVideo\\TimerEvent' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TimerEvent.php',
    'Google\\Service\\DisplayVideo\\TrackingFloodlightActivityConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/TrackingFloodlightActivityConfig.php',
    'Google\\Service\\DisplayVideo\\Transcode' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/Transcode.php',
    'Google\\Service\\DisplayVideo\\UniversalAdId' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/UniversalAdId.php',
    'Google\\Service\\DisplayVideo\\UrlAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/UrlAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\User' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/User.php',
    'Google\\Service\\DisplayVideo\\UserRewardedContentAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/UserRewardedContentAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\UserRewardedContentTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/UserRewardedContentTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\VideoAdSequenceSettings' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoAdSequenceSettings.php',
    'Google\\Service\\DisplayVideo\\VideoAdSequenceStep' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoAdSequenceStep.php',
    'Google\\Service\\DisplayVideo\\VideoDiscoveryAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoDiscoveryAd.php',
    'Google\\Service\\DisplayVideo\\VideoPerformanceAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoPerformanceAd.php',
    'Google\\Service\\DisplayVideo\\VideoPlayerSizeAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoPlayerSizeAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\VideoPlayerSizeTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/VideoPlayerSizeTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ViewabilityAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ViewabilityAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\ViewabilityTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/ViewabilityTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\YoutubeAdGroup' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAdGroup.php',
    'Google\\Service\\DisplayVideo\\YoutubeAdGroupAd' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAdGroupAd.php',
    'Google\\Service\\DisplayVideo\\YoutubeAdGroupAssignedTargetingOption' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAdGroupAssignedTargetingOption.php',
    'Google\\Service\\DisplayVideo\\YoutubeAndPartnersBiddingStrategy' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAndPartnersBiddingStrategy.php',
    'Google\\Service\\DisplayVideo\\YoutubeAndPartnersInventorySourceConfig' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAndPartnersInventorySourceConfig.php',
    'Google\\Service\\DisplayVideo\\YoutubeAndPartnersSettings' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAndPartnersSettings.php',
    'Google\\Service\\DisplayVideo\\YoutubeAndPartnersThirdPartyMeasurementSettings' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeAndPartnersThirdPartyMeasurementSettings.php',
    'Google\\Service\\DisplayVideo\\YoutubeChannelAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeChannelAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\YoutubeVideoAssignedTargetingOptionDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeVideoAssignedTargetingOptionDetails.php',
    'Google\\Service\\DisplayVideo\\YoutubeVideoDetails' => $vendorDir . '/google/apiclient-services/src/DisplayVideo/YoutubeVideoDetails.php',
    'Google\\Service\\Dns' => $vendorDir . '/google/apiclient-services/src/Dns.php',
    'Google\\Service\\Dns\\Change' => $vendorDir . '/google/apiclient-services/src/Dns/Change.php',
    'Google\\Service\\Dns\\ChangesListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ChangesListResponse.php',
    'Google\\Service\\Dns\\DnsKey' => $vendorDir . '/google/apiclient-services/src/Dns/DnsKey.php',
    'Google\\Service\\Dns\\DnsKeyDigest' => $vendorDir . '/google/apiclient-services/src/Dns/DnsKeyDigest.php',
    'Google\\Service\\Dns\\DnsKeySpec' => $vendorDir . '/google/apiclient-services/src/Dns/DnsKeySpec.php',
    'Google\\Service\\Dns\\DnsKeysListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/DnsKeysListResponse.php',
    'Google\\Service\\Dns\\Expr' => $vendorDir . '/google/apiclient-services/src/Dns/Expr.php',
    'Google\\Service\\Dns\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1AuditConfig.php',
    'Google\\Service\\Dns\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\Dns\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1Binding.php',
    'Google\\Service\\Dns\\GoogleIamV1GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1GetIamPolicyRequest.php',
    'Google\\Service\\Dns\\GoogleIamV1GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1GetPolicyOptions.php',
    'Google\\Service\\Dns\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1Policy.php',
    'Google\\Service\\Dns\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\Dns\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\Dns\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Dns/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\Dns\\ManagedZone' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZone.php',
    'Google\\Service\\Dns\\ManagedZoneCloudLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneCloudLoggingConfig.php',
    'Google\\Service\\Dns\\ManagedZoneDnsSecConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneDnsSecConfig.php',
    'Google\\Service\\Dns\\ManagedZoneForwardingConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneForwardingConfig.php',
    'Google\\Service\\Dns\\ManagedZoneForwardingConfigNameServerTarget' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneForwardingConfigNameServerTarget.php',
    'Google\\Service\\Dns\\ManagedZoneOperationsListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneOperationsListResponse.php',
    'Google\\Service\\Dns\\ManagedZonePeeringConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonePeeringConfig.php',
    'Google\\Service\\Dns\\ManagedZonePeeringConfigTargetNetwork' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonePeeringConfigTargetNetwork.php',
    'Google\\Service\\Dns\\ManagedZonePrivateVisibilityConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonePrivateVisibilityConfig.php',
    'Google\\Service\\Dns\\ManagedZonePrivateVisibilityConfigGKECluster' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonePrivateVisibilityConfigGKECluster.php',
    'Google\\Service\\Dns\\ManagedZonePrivateVisibilityConfigNetwork' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonePrivateVisibilityConfigNetwork.php',
    'Google\\Service\\Dns\\ManagedZoneReverseLookupConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneReverseLookupConfig.php',
    'Google\\Service\\Dns\\ManagedZoneServiceDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneServiceDirectoryConfig.php',
    'Google\\Service\\Dns\\ManagedZoneServiceDirectoryConfigNamespace' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZoneServiceDirectoryConfigNamespace.php',
    'Google\\Service\\Dns\\ManagedZonesListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ManagedZonesListResponse.php',
    'Google\\Service\\Dns\\Operation' => $vendorDir . '/google/apiclient-services/src/Dns/Operation.php',
    'Google\\Service\\Dns\\OperationDnsKeyContext' => $vendorDir . '/google/apiclient-services/src/Dns/OperationDnsKeyContext.php',
    'Google\\Service\\Dns\\OperationManagedZoneContext' => $vendorDir . '/google/apiclient-services/src/Dns/OperationManagedZoneContext.php',
    'Google\\Service\\Dns\\PoliciesListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/PoliciesListResponse.php',
    'Google\\Service\\Dns\\PoliciesPatchResponse' => $vendorDir . '/google/apiclient-services/src/Dns/PoliciesPatchResponse.php',
    'Google\\Service\\Dns\\PoliciesUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Dns/PoliciesUpdateResponse.php',
    'Google\\Service\\Dns\\Policy' => $vendorDir . '/google/apiclient-services/src/Dns/Policy.php',
    'Google\\Service\\Dns\\PolicyAlternativeNameServerConfig' => $vendorDir . '/google/apiclient-services/src/Dns/PolicyAlternativeNameServerConfig.php',
    'Google\\Service\\Dns\\PolicyAlternativeNameServerConfigTargetNameServer' => $vendorDir . '/google/apiclient-services/src/Dns/PolicyAlternativeNameServerConfigTargetNameServer.php',
    'Google\\Service\\Dns\\PolicyNetwork' => $vendorDir . '/google/apiclient-services/src/Dns/PolicyNetwork.php',
    'Google\\Service\\Dns\\Project' => $vendorDir . '/google/apiclient-services/src/Dns/Project.php',
    'Google\\Service\\Dns\\Quota' => $vendorDir . '/google/apiclient-services/src/Dns/Quota.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicy' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicy.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyGeoPolicy' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyGeoPolicy.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyGeoPolicyGeoPolicyItem' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyGeoPolicyGeoPolicyItem.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyHealthCheckTargets' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyHealthCheckTargets.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyLoadBalancerTarget' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyLoadBalancerTarget.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyPrimaryBackupPolicy' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyPrimaryBackupPolicy.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyWrrPolicy' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyWrrPolicy.php',
    'Google\\Service\\Dns\\RRSetRoutingPolicyWrrPolicyWrrPolicyItem' => $vendorDir . '/google/apiclient-services/src/Dns/RRSetRoutingPolicyWrrPolicyWrrPolicyItem.php',
    'Google\\Service\\Dns\\ResourceRecordSet' => $vendorDir . '/google/apiclient-services/src/Dns/ResourceRecordSet.php',
    'Google\\Service\\Dns\\ResourceRecordSetsDeleteResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResourceRecordSetsDeleteResponse.php',
    'Google\\Service\\Dns\\ResourceRecordSetsListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResourceRecordSetsListResponse.php',
    'Google\\Service\\Dns\\Resource\\Changes' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/Changes.php',
    'Google\\Service\\Dns\\Resource\\DnsKeys' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/DnsKeys.php',
    'Google\\Service\\Dns\\Resource\\ManagedZoneOperations' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ManagedZoneOperations.php',
    'Google\\Service\\Dns\\Resource\\ManagedZones' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ManagedZones.php',
    'Google\\Service\\Dns\\Resource\\Policies' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/Policies.php',
    'Google\\Service\\Dns\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/Projects.php',
    'Google\\Service\\Dns\\Resource\\ProjectsManagedZones' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ProjectsManagedZones.php',
    'Google\\Service\\Dns\\Resource\\ProjectsManagedZonesRrsets' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ProjectsManagedZonesRrsets.php',
    'Google\\Service\\Dns\\Resource\\ResourceRecordSets' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ResourceRecordSets.php',
    'Google\\Service\\Dns\\Resource\\ResponsePolicies' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ResponsePolicies.php',
    'Google\\Service\\Dns\\Resource\\ResponsePolicyRules' => $vendorDir . '/google/apiclient-services/src/Dns/Resource/ResponsePolicyRules.php',
    'Google\\Service\\Dns\\ResponseHeader' => $vendorDir . '/google/apiclient-services/src/Dns/ResponseHeader.php',
    'Google\\Service\\Dns\\ResponsePoliciesListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePoliciesListResponse.php',
    'Google\\Service\\Dns\\ResponsePoliciesPatchResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePoliciesPatchResponse.php',
    'Google\\Service\\Dns\\ResponsePoliciesUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePoliciesUpdateResponse.php',
    'Google\\Service\\Dns\\ResponsePolicy' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicy.php',
    'Google\\Service\\Dns\\ResponsePolicyGKECluster' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyGKECluster.php',
    'Google\\Service\\Dns\\ResponsePolicyNetwork' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyNetwork.php',
    'Google\\Service\\Dns\\ResponsePolicyRule' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyRule.php',
    'Google\\Service\\Dns\\ResponsePolicyRuleLocalData' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyRuleLocalData.php',
    'Google\\Service\\Dns\\ResponsePolicyRulesListResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyRulesListResponse.php',
    'Google\\Service\\Dns\\ResponsePolicyRulesPatchResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyRulesPatchResponse.php',
    'Google\\Service\\Dns\\ResponsePolicyRulesUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Dns/ResponsePolicyRulesUpdateResponse.php',
    'Google\\Service\\Docs' => $vendorDir . '/google/apiclient-services/src/Docs.php',
    'Google\\Service\\Docs\\AutoText' => $vendorDir . '/google/apiclient-services/src/Docs/AutoText.php',
    'Google\\Service\\Docs\\Background' => $vendorDir . '/google/apiclient-services/src/Docs/Background.php',
    'Google\\Service\\Docs\\BackgroundSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/BackgroundSuggestionState.php',
    'Google\\Service\\Docs\\BatchUpdateDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Docs/BatchUpdateDocumentRequest.php',
    'Google\\Service\\Docs\\BatchUpdateDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Docs/BatchUpdateDocumentResponse.php',
    'Google\\Service\\Docs\\Body' => $vendorDir . '/google/apiclient-services/src/Docs/Body.php',
    'Google\\Service\\Docs\\BookmarkLink' => $vendorDir . '/google/apiclient-services/src/Docs/BookmarkLink.php',
    'Google\\Service\\Docs\\Bullet' => $vendorDir . '/google/apiclient-services/src/Docs/Bullet.php',
    'Google\\Service\\Docs\\BulletSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/BulletSuggestionState.php',
    'Google\\Service\\Docs\\Color' => $vendorDir . '/google/apiclient-services/src/Docs/Color.php',
    'Google\\Service\\Docs\\ColumnBreak' => $vendorDir . '/google/apiclient-services/src/Docs/ColumnBreak.php',
    'Google\\Service\\Docs\\CreateFooterRequest' => $vendorDir . '/google/apiclient-services/src/Docs/CreateFooterRequest.php',
    'Google\\Service\\Docs\\CreateFooterResponse' => $vendorDir . '/google/apiclient-services/src/Docs/CreateFooterResponse.php',
    'Google\\Service\\Docs\\CreateFootnoteRequest' => $vendorDir . '/google/apiclient-services/src/Docs/CreateFootnoteRequest.php',
    'Google\\Service\\Docs\\CreateFootnoteResponse' => $vendorDir . '/google/apiclient-services/src/Docs/CreateFootnoteResponse.php',
    'Google\\Service\\Docs\\CreateHeaderRequest' => $vendorDir . '/google/apiclient-services/src/Docs/CreateHeaderRequest.php',
    'Google\\Service\\Docs\\CreateHeaderResponse' => $vendorDir . '/google/apiclient-services/src/Docs/CreateHeaderResponse.php',
    'Google\\Service\\Docs\\CreateNamedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Docs/CreateNamedRangeRequest.php',
    'Google\\Service\\Docs\\CreateNamedRangeResponse' => $vendorDir . '/google/apiclient-services/src/Docs/CreateNamedRangeResponse.php',
    'Google\\Service\\Docs\\CreateParagraphBulletsRequest' => $vendorDir . '/google/apiclient-services/src/Docs/CreateParagraphBulletsRequest.php',
    'Google\\Service\\Docs\\CropProperties' => $vendorDir . '/google/apiclient-services/src/Docs/CropProperties.php',
    'Google\\Service\\Docs\\CropPropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/CropPropertiesSuggestionState.php',
    'Google\\Service\\Docs\\DeleteContentRangeRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteContentRangeRequest.php',
    'Google\\Service\\Docs\\DeleteFooterRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteFooterRequest.php',
    'Google\\Service\\Docs\\DeleteHeaderRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteHeaderRequest.php',
    'Google\\Service\\Docs\\DeleteNamedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteNamedRangeRequest.php',
    'Google\\Service\\Docs\\DeleteParagraphBulletsRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteParagraphBulletsRequest.php',
    'Google\\Service\\Docs\\DeletePositionedObjectRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeletePositionedObjectRequest.php',
    'Google\\Service\\Docs\\DeleteTableColumnRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteTableColumnRequest.php',
    'Google\\Service\\Docs\\DeleteTableRowRequest' => $vendorDir . '/google/apiclient-services/src/Docs/DeleteTableRowRequest.php',
    'Google\\Service\\Docs\\Dimension' => $vendorDir . '/google/apiclient-services/src/Docs/Dimension.php',
    'Google\\Service\\Docs\\DocsList' => $vendorDir . '/google/apiclient-services/src/Docs/DocsList.php',
    'Google\\Service\\Docs\\Document' => $vendorDir . '/google/apiclient-services/src/Docs/Document.php',
    'Google\\Service\\Docs\\DocumentStyle' => $vendorDir . '/google/apiclient-services/src/Docs/DocumentStyle.php',
    'Google\\Service\\Docs\\DocumentStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/DocumentStyleSuggestionState.php',
    'Google\\Service\\Docs\\DocumentTab' => $vendorDir . '/google/apiclient-services/src/Docs/DocumentTab.php',
    'Google\\Service\\Docs\\EmbeddedDrawingProperties' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedDrawingProperties.php',
    'Google\\Service\\Docs\\EmbeddedDrawingPropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedDrawingPropertiesSuggestionState.php',
    'Google\\Service\\Docs\\EmbeddedObject' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedObject.php',
    'Google\\Service\\Docs\\EmbeddedObjectBorder' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedObjectBorder.php',
    'Google\\Service\\Docs\\EmbeddedObjectBorderSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedObjectBorderSuggestionState.php',
    'Google\\Service\\Docs\\EmbeddedObjectSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/EmbeddedObjectSuggestionState.php',
    'Google\\Service\\Docs\\EndOfSegmentLocation' => $vendorDir . '/google/apiclient-services/src/Docs/EndOfSegmentLocation.php',
    'Google\\Service\\Docs\\Equation' => $vendorDir . '/google/apiclient-services/src/Docs/Equation.php',
    'Google\\Service\\Docs\\Footer' => $vendorDir . '/google/apiclient-services/src/Docs/Footer.php',
    'Google\\Service\\Docs\\Footnote' => $vendorDir . '/google/apiclient-services/src/Docs/Footnote.php',
    'Google\\Service\\Docs\\FootnoteReference' => $vendorDir . '/google/apiclient-services/src/Docs/FootnoteReference.php',
    'Google\\Service\\Docs\\Header' => $vendorDir . '/google/apiclient-services/src/Docs/Header.php',
    'Google\\Service\\Docs\\HeadingLink' => $vendorDir . '/google/apiclient-services/src/Docs/HeadingLink.php',
    'Google\\Service\\Docs\\HorizontalRule' => $vendorDir . '/google/apiclient-services/src/Docs/HorizontalRule.php',
    'Google\\Service\\Docs\\ImageProperties' => $vendorDir . '/google/apiclient-services/src/Docs/ImageProperties.php',
    'Google\\Service\\Docs\\ImagePropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/ImagePropertiesSuggestionState.php',
    'Google\\Service\\Docs\\InlineObject' => $vendorDir . '/google/apiclient-services/src/Docs/InlineObject.php',
    'Google\\Service\\Docs\\InlineObjectElement' => $vendorDir . '/google/apiclient-services/src/Docs/InlineObjectElement.php',
    'Google\\Service\\Docs\\InlineObjectProperties' => $vendorDir . '/google/apiclient-services/src/Docs/InlineObjectProperties.php',
    'Google\\Service\\Docs\\InlineObjectPropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/InlineObjectPropertiesSuggestionState.php',
    'Google\\Service\\Docs\\InsertInlineImageRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertInlineImageRequest.php',
    'Google\\Service\\Docs\\InsertInlineImageResponse' => $vendorDir . '/google/apiclient-services/src/Docs/InsertInlineImageResponse.php',
    'Google\\Service\\Docs\\InsertInlineSheetsChartResponse' => $vendorDir . '/google/apiclient-services/src/Docs/InsertInlineSheetsChartResponse.php',
    'Google\\Service\\Docs\\InsertPageBreakRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertPageBreakRequest.php',
    'Google\\Service\\Docs\\InsertSectionBreakRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertSectionBreakRequest.php',
    'Google\\Service\\Docs\\InsertTableColumnRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertTableColumnRequest.php',
    'Google\\Service\\Docs\\InsertTableRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertTableRequest.php',
    'Google\\Service\\Docs\\InsertTableRowRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertTableRowRequest.php',
    'Google\\Service\\Docs\\InsertTextRequest' => $vendorDir . '/google/apiclient-services/src/Docs/InsertTextRequest.php',
    'Google\\Service\\Docs\\Link' => $vendorDir . '/google/apiclient-services/src/Docs/Link.php',
    'Google\\Service\\Docs\\LinkedContentReference' => $vendorDir . '/google/apiclient-services/src/Docs/LinkedContentReference.php',
    'Google\\Service\\Docs\\LinkedContentReferenceSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/LinkedContentReferenceSuggestionState.php',
    'Google\\Service\\Docs\\ListProperties' => $vendorDir . '/google/apiclient-services/src/Docs/ListProperties.php',
    'Google\\Service\\Docs\\ListPropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/ListPropertiesSuggestionState.php',
    'Google\\Service\\Docs\\Location' => $vendorDir . '/google/apiclient-services/src/Docs/Location.php',
    'Google\\Service\\Docs\\MergeTableCellsRequest' => $vendorDir . '/google/apiclient-services/src/Docs/MergeTableCellsRequest.php',
    'Google\\Service\\Docs\\NamedRange' => $vendorDir . '/google/apiclient-services/src/Docs/NamedRange.php',
    'Google\\Service\\Docs\\NamedRanges' => $vendorDir . '/google/apiclient-services/src/Docs/NamedRanges.php',
    'Google\\Service\\Docs\\NamedStyle' => $vendorDir . '/google/apiclient-services/src/Docs/NamedStyle.php',
    'Google\\Service\\Docs\\NamedStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/NamedStyleSuggestionState.php',
    'Google\\Service\\Docs\\NamedStyles' => $vendorDir . '/google/apiclient-services/src/Docs/NamedStyles.php',
    'Google\\Service\\Docs\\NamedStylesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/NamedStylesSuggestionState.php',
    'Google\\Service\\Docs\\NestingLevel' => $vendorDir . '/google/apiclient-services/src/Docs/NestingLevel.php',
    'Google\\Service\\Docs\\NestingLevelSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/NestingLevelSuggestionState.php',
    'Google\\Service\\Docs\\ObjectReferences' => $vendorDir . '/google/apiclient-services/src/Docs/ObjectReferences.php',
    'Google\\Service\\Docs\\OptionalColor' => $vendorDir . '/google/apiclient-services/src/Docs/OptionalColor.php',
    'Google\\Service\\Docs\\PageBreak' => $vendorDir . '/google/apiclient-services/src/Docs/PageBreak.php',
    'Google\\Service\\Docs\\Paragraph' => $vendorDir . '/google/apiclient-services/src/Docs/Paragraph.php',
    'Google\\Service\\Docs\\ParagraphBorder' => $vendorDir . '/google/apiclient-services/src/Docs/ParagraphBorder.php',
    'Google\\Service\\Docs\\ParagraphElement' => $vendorDir . '/google/apiclient-services/src/Docs/ParagraphElement.php',
    'Google\\Service\\Docs\\ParagraphStyle' => $vendorDir . '/google/apiclient-services/src/Docs/ParagraphStyle.php',
    'Google\\Service\\Docs\\ParagraphStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/ParagraphStyleSuggestionState.php',
    'Google\\Service\\Docs\\Person' => $vendorDir . '/google/apiclient-services/src/Docs/Person.php',
    'Google\\Service\\Docs\\PersonProperties' => $vendorDir . '/google/apiclient-services/src/Docs/PersonProperties.php',
    'Google\\Service\\Docs\\PinTableHeaderRowsRequest' => $vendorDir . '/google/apiclient-services/src/Docs/PinTableHeaderRowsRequest.php',
    'Google\\Service\\Docs\\PositionedObject' => $vendorDir . '/google/apiclient-services/src/Docs/PositionedObject.php',
    'Google\\Service\\Docs\\PositionedObjectPositioning' => $vendorDir . '/google/apiclient-services/src/Docs/PositionedObjectPositioning.php',
    'Google\\Service\\Docs\\PositionedObjectPositioningSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/PositionedObjectPositioningSuggestionState.php',
    'Google\\Service\\Docs\\PositionedObjectProperties' => $vendorDir . '/google/apiclient-services/src/Docs/PositionedObjectProperties.php',
    'Google\\Service\\Docs\\PositionedObjectPropertiesSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/PositionedObjectPropertiesSuggestionState.php',
    'Google\\Service\\Docs\\Range' => $vendorDir . '/google/apiclient-services/src/Docs/Range.php',
    'Google\\Service\\Docs\\ReplaceAllTextRequest' => $vendorDir . '/google/apiclient-services/src/Docs/ReplaceAllTextRequest.php',
    'Google\\Service\\Docs\\ReplaceAllTextResponse' => $vendorDir . '/google/apiclient-services/src/Docs/ReplaceAllTextResponse.php',
    'Google\\Service\\Docs\\ReplaceImageRequest' => $vendorDir . '/google/apiclient-services/src/Docs/ReplaceImageRequest.php',
    'Google\\Service\\Docs\\ReplaceNamedRangeContentRequest' => $vendorDir . '/google/apiclient-services/src/Docs/ReplaceNamedRangeContentRequest.php',
    'Google\\Service\\Docs\\Request' => $vendorDir . '/google/apiclient-services/src/Docs/Request.php',
    'Google\\Service\\Docs\\Resource\\Documents' => $vendorDir . '/google/apiclient-services/src/Docs/Resource/Documents.php',
    'Google\\Service\\Docs\\Response' => $vendorDir . '/google/apiclient-services/src/Docs/Response.php',
    'Google\\Service\\Docs\\RgbColor' => $vendorDir . '/google/apiclient-services/src/Docs/RgbColor.php',
    'Google\\Service\\Docs\\RichLink' => $vendorDir . '/google/apiclient-services/src/Docs/RichLink.php',
    'Google\\Service\\Docs\\RichLinkProperties' => $vendorDir . '/google/apiclient-services/src/Docs/RichLinkProperties.php',
    'Google\\Service\\Docs\\SectionBreak' => $vendorDir . '/google/apiclient-services/src/Docs/SectionBreak.php',
    'Google\\Service\\Docs\\SectionColumnProperties' => $vendorDir . '/google/apiclient-services/src/Docs/SectionColumnProperties.php',
    'Google\\Service\\Docs\\SectionStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SectionStyle.php',
    'Google\\Service\\Docs\\Shading' => $vendorDir . '/google/apiclient-services/src/Docs/Shading.php',
    'Google\\Service\\Docs\\ShadingSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/ShadingSuggestionState.php',
    'Google\\Service\\Docs\\SheetsChartReference' => $vendorDir . '/google/apiclient-services/src/Docs/SheetsChartReference.php',
    'Google\\Service\\Docs\\SheetsChartReferenceSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/SheetsChartReferenceSuggestionState.php',
    'Google\\Service\\Docs\\Size' => $vendorDir . '/google/apiclient-services/src/Docs/Size.php',
    'Google\\Service\\Docs\\SizeSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/SizeSuggestionState.php',
    'Google\\Service\\Docs\\StructuralElement' => $vendorDir . '/google/apiclient-services/src/Docs/StructuralElement.php',
    'Google\\Service\\Docs\\SubstringMatchCriteria' => $vendorDir . '/google/apiclient-services/src/Docs/SubstringMatchCriteria.php',
    'Google\\Service\\Docs\\SuggestedBullet' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedBullet.php',
    'Google\\Service\\Docs\\SuggestedDocumentStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedDocumentStyle.php',
    'Google\\Service\\Docs\\SuggestedInlineObjectProperties' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedInlineObjectProperties.php',
    'Google\\Service\\Docs\\SuggestedListProperties' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedListProperties.php',
    'Google\\Service\\Docs\\SuggestedNamedStyles' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedNamedStyles.php',
    'Google\\Service\\Docs\\SuggestedParagraphStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedParagraphStyle.php',
    'Google\\Service\\Docs\\SuggestedPositionedObjectProperties' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedPositionedObjectProperties.php',
    'Google\\Service\\Docs\\SuggestedTableCellStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedTableCellStyle.php',
    'Google\\Service\\Docs\\SuggestedTableRowStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedTableRowStyle.php',
    'Google\\Service\\Docs\\SuggestedTextStyle' => $vendorDir . '/google/apiclient-services/src/Docs/SuggestedTextStyle.php',
    'Google\\Service\\Docs\\Tab' => $vendorDir . '/google/apiclient-services/src/Docs/Tab.php',
    'Google\\Service\\Docs\\TabProperties' => $vendorDir . '/google/apiclient-services/src/Docs/TabProperties.php',
    'Google\\Service\\Docs\\TabStop' => $vendorDir . '/google/apiclient-services/src/Docs/TabStop.php',
    'Google\\Service\\Docs\\Table' => $vendorDir . '/google/apiclient-services/src/Docs/Table.php',
    'Google\\Service\\Docs\\TableCell' => $vendorDir . '/google/apiclient-services/src/Docs/TableCell.php',
    'Google\\Service\\Docs\\TableCellBorder' => $vendorDir . '/google/apiclient-services/src/Docs/TableCellBorder.php',
    'Google\\Service\\Docs\\TableCellLocation' => $vendorDir . '/google/apiclient-services/src/Docs/TableCellLocation.php',
    'Google\\Service\\Docs\\TableCellStyle' => $vendorDir . '/google/apiclient-services/src/Docs/TableCellStyle.php',
    'Google\\Service\\Docs\\TableCellStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/TableCellStyleSuggestionState.php',
    'Google\\Service\\Docs\\TableColumnProperties' => $vendorDir . '/google/apiclient-services/src/Docs/TableColumnProperties.php',
    'Google\\Service\\Docs\\TableOfContents' => $vendorDir . '/google/apiclient-services/src/Docs/TableOfContents.php',
    'Google\\Service\\Docs\\TableRange' => $vendorDir . '/google/apiclient-services/src/Docs/TableRange.php',
    'Google\\Service\\Docs\\TableRow' => $vendorDir . '/google/apiclient-services/src/Docs/TableRow.php',
    'Google\\Service\\Docs\\TableRowStyle' => $vendorDir . '/google/apiclient-services/src/Docs/TableRowStyle.php',
    'Google\\Service\\Docs\\TableRowStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/TableRowStyleSuggestionState.php',
    'Google\\Service\\Docs\\TableStyle' => $vendorDir . '/google/apiclient-services/src/Docs/TableStyle.php',
    'Google\\Service\\Docs\\TabsCriteria' => $vendorDir . '/google/apiclient-services/src/Docs/TabsCriteria.php',
    'Google\\Service\\Docs\\TextRun' => $vendorDir . '/google/apiclient-services/src/Docs/TextRun.php',
    'Google\\Service\\Docs\\TextStyle' => $vendorDir . '/google/apiclient-services/src/Docs/TextStyle.php',
    'Google\\Service\\Docs\\TextStyleSuggestionState' => $vendorDir . '/google/apiclient-services/src/Docs/TextStyleSuggestionState.php',
    'Google\\Service\\Docs\\UnmergeTableCellsRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UnmergeTableCellsRequest.php',
    'Google\\Service\\Docs\\UpdateDocumentStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateDocumentStyleRequest.php',
    'Google\\Service\\Docs\\UpdateParagraphStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateParagraphStyleRequest.php',
    'Google\\Service\\Docs\\UpdateSectionStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateSectionStyleRequest.php',
    'Google\\Service\\Docs\\UpdateTableCellStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateTableCellStyleRequest.php',
    'Google\\Service\\Docs\\UpdateTableColumnPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateTableColumnPropertiesRequest.php',
    'Google\\Service\\Docs\\UpdateTableRowStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateTableRowStyleRequest.php',
    'Google\\Service\\Docs\\UpdateTextStyleRequest' => $vendorDir . '/google/apiclient-services/src/Docs/UpdateTextStyleRequest.php',
    'Google\\Service\\Docs\\WeightedFontFamily' => $vendorDir . '/google/apiclient-services/src/Docs/WeightedFontFamily.php',
    'Google\\Service\\Docs\\WriteControl' => $vendorDir . '/google/apiclient-services/src/Docs/WriteControl.php',
    'Google\\Service\\Document' => $vendorDir . '/google/apiclient-services/src/Document.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchDeleteDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsMetadataIndividualBatchMoveStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsMetadataIndividualBatchMoveStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchMoveDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadataIndividualBatchUpdateStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadataIndividualBatchUpdateStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3CreateLabelerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3CreateLabelerPoolOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeleteDataLabelingJobOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeleteDataLabelingJobOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeleteLabelerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeleteLabelerPoolOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeleteProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeleteProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeleteProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeleteProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DisableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DisableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DisableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DisableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DocumentIdGCSManagedDocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DocumentIdGCSManagedDocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3DocumentIdUnmanagedDocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3DocumentIdUnmanagedDocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3EnableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3EnableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3EnableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3EnableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3EvaluateProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3EvaluateProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3EvaluateProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3EvaluateProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataIndividualExportStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataIndividualExportStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataSplitExportStat' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataSplitExportStat.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ExportProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ExportProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataImportConfigValidationResult' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataImportConfigValidationResult.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ImportProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ImportProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataDatasetResyncStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataDatasetResyncStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataIndividualDocumentResyncStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataIndividualDocumentResyncStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataUpdatedDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataUpdatedDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3ResyncDatasetResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3ResyncDatasetResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3RevisionRef' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3RevisionRef.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3RevisionReference' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3RevisionReference.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3SampleDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3SampleDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponseSelectedDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponseSelectedDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3SetDefaultProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3SetDefaultProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3SetDefaultProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3SetDefaultProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3UndeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3UndeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3UndeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3UndeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3UpdateDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3UpdateDatasetOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3UpdateHumanReviewConfigMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3UpdateHumanReviewConfigMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiUiv1beta3UpdateLabelerPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiUiv1beta3UpdateLabelerPoolOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Barcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Barcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BatchDocumentsInputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BatchDocumentsInputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BatchProcessMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BatchProcessMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BatchProcessRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BatchProcessRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BatchProcessResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BatchProcessResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1BoundingPoly.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1CommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1CommonOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DeleteProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DeleteProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DeleteProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DeleteProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DeployProcessorVersionRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DeployProcessorVersionRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DisableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DisableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DisableProcessorRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DisableProcessorRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DisableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DisableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Document' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Document.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentChunkedDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentChunkedDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentEntity' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentEntity.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentEntityNormalizedValue' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentEntityNormalizedValue.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentEntityRelation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentEntityRelation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentOutputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentOutputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfigShardingConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfigShardingConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageAnchorPageRef' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageDetectedBarcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageDetectedBarcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageDetectedLanguage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageDimension' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageDimension.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageFormField' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageFormField.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageImage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageImage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageImageQualityScores' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageImageQualityScores.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageImageQualityScoresDetectedDefect' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageImageQualityScoresDetectedDefect.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageLine' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageLine.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageMatrix' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageMatrix.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageParagraph' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageParagraph.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageSymbol' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageSymbol.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageTable' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageTable.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageTableTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageTableTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageTableTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageTableTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageToken' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageToken.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentPageVisualElement' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentPageVisualElement.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentProvenance' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentProvenance.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentProvenanceParent' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentProvenanceParent.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentRevision' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentRevision.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentRevisionHumanReview' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentRevisionHumanReview.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentSchema' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentSchema.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentSchemaEntityType' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentSchemaEntityType.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentSchemaEntityTypeEnumValues' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentSchemaEntityTypeEnumValues.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentSchemaMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentShardInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentShardInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentStyle' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentStyle.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentStyleFontSize' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentStyleFontSize.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentTextAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentTextAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1DocumentTextChange' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1DocumentTextChange.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EnableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EnableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EnableProcessorRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EnableProcessorRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EnableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EnableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EntityTypeMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EntityTypeMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluateProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluateProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluateProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluateProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Evaluation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Evaluation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluationCounters' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluationCounters.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluationMetrics' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluationMetrics.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1EvaluationReference' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1EvaluationReference.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1FetchProcessorTypesResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1FetchProcessorTypesResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1GcsDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1GcsDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1GcsDocuments' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1GcsDocuments.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1GcsPrefix' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1GcsPrefix.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1HumanReviewLabelingMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1HumanReviewLabelingMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1HumanReviewStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1HumanReviewStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1HumanReviewValidationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1HumanReviewValidationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ListEvaluationsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ListEvaluationsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ListProcessorTypesResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ListProcessorTypesResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ListProcessorVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ListProcessorVersionsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ListProcessorsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ListProcessorsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1NormalizedVertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1OcrConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1OcrConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1OcrConfigHints' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1OcrConfigHints.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1OcrConfigPremiumFeatures' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1OcrConfigPremiumFeatures.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessOptions' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessOptions.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Processor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Processor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorType' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorType.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorTypeLocationInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorTypeLocationInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersion' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersion.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersionAlias' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersionAlias.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoCustomGenAiModelInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoCustomGenAiModelInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1PropertyMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1PropertyMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1RawDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1RawDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1RawDocuments' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1RawDocuments.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ReviewDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ReviewDocumentOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ReviewDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ReviewDocumentRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1ReviewDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1ReviewDocumentResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Schema' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Schema.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1SchemaEntityType' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1SchemaEntityType.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1SchemaMutabilityMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1SchemaMutabilityMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1SetDefaultProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1SetDefaultProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1SetDefaultProcessorVersionRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1SetDefaultProcessorVersionRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1SetDefaultProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1SetDefaultProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1TrainProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1TrainProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1UndeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1UndeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1UndeployProcessorVersionRequest' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1UndeployProcessorVersionRequest.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1UndeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1UndeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1Vertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1Vertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1alpha1AnalyzeHitlDataMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1alpha1AnalyzeHitlDataMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1alpha1CommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1alpha1CommonOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1Barcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1Barcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1BatchProcessDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1BatchProcessDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1BoundingPoly.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1Document' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1Document.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentChunkedDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentChunkedDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunk' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunk.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageFooter' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageFooter.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageHeader' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageHeader.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentChunkedDocumentChunkChunkPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentEntity' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentEntity.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentEntityNormalizedValue' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentEntityNormalizedValue.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentEntityRelation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentEntityRelation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageAnchorPageRef' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageAnchorPageRef.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageDetectedBarcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageDetectedBarcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageDetectedLanguage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageDimension' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageDimension.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageFormField' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageFormField.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageImage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageImage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageImageQualityScores' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageImageQualityScores.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageImageQualityScoresDetectedDefect' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageImageQualityScoresDetectedDefect.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageLine' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageLine.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageMatrix' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageMatrix.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageParagraph' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageParagraph.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageSymbol' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageSymbol.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageTable' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageTable.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageTableTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageTableTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageTableTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageTableTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageToken' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageToken.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageTokenDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageTokenDetectedBreak.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageTokenStyleInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageTokenStyleInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentPageVisualElement' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentPageVisualElement.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentProvenance' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentProvenance.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentProvenanceParent' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentProvenanceParent.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentRevision' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentRevision.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentRevisionHumanReview' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentRevisionHumanReview.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentShardInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentShardInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentStyle' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentStyle.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentStyleFontSize' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentStyleFontSize.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentTextAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentTextAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentTextAnchorTextSegment' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentTextAnchorTextSegment.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1DocumentTextChange' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1DocumentTextChange.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1GcsDestination.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1GcsSource.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1InputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1NormalizedVertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1OperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1OutputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1ProcessDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1ProcessDocumentResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta1Vertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta1Vertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2Barcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2Barcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2BatchProcessDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2BatchProcessDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2BoundingPoly.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2Document' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2Document.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentChunkedDocument' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentChunkedDocument.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunk' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunk.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageFooter' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageFooter.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageHeader' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageHeader.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentChunkedDocumentChunkChunkPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentEntity' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentEntity.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentEntityNormalizedValue' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentEntityNormalizedValue.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentEntityRelation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentEntityRelation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentLabel' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentLabel.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageAnchorPageRef' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageAnchorPageRef.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageBlock' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageBlock.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageDetectedBarcode' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageDetectedBarcode.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageDimension' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageDimension.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageFormField' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageFormField.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageImage' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageImage.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageImageQualityScores' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageImageQualityScores.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageImageQualityScoresDetectedDefect' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageImageQualityScoresDetectedDefect.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageLayout' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageLayout.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageLine' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageLine.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageMatrix' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageMatrix.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageParagraph' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageParagraph.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageSymbol' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageSymbol.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageTable' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageTable.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageTableTableCell' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageTableTableCell.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageTableTableRow' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageTableTableRow.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageToken' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageToken.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageTokenDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageTokenDetectedBreak.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageTokenStyleInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageTokenStyleInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentPageVisualElement' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentPageVisualElement.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentProvenance' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentProvenance.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentProvenanceParent' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentProvenanceParent.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentRevision' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentRevision.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentRevisionHumanReview' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentRevisionHumanReview.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentShardInfo' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentShardInfo.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentStyle' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentStyle.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentStyleFontSize' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentStyleFontSize.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentTextAnchor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentTextAnchor.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentTextAnchorTextSegment' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentTextAnchorTextSegment.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2DocumentTextChange' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2DocumentTextChange.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2GcsDestination' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2GcsDestination.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2GcsSource' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2GcsSource.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2InputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2InputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2NormalizedVertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2OperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2OutputConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2OutputConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2ProcessDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2ProcessDocumentResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta2Vertex' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta2Vertex.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchProcessMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchProcessMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3BatchProcessResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3BatchProcessResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3CommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3CommonOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3Dataset' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3Dataset.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DatasetDocumentWarehouseConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DatasetDocumentWarehouseConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DatasetGCSManagedConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DatasetGCSManagedConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DatasetSpannerIndexingConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DatasetSpannerIndexingConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DatasetUnmanagedDatasetConfig' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DatasetUnmanagedDatasetConfig.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DeleteProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DeleteProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DeleteProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DeleteProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DisableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DisableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DisableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DisableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DocumentIdGCSManagedDocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DocumentIdGCSManagedDocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3DocumentIdUnmanagedDocumentId' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3DocumentIdUnmanagedDocumentId.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3EnableProcessorMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3EnableProcessorMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3EnableProcessorResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3EnableProcessorResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3EvaluateProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3EvaluateProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3EvaluateProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3EvaluateProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3GcsPrefix' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3GcsPrefix.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3HumanReviewStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3HumanReviewStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportDocumentsMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportDocumentsResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ImportProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ImportProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3ReviewDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3ReviewDocumentResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3RevisionRef' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3RevisionRef.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3SetDefaultProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3SetDefaultProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3SetDefaultProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3SetDefaultProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3TrainProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3TrainProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3TrainProcessorVersionMetadataDatasetValidation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3TrainProcessorVersionMetadataDatasetValidation.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3TrainProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3TrainProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3UndeployProcessorVersionMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3UndeployProcessorVersionMetadata.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3UndeployProcessorVersionResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3UndeployProcessorVersionResponse.php',
    'Google\\Service\\Document\\GoogleCloudDocumentaiV1beta3UpdateDatasetOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudDocumentaiV1beta3UpdateDatasetOperationMetadata.php',
    'Google\\Service\\Document\\GoogleCloudLocationListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudLocationListLocationsResponse.php',
    'Google\\Service\\Document\\GoogleCloudLocationLocation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleCloudLocationLocation.php',
    'Google\\Service\\Document\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Document/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Document\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Document/GoogleLongrunningOperation.php',
    'Google\\Service\\Document\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Document/GoogleProtobufEmpty.php',
    'Google\\Service\\Document\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Document/GoogleRpcStatus.php',
    'Google\\Service\\Document\\GoogleTypeColor' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypeColor.php',
    'Google\\Service\\Document\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypeDate.php',
    'Google\\Service\\Document\\GoogleTypeDateTime' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypeDateTime.php',
    'Google\\Service\\Document\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypeMoney.php',
    'Google\\Service\\Document\\GoogleTypePostalAddress' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypePostalAddress.php',
    'Google\\Service\\Document\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Document/GoogleTypeTimeZone.php',
    'Google\\Service\\Document\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Operations.php',
    'Google\\Service\\Document\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Projects.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocations.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsProcessorTypes' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsProcessorTypes.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsProcessors' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsProcessors.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsProcessorsHumanReviewConfig' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsProcessorsHumanReviewConfig.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsProcessorsProcessorVersions' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsProcessorsProcessorVersions.php',
    'Google\\Service\\Document\\Resource\\ProjectsLocationsProcessorsProcessorVersionsEvaluations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsLocationsProcessorsProcessorVersionsEvaluations.php',
    'Google\\Service\\Document\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/ProjectsOperations.php',
    'Google\\Service\\Document\\Resource\\Uiv1beta3' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Uiv1beta3.php',
    'Google\\Service\\Document\\Resource\\Uiv1beta3Projects' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Uiv1beta3Projects.php',
    'Google\\Service\\Document\\Resource\\Uiv1beta3ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Uiv1beta3ProjectsLocations.php',
    'Google\\Service\\Document\\Resource\\Uiv1beta3ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Document/Resource/Uiv1beta3ProjectsLocationsOperations.php',
    'Google\\Service\\DomainsRDAP' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP.php',
    'Google\\Service\\DomainsRDAP\\HttpBody' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/HttpBody.php',
    'Google\\Service\\DomainsRDAP\\Link' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Link.php',
    'Google\\Service\\DomainsRDAP\\Notice' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Notice.php',
    'Google\\Service\\DomainsRDAP\\RdapResponse' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/RdapResponse.php',
    'Google\\Service\\DomainsRDAP\\Resource\\Autnum' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/Autnum.php',
    'Google\\Service\\DomainsRDAP\\Resource\\Domain' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/Domain.php',
    'Google\\Service\\DomainsRDAP\\Resource\\Entity' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/Entity.php',
    'Google\\Service\\DomainsRDAP\\Resource\\Ip' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/Ip.php',
    'Google\\Service\\DomainsRDAP\\Resource\\Nameserver' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/Nameserver.php',
    'Google\\Service\\DomainsRDAP\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/DomainsRDAP/Resource/V1.php',
    'Google\\Service\\DoubleClickBidManager' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager.php',
    'Google\\Service\\DoubleClickBidManager\\ChannelGrouping' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ChannelGrouping.php',
    'Google\\Service\\DoubleClickBidManager\\DataRange' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/DataRange.php',
    'Google\\Service\\DoubleClickBidManager\\Date' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Date.php',
    'Google\\Service\\DoubleClickBidManager\\DisjunctiveMatchStatement' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/DisjunctiveMatchStatement.php',
    'Google\\Service\\DoubleClickBidManager\\EventFilter' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/EventFilter.php',
    'Google\\Service\\DoubleClickBidManager\\FilterPair' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/FilterPair.php',
    'Google\\Service\\DoubleClickBidManager\\ListQueriesResponse' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ListQueriesResponse.php',
    'Google\\Service\\DoubleClickBidManager\\ListReportsResponse' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ListReportsResponse.php',
    'Google\\Service\\DoubleClickBidManager\\Options' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Options.php',
    'Google\\Service\\DoubleClickBidManager\\Parameters' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Parameters.php',
    'Google\\Service\\DoubleClickBidManager\\PathFilter' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/PathFilter.php',
    'Google\\Service\\DoubleClickBidManager\\PathQueryOptions' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/PathQueryOptions.php',
    'Google\\Service\\DoubleClickBidManager\\PathQueryOptionsFilter' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/PathQueryOptionsFilter.php',
    'Google\\Service\\DoubleClickBidManager\\Query' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Query.php',
    'Google\\Service\\DoubleClickBidManager\\QueryMetadata' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/QueryMetadata.php',
    'Google\\Service\\DoubleClickBidManager\\QuerySchedule' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/QuerySchedule.php',
    'Google\\Service\\DoubleClickBidManager\\Report' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Report.php',
    'Google\\Service\\DoubleClickBidManager\\ReportFailure' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ReportFailure.php',
    'Google\\Service\\DoubleClickBidManager\\ReportKey' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ReportKey.php',
    'Google\\Service\\DoubleClickBidManager\\ReportMetadata' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ReportMetadata.php',
    'Google\\Service\\DoubleClickBidManager\\ReportStatus' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/ReportStatus.php',
    'Google\\Service\\DoubleClickBidManager\\Resource\\Queries' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Resource/Queries.php',
    'Google\\Service\\DoubleClickBidManager\\Resource\\QueriesReports' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Resource/QueriesReports.php',
    'Google\\Service\\DoubleClickBidManager\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Resource/Reports.php',
    'Google\\Service\\DoubleClickBidManager\\Rule' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/Rule.php',
    'Google\\Service\\DoubleClickBidManager\\RunQueryRequest' => $vendorDir . '/google/apiclient-services/src/DoubleClickBidManager/RunQueryRequest.php',
    'Google\\Service\\Doubleclicksearch' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch.php',
    'Google\\Service\\Doubleclicksearch\\Availability' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Availability.php',
    'Google\\Service\\Doubleclicksearch\\Conversion' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Conversion.php',
    'Google\\Service\\Doubleclicksearch\\ConversionList' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ConversionList.php',
    'Google\\Service\\Doubleclicksearch\\CustomDimension' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/CustomDimension.php',
    'Google\\Service\\Doubleclicksearch\\CustomMetric' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/CustomMetric.php',
    'Google\\Service\\Doubleclicksearch\\IdMappingFile' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/IdMappingFile.php',
    'Google\\Service\\Doubleclicksearch\\Report' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Report.php',
    'Google\\Service\\Doubleclicksearch\\ReportApiColumnSpec' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportApiColumnSpec.php',
    'Google\\Service\\Doubleclicksearch\\ReportFiles' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportFiles.php',
    'Google\\Service\\Doubleclicksearch\\ReportRequest' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportRequest.php',
    'Google\\Service\\Doubleclicksearch\\ReportRequestFilters' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportRequestFilters.php',
    'Google\\Service\\Doubleclicksearch\\ReportRequestOrderBy' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportRequestOrderBy.php',
    'Google\\Service\\Doubleclicksearch\\ReportRequestReportScope' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportRequestReportScope.php',
    'Google\\Service\\Doubleclicksearch\\ReportRequestTimeRange' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/ReportRequestTimeRange.php',
    'Google\\Service\\Doubleclicksearch\\Resource\\Conversion' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Resource/Conversion.php',
    'Google\\Service\\Doubleclicksearch\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Resource/Reports.php',
    'Google\\Service\\Doubleclicksearch\\Resource\\SavedColumns' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/Resource/SavedColumns.php',
    'Google\\Service\\Doubleclicksearch\\SavedColumn' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/SavedColumn.php',
    'Google\\Service\\Doubleclicksearch\\SavedColumnList' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/SavedColumnList.php',
    'Google\\Service\\Doubleclicksearch\\UpdateAvailabilityRequest' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/UpdateAvailabilityRequest.php',
    'Google\\Service\\Doubleclicksearch\\UpdateAvailabilityResponse' => $vendorDir . '/google/apiclient-services/src/Doubleclicksearch/UpdateAvailabilityResponse.php',
    'Google\\Service\\Drive' => $vendorDir . '/google/apiclient-services/src/Drive.php',
    'Google\\Service\\DriveActivity' => $vendorDir . '/google/apiclient-services/src/DriveActivity.php',
    'Google\\Service\\DriveActivity\\Action' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Action.php',
    'Google\\Service\\DriveActivity\\ActionDetail' => $vendorDir . '/google/apiclient-services/src/DriveActivity/ActionDetail.php',
    'Google\\Service\\DriveActivity\\Actor' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Actor.php',
    'Google\\Service\\DriveActivity\\Administrator' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Administrator.php',
    'Google\\Service\\DriveActivity\\AnonymousUser' => $vendorDir . '/google/apiclient-services/src/DriveActivity/AnonymousUser.php',
    'Google\\Service\\DriveActivity\\Anyone' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Anyone.php',
    'Google\\Service\\DriveActivity\\ApplicationReference' => $vendorDir . '/google/apiclient-services/src/DriveActivity/ApplicationReference.php',
    'Google\\Service\\DriveActivity\\AppliedLabelChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/AppliedLabelChange.php',
    'Google\\Service\\DriveActivity\\AppliedLabelChangeDetail' => $vendorDir . '/google/apiclient-services/src/DriveActivity/AppliedLabelChangeDetail.php',
    'Google\\Service\\DriveActivity\\Assignment' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Assignment.php',
    'Google\\Service\\DriveActivity\\Comment' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Comment.php',
    'Google\\Service\\DriveActivity\\ConsolidationStrategy' => $vendorDir . '/google/apiclient-services/src/DriveActivity/ConsolidationStrategy.php',
    'Google\\Service\\DriveActivity\\Copy' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Copy.php',
    'Google\\Service\\DriveActivity\\Create' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Create.php',
    'Google\\Service\\DriveActivity\\DataLeakPreventionChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DataLeakPreventionChange.php',
    'Google\\Service\\DriveActivity\\Date' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Date.php',
    'Google\\Service\\DriveActivity\\Delete' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Delete.php',
    'Google\\Service\\DriveActivity\\DeletedUser' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DeletedUser.php',
    'Google\\Service\\DriveActivity\\Domain' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Domain.php',
    'Google\\Service\\DriveActivity\\Drive' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Drive.php',
    'Google\\Service\\DriveActivity\\DriveActivity' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveActivity.php',
    'Google\\Service\\DriveActivity\\DriveFile' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveFile.php',
    'Google\\Service\\DriveActivity\\DriveFolder' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveFolder.php',
    'Google\\Service\\DriveActivity\\DriveItem' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveItem.php',
    'Google\\Service\\DriveActivity\\DriveItemReference' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveItemReference.php',
    'Google\\Service\\DriveActivity\\DriveReference' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveReference.php',
    'Google\\Service\\DriveActivity\\DriveactivityFile' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveactivityFile.php',
    'Google\\Service\\DriveActivity\\DriveactivityInteger' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveactivityInteger.php',
    'Google\\Service\\DriveActivity\\DriveactivityNew' => $vendorDir . '/google/apiclient-services/src/DriveActivity/DriveactivityNew.php',
    'Google\\Service\\DriveActivity\\Edit' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Edit.php',
    'Google\\Service\\DriveActivity\\FieldValue' => $vendorDir . '/google/apiclient-services/src/DriveActivity/FieldValue.php',
    'Google\\Service\\DriveActivity\\FieldValueChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/FieldValueChange.php',
    'Google\\Service\\DriveActivity\\FileComment' => $vendorDir . '/google/apiclient-services/src/DriveActivity/FileComment.php',
    'Google\\Service\\DriveActivity\\Folder' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Folder.php',
    'Google\\Service\\DriveActivity\\Group' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Group.php',
    'Google\\Service\\DriveActivity\\Impersonation' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Impersonation.php',
    'Google\\Service\\DriveActivity\\KnownUser' => $vendorDir . '/google/apiclient-services/src/DriveActivity/KnownUser.php',
    'Google\\Service\\DriveActivity\\Legacy' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Legacy.php',
    'Google\\Service\\DriveActivity\\Move' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Move.php',
    'Google\\Service\\DriveActivity\\NoConsolidation' => $vendorDir . '/google/apiclient-services/src/DriveActivity/NoConsolidation.php',
    'Google\\Service\\DriveActivity\\Owner' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Owner.php',
    'Google\\Service\\DriveActivity\\Permission' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Permission.php',
    'Google\\Service\\DriveActivity\\PermissionChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/PermissionChange.php',
    'Google\\Service\\DriveActivity\\Post' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Post.php',
    'Google\\Service\\DriveActivity\\QueryDriveActivityRequest' => $vendorDir . '/google/apiclient-services/src/DriveActivity/QueryDriveActivityRequest.php',
    'Google\\Service\\DriveActivity\\QueryDriveActivityResponse' => $vendorDir . '/google/apiclient-services/src/DriveActivity/QueryDriveActivityResponse.php',
    'Google\\Service\\DriveActivity\\Rename' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Rename.php',
    'Google\\Service\\DriveActivity\\Resource\\Activity' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Resource/Activity.php',
    'Google\\Service\\DriveActivity\\Restore' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Restore.php',
    'Google\\Service\\DriveActivity\\RestrictionChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/RestrictionChange.php',
    'Google\\Service\\DriveActivity\\Selection' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Selection.php',
    'Google\\Service\\DriveActivity\\SelectionList' => $vendorDir . '/google/apiclient-services/src/DriveActivity/SelectionList.php',
    'Google\\Service\\DriveActivity\\SettingsChange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/SettingsChange.php',
    'Google\\Service\\DriveActivity\\SingleUser' => $vendorDir . '/google/apiclient-services/src/DriveActivity/SingleUser.php',
    'Google\\Service\\DriveActivity\\Suggestion' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Suggestion.php',
    'Google\\Service\\DriveActivity\\SystemEvent' => $vendorDir . '/google/apiclient-services/src/DriveActivity/SystemEvent.php',
    'Google\\Service\\DriveActivity\\Target' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Target.php',
    'Google\\Service\\DriveActivity\\TargetReference' => $vendorDir . '/google/apiclient-services/src/DriveActivity/TargetReference.php',
    'Google\\Service\\DriveActivity\\TeamDrive' => $vendorDir . '/google/apiclient-services/src/DriveActivity/TeamDrive.php',
    'Google\\Service\\DriveActivity\\TeamDriveReference' => $vendorDir . '/google/apiclient-services/src/DriveActivity/TeamDriveReference.php',
    'Google\\Service\\DriveActivity\\Text' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Text.php',
    'Google\\Service\\DriveActivity\\TextList' => $vendorDir . '/google/apiclient-services/src/DriveActivity/TextList.php',
    'Google\\Service\\DriveActivity\\TimeRange' => $vendorDir . '/google/apiclient-services/src/DriveActivity/TimeRange.php',
    'Google\\Service\\DriveActivity\\UnknownUser' => $vendorDir . '/google/apiclient-services/src/DriveActivity/UnknownUser.php',
    'Google\\Service\\DriveActivity\\Upload' => $vendorDir . '/google/apiclient-services/src/DriveActivity/Upload.php',
    'Google\\Service\\DriveActivity\\User' => $vendorDir . '/google/apiclient-services/src/DriveActivity/User.php',
    'Google\\Service\\DriveActivity\\UserList' => $vendorDir . '/google/apiclient-services/src/DriveActivity/UserList.php',
    'Google\\Service\\DriveLabels' => $vendorDir . '/google/apiclient-services/src/DriveLabels.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2BadgeColors' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2BadgeColors.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2BadgeConfig' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2BadgeConfig.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2BatchDeleteLabelPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2BatchDeleteLabelPermissionsRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2BatchUpdateLabelPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2BatchUpdateLabelPermissionsRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2BatchUpdateLabelPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2BatchUpdateLabelPermissionsResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DateLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DateLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeleteLabelPermissionRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeleteLabelPermissionRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateFieldRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateFieldRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateSelectionChoiceRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateSelectionChoiceRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteFieldRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteFieldRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteSelectionChoiceRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteSelectionChoiceRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableFieldRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableFieldRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableSelectionChoiceRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableSelectionChoiceRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableFieldRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableFieldRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableSelectionChoiceRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableSelectionChoiceRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldPropertiesRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldTypeRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldTypeRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateLabelPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateLabelPropertiesRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateSelectionChoicePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateSelectionChoicePropertiesRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseCreateFieldResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseCreateFieldResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseCreateSelectionChoiceResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseCreateSelectionChoiceResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDeleteFieldResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDeleteFieldResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDeleteSelectionChoiceResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDeleteSelectionChoiceResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDisableFieldResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDisableFieldResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDisableSelectionChoiceResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseDisableSelectionChoiceResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseEnableFieldResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseEnableFieldResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseEnableSelectionChoiceResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseEnableSelectionChoiceResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateFieldPropertiesResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateFieldPropertiesResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateFieldTypeResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateFieldTypeResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateLabelPropertiesResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateLabelPropertiesResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateSelectionChoicePropertiesResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DeltaUpdateLabelResponseUpdateSelectionChoicePropertiesResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2DisableLabelRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2DisableLabelRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2EnableLabelRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2EnableLabelRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2Field' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2Field.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldAppliedCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldAppliedCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldDateOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldDateOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldDisplayHints' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldDisplayHints.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldIntegerOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldIntegerOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldListOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldListOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldLongTextOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldLongTextOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldProperties' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldProperties.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSchemaCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSchemaCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptionsChoice' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptionsChoice.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceAppliedCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceAppliedCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceProperties' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceProperties.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceSchemaCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceSchemaCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldTextOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldTextOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2FieldUserOptions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2FieldUserOptions.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2IntegerLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2IntegerLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2Label' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2Label.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelAppliedCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelAppliedCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelAppliedLabelPolicy' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelAppliedLabelPolicy.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelDisplayHints' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelDisplayHints.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelLock' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelLock.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelLockCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelLockCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelPermission' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelPermission.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelProperties' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelProperties.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LabelSchemaCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LabelSchemaCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2Lifecycle' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2Lifecycle.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LifecycleDisabledPolicy' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LifecycleDisabledPolicy.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2ListLabelLocksResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2ListLabelLocksResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2ListLabelPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2ListLabelPermissionsResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2ListLabelsResponse' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2ListLabelsResponse.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2ListLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2ListLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LockStatus' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LockStatus.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2LongTextLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2LongTextLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2PublishLabelRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2PublishLabelRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2SelectionLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2SelectionLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2TextLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2TextLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2UpdateLabelCopyModeRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2UpdateLabelCopyModeRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2UpdateLabelPermissionRequest' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2UpdateLabelPermissionRequest.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2UserCapabilities' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2UserCapabilities.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2UserInfo' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2UserInfo.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2UserLimits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2UserLimits.php',
    'Google\\Service\\DriveLabels\\GoogleAppsDriveLabelsV2WriteControl' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleAppsDriveLabelsV2WriteControl.php',
    'Google\\Service\\DriveLabels\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleProtobufEmpty.php',
    'Google\\Service\\DriveLabels\\GoogleTypeColor' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleTypeColor.php',
    'Google\\Service\\DriveLabels\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/DriveLabels/GoogleTypeDate.php',
    'Google\\Service\\DriveLabels\\Resource\\Labels' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/Labels.php',
    'Google\\Service\\DriveLabels\\Resource\\LabelsLocks' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/LabelsLocks.php',
    'Google\\Service\\DriveLabels\\Resource\\LabelsPermissions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/LabelsPermissions.php',
    'Google\\Service\\DriveLabels\\Resource\\LabelsRevisions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/LabelsRevisions.php',
    'Google\\Service\\DriveLabels\\Resource\\LabelsRevisionsLocks' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/LabelsRevisionsLocks.php',
    'Google\\Service\\DriveLabels\\Resource\\LabelsRevisionsPermissions' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/LabelsRevisionsPermissions.php',
    'Google\\Service\\DriveLabels\\Resource\\Limits' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/Limits.php',
    'Google\\Service\\DriveLabels\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/DriveLabels/Resource/Users.php',
    'Google\\Service\\Drive\\About' => $vendorDir . '/google/apiclient-services/src/Drive/About.php',
    'Google\\Service\\Drive\\AboutDriveThemes' => $vendorDir . '/google/apiclient-services/src/Drive/AboutDriveThemes.php',
    'Google\\Service\\Drive\\AboutStorageQuota' => $vendorDir . '/google/apiclient-services/src/Drive/AboutStorageQuota.php',
    'Google\\Service\\Drive\\AboutTeamDriveThemes' => $vendorDir . '/google/apiclient-services/src/Drive/AboutTeamDriveThemes.php',
    'Google\\Service\\Drive\\App' => $vendorDir . '/google/apiclient-services/src/Drive/App.php',
    'Google\\Service\\Drive\\AppIcons' => $vendorDir . '/google/apiclient-services/src/Drive/AppIcons.php',
    'Google\\Service\\Drive\\AppList' => $vendorDir . '/google/apiclient-services/src/Drive/AppList.php',
    'Google\\Service\\Drive\\Change' => $vendorDir . '/google/apiclient-services/src/Drive/Change.php',
    'Google\\Service\\Drive\\ChangeList' => $vendorDir . '/google/apiclient-services/src/Drive/ChangeList.php',
    'Google\\Service\\Drive\\Channel' => $vendorDir . '/google/apiclient-services/src/Drive/Channel.php',
    'Google\\Service\\Drive\\Comment' => $vendorDir . '/google/apiclient-services/src/Drive/Comment.php',
    'Google\\Service\\Drive\\CommentList' => $vendorDir . '/google/apiclient-services/src/Drive/CommentList.php',
    'Google\\Service\\Drive\\CommentQuotedFileContent' => $vendorDir . '/google/apiclient-services/src/Drive/CommentQuotedFileContent.php',
    'Google\\Service\\Drive\\ContentRestriction' => $vendorDir . '/google/apiclient-services/src/Drive/ContentRestriction.php',
    'Google\\Service\\Drive\\Drive' => $vendorDir . '/google/apiclient-services/src/Drive/Drive.php',
    'Google\\Service\\Drive\\DriveBackgroundImageFile' => $vendorDir . '/google/apiclient-services/src/Drive/DriveBackgroundImageFile.php',
    'Google\\Service\\Drive\\DriveCapabilities' => $vendorDir . '/google/apiclient-services/src/Drive/DriveCapabilities.php',
    'Google\\Service\\Drive\\DriveFile' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFile.php',
    'Google\\Service\\Drive\\DriveFileCapabilities' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileCapabilities.php',
    'Google\\Service\\Drive\\DriveFileContentHints' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileContentHints.php',
    'Google\\Service\\Drive\\DriveFileContentHintsThumbnail' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileContentHintsThumbnail.php',
    'Google\\Service\\Drive\\DriveFileImageMediaMetadata' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileImageMediaMetadata.php',
    'Google\\Service\\Drive\\DriveFileImageMediaMetadataLocation' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileImageMediaMetadataLocation.php',
    'Google\\Service\\Drive\\DriveFileLabelInfo' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileLabelInfo.php',
    'Google\\Service\\Drive\\DriveFileLinkShareMetadata' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileLinkShareMetadata.php',
    'Google\\Service\\Drive\\DriveFileShortcutDetails' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileShortcutDetails.php',
    'Google\\Service\\Drive\\DriveFileVideoMediaMetadata' => $vendorDir . '/google/apiclient-services/src/Drive/DriveFileVideoMediaMetadata.php',
    'Google\\Service\\Drive\\DriveList' => $vendorDir . '/google/apiclient-services/src/Drive/DriveList.php',
    'Google\\Service\\Drive\\DriveRestrictions' => $vendorDir . '/google/apiclient-services/src/Drive/DriveRestrictions.php',
    'Google\\Service\\Drive\\FileList' => $vendorDir . '/google/apiclient-services/src/Drive/FileList.php',
    'Google\\Service\\Drive\\GeneratedIds' => $vendorDir . '/google/apiclient-services/src/Drive/GeneratedIds.php',
    'Google\\Service\\Drive\\Label' => $vendorDir . '/google/apiclient-services/src/Drive/Label.php',
    'Google\\Service\\Drive\\LabelField' => $vendorDir . '/google/apiclient-services/src/Drive/LabelField.php',
    'Google\\Service\\Drive\\LabelFieldModification' => $vendorDir . '/google/apiclient-services/src/Drive/LabelFieldModification.php',
    'Google\\Service\\Drive\\LabelList' => $vendorDir . '/google/apiclient-services/src/Drive/LabelList.php',
    'Google\\Service\\Drive\\LabelModification' => $vendorDir . '/google/apiclient-services/src/Drive/LabelModification.php',
    'Google\\Service\\Drive\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Drive/ListOperationsResponse.php',
    'Google\\Service\\Drive\\ModifyLabelsRequest' => $vendorDir . '/google/apiclient-services/src/Drive/ModifyLabelsRequest.php',
    'Google\\Service\\Drive\\ModifyLabelsResponse' => $vendorDir . '/google/apiclient-services/src/Drive/ModifyLabelsResponse.php',
    'Google\\Service\\Drive\\Operation' => $vendorDir . '/google/apiclient-services/src/Drive/Operation.php',
    'Google\\Service\\Drive\\Permission' => $vendorDir . '/google/apiclient-services/src/Drive/Permission.php',
    'Google\\Service\\Drive\\PermissionList' => $vendorDir . '/google/apiclient-services/src/Drive/PermissionList.php',
    'Google\\Service\\Drive\\PermissionPermissionDetails' => $vendorDir . '/google/apiclient-services/src/Drive/PermissionPermissionDetails.php',
    'Google\\Service\\Drive\\PermissionTeamDrivePermissionDetails' => $vendorDir . '/google/apiclient-services/src/Drive/PermissionTeamDrivePermissionDetails.php',
    'Google\\Service\\Drive\\Reply' => $vendorDir . '/google/apiclient-services/src/Drive/Reply.php',
    'Google\\Service\\Drive\\ReplyList' => $vendorDir . '/google/apiclient-services/src/Drive/ReplyList.php',
    'Google\\Service\\Drive\\Resource\\About' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/About.php',
    'Google\\Service\\Drive\\Resource\\Apps' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Apps.php',
    'Google\\Service\\Drive\\Resource\\Changes' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Changes.php',
    'Google\\Service\\Drive\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Channels.php',
    'Google\\Service\\Drive\\Resource\\Comments' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Comments.php',
    'Google\\Service\\Drive\\Resource\\Drives' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Drives.php',
    'Google\\Service\\Drive\\Resource\\Files' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Files.php',
    'Google\\Service\\Drive\\Resource\\Operation' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Operation.php',
    'Google\\Service\\Drive\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Operations.php',
    'Google\\Service\\Drive\\Resource\\Permissions' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Permissions.php',
    'Google\\Service\\Drive\\Resource\\Replies' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Replies.php',
    'Google\\Service\\Drive\\Resource\\Revisions' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Revisions.php',
    'Google\\Service\\Drive\\Resource\\Teamdrives' => $vendorDir . '/google/apiclient-services/src/Drive/Resource/Teamdrives.php',
    'Google\\Service\\Drive\\Revision' => $vendorDir . '/google/apiclient-services/src/Drive/Revision.php',
    'Google\\Service\\Drive\\RevisionList' => $vendorDir . '/google/apiclient-services/src/Drive/RevisionList.php',
    'Google\\Service\\Drive\\StartPageToken' => $vendorDir . '/google/apiclient-services/src/Drive/StartPageToken.php',
    'Google\\Service\\Drive\\Status' => $vendorDir . '/google/apiclient-services/src/Drive/Status.php',
    'Google\\Service\\Drive\\TeamDrive' => $vendorDir . '/google/apiclient-services/src/Drive/TeamDrive.php',
    'Google\\Service\\Drive\\TeamDriveBackgroundImageFile' => $vendorDir . '/google/apiclient-services/src/Drive/TeamDriveBackgroundImageFile.php',
    'Google\\Service\\Drive\\TeamDriveCapabilities' => $vendorDir . '/google/apiclient-services/src/Drive/TeamDriveCapabilities.php',
    'Google\\Service\\Drive\\TeamDriveList' => $vendorDir . '/google/apiclient-services/src/Drive/TeamDriveList.php',
    'Google\\Service\\Drive\\TeamDriveRestrictions' => $vendorDir . '/google/apiclient-services/src/Drive/TeamDriveRestrictions.php',
    'Google\\Service\\Drive\\User' => $vendorDir . '/google/apiclient-services/src/Drive/User.php',
    'Google\\Service\\Essentialcontacts' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts.php',
    'Google\\Service\\Essentialcontacts\\GoogleCloudEssentialcontactsV1ComputeContactsResponse' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/GoogleCloudEssentialcontactsV1ComputeContactsResponse.php',
    'Google\\Service\\Essentialcontacts\\GoogleCloudEssentialcontactsV1Contact' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/GoogleCloudEssentialcontactsV1Contact.php',
    'Google\\Service\\Essentialcontacts\\GoogleCloudEssentialcontactsV1ListContactsResponse' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/GoogleCloudEssentialcontactsV1ListContactsResponse.php',
    'Google\\Service\\Essentialcontacts\\GoogleCloudEssentialcontactsV1SendTestMessageRequest' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/GoogleCloudEssentialcontactsV1SendTestMessageRequest.php',
    'Google\\Service\\Essentialcontacts\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/GoogleProtobufEmpty.php',
    'Google\\Service\\Essentialcontacts\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/Folders.php',
    'Google\\Service\\Essentialcontacts\\Resource\\FoldersContacts' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/FoldersContacts.php',
    'Google\\Service\\Essentialcontacts\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/Organizations.php',
    'Google\\Service\\Essentialcontacts\\Resource\\OrganizationsContacts' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/OrganizationsContacts.php',
    'Google\\Service\\Essentialcontacts\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/Projects.php',
    'Google\\Service\\Essentialcontacts\\Resource\\ProjectsContacts' => $vendorDir . '/google/apiclient-services/src/Essentialcontacts/Resource/ProjectsContacts.php',
    'Google\\Service\\Eventarc' => $vendorDir . '/google/apiclient-services/src/Eventarc.php',
    'Google\\Service\\Eventarc\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Eventarc/AuditConfig.php',
    'Google\\Service\\Eventarc\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Eventarc/AuditLogConfig.php',
    'Google\\Service\\Eventarc\\Binding' => $vendorDir . '/google/apiclient-services/src/Eventarc/Binding.php',
    'Google\\Service\\Eventarc\\Channel' => $vendorDir . '/google/apiclient-services/src/Eventarc/Channel.php',
    'Google\\Service\\Eventarc\\ChannelConnection' => $vendorDir . '/google/apiclient-services/src/Eventarc/ChannelConnection.php',
    'Google\\Service\\Eventarc\\CloudRun' => $vendorDir . '/google/apiclient-services/src/Eventarc/CloudRun.php',
    'Google\\Service\\Eventarc\\Destination' => $vendorDir . '/google/apiclient-services/src/Eventarc/Destination.php',
    'Google\\Service\\Eventarc\\EventFilter' => $vendorDir . '/google/apiclient-services/src/Eventarc/EventFilter.php',
    'Google\\Service\\Eventarc\\EventType' => $vendorDir . '/google/apiclient-services/src/Eventarc/EventType.php',
    'Google\\Service\\Eventarc\\EventarcEmpty' => $vendorDir . '/google/apiclient-services/src/Eventarc/EventarcEmpty.php',
    'Google\\Service\\Eventarc\\Expr' => $vendorDir . '/google/apiclient-services/src/Eventarc/Expr.php',
    'Google\\Service\\Eventarc\\FilteringAttribute' => $vendorDir . '/google/apiclient-services/src/Eventarc/FilteringAttribute.php',
    'Google\\Service\\Eventarc\\GKE' => $vendorDir . '/google/apiclient-services/src/Eventarc/GKE.php',
    'Google\\Service\\Eventarc\\GoogleChannelConfig' => $vendorDir . '/google/apiclient-services/src/Eventarc/GoogleChannelConfig.php',
    'Google\\Service\\Eventarc\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Eventarc/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\Eventarc\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Eventarc\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Eventarc/GoogleLongrunningOperation.php',
    'Google\\Service\\Eventarc\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Eventarc/GoogleRpcStatus.php',
    'Google\\Service\\Eventarc\\HttpEndpoint' => $vendorDir . '/google/apiclient-services/src/Eventarc/HttpEndpoint.php',
    'Google\\Service\\Eventarc\\ListChannelConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/ListChannelConnectionsResponse.php',
    'Google\\Service\\Eventarc\\ListChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/ListChannelsResponse.php',
    'Google\\Service\\Eventarc\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/ListLocationsResponse.php',
    'Google\\Service\\Eventarc\\ListProvidersResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/ListProvidersResponse.php',
    'Google\\Service\\Eventarc\\ListTriggersResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/ListTriggersResponse.php',
    'Google\\Service\\Eventarc\\Location' => $vendorDir . '/google/apiclient-services/src/Eventarc/Location.php',
    'Google\\Service\\Eventarc\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/Eventarc/NetworkConfig.php',
    'Google\\Service\\Eventarc\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Eventarc/OperationMetadata.php',
    'Google\\Service\\Eventarc\\Policy' => $vendorDir . '/google/apiclient-services/src/Eventarc/Policy.php',
    'Google\\Service\\Eventarc\\Provider' => $vendorDir . '/google/apiclient-services/src/Eventarc/Provider.php',
    'Google\\Service\\Eventarc\\Pubsub' => $vendorDir . '/google/apiclient-services/src/Eventarc/Pubsub.php',
    'Google\\Service\\Eventarc\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/Projects.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocations.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocationsChannelConnections' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocationsChannelConnections.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocationsChannels' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocationsChannels.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocationsProviders' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocationsProviders.php',
    'Google\\Service\\Eventarc\\Resource\\ProjectsLocationsTriggers' => $vendorDir . '/google/apiclient-services/src/Eventarc/Resource/ProjectsLocationsTriggers.php',
    'Google\\Service\\Eventarc\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Eventarc/SetIamPolicyRequest.php',
    'Google\\Service\\Eventarc\\StateCondition' => $vendorDir . '/google/apiclient-services/src/Eventarc/StateCondition.php',
    'Google\\Service\\Eventarc\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Eventarc/TestIamPermissionsRequest.php',
    'Google\\Service\\Eventarc\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Eventarc/TestIamPermissionsResponse.php',
    'Google\\Service\\Eventarc\\Transport' => $vendorDir . '/google/apiclient-services/src/Eventarc/Transport.php',
    'Google\\Service\\Eventarc\\Trigger' => $vendorDir . '/google/apiclient-services/src/Eventarc/Trigger.php',
    'Google\\Service\\Exception' => $vendorDir . '/google/apiclient/src/Service/Exception.php',
    'Google\\Service\\FactCheckTools' => $vendorDir . '/google/apiclient-services/src/FactCheckTools.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1Claim' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1Claim.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimReview' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimReview.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewAuthor' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewAuthor.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimImageSearchResponse' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimImageSearchResponse.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimImageSearchResponseResult' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimImageSearchResponseResult.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimSearchResponse' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimSearchResponse.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1ListClaimReviewMarkupPagesResponse' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1ListClaimReviewMarkupPagesResponse.php',
    'Google\\Service\\FactCheckTools\\GoogleFactcheckingFactchecktoolsV1alpha1Publisher' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleFactcheckingFactchecktoolsV1alpha1Publisher.php',
    'Google\\Service\\FactCheckTools\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/GoogleProtobufEmpty.php',
    'Google\\Service\\FactCheckTools\\Resource\\Claims' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/Resource/Claims.php',
    'Google\\Service\\FactCheckTools\\Resource\\Pages' => $vendorDir . '/google/apiclient-services/src/FactCheckTools/Resource/Pages.php',
    'Google\\Service\\Fcmdata' => $vendorDir . '/google/apiclient-services/src/Fcmdata.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1AndroidDeliveryData' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1AndroidDeliveryData.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1Data' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1Data.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponse' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponse.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1MessageInsightPercents' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1MessageInsightPercents.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1MessageOutcomePercents' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1MessageOutcomePercents.php',
    'Google\\Service\\Fcmdata\\GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents.php',
    'Google\\Service\\Fcmdata\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/Fcmdata/GoogleTypeDate.php',
    'Google\\Service\\Fcmdata\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Fcmdata/Resource/Projects.php',
    'Google\\Service\\Fcmdata\\Resource\\ProjectsAndroidApps' => $vendorDir . '/google/apiclient-services/src/Fcmdata/Resource/ProjectsAndroidApps.php',
    'Google\\Service\\Fcmdata\\Resource\\ProjectsAndroidAppsDeliveryData' => $vendorDir . '/google/apiclient-services/src/Fcmdata/Resource/ProjectsAndroidAppsDeliveryData.php',
    'Google\\Service\\FirebaseAppDistribution' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataBlobstore2Info' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataBlobstore2Info.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataCompositeMedia' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataCompositeMedia.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataContentTypeInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataContentTypeInfo.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDiffChecksumsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDiffChecksumsResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDiffDownloadResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDiffDownloadResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDiffUploadRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDiffUploadRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDiffUploadResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDiffUploadResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDiffVersionResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDiffVersionResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataDownloadParameters' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataDownloadParameters.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataMedia' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataMedia.php',
    'Google\\Service\\FirebaseAppDistribution\\GdataObjectId' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GdataObjectId.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1AabInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1AabInfo.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchAddTestersRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchAddTestersRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchAddTestersResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchAddTestersResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchDeleteReleasesRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchDeleteReleasesRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchJoinGroupRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchJoinGroupRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchLeaveGroupRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchLeaveGroupRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchRemoveTestersRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchRemoveTestersRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1BatchRemoveTestersResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1BatchRemoveTestersResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1DistributeReleaseRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1DistributeReleaseRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1DistributeReleaseResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1DistributeReleaseResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1FeedbackReport' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1FeedbackReport.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1Group' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1Group.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1ListFeedbackReportsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1ListFeedbackReportsResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1ListGroupsResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1ListReleasesResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1ListReleasesResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1ListTestersResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1ListTestersResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1Release' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1Release.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1ReleaseNotes' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1ReleaseNotes.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1TestCertificate' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1TestCertificate.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1Tester' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1Tester.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1UploadReleaseMetadata' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1UploadReleaseMetadata.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1UploadReleaseRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1UploadReleaseRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1UploadReleaseResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1UploadReleaseResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1alphaTestReleaseRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1alphaTestReleaseRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleFirebaseAppdistroV1alphaTestReleaseResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleFirebaseAppdistroV1alphaTestReleaseResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleLongrunningOperation.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleLongrunningWaitOperationRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleLongrunningWaitOperationRequest.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleProtobufEmpty.php',
    'Google\\Service\\FirebaseAppDistribution\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/GoogleRpcStatus.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/Media.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/Projects.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsApps' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsApps.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsAppsReleases' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsAppsReleases.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsAppsReleasesFeedbackReports' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsAppsReleasesFeedbackReports.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsAppsReleasesOperations' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsAppsReleasesOperations.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsGroups' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsGroups.php',
    'Google\\Service\\FirebaseAppDistribution\\Resource\\ProjectsTesters' => $vendorDir . '/google/apiclient-services/src/FirebaseAppDistribution/Resource/ProjectsTesters.php',
    'Google\\Service\\FirebaseCloudMessaging' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging.php',
    'Google\\Service\\FirebaseCloudMessaging\\AndroidConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/AndroidConfig.php',
    'Google\\Service\\FirebaseCloudMessaging\\AndroidFcmOptions' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/AndroidFcmOptions.php',
    'Google\\Service\\FirebaseCloudMessaging\\AndroidNotification' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/AndroidNotification.php',
    'Google\\Service\\FirebaseCloudMessaging\\ApnsConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/ApnsConfig.php',
    'Google\\Service\\FirebaseCloudMessaging\\ApnsFcmOptions' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/ApnsFcmOptions.php',
    'Google\\Service\\FirebaseCloudMessaging\\Color' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/Color.php',
    'Google\\Service\\FirebaseCloudMessaging\\FcmOptions' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/FcmOptions.php',
    'Google\\Service\\FirebaseCloudMessaging\\LightSettings' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/LightSettings.php',
    'Google\\Service\\FirebaseCloudMessaging\\Message' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/Message.php',
    'Google\\Service\\FirebaseCloudMessaging\\Notification' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/Notification.php',
    'Google\\Service\\FirebaseCloudMessaging\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/Resource/Projects.php',
    'Google\\Service\\FirebaseCloudMessaging\\Resource\\ProjectsMessages' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/Resource/ProjectsMessages.php',
    'Google\\Service\\FirebaseCloudMessaging\\SendMessageRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/SendMessageRequest.php',
    'Google\\Service\\FirebaseCloudMessaging\\WebpushConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/WebpushConfig.php',
    'Google\\Service\\FirebaseCloudMessaging\\WebpushFcmOptions' => $vendorDir . '/google/apiclient-services/src/FirebaseCloudMessaging/WebpushFcmOptions.php',
    'Google\\Service\\FirebaseDynamicLinks' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks.php',
    'Google\\Service\\FirebaseDynamicLinks\\AnalyticsInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/AnalyticsInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\AndroidInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/AndroidInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\CreateManagedShortLinkRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/CreateManagedShortLinkRequest.php',
    'Google\\Service\\FirebaseDynamicLinks\\CreateManagedShortLinkResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/CreateManagedShortLinkResponse.php',
    'Google\\Service\\FirebaseDynamicLinks\\CreateShortDynamicLinkRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/CreateShortDynamicLinkRequest.php',
    'Google\\Service\\FirebaseDynamicLinks\\CreateShortDynamicLinkResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/CreateShortDynamicLinkResponse.php',
    'Google\\Service\\FirebaseDynamicLinks\\DesktopInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DesktopInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\DeviceInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DeviceInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\DynamicLinkEventStat' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DynamicLinkEventStat.php',
    'Google\\Service\\FirebaseDynamicLinks\\DynamicLinkInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DynamicLinkInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\DynamicLinkStats' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DynamicLinkStats.php',
    'Google\\Service\\FirebaseDynamicLinks\\DynamicLinkWarning' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/DynamicLinkWarning.php',
    'Google\\Service\\FirebaseDynamicLinks\\GetIosPostInstallAttributionRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/GetIosPostInstallAttributionRequest.php',
    'Google\\Service\\FirebaseDynamicLinks\\GetIosPostInstallAttributionResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/GetIosPostInstallAttributionResponse.php',
    'Google\\Service\\FirebaseDynamicLinks\\GetIosReopenAttributionRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/GetIosReopenAttributionRequest.php',
    'Google\\Service\\FirebaseDynamicLinks\\GetIosReopenAttributionResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/GetIosReopenAttributionResponse.php',
    'Google\\Service\\FirebaseDynamicLinks\\GooglePlayAnalytics' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/GooglePlayAnalytics.php',
    'Google\\Service\\FirebaseDynamicLinks\\ITunesConnectAnalytics' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/ITunesConnectAnalytics.php',
    'Google\\Service\\FirebaseDynamicLinks\\IosInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/IosInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\ManagedShortLink' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/ManagedShortLink.php',
    'Google\\Service\\FirebaseDynamicLinks\\NavigationInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/NavigationInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\Resource\\ManagedShortLinks' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/Resource/ManagedShortLinks.php',
    'Google\\Service\\FirebaseDynamicLinks\\Resource\\ShortLinks' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/Resource/ShortLinks.php',
    'Google\\Service\\FirebaseDynamicLinks\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/Resource/V1.php',
    'Google\\Service\\FirebaseDynamicLinks\\SocialMetaTagInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/SocialMetaTagInfo.php',
    'Google\\Service\\FirebaseDynamicLinks\\Suffix' => $vendorDir . '/google/apiclient-services/src/FirebaseDynamicLinks/Suffix.php',
    'Google\\Service\\FirebaseHosting' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting.php',
    'Google\\Service\\FirebaseHosting\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/CancelOperationRequest.php',
    'Google\\Service\\FirebaseHosting\\CertVerification' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/CertVerification.php',
    'Google\\Service\\FirebaseHosting\\CustomDomainMetadata' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/CustomDomainMetadata.php',
    'Google\\Service\\FirebaseHosting\\DnsRecord' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/DnsRecord.php',
    'Google\\Service\\FirebaseHosting\\DnsRecordSet' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/DnsRecordSet.php',
    'Google\\Service\\FirebaseHosting\\DnsUpdates' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/DnsUpdates.php',
    'Google\\Service\\FirebaseHosting\\FirebasehostingEmpty' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/FirebasehostingEmpty.php',
    'Google\\Service\\FirebaseHosting\\HttpUpdate' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/HttpUpdate.php',
    'Google\\Service\\FirebaseHosting\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/ListOperationsResponse.php',
    'Google\\Service\\FirebaseHosting\\LiveMigrationStep' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/LiveMigrationStep.php',
    'Google\\Service\\FirebaseHosting\\Operation' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Operation.php',
    'Google\\Service\\FirebaseHosting\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Resource/Operations.php',
    'Google\\Service\\FirebaseHosting\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Resource/Projects.php',
    'Google\\Service\\FirebaseHosting\\Resource\\ProjectsSites' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Resource/ProjectsSites.php',
    'Google\\Service\\FirebaseHosting\\Resource\\ProjectsSitesCustomDomains' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Resource/ProjectsSitesCustomDomains.php',
    'Google\\Service\\FirebaseHosting\\Resource\\ProjectsSitesCustomDomainsOperations' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Resource/ProjectsSitesCustomDomainsOperations.php',
    'Google\\Service\\FirebaseHosting\\Status' => $vendorDir . '/google/apiclient-services/src/FirebaseHosting/Status.php',
    'Google\\Service\\FirebaseML' => $vendorDir . '/google/apiclient-services/src/FirebaseML.php',
    'Google\\Service\\FirebaseML\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseML/CancelOperationRequest.php',
    'Google\\Service\\FirebaseML\\FirebasemlEmpty' => $vendorDir . '/google/apiclient-services/src/FirebaseML/FirebasemlEmpty.php',
    'Google\\Service\\FirebaseML\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseML/ListOperationsResponse.php',
    'Google\\Service\\FirebaseML\\ModelOperationMetadata' => $vendorDir . '/google/apiclient-services/src/FirebaseML/ModelOperationMetadata.php',
    'Google\\Service\\FirebaseML\\Operation' => $vendorDir . '/google/apiclient-services/src/FirebaseML/Operation.php',
    'Google\\Service\\FirebaseML\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/FirebaseML/Resource/Operations.php',
    'Google\\Service\\FirebaseML\\Status' => $vendorDir . '/google/apiclient-services/src/FirebaseML/Status.php',
    'Google\\Service\\FirebaseManagement' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement.php',
    'Google\\Service\\FirebaseManagement\\AddFirebaseRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AddFirebaseRequest.php',
    'Google\\Service\\FirebaseManagement\\AddGoogleAnalyticsRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AddGoogleAnalyticsRequest.php',
    'Google\\Service\\FirebaseManagement\\AdminSdkConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AdminSdkConfig.php',
    'Google\\Service\\FirebaseManagement\\AnalyticsDetails' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AnalyticsDetails.php',
    'Google\\Service\\FirebaseManagement\\AnalyticsProperty' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AnalyticsProperty.php',
    'Google\\Service\\FirebaseManagement\\AndroidApp' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AndroidApp.php',
    'Google\\Service\\FirebaseManagement\\AndroidAppConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/AndroidAppConfig.php',
    'Google\\Service\\FirebaseManagement\\DefaultResources' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/DefaultResources.php',
    'Google\\Service\\FirebaseManagement\\FinalizeDefaultLocationRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/FinalizeDefaultLocationRequest.php',
    'Google\\Service\\FirebaseManagement\\FirebaseAppInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/FirebaseAppInfo.php',
    'Google\\Service\\FirebaseManagement\\FirebaseEmpty' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/FirebaseEmpty.php',
    'Google\\Service\\FirebaseManagement\\FirebaseProject' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/FirebaseProject.php',
    'Google\\Service\\FirebaseManagement\\IosApp' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/IosApp.php',
    'Google\\Service\\FirebaseManagement\\IosAppConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/IosAppConfig.php',
    'Google\\Service\\FirebaseManagement\\ListAndroidAppsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListAndroidAppsResponse.php',
    'Google\\Service\\FirebaseManagement\\ListAvailableLocationsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListAvailableLocationsResponse.php',
    'Google\\Service\\FirebaseManagement\\ListAvailableProjectsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListAvailableProjectsResponse.php',
    'Google\\Service\\FirebaseManagement\\ListFirebaseProjectsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListFirebaseProjectsResponse.php',
    'Google\\Service\\FirebaseManagement\\ListIosAppsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListIosAppsResponse.php',
    'Google\\Service\\FirebaseManagement\\ListShaCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListShaCertificatesResponse.php',
    'Google\\Service\\FirebaseManagement\\ListWebAppsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ListWebAppsResponse.php',
    'Google\\Service\\FirebaseManagement\\Location' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Location.php',
    'Google\\Service\\FirebaseManagement\\MessageSet' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/MessageSet.php',
    'Google\\Service\\FirebaseManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Operation.php',
    'Google\\Service\\FirebaseManagement\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/OperationMetadata.php',
    'Google\\Service\\FirebaseManagement\\ProductMetadata' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ProductMetadata.php',
    'Google\\Service\\FirebaseManagement\\ProjectInfo' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ProjectInfo.php',
    'Google\\Service\\FirebaseManagement\\RemoveAnalyticsRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/RemoveAnalyticsRequest.php',
    'Google\\Service\\FirebaseManagement\\RemoveAndroidAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/RemoveAndroidAppRequest.php',
    'Google\\Service\\FirebaseManagement\\RemoveIosAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/RemoveIosAppRequest.php',
    'Google\\Service\\FirebaseManagement\\RemoveWebAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/RemoveWebAppRequest.php',
    'Google\\Service\\FirebaseManagement\\Resource\\AvailableProjects' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/AvailableProjects.php',
    'Google\\Service\\FirebaseManagement\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/Operations.php',
    'Google\\Service\\FirebaseManagement\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/Projects.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsAndroidApps' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsAndroidApps.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsAndroidAppsSha' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsAndroidAppsSha.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsAvailableLocations' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsAvailableLocations.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsDefaultLocation' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsDefaultLocation.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsIosApps' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsIosApps.php',
    'Google\\Service\\FirebaseManagement\\Resource\\ProjectsWebApps' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Resource/ProjectsWebApps.php',
    'Google\\Service\\FirebaseManagement\\SearchFirebaseAppsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/SearchFirebaseAppsResponse.php',
    'Google\\Service\\FirebaseManagement\\ShaCertificate' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/ShaCertificate.php',
    'Google\\Service\\FirebaseManagement\\Status' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/Status.php',
    'Google\\Service\\FirebaseManagement\\StatusProto' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/StatusProto.php',
    'Google\\Service\\FirebaseManagement\\StreamMapping' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/StreamMapping.php',
    'Google\\Service\\FirebaseManagement\\UndeleteAndroidAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/UndeleteAndroidAppRequest.php',
    'Google\\Service\\FirebaseManagement\\UndeleteIosAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/UndeleteIosAppRequest.php',
    'Google\\Service\\FirebaseManagement\\UndeleteWebAppRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/UndeleteWebAppRequest.php',
    'Google\\Service\\FirebaseManagement\\WebApp' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/WebApp.php',
    'Google\\Service\\FirebaseManagement\\WebAppConfig' => $vendorDir . '/google/apiclient-services/src/FirebaseManagement/WebAppConfig.php',
    'Google\\Service\\FirebaseRealtimeDatabase' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\DatabaseInstance' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/DatabaseInstance.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\DisableDatabaseInstanceRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/DisableDatabaseInstanceRequest.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\ListDatabaseInstancesResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/ListDatabaseInstancesResponse.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\ReenableDatabaseInstanceRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/ReenableDatabaseInstanceRequest.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/Resource/Projects.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/Resource/ProjectsLocations.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\FirebaseRealtimeDatabase\\UndeleteDatabaseInstanceRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseRealtimeDatabase/UndeleteDatabaseInstanceRequest.php',
    'Google\\Service\\FirebaseRules' => $vendorDir . '/google/apiclient-services/src/FirebaseRules.php',
    'Google\\Service\\FirebaseRules\\Arg' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Arg.php',
    'Google\\Service\\FirebaseRules\\ExpressionReport' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/ExpressionReport.php',
    'Google\\Service\\FirebaseRules\\FirebaserulesEmpty' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/FirebaserulesEmpty.php',
    'Google\\Service\\FirebaseRules\\FirebaserulesFile' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/FirebaserulesFile.php',
    'Google\\Service\\FirebaseRules\\FunctionCall' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/FunctionCall.php',
    'Google\\Service\\FirebaseRules\\FunctionMock' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/FunctionMock.php',
    'Google\\Service\\FirebaseRules\\GetReleaseExecutableResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/GetReleaseExecutableResponse.php',
    'Google\\Service\\FirebaseRules\\Issue' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Issue.php',
    'Google\\Service\\FirebaseRules\\ListReleasesResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/ListReleasesResponse.php',
    'Google\\Service\\FirebaseRules\\ListRulesetsResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/ListRulesetsResponse.php',
    'Google\\Service\\FirebaseRules\\Metadata' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Metadata.php',
    'Google\\Service\\FirebaseRules\\Release' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Release.php',
    'Google\\Service\\FirebaseRules\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Resource/Projects.php',
    'Google\\Service\\FirebaseRules\\Resource\\ProjectsReleases' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Resource/ProjectsReleases.php',
    'Google\\Service\\FirebaseRules\\Resource\\ProjectsRulesets' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Resource/ProjectsRulesets.php',
    'Google\\Service\\FirebaseRules\\Result' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Result.php',
    'Google\\Service\\FirebaseRules\\Ruleset' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Ruleset.php',
    'Google\\Service\\FirebaseRules\\Source' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/Source.php',
    'Google\\Service\\FirebaseRules\\SourcePosition' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/SourcePosition.php',
    'Google\\Service\\FirebaseRules\\TestCase' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/TestCase.php',
    'Google\\Service\\FirebaseRules\\TestResult' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/TestResult.php',
    'Google\\Service\\FirebaseRules\\TestRulesetRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/TestRulesetRequest.php',
    'Google\\Service\\FirebaseRules\\TestRulesetResponse' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/TestRulesetResponse.php',
    'Google\\Service\\FirebaseRules\\TestSuite' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/TestSuite.php',
    'Google\\Service\\FirebaseRules\\UpdateReleaseRequest' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/UpdateReleaseRequest.php',
    'Google\\Service\\FirebaseRules\\ValueCount' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/ValueCount.php',
    'Google\\Service\\FirebaseRules\\VisitedExpression' => $vendorDir . '/google/apiclient-services/src/FirebaseRules/VisitedExpression.php',
    'Google\\Service\\Firebaseappcheck' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1AppAttestConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1AppAttestConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1AppCheckToken' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1AppCheckToken.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetAppAttestConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetAppAttestConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetDeviceCheckConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetDeviceCheckConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetPlayIntegrityConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetPlayIntegrityConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetRecaptchaEnterpriseConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetRecaptchaEnterpriseConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetRecaptchaV3ConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetRecaptchaV3ConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchGetSafetyNetConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchGetSafetyNetConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchUpdateServicesRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchUpdateServicesRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1BatchUpdateServicesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1BatchUpdateServicesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1DebugToken' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1DebugToken.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1DeviceCheckConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1DeviceCheckConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeCustomTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeCustomTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeDeviceCheckTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeDeviceCheckTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeRecaptchaV3TokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeRecaptchaV3TokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ExchangeSafetyNetTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ExchangeSafetyNetTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1GenerateAppAttestChallengeRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1GenerateAppAttestChallengeRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1GenerateAppAttestChallengeResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1GenerateAppAttestChallengeResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ListDebugTokensResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ListDebugTokensResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ListResourcePoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ListResourcePoliciesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ListServicesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1PlayIntegrityConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1PlayIntegrityConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1PublicJwk' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1PublicJwk.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1PublicJwkSet' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1PublicJwkSet.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1RecaptchaV3Config' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1RecaptchaV3Config.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1ResourcePolicy' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1ResourcePolicy.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1SafetyNetConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1SafetyNetConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1Service' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1Service.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1UpdateResourcePolicyRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1UpdateResourcePolicyRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1UpdateServiceRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1UpdateServiceRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaAppAttestChallengeResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaAppAttestChallengeResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaAppAttestConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaAppAttestConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaAppCheckToken' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaAppCheckToken.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaAttestationTokenResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaAttestationTokenResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaDebugToken' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaDebugToken.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaDeviceCheckConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaDeviceCheckConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeDebugTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeDebugTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeDeviceCheckTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeDeviceCheckTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangePlayIntegrityTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangePlayIntegrityTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeRecaptchaEnterpriseTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeRecaptchaEnterpriseTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeRecaptchaTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeRecaptchaTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeRecaptchaV3TokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeRecaptchaV3TokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaExchangeSafetyNetTokenRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaExchangeSafetyNetTokenRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaListDebugTokensResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaListDebugTokensResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaListServicesResponse' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaListServicesResponse.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaPlayIntegrityConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaPlayIntegrityConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaPublicJwk' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaPublicJwk.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaPublicJwkSet' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaPublicJwkSet.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaRecaptchaConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaRecaptchaConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaRecaptchaV3Config' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaRecaptchaV3Config.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaSafetyNetConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaSafetyNetConfig.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaService' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaService.php',
    'Google\\Service\\Firebaseappcheck\\GoogleFirebaseAppcheckV1betaUpdateServiceRequest' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleFirebaseAppcheckV1betaUpdateServiceRequest.php',
    'Google\\Service\\Firebaseappcheck\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/GoogleProtobufEmpty.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\Jwks' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/Jwks.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\OauthClients' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/OauthClients.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/Projects.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsApps' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsApps.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsAppAttestConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsAppAttestConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsDebugTokens' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsDebugTokens.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsDeviceCheckConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsDeviceCheckConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsPlayIntegrityConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsPlayIntegrityConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsRecaptchaConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsRecaptchaConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsRecaptchaEnterpriseConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsRecaptchaEnterpriseConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsRecaptchaV3Config' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsRecaptchaV3Config.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsAppsSafetyNetConfig' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsAppsSafetyNetConfig.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsServices' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsServices.php',
    'Google\\Service\\Firebaseappcheck\\Resource\\ProjectsServicesResourcePolicies' => $vendorDir . '/google/apiclient-services/src/Firebaseappcheck/Resource/ProjectsServicesResourcePolicies.php',
    'Google\\Service\\Firebasestorage' => $vendorDir . '/google/apiclient-services/src/Firebasestorage.php',
    'Google\\Service\\Firebasestorage\\AddFirebaseRequest' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/AddFirebaseRequest.php',
    'Google\\Service\\Firebasestorage\\Bucket' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/Bucket.php',
    'Google\\Service\\Firebasestorage\\FirebasestorageEmpty' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/FirebasestorageEmpty.php',
    'Google\\Service\\Firebasestorage\\GoogleFirebaseStorageControlplaneV1alphaMigrateLocationDestructivelyMetadata' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/GoogleFirebaseStorageControlplaneV1alphaMigrateLocationDestructivelyMetadata.php',
    'Google\\Service\\Firebasestorage\\GoogleFirebaseStorageControlplaneV1betaMigrateLocationDestructivelyMetadata' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/GoogleFirebaseStorageControlplaneV1betaMigrateLocationDestructivelyMetadata.php',
    'Google\\Service\\Firebasestorage\\ListBucketsResponse' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/ListBucketsResponse.php',
    'Google\\Service\\Firebasestorage\\RemoveFirebaseRequest' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/RemoveFirebaseRequest.php',
    'Google\\Service\\Firebasestorage\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/Resource/Projects.php',
    'Google\\Service\\Firebasestorage\\Resource\\ProjectsBuckets' => $vendorDir . '/google/apiclient-services/src/Firebasestorage/Resource/ProjectsBuckets.php',
    'Google\\Service\\Firestore' => $vendorDir . '/google/apiclient-services/src/Firestore.php',
    'Google\\Service\\Firestore\\Aggregation' => $vendorDir . '/google/apiclient-services/src/Firestore/Aggregation.php',
    'Google\\Service\\Firestore\\AggregationResult' => $vendorDir . '/google/apiclient-services/src/Firestore/AggregationResult.php',
    'Google\\Service\\Firestore\\ArrayValue' => $vendorDir . '/google/apiclient-services/src/Firestore/ArrayValue.php',
    'Google\\Service\\Firestore\\Avg' => $vendorDir . '/google/apiclient-services/src/Firestore/Avg.php',
    'Google\\Service\\Firestore\\BatchGetDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/BatchGetDocumentsRequest.php',
    'Google\\Service\\Firestore\\BatchGetDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/BatchGetDocumentsResponse.php',
    'Google\\Service\\Firestore\\BatchWriteRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/BatchWriteRequest.php',
    'Google\\Service\\Firestore\\BatchWriteResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/BatchWriteResponse.php',
    'Google\\Service\\Firestore\\BeginTransactionRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/BeginTransactionRequest.php',
    'Google\\Service\\Firestore\\BeginTransactionResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/BeginTransactionResponse.php',
    'Google\\Service\\Firestore\\BitSequence' => $vendorDir . '/google/apiclient-services/src/Firestore/BitSequence.php',
    'Google\\Service\\Firestore\\BloomFilter' => $vendorDir . '/google/apiclient-services/src/Firestore/BloomFilter.php',
    'Google\\Service\\Firestore\\CollectionSelector' => $vendorDir . '/google/apiclient-services/src/Firestore/CollectionSelector.php',
    'Google\\Service\\Firestore\\CommitRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/CommitRequest.php',
    'Google\\Service\\Firestore\\CommitResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/CommitResponse.php',
    'Google\\Service\\Firestore\\CompositeFilter' => $vendorDir . '/google/apiclient-services/src/Firestore/CompositeFilter.php',
    'Google\\Service\\Firestore\\Count' => $vendorDir . '/google/apiclient-services/src/Firestore/Count.php',
    'Google\\Service\\Firestore\\Cursor' => $vendorDir . '/google/apiclient-services/src/Firestore/Cursor.php',
    'Google\\Service\\Firestore\\Document' => $vendorDir . '/google/apiclient-services/src/Firestore/Document.php',
    'Google\\Service\\Firestore\\DocumentChange' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentChange.php',
    'Google\\Service\\Firestore\\DocumentDelete' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentDelete.php',
    'Google\\Service\\Firestore\\DocumentMask' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentMask.php',
    'Google\\Service\\Firestore\\DocumentRemove' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentRemove.php',
    'Google\\Service\\Firestore\\DocumentTransform' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentTransform.php',
    'Google\\Service\\Firestore\\DocumentsTarget' => $vendorDir . '/google/apiclient-services/src/Firestore/DocumentsTarget.php',
    'Google\\Service\\Firestore\\ExecutionStats' => $vendorDir . '/google/apiclient-services/src/Firestore/ExecutionStats.php',
    'Google\\Service\\Firestore\\ExistenceFilter' => $vendorDir . '/google/apiclient-services/src/Firestore/ExistenceFilter.php',
    'Google\\Service\\Firestore\\ExplainMetrics' => $vendorDir . '/google/apiclient-services/src/Firestore/ExplainMetrics.php',
    'Google\\Service\\Firestore\\ExplainOptions' => $vendorDir . '/google/apiclient-services/src/Firestore/ExplainOptions.php',
    'Google\\Service\\Firestore\\FieldFilter' => $vendorDir . '/google/apiclient-services/src/Firestore/FieldFilter.php',
    'Google\\Service\\Firestore\\FieldReference' => $vendorDir . '/google/apiclient-services/src/Firestore/FieldReference.php',
    'Google\\Service\\Firestore\\FieldTransform' => $vendorDir . '/google/apiclient-services/src/Firestore/FieldTransform.php',
    'Google\\Service\\Firestore\\Filter' => $vendorDir . '/google/apiclient-services/src/Firestore/Filter.php',
    'Google\\Service\\Firestore\\FindNearest' => $vendorDir . '/google/apiclient-services/src/Firestore/FindNearest.php',
    'Google\\Service\\Firestore\\FirestoreEmpty' => $vendorDir . '/google/apiclient-services/src/Firestore/FirestoreEmpty.php',
    'Google\\Service\\Firestore\\FirestoreReadOnly' => $vendorDir . '/google/apiclient-services/src/Firestore/FirestoreReadOnly.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Backup' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Backup.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1BackupSchedule' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1BackupSchedule.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1BulkDeleteDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1BulkDeleteDocumentsRequest.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1CmekConfig' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1CmekConfig.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1CreateDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1CreateDatabaseMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1CustomerManagedEncryptionOptions' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1CustomerManagedEncryptionOptions.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1DailyRecurrence' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1DailyRecurrence.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Database' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Database.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1DatabaseSnapshot' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1DatabaseSnapshot.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1DeleteDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1DeleteDatabaseMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1EncryptionConfig.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ExportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ExportDocumentsMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ExportDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ExportDocumentsRequest.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ExportDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ExportDocumentsResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Field' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Field.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1FieldOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1FieldOperationMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1FlatIndex' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1FlatIndex.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1GoogleDefaultEncryptionOptions' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1GoogleDefaultEncryptionOptions.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ImportDocumentsMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ImportDocumentsMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ImportDocumentsRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ImportDocumentsRequest.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Index' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Index.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1IndexConfig' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1IndexConfig.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1IndexConfigDelta' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1IndexConfigDelta.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1IndexField' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1IndexField.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1IndexOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1IndexOperationMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ListBackupSchedulesResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ListBackupSchedulesResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ListBackupsResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ListDatabasesResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ListDatabasesResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ListFieldsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ListFieldsResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1ListIndexesResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1ListIndexesResponse.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1LocationMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1LocationMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Progress' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Progress.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1RestoreDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1RestoreDatabaseMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1RestoreDatabaseRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1RestoreDatabaseRequest.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1SourceEncryptionOptions' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1SourceEncryptionOptions.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1Stats' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1Stats.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1TtlConfig' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1TtlConfig.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1TtlConfigDelta' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1TtlConfigDelta.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1UpdateDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1UpdateDatabaseMetadata.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1VectorConfig' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1VectorConfig.php',
    'Google\\Service\\Firestore\\GoogleFirestoreAdminV1WeeklyRecurrence' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleFirestoreAdminV1WeeklyRecurrence.php',
    'Google\\Service\\Firestore\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\Firestore\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Firestore\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Firestore/GoogleLongrunningOperation.php',
    'Google\\Service\\Firestore\\LatLng' => $vendorDir . '/google/apiclient-services/src/Firestore/LatLng.php',
    'Google\\Service\\Firestore\\ListCollectionIdsRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/ListCollectionIdsRequest.php',
    'Google\\Service\\Firestore\\ListCollectionIdsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/ListCollectionIdsResponse.php',
    'Google\\Service\\Firestore\\ListDocumentsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/ListDocumentsResponse.php',
    'Google\\Service\\Firestore\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/ListLocationsResponse.php',
    'Google\\Service\\Firestore\\ListenRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/ListenRequest.php',
    'Google\\Service\\Firestore\\ListenResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/ListenResponse.php',
    'Google\\Service\\Firestore\\Location' => $vendorDir . '/google/apiclient-services/src/Firestore/Location.php',
    'Google\\Service\\Firestore\\MapValue' => $vendorDir . '/google/apiclient-services/src/Firestore/MapValue.php',
    'Google\\Service\\Firestore\\Order' => $vendorDir . '/google/apiclient-services/src/Firestore/Order.php',
    'Google\\Service\\Firestore\\PartitionQueryRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/PartitionQueryRequest.php',
    'Google\\Service\\Firestore\\PartitionQueryResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/PartitionQueryResponse.php',
    'Google\\Service\\Firestore\\PlanSummary' => $vendorDir . '/google/apiclient-services/src/Firestore/PlanSummary.php',
    'Google\\Service\\Firestore\\Precondition' => $vendorDir . '/google/apiclient-services/src/Firestore/Precondition.php',
    'Google\\Service\\Firestore\\Projection' => $vendorDir . '/google/apiclient-services/src/Firestore/Projection.php',
    'Google\\Service\\Firestore\\QueryPlan' => $vendorDir . '/google/apiclient-services/src/Firestore/QueryPlan.php',
    'Google\\Service\\Firestore\\QueryTarget' => $vendorDir . '/google/apiclient-services/src/Firestore/QueryTarget.php',
    'Google\\Service\\Firestore\\ReadWrite' => $vendorDir . '/google/apiclient-services/src/Firestore/ReadWrite.php',
    'Google\\Service\\Firestore\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/Projects.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabases' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabases.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesBackupSchedules' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesBackupSchedules.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesCollectionGroups' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesCollectionGroups.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesCollectionGroupsFields' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesCollectionGroupsFields.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesCollectionGroupsIndexes' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesCollectionGroupsIndexes.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesDocuments' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesDocuments.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsDatabasesOperations' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsDatabasesOperations.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsLocations.php',
    'Google\\Service\\Firestore\\Resource\\ProjectsLocationsBackups' => $vendorDir . '/google/apiclient-services/src/Firestore/Resource/ProjectsLocationsBackups.php',
    'Google\\Service\\Firestore\\ResultSetStats' => $vendorDir . '/google/apiclient-services/src/Firestore/ResultSetStats.php',
    'Google\\Service\\Firestore\\RollbackRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/RollbackRequest.php',
    'Google\\Service\\Firestore\\RunAggregationQueryRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/RunAggregationQueryRequest.php',
    'Google\\Service\\Firestore\\RunAggregationQueryResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/RunAggregationQueryResponse.php',
    'Google\\Service\\Firestore\\RunQueryRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/RunQueryRequest.php',
    'Google\\Service\\Firestore\\RunQueryResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/RunQueryResponse.php',
    'Google\\Service\\Firestore\\Status' => $vendorDir . '/google/apiclient-services/src/Firestore/Status.php',
    'Google\\Service\\Firestore\\StructuredAggregationQuery' => $vendorDir . '/google/apiclient-services/src/Firestore/StructuredAggregationQuery.php',
    'Google\\Service\\Firestore\\StructuredQuery' => $vendorDir . '/google/apiclient-services/src/Firestore/StructuredQuery.php',
    'Google\\Service\\Firestore\\Sum' => $vendorDir . '/google/apiclient-services/src/Firestore/Sum.php',
    'Google\\Service\\Firestore\\Target' => $vendorDir . '/google/apiclient-services/src/Firestore/Target.php',
    'Google\\Service\\Firestore\\TargetChange' => $vendorDir . '/google/apiclient-services/src/Firestore/TargetChange.php',
    'Google\\Service\\Firestore\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Firestore/TimeOfDay.php',
    'Google\\Service\\Firestore\\TransactionOptions' => $vendorDir . '/google/apiclient-services/src/Firestore/TransactionOptions.php',
    'Google\\Service\\Firestore\\UnaryFilter' => $vendorDir . '/google/apiclient-services/src/Firestore/UnaryFilter.php',
    'Google\\Service\\Firestore\\Value' => $vendorDir . '/google/apiclient-services/src/Firestore/Value.php',
    'Google\\Service\\Firestore\\Write' => $vendorDir . '/google/apiclient-services/src/Firestore/Write.php',
    'Google\\Service\\Firestore\\WriteRequest' => $vendorDir . '/google/apiclient-services/src/Firestore/WriteRequest.php',
    'Google\\Service\\Firestore\\WriteResponse' => $vendorDir . '/google/apiclient-services/src/Firestore/WriteResponse.php',
    'Google\\Service\\Firestore\\WriteResult' => $vendorDir . '/google/apiclient-services/src/Firestore/WriteResult.php',
    'Google\\Service\\Fitness' => $vendorDir . '/google/apiclient-services/src/Fitness.php',
    'Google\\Service\\Fitness\\AggregateBucket' => $vendorDir . '/google/apiclient-services/src/Fitness/AggregateBucket.php',
    'Google\\Service\\Fitness\\AggregateBy' => $vendorDir . '/google/apiclient-services/src/Fitness/AggregateBy.php',
    'Google\\Service\\Fitness\\AggregateRequest' => $vendorDir . '/google/apiclient-services/src/Fitness/AggregateRequest.php',
    'Google\\Service\\Fitness\\AggregateResponse' => $vendorDir . '/google/apiclient-services/src/Fitness/AggregateResponse.php',
    'Google\\Service\\Fitness\\Application' => $vendorDir . '/google/apiclient-services/src/Fitness/Application.php',
    'Google\\Service\\Fitness\\BucketByActivity' => $vendorDir . '/google/apiclient-services/src/Fitness/BucketByActivity.php',
    'Google\\Service\\Fitness\\BucketBySession' => $vendorDir . '/google/apiclient-services/src/Fitness/BucketBySession.php',
    'Google\\Service\\Fitness\\BucketByTime' => $vendorDir . '/google/apiclient-services/src/Fitness/BucketByTime.php',
    'Google\\Service\\Fitness\\BucketByTimePeriod' => $vendorDir . '/google/apiclient-services/src/Fitness/BucketByTimePeriod.php',
    'Google\\Service\\Fitness\\DataPoint' => $vendorDir . '/google/apiclient-services/src/Fitness/DataPoint.php',
    'Google\\Service\\Fitness\\DataSource' => $vendorDir . '/google/apiclient-services/src/Fitness/DataSource.php',
    'Google\\Service\\Fitness\\DataType' => $vendorDir . '/google/apiclient-services/src/Fitness/DataType.php',
    'Google\\Service\\Fitness\\DataTypeField' => $vendorDir . '/google/apiclient-services/src/Fitness/DataTypeField.php',
    'Google\\Service\\Fitness\\Dataset' => $vendorDir . '/google/apiclient-services/src/Fitness/Dataset.php',
    'Google\\Service\\Fitness\\Device' => $vendorDir . '/google/apiclient-services/src/Fitness/Device.php',
    'Google\\Service\\Fitness\\ListDataPointChangesResponse' => $vendorDir . '/google/apiclient-services/src/Fitness/ListDataPointChangesResponse.php',
    'Google\\Service\\Fitness\\ListDataSourcesResponse' => $vendorDir . '/google/apiclient-services/src/Fitness/ListDataSourcesResponse.php',
    'Google\\Service\\Fitness\\ListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Fitness/ListSessionsResponse.php',
    'Google\\Service\\Fitness\\MapValue' => $vendorDir . '/google/apiclient-services/src/Fitness/MapValue.php',
    'Google\\Service\\Fitness\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/Users.php',
    'Google\\Service\\Fitness\\Resource\\UsersDataSources' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/UsersDataSources.php',
    'Google\\Service\\Fitness\\Resource\\UsersDataSourcesDataPointChanges' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/UsersDataSourcesDataPointChanges.php',
    'Google\\Service\\Fitness\\Resource\\UsersDataSourcesDatasets' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/UsersDataSourcesDatasets.php',
    'Google\\Service\\Fitness\\Resource\\UsersDataset' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/UsersDataset.php',
    'Google\\Service\\Fitness\\Resource\\UsersSessions' => $vendorDir . '/google/apiclient-services/src/Fitness/Resource/UsersSessions.php',
    'Google\\Service\\Fitness\\Session' => $vendorDir . '/google/apiclient-services/src/Fitness/Session.php',
    'Google\\Service\\Fitness\\Value' => $vendorDir . '/google/apiclient-services/src/Fitness/Value.php',
    'Google\\Service\\Fitness\\ValueMapValEntry' => $vendorDir . '/google/apiclient-services/src/Fitness/ValueMapValEntry.php',
    'Google\\Service\\Forms' => $vendorDir . '/google/apiclient-services/src/Forms.php',
    'Google\\Service\\Forms\\Answer' => $vendorDir . '/google/apiclient-services/src/Forms/Answer.php',
    'Google\\Service\\Forms\\BatchUpdateFormRequest' => $vendorDir . '/google/apiclient-services/src/Forms/BatchUpdateFormRequest.php',
    'Google\\Service\\Forms\\BatchUpdateFormResponse' => $vendorDir . '/google/apiclient-services/src/Forms/BatchUpdateFormResponse.php',
    'Google\\Service\\Forms\\ChoiceQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/ChoiceQuestion.php',
    'Google\\Service\\Forms\\CloudPubsubTopic' => $vendorDir . '/google/apiclient-services/src/Forms/CloudPubsubTopic.php',
    'Google\\Service\\Forms\\CorrectAnswer' => $vendorDir . '/google/apiclient-services/src/Forms/CorrectAnswer.php',
    'Google\\Service\\Forms\\CorrectAnswers' => $vendorDir . '/google/apiclient-services/src/Forms/CorrectAnswers.php',
    'Google\\Service\\Forms\\CreateItemRequest' => $vendorDir . '/google/apiclient-services/src/Forms/CreateItemRequest.php',
    'Google\\Service\\Forms\\CreateItemResponse' => $vendorDir . '/google/apiclient-services/src/Forms/CreateItemResponse.php',
    'Google\\Service\\Forms\\CreateWatchRequest' => $vendorDir . '/google/apiclient-services/src/Forms/CreateWatchRequest.php',
    'Google\\Service\\Forms\\DateQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/DateQuestion.php',
    'Google\\Service\\Forms\\DeleteItemRequest' => $vendorDir . '/google/apiclient-services/src/Forms/DeleteItemRequest.php',
    'Google\\Service\\Forms\\ExtraMaterial' => $vendorDir . '/google/apiclient-services/src/Forms/ExtraMaterial.php',
    'Google\\Service\\Forms\\Feedback' => $vendorDir . '/google/apiclient-services/src/Forms/Feedback.php',
    'Google\\Service\\Forms\\FileUploadAnswer' => $vendorDir . '/google/apiclient-services/src/Forms/FileUploadAnswer.php',
    'Google\\Service\\Forms\\FileUploadAnswers' => $vendorDir . '/google/apiclient-services/src/Forms/FileUploadAnswers.php',
    'Google\\Service\\Forms\\FileUploadQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/FileUploadQuestion.php',
    'Google\\Service\\Forms\\Form' => $vendorDir . '/google/apiclient-services/src/Forms/Form.php',
    'Google\\Service\\Forms\\FormResponse' => $vendorDir . '/google/apiclient-services/src/Forms/FormResponse.php',
    'Google\\Service\\Forms\\FormSettings' => $vendorDir . '/google/apiclient-services/src/Forms/FormSettings.php',
    'Google\\Service\\Forms\\FormsEmpty' => $vendorDir . '/google/apiclient-services/src/Forms/FormsEmpty.php',
    'Google\\Service\\Forms\\Grade' => $vendorDir . '/google/apiclient-services/src/Forms/Grade.php',
    'Google\\Service\\Forms\\Grading' => $vendorDir . '/google/apiclient-services/src/Forms/Grading.php',
    'Google\\Service\\Forms\\Grid' => $vendorDir . '/google/apiclient-services/src/Forms/Grid.php',
    'Google\\Service\\Forms\\Image' => $vendorDir . '/google/apiclient-services/src/Forms/Image.php',
    'Google\\Service\\Forms\\ImageItem' => $vendorDir . '/google/apiclient-services/src/Forms/ImageItem.php',
    'Google\\Service\\Forms\\Info' => $vendorDir . '/google/apiclient-services/src/Forms/Info.php',
    'Google\\Service\\Forms\\Item' => $vendorDir . '/google/apiclient-services/src/Forms/Item.php',
    'Google\\Service\\Forms\\ListFormResponsesResponse' => $vendorDir . '/google/apiclient-services/src/Forms/ListFormResponsesResponse.php',
    'Google\\Service\\Forms\\ListWatchesResponse' => $vendorDir . '/google/apiclient-services/src/Forms/ListWatchesResponse.php',
    'Google\\Service\\Forms\\Location' => $vendorDir . '/google/apiclient-services/src/Forms/Location.php',
    'Google\\Service\\Forms\\MediaProperties' => $vendorDir . '/google/apiclient-services/src/Forms/MediaProperties.php',
    'Google\\Service\\Forms\\MoveItemRequest' => $vendorDir . '/google/apiclient-services/src/Forms/MoveItemRequest.php',
    'Google\\Service\\Forms\\Option' => $vendorDir . '/google/apiclient-services/src/Forms/Option.php',
    'Google\\Service\\Forms\\PageBreakItem' => $vendorDir . '/google/apiclient-services/src/Forms/PageBreakItem.php',
    'Google\\Service\\Forms\\Question' => $vendorDir . '/google/apiclient-services/src/Forms/Question.php',
    'Google\\Service\\Forms\\QuestionGroupItem' => $vendorDir . '/google/apiclient-services/src/Forms/QuestionGroupItem.php',
    'Google\\Service\\Forms\\QuestionItem' => $vendorDir . '/google/apiclient-services/src/Forms/QuestionItem.php',
    'Google\\Service\\Forms\\QuizSettings' => $vendorDir . '/google/apiclient-services/src/Forms/QuizSettings.php',
    'Google\\Service\\Forms\\RenewWatchRequest' => $vendorDir . '/google/apiclient-services/src/Forms/RenewWatchRequest.php',
    'Google\\Service\\Forms\\Request' => $vendorDir . '/google/apiclient-services/src/Forms/Request.php',
    'Google\\Service\\Forms\\Resource\\Forms' => $vendorDir . '/google/apiclient-services/src/Forms/Resource/Forms.php',
    'Google\\Service\\Forms\\Resource\\FormsResponses' => $vendorDir . '/google/apiclient-services/src/Forms/Resource/FormsResponses.php',
    'Google\\Service\\Forms\\Resource\\FormsWatches' => $vendorDir . '/google/apiclient-services/src/Forms/Resource/FormsWatches.php',
    'Google\\Service\\Forms\\Response' => $vendorDir . '/google/apiclient-services/src/Forms/Response.php',
    'Google\\Service\\Forms\\RowQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/RowQuestion.php',
    'Google\\Service\\Forms\\ScaleQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/ScaleQuestion.php',
    'Google\\Service\\Forms\\TextAnswer' => $vendorDir . '/google/apiclient-services/src/Forms/TextAnswer.php',
    'Google\\Service\\Forms\\TextAnswers' => $vendorDir . '/google/apiclient-services/src/Forms/TextAnswers.php',
    'Google\\Service\\Forms\\TextItem' => $vendorDir . '/google/apiclient-services/src/Forms/TextItem.php',
    'Google\\Service\\Forms\\TextLink' => $vendorDir . '/google/apiclient-services/src/Forms/TextLink.php',
    'Google\\Service\\Forms\\TextQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/TextQuestion.php',
    'Google\\Service\\Forms\\TimeQuestion' => $vendorDir . '/google/apiclient-services/src/Forms/TimeQuestion.php',
    'Google\\Service\\Forms\\UpdateFormInfoRequest' => $vendorDir . '/google/apiclient-services/src/Forms/UpdateFormInfoRequest.php',
    'Google\\Service\\Forms\\UpdateItemRequest' => $vendorDir . '/google/apiclient-services/src/Forms/UpdateItemRequest.php',
    'Google\\Service\\Forms\\UpdateSettingsRequest' => $vendorDir . '/google/apiclient-services/src/Forms/UpdateSettingsRequest.php',
    'Google\\Service\\Forms\\Video' => $vendorDir . '/google/apiclient-services/src/Forms/Video.php',
    'Google\\Service\\Forms\\VideoItem' => $vendorDir . '/google/apiclient-services/src/Forms/VideoItem.php',
    'Google\\Service\\Forms\\VideoLink' => $vendorDir . '/google/apiclient-services/src/Forms/VideoLink.php',
    'Google\\Service\\Forms\\Watch' => $vendorDir . '/google/apiclient-services/src/Forms/Watch.php',
    'Google\\Service\\Forms\\WatchTarget' => $vendorDir . '/google/apiclient-services/src/Forms/WatchTarget.php',
    'Google\\Service\\Forms\\WriteControl' => $vendorDir . '/google/apiclient-services/src/Forms/WriteControl.php',
    'Google\\Service\\GKEHub' => $vendorDir . '/google/apiclient-services/src/GKEHub.php',
    'Google\\Service\\GKEHub\\AnthosVMMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/AnthosVMMembershipSpec.php',
    'Google\\Service\\GKEHub\\AnthosVMMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/AnthosVMMembershipState.php',
    'Google\\Service\\GKEHub\\AnthosVMSubFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/AnthosVMSubFeatureSpec.php',
    'Google\\Service\\GKEHub\\AnthosVMSubFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/AnthosVMSubFeatureState.php',
    'Google\\Service\\GKEHub\\AppDevExperienceFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/AppDevExperienceFeatureSpec.php',
    'Google\\Service\\GKEHub\\AppDevExperienceFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/AppDevExperienceFeatureState.php',
    'Google\\Service\\GKEHub\\ApplianceCluster' => $vendorDir . '/google/apiclient-services/src/GKEHub/ApplianceCluster.php',
    'Google\\Service\\GKEHub\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/AuditConfig.php',
    'Google\\Service\\GKEHub\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/AuditLogConfig.php',
    'Google\\Service\\GKEHub\\Authority' => $vendorDir . '/google/apiclient-services/src/GKEHub/Authority.php',
    'Google\\Service\\GKEHub\\BinaryAuthorizationConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/BinaryAuthorizationConfig.php',
    'Google\\Service\\GKEHub\\Binding' => $vendorDir . '/google/apiclient-services/src/GKEHub/Binding.php',
    'Google\\Service\\GKEHub\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/GKEHub/CancelOperationRequest.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeFleetSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeFleetSpec.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeFleetState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeFleetState.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeGKEUpgrade' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeGKEUpgrade.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeGKEUpgradeFeatureCondition' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeGKEUpgradeFeatureCondition.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeGKEUpgradeFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeGKEUpgradeFeatureState.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeGKEUpgradeOverride' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeGKEUpgradeOverride.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeGKEUpgradeState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeGKEUpgradeState.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeIgnoredMembership' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeIgnoredMembership.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeMembershipGKEUpgradeState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeMembershipGKEUpgradeState.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeMembershipState.php',
    'Google\\Service\\GKEHub\\ClusterUpgradePostConditions' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradePostConditions.php',
    'Google\\Service\\GKEHub\\ClusterUpgradeUpgradeStatus' => $vendorDir . '/google/apiclient-services/src/GKEHub/ClusterUpgradeUpgradeStatus.php',
    'Google\\Service\\GKEHub\\CommonFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/CommonFeatureSpec.php',
    'Google\\Service\\GKEHub\\CommonFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/CommonFeatureState.php',
    'Google\\Service\\GKEHub\\CommonFleetDefaultMemberConfigSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/CommonFleetDefaultMemberConfigSpec.php',
    'Google\\Service\\GKEHub\\ConfigManagementConfigSync' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementConfigSync.php',
    'Google\\Service\\GKEHub\\ConfigManagementConfigSyncDeploymentState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementConfigSyncDeploymentState.php',
    'Google\\Service\\GKEHub\\ConfigManagementConfigSyncError' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementConfigSyncError.php',
    'Google\\Service\\GKEHub\\ConfigManagementConfigSyncState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementConfigSyncState.php',
    'Google\\Service\\GKEHub\\ConfigManagementConfigSyncVersion' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementConfigSyncVersion.php',
    'Google\\Service\\GKEHub\\ConfigManagementContainerResourceRequirements' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementContainerResourceRequirements.php',
    'Google\\Service\\GKEHub\\ConfigManagementErrorResource' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementErrorResource.php',
    'Google\\Service\\GKEHub\\ConfigManagementGatekeeperDeploymentState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementGatekeeperDeploymentState.php',
    'Google\\Service\\GKEHub\\ConfigManagementGitConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementGitConfig.php',
    'Google\\Service\\GKEHub\\ConfigManagementGroupVersionKind' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementGroupVersionKind.php',
    'Google\\Service\\GKEHub\\ConfigManagementHierarchyControllerConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementHierarchyControllerConfig.php',
    'Google\\Service\\GKEHub\\ConfigManagementHierarchyControllerDeploymentState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementHierarchyControllerDeploymentState.php',
    'Google\\Service\\GKEHub\\ConfigManagementHierarchyControllerState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementHierarchyControllerState.php',
    'Google\\Service\\GKEHub\\ConfigManagementHierarchyControllerVersion' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementHierarchyControllerVersion.php',
    'Google\\Service\\GKEHub\\ConfigManagementInstallError' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementInstallError.php',
    'Google\\Service\\GKEHub\\ConfigManagementManaged' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementManaged.php',
    'Google\\Service\\GKEHub\\ConfigManagementMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementMembershipSpec.php',
    'Google\\Service\\GKEHub\\ConfigManagementMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementMembershipState.php',
    'Google\\Service\\GKEHub\\ConfigManagementOciConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementOciConfig.php',
    'Google\\Service\\GKEHub\\ConfigManagementOperatorState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementOperatorState.php',
    'Google\\Service\\GKEHub\\ConfigManagementPolicyController' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementPolicyController.php',
    'Google\\Service\\GKEHub\\ConfigManagementPolicyControllerMigration' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementPolicyControllerMigration.php',
    'Google\\Service\\GKEHub\\ConfigManagementPolicyControllerMonitoring' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementPolicyControllerMonitoring.php',
    'Google\\Service\\GKEHub\\ConfigManagementPolicyControllerState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementPolicyControllerState.php',
    'Google\\Service\\GKEHub\\ConfigManagementPolicyControllerVersion' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementPolicyControllerVersion.php',
    'Google\\Service\\GKEHub\\ConfigManagementQuantity' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementQuantity.php',
    'Google\\Service\\GKEHub\\ConfigManagementSyncError' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementSyncError.php',
    'Google\\Service\\GKEHub\\ConfigManagementSyncState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConfigManagementSyncState.php',
    'Google\\Service\\GKEHub\\ConnectAgentResource' => $vendorDir . '/google/apiclient-services/src/GKEHub/ConnectAgentResource.php',
    'Google\\Service\\GKEHub\\DataplaneV2FeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/DataplaneV2FeatureSpec.php',
    'Google\\Service\\GKEHub\\DefaultClusterConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/DefaultClusterConfig.php',
    'Google\\Service\\GKEHub\\EdgeCluster' => $vendorDir . '/google/apiclient-services/src/GKEHub/EdgeCluster.php',
    'Google\\Service\\GKEHub\\Expr' => $vendorDir . '/google/apiclient-services/src/GKEHub/Expr.php',
    'Google\\Service\\GKEHub\\Feature' => $vendorDir . '/google/apiclient-services/src/GKEHub/Feature.php',
    'Google\\Service\\GKEHub\\FeatureResourceState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FeatureResourceState.php',
    'Google\\Service\\GKEHub\\FeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FeatureState.php',
    'Google\\Service\\GKEHub\\Fleet' => $vendorDir . '/google/apiclient-services/src/GKEHub/Fleet.php',
    'Google\\Service\\GKEHub\\FleetLifecycleState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetLifecycleState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFeatureError' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFeatureError.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFeatureSpec.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFeatureState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFleetObservabilityBaseFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFleetObservabilityBaseFeatureState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFleetObservabilityLoggingState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFleetObservabilityLoggingState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityFleetObservabilityMonitoringState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityFleetObservabilityMonitoringState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityLoggingConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityLoggingConfig.php',
    'Google\\Service\\GKEHub\\FleetObservabilityMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityMembershipSpec.php',
    'Google\\Service\\GKEHub\\FleetObservabilityMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityMembershipState.php',
    'Google\\Service\\GKEHub\\FleetObservabilityRoutingConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/FleetObservabilityRoutingConfig.php',
    'Google\\Service\\GKEHub\\GenerateConnectManifestResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/GenerateConnectManifestResponse.php',
    'Google\\Service\\GKEHub\\GenerateMembershipRBACRoleBindingYAMLResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/GenerateMembershipRBACRoleBindingYAMLResponse.php',
    'Google\\Service\\GKEHub\\GkeCluster' => $vendorDir . '/google/apiclient-services/src/GKEHub/GkeCluster.php',
    'Google\\Service\\GKEHub\\GkehubEmpty' => $vendorDir . '/google/apiclient-services/src/GKEHub/GkehubEmpty.php',
    'Google\\Service\\GKEHub\\GkehubNamespace' => $vendorDir . '/google/apiclient-services/src/GKEHub/GkehubNamespace.php',
    'Google\\Service\\GKEHub\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/GKEHub/GoogleRpcStatus.php',
    'Google\\Service\\GKEHub\\IdentityServiceAuthMethod' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceAuthMethod.php',
    'Google\\Service\\GKEHub\\IdentityServiceAzureADConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceAzureADConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceGoogleConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceGoogleConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceGroupConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceGroupConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceIdentityServiceOptions' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceIdentityServiceOptions.php',
    'Google\\Service\\GKEHub\\IdentityServiceLdapConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceLdapConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceMembershipSpec.php',
    'Google\\Service\\GKEHub\\IdentityServiceMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceMembershipState.php',
    'Google\\Service\\GKEHub\\IdentityServiceOidcConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceOidcConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceSamlConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceSamlConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceServerConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceServerConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceServiceAccountConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceServiceAccountConfig.php',
    'Google\\Service\\GKEHub\\IdentityServiceSimpleBindCredentials' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceSimpleBindCredentials.php',
    'Google\\Service\\GKEHub\\IdentityServiceUserConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/IdentityServiceUserConfig.php',
    'Google\\Service\\GKEHub\\KubernetesMetadata' => $vendorDir . '/google/apiclient-services/src/GKEHub/KubernetesMetadata.php',
    'Google\\Service\\GKEHub\\KubernetesResource' => $vendorDir . '/google/apiclient-services/src/GKEHub/KubernetesResource.php',
    'Google\\Service\\GKEHub\\ListBoundMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListBoundMembershipsResponse.php',
    'Google\\Service\\GKEHub\\ListFeaturesResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListFeaturesResponse.php',
    'Google\\Service\\GKEHub\\ListFleetsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListFleetsResponse.php',
    'Google\\Service\\GKEHub\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListLocationsResponse.php',
    'Google\\Service\\GKEHub\\ListMembershipBindingsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListMembershipBindingsResponse.php',
    'Google\\Service\\GKEHub\\ListMembershipRBACRoleBindingsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListMembershipRBACRoleBindingsResponse.php',
    'Google\\Service\\GKEHub\\ListMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListMembershipsResponse.php',
    'Google\\Service\\GKEHub\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListOperationsResponse.php',
    'Google\\Service\\GKEHub\\ListPermittedScopesResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListPermittedScopesResponse.php',
    'Google\\Service\\GKEHub\\ListScopeNamespacesResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListScopeNamespacesResponse.php',
    'Google\\Service\\GKEHub\\ListScopeRBACRoleBindingsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListScopeRBACRoleBindingsResponse.php',
    'Google\\Service\\GKEHub\\ListScopesResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/ListScopesResponse.php',
    'Google\\Service\\GKEHub\\LocalControllerState' => $vendorDir . '/google/apiclient-services/src/GKEHub/LocalControllerState.php',
    'Google\\Service\\GKEHub\\Location' => $vendorDir . '/google/apiclient-services/src/GKEHub/Location.php',
    'Google\\Service\\GKEHub\\Membership' => $vendorDir . '/google/apiclient-services/src/GKEHub/Membership.php',
    'Google\\Service\\GKEHub\\MembershipBinding' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipBinding.php',
    'Google\\Service\\GKEHub\\MembershipBindingLifecycleState' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipBindingLifecycleState.php',
    'Google\\Service\\GKEHub\\MembershipEndpoint' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipEndpoint.php',
    'Google\\Service\\GKEHub\\MembershipFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipFeatureSpec.php',
    'Google\\Service\\GKEHub\\MembershipFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipFeatureState.php',
    'Google\\Service\\GKEHub\\MembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/MembershipState.php',
    'Google\\Service\\GKEHub\\MigrateSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/MigrateSpec.php',
    'Google\\Service\\GKEHub\\MigrateState' => $vendorDir . '/google/apiclient-services/src/GKEHub/MigrateState.php',
    'Google\\Service\\GKEHub\\MonitoringConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/MonitoringConfig.php',
    'Google\\Service\\GKEHub\\MultiCloudCluster' => $vendorDir . '/google/apiclient-services/src/GKEHub/MultiCloudCluster.php',
    'Google\\Service\\GKEHub\\MultiClusterIngressFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/MultiClusterIngressFeatureSpec.php',
    'Google\\Service\\GKEHub\\NamespaceLifecycleState' => $vendorDir . '/google/apiclient-services/src/GKEHub/NamespaceLifecycleState.php',
    'Google\\Service\\GKEHub\\OnPremCluster' => $vendorDir . '/google/apiclient-services/src/GKEHub/OnPremCluster.php',
    'Google\\Service\\GKEHub\\Operation' => $vendorDir . '/google/apiclient-services/src/GKEHub/Operation.php',
    'Google\\Service\\GKEHub\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/GKEHub/OperationMetadata.php',
    'Google\\Service\\GKEHub\\Origin' => $vendorDir . '/google/apiclient-services/src/GKEHub/Origin.php',
    'Google\\Service\\GKEHub\\Policy' => $vendorDir . '/google/apiclient-services/src/GKEHub/Policy.php',
    'Google\\Service\\GKEHub\\PolicyBinding' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyBinding.php',
    'Google\\Service\\GKEHub\\PolicyControllerBundleInstallSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerBundleInstallSpec.php',
    'Google\\Service\\GKEHub\\PolicyControllerHubConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerHubConfig.php',
    'Google\\Service\\GKEHub\\PolicyControllerMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerMembershipSpec.php',
    'Google\\Service\\GKEHub\\PolicyControllerMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerMembershipState.php',
    'Google\\Service\\GKEHub\\PolicyControllerMonitoringConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerMonitoringConfig.php',
    'Google\\Service\\GKEHub\\PolicyControllerOnClusterState' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerOnClusterState.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyContentSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyContentSpec.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyContentState' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyContentState.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyControllerDeploymentConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyControllerDeploymentConfig.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyControllerHubConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyControllerHubConfig.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyControllerHubState' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyControllerHubState.php',
    'Google\\Service\\GKEHub\\PolicyControllerPolicyControllerHubVersion' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerPolicyControllerHubVersion.php',
    'Google\\Service\\GKEHub\\PolicyControllerResourceList' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerResourceList.php',
    'Google\\Service\\GKEHub\\PolicyControllerResourceRequirements' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerResourceRequirements.php',
    'Google\\Service\\GKEHub\\PolicyControllerTemplateLibraryConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerTemplateLibraryConfig.php',
    'Google\\Service\\GKEHub\\PolicyControllerToleration' => $vendorDir . '/google/apiclient-services/src/GKEHub/PolicyControllerToleration.php',
    'Google\\Service\\GKEHub\\RBACRoleBinding' => $vendorDir . '/google/apiclient-services/src/GKEHub/RBACRoleBinding.php',
    'Google\\Service\\GKEHub\\RBACRoleBindingLifecycleState' => $vendorDir . '/google/apiclient-services/src/GKEHub/RBACRoleBindingLifecycleState.php',
    'Google\\Service\\GKEHub\\ResourceManifest' => $vendorDir . '/google/apiclient-services/src/GKEHub/ResourceManifest.php',
    'Google\\Service\\GKEHub\\ResourceOptions' => $vendorDir . '/google/apiclient-services/src/GKEHub/ResourceOptions.php',
    'Google\\Service\\GKEHub\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/Organizations.php',
    'Google\\Service\\GKEHub\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/OrganizationsLocations.php',
    'Google\\Service\\GKEHub\\Resource\\OrganizationsLocationsFleets' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/OrganizationsLocationsFleets.php',
    'Google\\Service\\GKEHub\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/Projects.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocations.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsFeatures' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsFeatures.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsFleets' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsFleets.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsMemberships' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsMemberships.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsMembershipsBindings' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsMembershipsBindings.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsMembershipsRbacrolebindings' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsMembershipsRbacrolebindings.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsScopes' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsScopes.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsScopesNamespaces' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsScopesNamespaces.php',
    'Google\\Service\\GKEHub\\Resource\\ProjectsLocationsScopesRbacrolebindings' => $vendorDir . '/google/apiclient-services/src/GKEHub/Resource/ProjectsLocationsScopesRbacrolebindings.php',
    'Google\\Service\\GKEHub\\Role' => $vendorDir . '/google/apiclient-services/src/GKEHub/Role.php',
    'Google\\Service\\GKEHub\\Scope' => $vendorDir . '/google/apiclient-services/src/GKEHub/Scope.php',
    'Google\\Service\\GKEHub\\ScopeFeatureSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/ScopeFeatureSpec.php',
    'Google\\Service\\GKEHub\\ScopeFeatureState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ScopeFeatureState.php',
    'Google\\Service\\GKEHub\\ScopeLifecycleState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ScopeLifecycleState.php',
    'Google\\Service\\GKEHub\\SecurityPostureConfig' => $vendorDir . '/google/apiclient-services/src/GKEHub/SecurityPostureConfig.php',
    'Google\\Service\\GKEHub\\ServiceMeshCondition' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshCondition.php',
    'Google\\Service\\GKEHub\\ServiceMeshControlPlaneManagement' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshControlPlaneManagement.php',
    'Google\\Service\\GKEHub\\ServiceMeshDataPlaneManagement' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshDataPlaneManagement.php',
    'Google\\Service\\GKEHub\\ServiceMeshMembershipSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshMembershipSpec.php',
    'Google\\Service\\GKEHub\\ServiceMeshMembershipState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshMembershipState.php',
    'Google\\Service\\GKEHub\\ServiceMeshSpec' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshSpec.php',
    'Google\\Service\\GKEHub\\ServiceMeshState' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshState.php',
    'Google\\Service\\GKEHub\\ServiceMeshStatusDetails' => $vendorDir . '/google/apiclient-services/src/GKEHub/ServiceMeshStatusDetails.php',
    'Google\\Service\\GKEHub\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/GKEHub/SetIamPolicyRequest.php',
    'Google\\Service\\GKEHub\\Status' => $vendorDir . '/google/apiclient-services/src/GKEHub/Status.php',
    'Google\\Service\\GKEHub\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/GKEHub/TestIamPermissionsRequest.php',
    'Google\\Service\\GKEHub\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/GKEHub/TestIamPermissionsResponse.php',
    'Google\\Service\\GKEHub\\TypeMeta' => $vendorDir . '/google/apiclient-services/src/GKEHub/TypeMeta.php',
    'Google\\Service\\GKEOnPrem' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem.php',
    'Google\\Service\\GKEOnPrem\\Authorization' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Authorization.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminApiServerArgument' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminApiServerArgument.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminCluster' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminCluster.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminClusterOperationsConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminClusterOperationsConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminControlPlaneConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminControlPlaneConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminControlPlaneNodePoolConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminControlPlaneNodePoolConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminDrainedMachine' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminDrainedMachine.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminDrainingMachine' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminDrainingMachine.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminIslandModeCidrConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminIslandModeCidrConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminLoadBalancerConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminLoadBalancerConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminMachineDrainStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminMachineDrainStatus.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminMaintenanceConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminMaintenanceConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminMaintenanceStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminMaintenanceStatus.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminManualLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminManualLbConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminNetworkConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminNetworkConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminNodeAccessConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminNodeAccessConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminOsEnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminOsEnvironmentConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminPortConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminPortConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminProxyConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminProxyConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminSecurityConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminSecurityConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminStorageConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminStorageConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminVipConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminVipConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalAdminWorkloadNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalAdminWorkloadNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalApiServerArgument' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalApiServerArgument.php',
    'Google\\Service\\GKEOnPrem\\BareMetalBgpLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalBgpLbConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalBgpPeerConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalBgpPeerConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalCluster' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalCluster.php',
    'Google\\Service\\GKEOnPrem\\BareMetalClusterOperationsConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalClusterOperationsConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalClusterUpgradePolicy' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalClusterUpgradePolicy.php',
    'Google\\Service\\GKEOnPrem\\BareMetalControlPlaneConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalControlPlaneConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalControlPlaneNodePoolConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalControlPlaneNodePoolConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalDrainedMachine' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalDrainedMachine.php',
    'Google\\Service\\GKEOnPrem\\BareMetalDrainingMachine' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalDrainingMachine.php',
    'Google\\Service\\GKEOnPrem\\BareMetalIslandModeCidrConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalIslandModeCidrConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalKubeletConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalKubeletConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalLoadBalancerAddressPool' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalLoadBalancerAddressPool.php',
    'Google\\Service\\GKEOnPrem\\BareMetalLoadBalancerConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalLoadBalancerConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalLoadBalancerNodePoolConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalLoadBalancerNodePoolConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalLvpConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalLvpConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalLvpShareConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalLvpShareConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalMachineDrainStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalMachineDrainStatus.php',
    'Google\\Service\\GKEOnPrem\\BareMetalMaintenanceConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalMaintenanceConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalMaintenanceStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalMaintenanceStatus.php',
    'Google\\Service\\GKEOnPrem\\BareMetalManualLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalManualLbConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalMetalLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalMetalLbConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalMultipleNetworkInterfacesConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalMultipleNetworkInterfacesConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNetworkConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNetworkConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNodeAccessConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNodeAccessConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNodePool' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNodePool.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNodePoolConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNodePoolConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalNodePoolUpgradePolicy' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalNodePoolUpgradePolicy.php',
    'Google\\Service\\GKEOnPrem\\BareMetalOsEnvironmentConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalOsEnvironmentConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalParallelUpgradeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalParallelUpgradeConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalPortConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalPortConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalProxyConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalProxyConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalSecurityConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalSecurityConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalSrIovConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalSrIovConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalStorageConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalStorageConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalVersionInfo' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalVersionInfo.php',
    'Google\\Service\\GKEOnPrem\\BareMetalVipConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalVipConfig.php',
    'Google\\Service\\GKEOnPrem\\BareMetalWorkloadNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BareMetalWorkloadNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\BinaryAuthorization' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/BinaryAuthorization.php',
    'Google\\Service\\GKEOnPrem\\Binding' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Binding.php',
    'Google\\Service\\GKEOnPrem\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/CancelOperationRequest.php',
    'Google\\Service\\GKEOnPrem\\ClusterUser' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ClusterUser.php',
    'Google\\Service\\GKEOnPrem\\EnrollBareMetalAdminClusterRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollBareMetalAdminClusterRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollBareMetalClusterRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollBareMetalClusterRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollBareMetalNodePoolRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollBareMetalNodePoolRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollBareMetalStandaloneNodePoolRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollBareMetalStandaloneNodePoolRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollVmwareAdminClusterRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollVmwareAdminClusterRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollVmwareClusterRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollVmwareClusterRequest.php',
    'Google\\Service\\GKEOnPrem\\EnrollVmwareNodePoolRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/EnrollVmwareNodePoolRequest.php',
    'Google\\Service\\GKEOnPrem\\Expr' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Expr.php',
    'Google\\Service\\GKEOnPrem\\Fleet' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Fleet.php',
    'Google\\Service\\GKEOnPrem\\GkeonpremEmpty' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/GkeonpremEmpty.php',
    'Google\\Service\\GKEOnPrem\\ListBareMetalAdminClustersResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListBareMetalAdminClustersResponse.php',
    'Google\\Service\\GKEOnPrem\\ListBareMetalClustersResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListBareMetalClustersResponse.php',
    'Google\\Service\\GKEOnPrem\\ListBareMetalNodePoolsResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListBareMetalNodePoolsResponse.php',
    'Google\\Service\\GKEOnPrem\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListLocationsResponse.php',
    'Google\\Service\\GKEOnPrem\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListOperationsResponse.php',
    'Google\\Service\\GKEOnPrem\\ListVmwareAdminClustersResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListVmwareAdminClustersResponse.php',
    'Google\\Service\\GKEOnPrem\\ListVmwareClustersResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListVmwareClustersResponse.php',
    'Google\\Service\\GKEOnPrem\\ListVmwareNodePoolsResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ListVmwareNodePoolsResponse.php',
    'Google\\Service\\GKEOnPrem\\Location' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Location.php',
    'Google\\Service\\GKEOnPrem\\Metric' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Metric.php',
    'Google\\Service\\GKEOnPrem\\NodeTaint' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/NodeTaint.php',
    'Google\\Service\\GKEOnPrem\\Operation' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Operation.php',
    'Google\\Service\\GKEOnPrem\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/OperationMetadata.php',
    'Google\\Service\\GKEOnPrem\\OperationProgress' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/OperationProgress.php',
    'Google\\Service\\GKEOnPrem\\OperationStage' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/OperationStage.php',
    'Google\\Service\\GKEOnPrem\\Policy' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Policy.php',
    'Google\\Service\\GKEOnPrem\\QueryBareMetalAdminVersionConfigResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/QueryBareMetalAdminVersionConfigResponse.php',
    'Google\\Service\\GKEOnPrem\\QueryBareMetalVersionConfigResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/QueryBareMetalVersionConfigResponse.php',
    'Google\\Service\\GKEOnPrem\\QueryVmwareVersionConfigResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/QueryVmwareVersionConfigResponse.php',
    'Google\\Service\\GKEOnPrem\\ResourceCondition' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ResourceCondition.php',
    'Google\\Service\\GKEOnPrem\\ResourceStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ResourceStatus.php',
    'Google\\Service\\GKEOnPrem\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/Projects.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalAdminClusters' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalAdminClusters.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalAdminClustersOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalAdminClustersOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalClusters' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalClusters.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalClustersBareMetalNodePools' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalClustersBareMetalNodePools.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalClustersBareMetalNodePoolsOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalClustersBareMetalNodePoolsOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalClustersOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalClustersOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalStandaloneClusters' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalStandaloneClusters.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsBareMetalStandaloneClustersBareMetalStandaloneNodePools' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsBareMetalStandaloneClustersBareMetalStandaloneNodePools.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareAdminClusters' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareAdminClusters.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareAdminClustersOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareAdminClustersOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareClusters' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareClusters.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareClustersOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareClustersOperations.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareClustersVmwareNodePools' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareClustersVmwareNodePools.php',
    'Google\\Service\\GKEOnPrem\\Resource\\ProjectsLocationsVmwareClustersVmwareNodePoolsOperations' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Resource/ProjectsLocationsVmwareClustersVmwareNodePoolsOperations.php',
    'Google\\Service\\GKEOnPrem\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/SetIamPolicyRequest.php',
    'Google\\Service\\GKEOnPrem\\Status' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Status.php',
    'Google\\Service\\GKEOnPrem\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/TestIamPermissionsRequest.php',
    'Google\\Service\\GKEOnPrem\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/TestIamPermissionsResponse.php',
    'Google\\Service\\GKEOnPrem\\UpgradeDependency' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/UpgradeDependency.php',
    'Google\\Service\\GKEOnPrem\\ValidationCheck' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ValidationCheck.php',
    'Google\\Service\\GKEOnPrem\\ValidationCheckResult' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ValidationCheckResult.php',
    'Google\\Service\\GKEOnPrem\\ValidationCheckStatus' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/ValidationCheckStatus.php',
    'Google\\Service\\GKEOnPrem\\Version' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Version.php',
    'Google\\Service\\GKEOnPrem\\Versions' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/Versions.php',
    'Google\\Service\\GKEOnPrem\\VmwareAAGConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAAGConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAddressPool' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAddressPool.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminAddonNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminAddonNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminAuthorizationConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminAuthorizationConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminCluster' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminCluster.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminControlPlaneNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminControlPlaneNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminF5BigIpConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminF5BigIpConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminHAControlPlaneConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminHAControlPlaneConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminLoadBalancerConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminLoadBalancerConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminManualLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminManualLbConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminMetalLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminMetalLbConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminNetworkConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminNetworkConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminPreparedSecretsConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminPreparedSecretsConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminSeesawConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminSeesawConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminVCenterConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminVCenterConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAdminVipConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAdminVipConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAutoRepairConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAutoRepairConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareAutoResizeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareAutoResizeConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareBundleConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareBundleConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareCluster' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareCluster.php',
    'Google\\Service\\GKEOnPrem\\VmwareClusterUpgradePolicy' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareClusterUpgradePolicy.php',
    'Google\\Service\\GKEOnPrem\\VmwareControlPlaneNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareControlPlaneNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareControlPlaneV2Config' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareControlPlaneV2Config.php',
    'Google\\Service\\GKEOnPrem\\VmwareControlPlaneVsphereConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareControlPlaneVsphereConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareDataplaneV2Config' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareDataplaneV2Config.php',
    'Google\\Service\\GKEOnPrem\\VmwareDhcpIpConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareDhcpIpConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareF5BigIpConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareF5BigIpConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareHostConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareHostConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareHostIp' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareHostIp.php',
    'Google\\Service\\GKEOnPrem\\VmwareIpBlock' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareIpBlock.php',
    'Google\\Service\\GKEOnPrem\\VmwareLoadBalancerConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareLoadBalancerConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareManualLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareManualLbConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareMetalLbConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareMetalLbConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareNetworkConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareNetworkConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareNodeConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareNodeConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareNodePool' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareNodePool.php',
    'Google\\Service\\GKEOnPrem\\VmwareNodePoolAutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareNodePoolAutoscalingConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwarePlatformConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwarePlatformConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareSeesawConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareSeesawConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareStaticIpConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareStaticIpConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareStorageConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareStorageConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareVCenterConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareVCenterConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareVersionInfo' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareVersionInfo.php',
    'Google\\Service\\GKEOnPrem\\VmwareVipConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareVipConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareVsphereConfig' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareVsphereConfig.php',
    'Google\\Service\\GKEOnPrem\\VmwareVsphereTag' => $vendorDir . '/google/apiclient-services/src/GKEOnPrem/VmwareVsphereTag.php',
    'Google\\Service\\GameServices' => $vendorDir . '/google/apiclient-services/src/GameServices.php',
    'Google\\Service\\GameServices\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/AuditConfig.php',
    'Google\\Service\\GameServices\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/AuditLogConfig.php',
    'Google\\Service\\GameServices\\AuthorizationLoggingOptions' => $vendorDir . '/google/apiclient-services/src/GameServices/AuthorizationLoggingOptions.php',
    'Google\\Service\\GameServices\\Binding' => $vendorDir . '/google/apiclient-services/src/GameServices/Binding.php',
    'Google\\Service\\GameServices\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/GameServices/CancelOperationRequest.php',
    'Google\\Service\\GameServices\\CloudAuditOptions' => $vendorDir . '/google/apiclient-services/src/GameServices/CloudAuditOptions.php',
    'Google\\Service\\GameServices\\Condition' => $vendorDir . '/google/apiclient-services/src/GameServices/Condition.php',
    'Google\\Service\\GameServices\\CounterOptions' => $vendorDir . '/google/apiclient-services/src/GameServices/CounterOptions.php',
    'Google\\Service\\GameServices\\CustomField' => $vendorDir . '/google/apiclient-services/src/GameServices/CustomField.php',
    'Google\\Service\\GameServices\\DataAccessOptions' => $vendorDir . '/google/apiclient-services/src/GameServices/DataAccessOptions.php',
    'Google\\Service\\GameServices\\DeployedClusterState' => $vendorDir . '/google/apiclient-services/src/GameServices/DeployedClusterState.php',
    'Google\\Service\\GameServices\\DeployedFleet' => $vendorDir . '/google/apiclient-services/src/GameServices/DeployedFleet.php',
    'Google\\Service\\GameServices\\DeployedFleetAutoscaler' => $vendorDir . '/google/apiclient-services/src/GameServices/DeployedFleetAutoscaler.php',
    'Google\\Service\\GameServices\\DeployedFleetDetails' => $vendorDir . '/google/apiclient-services/src/GameServices/DeployedFleetDetails.php',
    'Google\\Service\\GameServices\\DeployedFleetStatus' => $vendorDir . '/google/apiclient-services/src/GameServices/DeployedFleetStatus.php',
    'Google\\Service\\GameServices\\Expr' => $vendorDir . '/google/apiclient-services/src/GameServices/Expr.php',
    'Google\\Service\\GameServices\\FetchDeploymentStateRequest' => $vendorDir . '/google/apiclient-services/src/GameServices/FetchDeploymentStateRequest.php',
    'Google\\Service\\GameServices\\FetchDeploymentStateResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/FetchDeploymentStateResponse.php',
    'Google\\Service\\GameServices\\FleetConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/FleetConfig.php',
    'Google\\Service\\GameServices\\GameServerCluster' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerCluster.php',
    'Google\\Service\\GameServices\\GameServerClusterConnectionInfo' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerClusterConnectionInfo.php',
    'Google\\Service\\GameServices\\GameServerConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerConfig.php',
    'Google\\Service\\GameServices\\GameServerConfigOverride' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerConfigOverride.php',
    'Google\\Service\\GameServices\\GameServerDeployment' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerDeployment.php',
    'Google\\Service\\GameServices\\GameServerDeploymentRollout' => $vendorDir . '/google/apiclient-services/src/GameServices/GameServerDeploymentRollout.php',
    'Google\\Service\\GameServices\\GameservicesEmpty' => $vendorDir . '/google/apiclient-services/src/GameServices/GameservicesEmpty.php',
    'Google\\Service\\GameServices\\GkeClusterReference' => $vendorDir . '/google/apiclient-services/src/GameServices/GkeClusterReference.php',
    'Google\\Service\\GameServices\\KubernetesClusterState' => $vendorDir . '/google/apiclient-services/src/GameServices/KubernetesClusterState.php',
    'Google\\Service\\GameServices\\LabelSelector' => $vendorDir . '/google/apiclient-services/src/GameServices/LabelSelector.php',
    'Google\\Service\\GameServices\\ListGameServerClustersResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListGameServerClustersResponse.php',
    'Google\\Service\\GameServices\\ListGameServerConfigsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListGameServerConfigsResponse.php',
    'Google\\Service\\GameServices\\ListGameServerDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListGameServerDeploymentsResponse.php',
    'Google\\Service\\GameServices\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListLocationsResponse.php',
    'Google\\Service\\GameServices\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListOperationsResponse.php',
    'Google\\Service\\GameServices\\ListRealmsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/ListRealmsResponse.php',
    'Google\\Service\\GameServices\\Location' => $vendorDir . '/google/apiclient-services/src/GameServices/Location.php',
    'Google\\Service\\GameServices\\LogConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/LogConfig.php',
    'Google\\Service\\GameServices\\Operation' => $vendorDir . '/google/apiclient-services/src/GameServices/Operation.php',
    'Google\\Service\\GameServices\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/GameServices/OperationMetadata.php',
    'Google\\Service\\GameServices\\OperationStatus' => $vendorDir . '/google/apiclient-services/src/GameServices/OperationStatus.php',
    'Google\\Service\\GameServices\\Policy' => $vendorDir . '/google/apiclient-services/src/GameServices/Policy.php',
    'Google\\Service\\GameServices\\PreviewCreateGameServerClusterResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/PreviewCreateGameServerClusterResponse.php',
    'Google\\Service\\GameServices\\PreviewDeleteGameServerClusterResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/PreviewDeleteGameServerClusterResponse.php',
    'Google\\Service\\GameServices\\PreviewGameServerDeploymentRolloutResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/PreviewGameServerDeploymentRolloutResponse.php',
    'Google\\Service\\GameServices\\PreviewRealmUpdateResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/PreviewRealmUpdateResponse.php',
    'Google\\Service\\GameServices\\PreviewUpdateGameServerClusterResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/PreviewUpdateGameServerClusterResponse.php',
    'Google\\Service\\GameServices\\Realm' => $vendorDir . '/google/apiclient-services/src/GameServices/Realm.php',
    'Google\\Service\\GameServices\\RealmSelector' => $vendorDir . '/google/apiclient-services/src/GameServices/RealmSelector.php',
    'Google\\Service\\GameServices\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/Projects.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocations.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocationsGameServerDeployments' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocationsGameServerDeployments.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocationsGameServerDeploymentsConfigs' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocationsGameServerDeploymentsConfigs.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocationsRealms' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocationsRealms.php',
    'Google\\Service\\GameServices\\Resource\\ProjectsLocationsRealmsGameServerClusters' => $vendorDir . '/google/apiclient-services/src/GameServices/Resource/ProjectsLocationsRealmsGameServerClusters.php',
    'Google\\Service\\GameServices\\Rule' => $vendorDir . '/google/apiclient-services/src/GameServices/Rule.php',
    'Google\\Service\\GameServices\\ScalingConfig' => $vendorDir . '/google/apiclient-services/src/GameServices/ScalingConfig.php',
    'Google\\Service\\GameServices\\Schedule' => $vendorDir . '/google/apiclient-services/src/GameServices/Schedule.php',
    'Google\\Service\\GameServices\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/GameServices/SetIamPolicyRequest.php',
    'Google\\Service\\GameServices\\SpecSource' => $vendorDir . '/google/apiclient-services/src/GameServices/SpecSource.php',
    'Google\\Service\\GameServices\\Status' => $vendorDir . '/google/apiclient-services/src/GameServices/Status.php',
    'Google\\Service\\GameServices\\TargetDetails' => $vendorDir . '/google/apiclient-services/src/GameServices/TargetDetails.php',
    'Google\\Service\\GameServices\\TargetFleet' => $vendorDir . '/google/apiclient-services/src/GameServices/TargetFleet.php',
    'Google\\Service\\GameServices\\TargetFleetAutoscaler' => $vendorDir . '/google/apiclient-services/src/GameServices/TargetFleetAutoscaler.php',
    'Google\\Service\\GameServices\\TargetFleetDetails' => $vendorDir . '/google/apiclient-services/src/GameServices/TargetFleetDetails.php',
    'Google\\Service\\GameServices\\TargetState' => $vendorDir . '/google/apiclient-services/src/GameServices/TargetState.php',
    'Google\\Service\\GameServices\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/GameServices/TestIamPermissionsRequest.php',
    'Google\\Service\\GameServices\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/GameServices/TestIamPermissionsResponse.php',
    'Google\\Service\\Games' => $vendorDir . '/google/apiclient-services/src/Games.php',
    'Google\\Service\\GamesConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration.php',
    'Google\\Service\\GamesConfiguration\\AchievementConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/AchievementConfiguration.php',
    'Google\\Service\\GamesConfiguration\\AchievementConfigurationDetail' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/AchievementConfigurationDetail.php',
    'Google\\Service\\GamesConfiguration\\AchievementConfigurationListResponse' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/AchievementConfigurationListResponse.php',
    'Google\\Service\\GamesConfiguration\\GamesNumberAffixConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/GamesNumberAffixConfiguration.php',
    'Google\\Service\\GamesConfiguration\\GamesNumberFormatConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/GamesNumberFormatConfiguration.php',
    'Google\\Service\\GamesConfiguration\\ImageConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/ImageConfiguration.php',
    'Google\\Service\\GamesConfiguration\\LeaderboardConfiguration' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/LeaderboardConfiguration.php',
    'Google\\Service\\GamesConfiguration\\LeaderboardConfigurationDetail' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/LeaderboardConfigurationDetail.php',
    'Google\\Service\\GamesConfiguration\\LeaderboardConfigurationListResponse' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/LeaderboardConfigurationListResponse.php',
    'Google\\Service\\GamesConfiguration\\LocalizedString' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/LocalizedString.php',
    'Google\\Service\\GamesConfiguration\\LocalizedStringBundle' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/LocalizedStringBundle.php',
    'Google\\Service\\GamesConfiguration\\Resource\\AchievementConfigurations' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/Resource/AchievementConfigurations.php',
    'Google\\Service\\GamesConfiguration\\Resource\\ImageConfigurations' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/Resource/ImageConfigurations.php',
    'Google\\Service\\GamesConfiguration\\Resource\\LeaderboardConfigurations' => $vendorDir . '/google/apiclient-services/src/GamesConfiguration/Resource/LeaderboardConfigurations.php',
    'Google\\Service\\GamesManagement' => $vendorDir . '/google/apiclient-services/src/GamesManagement.php',
    'Google\\Service\\GamesManagement\\AchievementResetAllResponse' => $vendorDir . '/google/apiclient-services/src/GamesManagement/AchievementResetAllResponse.php',
    'Google\\Service\\GamesManagement\\AchievementResetMultipleForAllRequest' => $vendorDir . '/google/apiclient-services/src/GamesManagement/AchievementResetMultipleForAllRequest.php',
    'Google\\Service\\GamesManagement\\AchievementResetResponse' => $vendorDir . '/google/apiclient-services/src/GamesManagement/AchievementResetResponse.php',
    'Google\\Service\\GamesManagement\\EventsResetMultipleForAllRequest' => $vendorDir . '/google/apiclient-services/src/GamesManagement/EventsResetMultipleForAllRequest.php',
    'Google\\Service\\GamesManagement\\GamesPlayerExperienceInfoResource' => $vendorDir . '/google/apiclient-services/src/GamesManagement/GamesPlayerExperienceInfoResource.php',
    'Google\\Service\\GamesManagement\\GamesPlayerLevelResource' => $vendorDir . '/google/apiclient-services/src/GamesManagement/GamesPlayerLevelResource.php',
    'Google\\Service\\GamesManagement\\HiddenPlayer' => $vendorDir . '/google/apiclient-services/src/GamesManagement/HiddenPlayer.php',
    'Google\\Service\\GamesManagement\\HiddenPlayerList' => $vendorDir . '/google/apiclient-services/src/GamesManagement/HiddenPlayerList.php',
    'Google\\Service\\GamesManagement\\Player' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Player.php',
    'Google\\Service\\GamesManagement\\PlayerName' => $vendorDir . '/google/apiclient-services/src/GamesManagement/PlayerName.php',
    'Google\\Service\\GamesManagement\\PlayerScoreResetAllResponse' => $vendorDir . '/google/apiclient-services/src/GamesManagement/PlayerScoreResetAllResponse.php',
    'Google\\Service\\GamesManagement\\PlayerScoreResetResponse' => $vendorDir . '/google/apiclient-services/src/GamesManagement/PlayerScoreResetResponse.php',
    'Google\\Service\\GamesManagement\\ProfileSettings' => $vendorDir . '/google/apiclient-services/src/GamesManagement/ProfileSettings.php',
    'Google\\Service\\GamesManagement\\Resource\\Achievements' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Resource/Achievements.php',
    'Google\\Service\\GamesManagement\\Resource\\Applications' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Resource/Applications.php',
    'Google\\Service\\GamesManagement\\Resource\\Events' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Resource/Events.php',
    'Google\\Service\\GamesManagement\\Resource\\Players' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Resource/Players.php',
    'Google\\Service\\GamesManagement\\Resource\\Scores' => $vendorDir . '/google/apiclient-services/src/GamesManagement/Resource/Scores.php',
    'Google\\Service\\GamesManagement\\ScoresResetMultipleForAllRequest' => $vendorDir . '/google/apiclient-services/src/GamesManagement/ScoresResetMultipleForAllRequest.php',
    'Google\\Service\\Games\\AchievementDefinition' => $vendorDir . '/google/apiclient-services/src/Games/AchievementDefinition.php',
    'Google\\Service\\Games\\AchievementDefinitionsListResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementDefinitionsListResponse.php',
    'Google\\Service\\Games\\AchievementIncrementResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementIncrementResponse.php',
    'Google\\Service\\Games\\AchievementRevealResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementRevealResponse.php',
    'Google\\Service\\Games\\AchievementSetStepsAtLeastResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementSetStepsAtLeastResponse.php',
    'Google\\Service\\Games\\AchievementUnlockResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementUnlockResponse.php',
    'Google\\Service\\Games\\AchievementUpdateMultipleRequest' => $vendorDir . '/google/apiclient-services/src/Games/AchievementUpdateMultipleRequest.php',
    'Google\\Service\\Games\\AchievementUpdateMultipleResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementUpdateMultipleResponse.php',
    'Google\\Service\\Games\\AchievementUpdateRequest' => $vendorDir . '/google/apiclient-services/src/Games/AchievementUpdateRequest.php',
    'Google\\Service\\Games\\AchievementUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Games/AchievementUpdateResponse.php',
    'Google\\Service\\Games\\Application' => $vendorDir . '/google/apiclient-services/src/Games/Application.php',
    'Google\\Service\\Games\\ApplicationCategory' => $vendorDir . '/google/apiclient-services/src/Games/ApplicationCategory.php',
    'Google\\Service\\Games\\ApplicationPlayerId' => $vendorDir . '/google/apiclient-services/src/Games/ApplicationPlayerId.php',
    'Google\\Service\\Games\\ApplicationVerifyResponse' => $vendorDir . '/google/apiclient-services/src/Games/ApplicationVerifyResponse.php',
    'Google\\Service\\Games\\Category' => $vendorDir . '/google/apiclient-services/src/Games/Category.php',
    'Google\\Service\\Games\\CategoryListResponse' => $vendorDir . '/google/apiclient-services/src/Games/CategoryListResponse.php',
    'Google\\Service\\Games\\EndPoint' => $vendorDir . '/google/apiclient-services/src/Games/EndPoint.php',
    'Google\\Service\\Games\\EventBatchRecordFailure' => $vendorDir . '/google/apiclient-services/src/Games/EventBatchRecordFailure.php',
    'Google\\Service\\Games\\EventChild' => $vendorDir . '/google/apiclient-services/src/Games/EventChild.php',
    'Google\\Service\\Games\\EventDefinition' => $vendorDir . '/google/apiclient-services/src/Games/EventDefinition.php',
    'Google\\Service\\Games\\EventDefinitionListResponse' => $vendorDir . '/google/apiclient-services/src/Games/EventDefinitionListResponse.php',
    'Google\\Service\\Games\\EventPeriodRange' => $vendorDir . '/google/apiclient-services/src/Games/EventPeriodRange.php',
    'Google\\Service\\Games\\EventPeriodUpdate' => $vendorDir . '/google/apiclient-services/src/Games/EventPeriodUpdate.php',
    'Google\\Service\\Games\\EventRecordFailure' => $vendorDir . '/google/apiclient-services/src/Games/EventRecordFailure.php',
    'Google\\Service\\Games\\EventRecordRequest' => $vendorDir . '/google/apiclient-services/src/Games/EventRecordRequest.php',
    'Google\\Service\\Games\\EventUpdateRequest' => $vendorDir . '/google/apiclient-services/src/Games/EventUpdateRequest.php',
    'Google\\Service\\Games\\EventUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Games/EventUpdateResponse.php',
    'Google\\Service\\Games\\GamePlayerToken' => $vendorDir . '/google/apiclient-services/src/Games/GamePlayerToken.php',
    'Google\\Service\\Games\\GamesAchievementIncrement' => $vendorDir . '/google/apiclient-services/src/Games/GamesAchievementIncrement.php',
    'Google\\Service\\Games\\GamesAchievementSetStepsAtLeast' => $vendorDir . '/google/apiclient-services/src/Games/GamesAchievementSetStepsAtLeast.php',
    'Google\\Service\\Games\\GeneratePlayGroupingApiTokenResponse' => $vendorDir . '/google/apiclient-services/src/Games/GeneratePlayGroupingApiTokenResponse.php',
    'Google\\Service\\Games\\GenerateRecallPlayGroupingApiTokenResponse' => $vendorDir . '/google/apiclient-services/src/Games/GenerateRecallPlayGroupingApiTokenResponse.php',
    'Google\\Service\\Games\\GetMultipleApplicationPlayerIdsResponse' => $vendorDir . '/google/apiclient-services/src/Games/GetMultipleApplicationPlayerIdsResponse.php',
    'Google\\Service\\Games\\ImageAsset' => $vendorDir . '/google/apiclient-services/src/Games/ImageAsset.php',
    'Google\\Service\\Games\\Instance' => $vendorDir . '/google/apiclient-services/src/Games/Instance.php',
    'Google\\Service\\Games\\InstanceAndroidDetails' => $vendorDir . '/google/apiclient-services/src/Games/InstanceAndroidDetails.php',
    'Google\\Service\\Games\\InstanceIosDetails' => $vendorDir . '/google/apiclient-services/src/Games/InstanceIosDetails.php',
    'Google\\Service\\Games\\InstanceWebDetails' => $vendorDir . '/google/apiclient-services/src/Games/InstanceWebDetails.php',
    'Google\\Service\\Games\\Leaderboard' => $vendorDir . '/google/apiclient-services/src/Games/Leaderboard.php',
    'Google\\Service\\Games\\LeaderboardEntry' => $vendorDir . '/google/apiclient-services/src/Games/LeaderboardEntry.php',
    'Google\\Service\\Games\\LeaderboardListResponse' => $vendorDir . '/google/apiclient-services/src/Games/LeaderboardListResponse.php',
    'Google\\Service\\Games\\LeaderboardScoreRank' => $vendorDir . '/google/apiclient-services/src/Games/LeaderboardScoreRank.php',
    'Google\\Service\\Games\\LeaderboardScores' => $vendorDir . '/google/apiclient-services/src/Games/LeaderboardScores.php',
    'Google\\Service\\Games\\LinkPersonaRequest' => $vendorDir . '/google/apiclient-services/src/Games/LinkPersonaRequest.php',
    'Google\\Service\\Games\\LinkPersonaResponse' => $vendorDir . '/google/apiclient-services/src/Games/LinkPersonaResponse.php',
    'Google\\Service\\Games\\MetagameConfig' => $vendorDir . '/google/apiclient-services/src/Games/MetagameConfig.php',
    'Google\\Service\\Games\\PlayGroupingApiToken' => $vendorDir . '/google/apiclient-services/src/Games/PlayGroupingApiToken.php',
    'Google\\Service\\Games\\Player' => $vendorDir . '/google/apiclient-services/src/Games/Player.php',
    'Google\\Service\\Games\\PlayerAchievement' => $vendorDir . '/google/apiclient-services/src/Games/PlayerAchievement.php',
    'Google\\Service\\Games\\PlayerAchievementListResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerAchievementListResponse.php',
    'Google\\Service\\Games\\PlayerEvent' => $vendorDir . '/google/apiclient-services/src/Games/PlayerEvent.php',
    'Google\\Service\\Games\\PlayerEventListResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerEventListResponse.php',
    'Google\\Service\\Games\\PlayerExperienceInfo' => $vendorDir . '/google/apiclient-services/src/Games/PlayerExperienceInfo.php',
    'Google\\Service\\Games\\PlayerLeaderboardScore' => $vendorDir . '/google/apiclient-services/src/Games/PlayerLeaderboardScore.php',
    'Google\\Service\\Games\\PlayerLeaderboardScoreListResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerLeaderboardScoreListResponse.php',
    'Google\\Service\\Games\\PlayerLevel' => $vendorDir . '/google/apiclient-services/src/Games/PlayerLevel.php',
    'Google\\Service\\Games\\PlayerListResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerListResponse.php',
    'Google\\Service\\Games\\PlayerName' => $vendorDir . '/google/apiclient-services/src/Games/PlayerName.php',
    'Google\\Service\\Games\\PlayerScore' => $vendorDir . '/google/apiclient-services/src/Games/PlayerScore.php',
    'Google\\Service\\Games\\PlayerScoreListResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerScoreListResponse.php',
    'Google\\Service\\Games\\PlayerScoreResponse' => $vendorDir . '/google/apiclient-services/src/Games/PlayerScoreResponse.php',
    'Google\\Service\\Games\\PlayerScoreSubmissionList' => $vendorDir . '/google/apiclient-services/src/Games/PlayerScoreSubmissionList.php',
    'Google\\Service\\Games\\ProfileSettings' => $vendorDir . '/google/apiclient-services/src/Games/ProfileSettings.php',
    'Google\\Service\\Games\\RecallToken' => $vendorDir . '/google/apiclient-services/src/Games/RecallToken.php',
    'Google\\Service\\Games\\ResetPersonaRequest' => $vendorDir . '/google/apiclient-services/src/Games/ResetPersonaRequest.php',
    'Google\\Service\\Games\\ResetPersonaResponse' => $vendorDir . '/google/apiclient-services/src/Games/ResetPersonaResponse.php',
    'Google\\Service\\Games\\Resource\\Accesstokens' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Accesstokens.php',
    'Google\\Service\\Games\\Resource\\AchievementDefinitions' => $vendorDir . '/google/apiclient-services/src/Games/Resource/AchievementDefinitions.php',
    'Google\\Service\\Games\\Resource\\Achievements' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Achievements.php',
    'Google\\Service\\Games\\Resource\\Applications' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Applications.php',
    'Google\\Service\\Games\\Resource\\Events' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Events.php',
    'Google\\Service\\Games\\Resource\\Leaderboards' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Leaderboards.php',
    'Google\\Service\\Games\\Resource\\Metagame' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Metagame.php',
    'Google\\Service\\Games\\Resource\\Players' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Players.php',
    'Google\\Service\\Games\\Resource\\Recall' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Recall.php',
    'Google\\Service\\Games\\Resource\\Revisions' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Revisions.php',
    'Google\\Service\\Games\\Resource\\Scores' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Scores.php',
    'Google\\Service\\Games\\Resource\\Snapshots' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Snapshots.php',
    'Google\\Service\\Games\\Resource\\Stats' => $vendorDir . '/google/apiclient-services/src/Games/Resource/Stats.php',
    'Google\\Service\\Games\\RetrieveDeveloperGamesLastPlayerTokenResponse' => $vendorDir . '/google/apiclient-services/src/Games/RetrieveDeveloperGamesLastPlayerTokenResponse.php',
    'Google\\Service\\Games\\RetrieveGamesPlayerTokensResponse' => $vendorDir . '/google/apiclient-services/src/Games/RetrieveGamesPlayerTokensResponse.php',
    'Google\\Service\\Games\\RetrievePlayerTokensResponse' => $vendorDir . '/google/apiclient-services/src/Games/RetrievePlayerTokensResponse.php',
    'Google\\Service\\Games\\RevisionCheckResponse' => $vendorDir . '/google/apiclient-services/src/Games/RevisionCheckResponse.php',
    'Google\\Service\\Games\\ScopedPlayerIds' => $vendorDir . '/google/apiclient-services/src/Games/ScopedPlayerIds.php',
    'Google\\Service\\Games\\ScoreSubmission' => $vendorDir . '/google/apiclient-services/src/Games/ScoreSubmission.php',
    'Google\\Service\\Games\\Snapshot' => $vendorDir . '/google/apiclient-services/src/Games/Snapshot.php',
    'Google\\Service\\Games\\SnapshotImage' => $vendorDir . '/google/apiclient-services/src/Games/SnapshotImage.php',
    'Google\\Service\\Games\\SnapshotListResponse' => $vendorDir . '/google/apiclient-services/src/Games/SnapshotListResponse.php',
    'Google\\Service\\Games\\StatsResponse' => $vendorDir . '/google/apiclient-services/src/Games/StatsResponse.php',
    'Google\\Service\\Games\\UnlinkPersonaRequest' => $vendorDir . '/google/apiclient-services/src/Games/UnlinkPersonaRequest.php',
    'Google\\Service\\Games\\UnlinkPersonaResponse' => $vendorDir . '/google/apiclient-services/src/Games/UnlinkPersonaResponse.php',
    'Google\\Service\\Genomics' => $vendorDir . '/google/apiclient-services/src/Genomics.php',
    'Google\\Service\\Genomics\\Accelerator' => $vendorDir . '/google/apiclient-services/src/Genomics/Accelerator.php',
    'Google\\Service\\Genomics\\Action' => $vendorDir . '/google/apiclient-services/src/Genomics/Action.php',
    'Google\\Service\\Genomics\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Genomics/CancelOperationRequest.php',
    'Google\\Service\\Genomics\\CheckInRequest' => $vendorDir . '/google/apiclient-services/src/Genomics/CheckInRequest.php',
    'Google\\Service\\Genomics\\CheckInResponse' => $vendorDir . '/google/apiclient-services/src/Genomics/CheckInResponse.php',
    'Google\\Service\\Genomics\\ContainerKilledEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/ContainerKilledEvent.php',
    'Google\\Service\\Genomics\\ContainerStartedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/ContainerStartedEvent.php',
    'Google\\Service\\Genomics\\ContainerStoppedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/ContainerStoppedEvent.php',
    'Google\\Service\\Genomics\\DelayedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/DelayedEvent.php',
    'Google\\Service\\Genomics\\Disk' => $vendorDir . '/google/apiclient-services/src/Genomics/Disk.php',
    'Google\\Service\\Genomics\\DiskStatus' => $vendorDir . '/google/apiclient-services/src/Genomics/DiskStatus.php',
    'Google\\Service\\Genomics\\Event' => $vendorDir . '/google/apiclient-services/src/Genomics/Event.php',
    'Google\\Service\\Genomics\\ExistingDisk' => $vendorDir . '/google/apiclient-services/src/Genomics/ExistingDisk.php',
    'Google\\Service\\Genomics\\FailedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/FailedEvent.php',
    'Google\\Service\\Genomics\\GenomicsEmpty' => $vendorDir . '/google/apiclient-services/src/Genomics/GenomicsEmpty.php',
    'Google\\Service\\Genomics\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Genomics/ListOperationsResponse.php',
    'Google\\Service\\Genomics\\Metadata' => $vendorDir . '/google/apiclient-services/src/Genomics/Metadata.php',
    'Google\\Service\\Genomics\\Mount' => $vendorDir . '/google/apiclient-services/src/Genomics/Mount.php',
    'Google\\Service\\Genomics\\NFSMount' => $vendorDir . '/google/apiclient-services/src/Genomics/NFSMount.php',
    'Google\\Service\\Genomics\\Network' => $vendorDir . '/google/apiclient-services/src/Genomics/Network.php',
    'Google\\Service\\Genomics\\Operation' => $vendorDir . '/google/apiclient-services/src/Genomics/Operation.php',
    'Google\\Service\\Genomics\\PersistentDisk' => $vendorDir . '/google/apiclient-services/src/Genomics/PersistentDisk.php',
    'Google\\Service\\Genomics\\Pipeline' => $vendorDir . '/google/apiclient-services/src/Genomics/Pipeline.php',
    'Google\\Service\\Genomics\\PullStartedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/PullStartedEvent.php',
    'Google\\Service\\Genomics\\PullStoppedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/PullStoppedEvent.php',
    'Google\\Service\\Genomics\\Resource\\Pipelines' => $vendorDir . '/google/apiclient-services/src/Genomics/Resource/Pipelines.php',
    'Google\\Service\\Genomics\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Genomics/Resource/Projects.php',
    'Google\\Service\\Genomics\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/Genomics/Resource/ProjectsOperations.php',
    'Google\\Service\\Genomics\\Resource\\ProjectsWorkers' => $vendorDir . '/google/apiclient-services/src/Genomics/Resource/ProjectsWorkers.php',
    'Google\\Service\\Genomics\\Resource\\Workers' => $vendorDir . '/google/apiclient-services/src/Genomics/Resource/Workers.php',
    'Google\\Service\\Genomics\\Resources' => $vendorDir . '/google/apiclient-services/src/Genomics/Resources.php',
    'Google\\Service\\Genomics\\RunPipelineRequest' => $vendorDir . '/google/apiclient-services/src/Genomics/RunPipelineRequest.php',
    'Google\\Service\\Genomics\\RunPipelineResponse' => $vendorDir . '/google/apiclient-services/src/Genomics/RunPipelineResponse.php',
    'Google\\Service\\Genomics\\Secret' => $vendorDir . '/google/apiclient-services/src/Genomics/Secret.php',
    'Google\\Service\\Genomics\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Genomics/ServiceAccount.php',
    'Google\\Service\\Genomics\\Status' => $vendorDir . '/google/apiclient-services/src/Genomics/Status.php',
    'Google\\Service\\Genomics\\TimestampedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/TimestampedEvent.php',
    'Google\\Service\\Genomics\\UnexpectedExitStatusEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/UnexpectedExitStatusEvent.php',
    'Google\\Service\\Genomics\\VirtualMachine' => $vendorDir . '/google/apiclient-services/src/Genomics/VirtualMachine.php',
    'Google\\Service\\Genomics\\Volume' => $vendorDir . '/google/apiclient-services/src/Genomics/Volume.php',
    'Google\\Service\\Genomics\\WorkerAssignedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/WorkerAssignedEvent.php',
    'Google\\Service\\Genomics\\WorkerReleasedEvent' => $vendorDir . '/google/apiclient-services/src/Genomics/WorkerReleasedEvent.php',
    'Google\\Service\\Genomics\\WorkerStatus' => $vendorDir . '/google/apiclient-services/src/Genomics/WorkerStatus.php',
    'Google\\Service\\Gmail' => $vendorDir . '/google/apiclient-services/src/Gmail.php',
    'Google\\Service\\Gmail\\AutoForwarding' => $vendorDir . '/google/apiclient-services/src/Gmail/AutoForwarding.php',
    'Google\\Service\\Gmail\\BatchDeleteMessagesRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/BatchDeleteMessagesRequest.php',
    'Google\\Service\\Gmail\\BatchModifyMessagesRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/BatchModifyMessagesRequest.php',
    'Google\\Service\\Gmail\\CseIdentity' => $vendorDir . '/google/apiclient-services/src/Gmail/CseIdentity.php',
    'Google\\Service\\Gmail\\CseKeyPair' => $vendorDir . '/google/apiclient-services/src/Gmail/CseKeyPair.php',
    'Google\\Service\\Gmail\\CsePrivateKeyMetadata' => $vendorDir . '/google/apiclient-services/src/Gmail/CsePrivateKeyMetadata.php',
    'Google\\Service\\Gmail\\Delegate' => $vendorDir . '/google/apiclient-services/src/Gmail/Delegate.php',
    'Google\\Service\\Gmail\\DisableCseKeyPairRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/DisableCseKeyPairRequest.php',
    'Google\\Service\\Gmail\\Draft' => $vendorDir . '/google/apiclient-services/src/Gmail/Draft.php',
    'Google\\Service\\Gmail\\EnableCseKeyPairRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/EnableCseKeyPairRequest.php',
    'Google\\Service\\Gmail\\Filter' => $vendorDir . '/google/apiclient-services/src/Gmail/Filter.php',
    'Google\\Service\\Gmail\\FilterAction' => $vendorDir . '/google/apiclient-services/src/Gmail/FilterAction.php',
    'Google\\Service\\Gmail\\FilterCriteria' => $vendorDir . '/google/apiclient-services/src/Gmail/FilterCriteria.php',
    'Google\\Service\\Gmail\\ForwardingAddress' => $vendorDir . '/google/apiclient-services/src/Gmail/ForwardingAddress.php',
    'Google\\Service\\Gmail\\HardwareKeyMetadata' => $vendorDir . '/google/apiclient-services/src/Gmail/HardwareKeyMetadata.php',
    'Google\\Service\\Gmail\\History' => $vendorDir . '/google/apiclient-services/src/Gmail/History.php',
    'Google\\Service\\Gmail\\HistoryLabelAdded' => $vendorDir . '/google/apiclient-services/src/Gmail/HistoryLabelAdded.php',
    'Google\\Service\\Gmail\\HistoryLabelRemoved' => $vendorDir . '/google/apiclient-services/src/Gmail/HistoryLabelRemoved.php',
    'Google\\Service\\Gmail\\HistoryMessageAdded' => $vendorDir . '/google/apiclient-services/src/Gmail/HistoryMessageAdded.php',
    'Google\\Service\\Gmail\\HistoryMessageDeleted' => $vendorDir . '/google/apiclient-services/src/Gmail/HistoryMessageDeleted.php',
    'Google\\Service\\Gmail\\ImapSettings' => $vendorDir . '/google/apiclient-services/src/Gmail/ImapSettings.php',
    'Google\\Service\\Gmail\\KaclsKeyMetadata' => $vendorDir . '/google/apiclient-services/src/Gmail/KaclsKeyMetadata.php',
    'Google\\Service\\Gmail\\Label' => $vendorDir . '/google/apiclient-services/src/Gmail/Label.php',
    'Google\\Service\\Gmail\\LabelColor' => $vendorDir . '/google/apiclient-services/src/Gmail/LabelColor.php',
    'Google\\Service\\Gmail\\LanguageSettings' => $vendorDir . '/google/apiclient-services/src/Gmail/LanguageSettings.php',
    'Google\\Service\\Gmail\\ListCseIdentitiesResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListCseIdentitiesResponse.php',
    'Google\\Service\\Gmail\\ListCseKeyPairsResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListCseKeyPairsResponse.php',
    'Google\\Service\\Gmail\\ListDelegatesResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListDelegatesResponse.php',
    'Google\\Service\\Gmail\\ListDraftsResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListDraftsResponse.php',
    'Google\\Service\\Gmail\\ListFiltersResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListFiltersResponse.php',
    'Google\\Service\\Gmail\\ListForwardingAddressesResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListForwardingAddressesResponse.php',
    'Google\\Service\\Gmail\\ListHistoryResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListHistoryResponse.php',
    'Google\\Service\\Gmail\\ListLabelsResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListLabelsResponse.php',
    'Google\\Service\\Gmail\\ListMessagesResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListMessagesResponse.php',
    'Google\\Service\\Gmail\\ListSendAsResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListSendAsResponse.php',
    'Google\\Service\\Gmail\\ListSmimeInfoResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListSmimeInfoResponse.php',
    'Google\\Service\\Gmail\\ListThreadsResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/ListThreadsResponse.php',
    'Google\\Service\\Gmail\\Message' => $vendorDir . '/google/apiclient-services/src/Gmail/Message.php',
    'Google\\Service\\Gmail\\MessagePart' => $vendorDir . '/google/apiclient-services/src/Gmail/MessagePart.php',
    'Google\\Service\\Gmail\\MessagePartBody' => $vendorDir . '/google/apiclient-services/src/Gmail/MessagePartBody.php',
    'Google\\Service\\Gmail\\MessagePartHeader' => $vendorDir . '/google/apiclient-services/src/Gmail/MessagePartHeader.php',
    'Google\\Service\\Gmail\\ModifyMessageRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/ModifyMessageRequest.php',
    'Google\\Service\\Gmail\\ModifyThreadRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/ModifyThreadRequest.php',
    'Google\\Service\\Gmail\\ObliterateCseKeyPairRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/ObliterateCseKeyPairRequest.php',
    'Google\\Service\\Gmail\\PivKeyMetadata' => $vendorDir . '/google/apiclient-services/src/Gmail/PivKeyMetadata.php',
    'Google\\Service\\Gmail\\PopSettings' => $vendorDir . '/google/apiclient-services/src/Gmail/PopSettings.php',
    'Google\\Service\\Gmail\\Profile' => $vendorDir . '/google/apiclient-services/src/Gmail/Profile.php',
    'Google\\Service\\Gmail\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/Users.php',
    'Google\\Service\\Gmail\\Resource\\UsersDrafts' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersDrafts.php',
    'Google\\Service\\Gmail\\Resource\\UsersHistory' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersHistory.php',
    'Google\\Service\\Gmail\\Resource\\UsersLabels' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersLabels.php',
    'Google\\Service\\Gmail\\Resource\\UsersMessages' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersMessages.php',
    'Google\\Service\\Gmail\\Resource\\UsersMessagesAttachments' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersMessagesAttachments.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettings' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettings.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsCse' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsCse.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsCseIdentities' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsCseIdentities.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsCseKeypairs' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsCseKeypairs.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsDelegates' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsDelegates.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsFilters' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsFilters.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsForwardingAddresses' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsForwardingAddresses.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsSendAs' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsSendAs.php',
    'Google\\Service\\Gmail\\Resource\\UsersSettingsSendAsSmimeInfo' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersSettingsSendAsSmimeInfo.php',
    'Google\\Service\\Gmail\\Resource\\UsersThreads' => $vendorDir . '/google/apiclient-services/src/Gmail/Resource/UsersThreads.php',
    'Google\\Service\\Gmail\\SendAs' => $vendorDir . '/google/apiclient-services/src/Gmail/SendAs.php',
    'Google\\Service\\Gmail\\SignAndEncryptKeyPairs' => $vendorDir . '/google/apiclient-services/src/Gmail/SignAndEncryptKeyPairs.php',
    'Google\\Service\\Gmail\\SmimeInfo' => $vendorDir . '/google/apiclient-services/src/Gmail/SmimeInfo.php',
    'Google\\Service\\Gmail\\SmtpMsa' => $vendorDir . '/google/apiclient-services/src/Gmail/SmtpMsa.php',
    'Google\\Service\\Gmail\\Thread' => $vendorDir . '/google/apiclient-services/src/Gmail/Thread.php',
    'Google\\Service\\Gmail\\VacationSettings' => $vendorDir . '/google/apiclient-services/src/Gmail/VacationSettings.php',
    'Google\\Service\\Gmail\\WatchRequest' => $vendorDir . '/google/apiclient-services/src/Gmail/WatchRequest.php',
    'Google\\Service\\Gmail\\WatchResponse' => $vendorDir . '/google/apiclient-services/src/Gmail/WatchResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessBetweenFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessBetweenFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessDateRange' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDateRange.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessDimension' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimension.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessDimensionHeader' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimensionHeader.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessDimensionValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimensionValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessFilterExpression' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilterExpression.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessFilterExpressionList' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilterExpressionList.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessInListFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessInListFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessMetric' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetric.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessMetricHeader' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetricHeader.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessMetricValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetricValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessNumericFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessNumericFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessOrderByDimensionOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderByDimensionOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessOrderByMetricOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderByMetricOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessQuota' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessQuota.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessQuotaStatus' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessQuotaStatus.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessRow' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessRow.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccessStringFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessStringFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccount' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccount.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAccountSummary' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccountSummary.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAndroidAppDataStream' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAndroidAppDataStream.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaArchiveAudienceRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveAudienceRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaArchiveCustomDimensionRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveCustomDimensionRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaArchiveCustomMetricRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveCustomMetricRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAttributionSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAttributionSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudience' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudience.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterBetweenFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterBetweenFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterInListFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterInListFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterStringFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterStringFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceEventFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceEventFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceEventTrigger' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceEventTrigger.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceFilterClause' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterClause.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceFilterExpression' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterExpression.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceFilterExpressionList' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterExpressionList.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceSequenceFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSequenceFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceSequenceFilterAudienceSequenceStep' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSequenceFilterAudienceSequenceStep.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAudienceSimpleFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSimpleFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAuditUserLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAuditUserLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAuditUserLinksRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAuditUserLinksRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaAuditUserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAuditUserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchCreateUserLinksRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchCreateUserLinksRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchCreateUserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchCreateUserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchDeleteUserLinksRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchDeleteUserLinksRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchGetUserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchGetUserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchUpdateUserLinksRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchUpdateUserLinksRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaBatchUpdateUserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchUpdateUserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaCancelDisplayVideo360AdvertiserLinkProposalRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCancelDisplayVideo360AdvertiserLinkProposalRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaChangeHistoryChange' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryChange.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaChangeHistoryChangeChangeHistoryResource' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryChangeChangeHistoryResource.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaChangeHistoryEvent' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryEvent.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaConversionEvent' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaConversionEvent.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaCreateUserLinkRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCreateUserLinkRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaCustomDimension' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCustomDimension.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaCustomMetric' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCustomMetric.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataRetentionSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataRetentionSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataSharingSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataSharingSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataStream' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStream.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataStreamAndroidAppStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamAndroidAppStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataStreamIosAppStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamIosAppStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDataStreamWebStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamWebStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDeleteUserLinkRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDeleteUserLinkRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaEnhancedMeasurementSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaEnhancedMeasurementSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSet' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSet.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpression' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpression.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpressionList' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpressionList.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterInListFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterInListFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterStringFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterStringFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaFirebaseLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaFirebaseLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaGlobalSiteTag' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGlobalSiteTag.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaGoogleAdsLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGoogleAdsLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaGoogleSignalsSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGoogleSignalsSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaIosAppDataStream' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaIosAppDataStream.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaLinkProposalStatusDetails' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaLinkProposalStatusDetails.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListAccountSummariesResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAccountSummariesResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAccountsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListAndroidAppDataStreamsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAndroidAppDataStreamsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListAudiencesResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAudiencesResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListConversionEventsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListConversionEventsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListCustomDimensionsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListCustomDimensionsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListCustomMetricsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListCustomMetricsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListDataStreamsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDataStreamsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinkProposalsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinkProposalsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListGoogleAdsLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListGoogleAdsLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListIosAppDataStreamsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListIosAppDataStreamsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListMeasurementProtocolSecretsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListMeasurementProtocolSecretsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListPropertiesResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListPropertiesResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListSearchAds360LinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListSearchAds360LinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListUserLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListUserLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaListWebDataStreamsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListWebDataStreamsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaNumericValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaNumericValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaProperty' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProperty.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaPropertySummary' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaPropertySummary.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaProvisionAccountTicketRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionAccountTicketRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaProvisionAccountTicketResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionAccountTicketResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaRunAccessReportRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaRunAccessReportRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaRunAccessReportResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaRunAccessReportResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaSearchAds360Link' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchAds360Link.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaUpdateUserLinkRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaUpdateUserLinkRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaUserLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaUserLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1alphaWebDataStream' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaWebDataStream.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessBetweenFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessBetweenFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDateRange' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDateRange.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimension' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimension.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimensionHeader' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimensionHeader.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimensionValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimensionValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilterExpression' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilterExpression.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilterExpressionList' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilterExpressionList.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessInListFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessInListFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetric' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetric.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetricHeader' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetricHeader.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetricValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetricValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessNumericFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessNumericFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderByDimensionOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderByDimensionOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderByMetricOrderBy' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderByMetricOrderBy.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessQuota' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessQuota.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessQuotaStatus' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessQuotaStatus.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessRow' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessRow.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessStringFilter' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessStringFilter.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccount' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccount.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccountSummary' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccountSummary.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaArchiveCustomDimensionRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaArchiveCustomDimensionRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaArchiveCustomMetricRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaArchiveCustomMetricRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryChange' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryChange.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryEvent' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryEvent.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaConversionEvent' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaConversionEvent.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaConversionEventDefaultConversionValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaConversionEventDefaultConversionValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaCustomDimension' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaCustomDimension.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaCustomMetric' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaCustomMetric.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataRetentionSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataRetentionSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataSharingSettings' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataSharingSettings.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStream' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStream.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamAndroidAppStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamAndroidAppStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamIosAppStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamIosAppStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamWebStreamData' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamWebStreamData.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaFirebaseLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaFirebaseLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaGoogleAdsLink' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaGoogleAdsLink.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaKeyEvent' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaKeyEvent.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaKeyEventDefaultValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaKeyEventDefaultValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListAccountSummariesResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListAccountSummariesResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListAccountsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListConversionEventsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListConversionEventsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListCustomDimensionsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListCustomDimensionsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListCustomMetricsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListCustomMetricsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListDataStreamsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListDataStreamsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListFirebaseLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListFirebaseLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListGoogleAdsLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListGoogleAdsLinksResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListKeyEventsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListKeyEventsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListMeasurementProtocolSecretsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListMeasurementProtocolSecretsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListPropertiesResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListPropertiesResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaMeasurementProtocolSecret' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaMeasurementProtocolSecret.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaNumericValue' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaNumericValue.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProperty' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProperty.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaPropertySummary' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaPropertySummary.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProvisionAccountTicketRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProvisionAccountTicketRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProvisionAccountTicketResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProvisionAccountTicketResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaReorderEventEditRulesRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaReorderEventEditRulesRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaRunAccessReportRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaRunAccessReportRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaRunAccessReportResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaRunAccessReportResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsResponse' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsResponse.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/GoogleProtobufEmpty.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\AccountSummaries' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/AccountSummaries.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/Accounts.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\AccountsUserLinks' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/AccountsUserLinks.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\Properties' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/Properties.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesAndroidAppDataStreams' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesAndroidAppDataStreams.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesAndroidAppDataStreamsMeasurementProtocolSecrets' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesAndroidAppDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesAudiences' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesAudiences.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesConversionEvents' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesConversionEvents.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesCustomDimensions' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomDimensions.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesCustomMetrics' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomMetrics.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDataStreams' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreams.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDataStreamsEventEditRules' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsEventEditRules.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDataStreamsMeasurementProtocolSecrets' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDisplayVideo360AdvertiserLinkProposals' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesDisplayVideo360AdvertiserLinkProposals.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDisplayVideo360AdvertiserLinks' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesDisplayVideo360AdvertiserLinks.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesFirebaseLinks' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesFirebaseLinks.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesGoogleAdsLinks' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesGoogleAdsLinks.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesIosAppDataStreams' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesIosAppDataStreams.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesIosAppDataStreamsMeasurementProtocolSecrets' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesIosAppDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesKeyEvents' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesKeyEvents.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesSearchAds360Links' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesSearchAds360Links.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesUserLinks' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesUserLinks.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesWebDataStreams' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesWebDataStreams.php',
    'Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesWebDataStreamsMeasurementProtocolSecrets' => $vendorDir . '/google/apiclient-services/src/GoogleAnalyticsAdmin/Resource/PropertiesWebDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\AnalyticsAccountLink' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/AnalyticsAccountLink.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\ListAnalyticsAccountLinksResponse' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/ListAnalyticsAccountLinksResponse.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\MarketingplatformadminEmpty' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/MarketingplatformadminEmpty.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\Organization' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/Organization.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/Resource/Organizations.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\Resource\\OrganizationsAnalyticsAccountLinks' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/Resource/OrganizationsAnalyticsAccountLinks.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\SetPropertyServiceLevelRequest' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/SetPropertyServiceLevelRequest.php',
    'Google\\Service\\GoogleMarketingPlatformAdminAPI\\SetPropertyServiceLevelResponse' => $vendorDir . '/google/apiclient-services/src/GoogleMarketingPlatformAdminAPI/SetPropertyServiceLevelResponse.php',
    'Google\\Service\\GroupsMigration' => $vendorDir . '/google/apiclient-services/src/GroupsMigration.php',
    'Google\\Service\\GroupsMigration\\Groups' => $vendorDir . '/google/apiclient-services/src/GroupsMigration/Groups.php',
    'Google\\Service\\GroupsMigration\\Resource\\Archive' => $vendorDir . '/google/apiclient-services/src/GroupsMigration/Resource/Archive.php',
    'Google\\Service\\Groupssettings' => $vendorDir . '/google/apiclient-services/src/Groupssettings.php',
    'Google\\Service\\Groupssettings\\Groups' => $vendorDir . '/google/apiclient-services/src/Groupssettings/Groups.php',
    'Google\\Service\\Groupssettings\\Resource\\Groups' => $vendorDir . '/google/apiclient-services/src/Groupssettings/Resource/Groups.php',
    'Google\\Service\\HangoutsChat' => $vendorDir . '/google/apiclient-services/src/HangoutsChat.php',
    'Google\\Service\\HangoutsChat\\AccessSettings' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/AccessSettings.php',
    'Google\\Service\\HangoutsChat\\AccessoryWidget' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/AccessoryWidget.php',
    'Google\\Service\\HangoutsChat\\ActionParameter' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ActionParameter.php',
    'Google\\Service\\HangoutsChat\\ActionResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ActionResponse.php',
    'Google\\Service\\HangoutsChat\\ActionStatus' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ActionStatus.php',
    'Google\\Service\\HangoutsChat\\Annotation' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Annotation.php',
    'Google\\Service\\HangoutsChat\\AttachedGif' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/AttachedGif.php',
    'Google\\Service\\HangoutsChat\\Attachment' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Attachment.php',
    'Google\\Service\\HangoutsChat\\AttachmentDataRef' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/AttachmentDataRef.php',
    'Google\\Service\\HangoutsChat\\Button' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Button.php',
    'Google\\Service\\HangoutsChat\\Card' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Card.php',
    'Google\\Service\\HangoutsChat\\CardAction' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CardAction.php',
    'Google\\Service\\HangoutsChat\\CardHeader' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CardHeader.php',
    'Google\\Service\\HangoutsChat\\CardWithId' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CardWithId.php',
    'Google\\Service\\HangoutsChat\\ChatAppLogEntry' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ChatAppLogEntry.php',
    'Google\\Service\\HangoutsChat\\ChatClientDataSourceMarkup' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ChatClientDataSourceMarkup.php',
    'Google\\Service\\HangoutsChat\\ChatEmpty' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ChatEmpty.php',
    'Google\\Service\\HangoutsChat\\ChatSpaceLinkData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ChatSpaceLinkData.php',
    'Google\\Service\\HangoutsChat\\Color' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Color.php',
    'Google\\Service\\HangoutsChat\\CommonEventObject' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CommonEventObject.php',
    'Google\\Service\\HangoutsChat\\CompleteImportSpaceRequest' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CompleteImportSpaceRequest.php',
    'Google\\Service\\HangoutsChat\\CompleteImportSpaceResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CompleteImportSpaceResponse.php',
    'Google\\Service\\HangoutsChat\\CustomEmoji' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/CustomEmoji.php',
    'Google\\Service\\HangoutsChat\\DateInput' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DateInput.php',
    'Google\\Service\\HangoutsChat\\DateTimeInput' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DateTimeInput.php',
    'Google\\Service\\HangoutsChat\\DeletionMetadata' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DeletionMetadata.php',
    'Google\\Service\\HangoutsChat\\DeprecatedEvent' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DeprecatedEvent.php',
    'Google\\Service\\HangoutsChat\\Dialog' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Dialog.php',
    'Google\\Service\\HangoutsChat\\DialogAction' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DialogAction.php',
    'Google\\Service\\HangoutsChat\\DriveDataRef' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DriveDataRef.php',
    'Google\\Service\\HangoutsChat\\DriveLinkData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DriveLinkData.php',
    'Google\\Service\\HangoutsChat\\DynamiteIntegrationLogEntry' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/DynamiteIntegrationLogEntry.php',
    'Google\\Service\\HangoutsChat\\Emoji' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Emoji.php',
    'Google\\Service\\HangoutsChat\\EmojiReactionSummary' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/EmojiReactionSummary.php',
    'Google\\Service\\HangoutsChat\\FormAction' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/FormAction.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Action' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Action.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1ActionParameter' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1ActionParameter.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1AppUri' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1AppUri.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1BorderStyle' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1BorderStyle.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Button' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Button.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1ButtonList' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1ButtonList.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Card' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Card.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1CardAction' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1CardAction.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1CardFixedFooter' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1CardFixedFooter.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1CardHeader' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1CardHeader.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Column' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Column.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Columns' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Columns.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1DateTimePicker' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1DateTimePicker.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1DecoratedText' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1DecoratedText.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Divider' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Divider.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1ExtraData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1ExtraData.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1FooterWidget' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1FooterWidget.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Grid' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Grid.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1GridItem' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1GridItem.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Icon' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Icon.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Image' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Image.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1ImageComponent' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1ImageComponent.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1ImageCropStyle' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1ImageCropStyle.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Intent' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Intent.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1MaterialIcon' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1MaterialIcon.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1OnClick' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1OnClick.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1OpenLink' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1OpenLink.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1PlatformDataSource' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1PlatformDataSource.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Section' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Section.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1SelectionInput' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1SelectionInput.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1SelectionItem' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1SelectionItem.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1SuggestionItem' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1SuggestionItem.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Suggestions' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Suggestions.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1SwitchControl' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1SwitchControl.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1TextInput' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1TextInput.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1TextParagraph' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1TextParagraph.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Widget' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Widget.php',
    'Google\\Service\\HangoutsChat\\GoogleAppsCardV1Widgets' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/GoogleAppsCardV1Widgets.php',
    'Google\\Service\\HangoutsChat\\Group' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Group.php',
    'Google\\Service\\HangoutsChat\\HostAppDataSourceMarkup' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/HostAppDataSourceMarkup.php',
    'Google\\Service\\HangoutsChat\\Image' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Image.php',
    'Google\\Service\\HangoutsChat\\ImageButton' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ImageButton.php',
    'Google\\Service\\HangoutsChat\\Inputs' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Inputs.php',
    'Google\\Service\\HangoutsChat\\KeyValue' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/KeyValue.php',
    'Google\\Service\\HangoutsChat\\ListMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ListMembershipsResponse.php',
    'Google\\Service\\HangoutsChat\\ListMessagesResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ListMessagesResponse.php',
    'Google\\Service\\HangoutsChat\\ListReactionsResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ListReactionsResponse.php',
    'Google\\Service\\HangoutsChat\\ListSpaceEventsResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ListSpaceEventsResponse.php',
    'Google\\Service\\HangoutsChat\\ListSpacesResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ListSpacesResponse.php',
    'Google\\Service\\HangoutsChat\\MatchedUrl' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MatchedUrl.php',
    'Google\\Service\\HangoutsChat\\Media' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Media.php',
    'Google\\Service\\HangoutsChat\\Membership' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Membership.php',
    'Google\\Service\\HangoutsChat\\MembershipBatchCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipBatchCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\MembershipBatchDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipBatchDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\MembershipBatchUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipBatchUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\MembershipCount' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipCount.php',
    'Google\\Service\\HangoutsChat\\MembershipCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\MembershipDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\MembershipUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MembershipUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\Message' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Message.php',
    'Google\\Service\\HangoutsChat\\MessageBatchCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageBatchCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\MessageBatchDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageBatchDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\MessageBatchUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageBatchUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\MessageCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\MessageDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\MessageUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/MessageUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\OnClick' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/OnClick.php',
    'Google\\Service\\HangoutsChat\\OpenLink' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/OpenLink.php',
    'Google\\Service\\HangoutsChat\\QuotedMessageMetadata' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/QuotedMessageMetadata.php',
    'Google\\Service\\HangoutsChat\\Reaction' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Reaction.php',
    'Google\\Service\\HangoutsChat\\ReactionBatchCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ReactionBatchCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\ReactionBatchDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ReactionBatchDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\ReactionCreatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ReactionCreatedEventData.php',
    'Google\\Service\\HangoutsChat\\ReactionDeletedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ReactionDeletedEventData.php',
    'Google\\Service\\HangoutsChat\\Resource\\Dms' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/Dms.php',
    'Google\\Service\\HangoutsChat\\Resource\\DmsConversations' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/DmsConversations.php',
    'Google\\Service\\HangoutsChat\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/Media.php',
    'Google\\Service\\HangoutsChat\\Resource\\Rooms' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/Rooms.php',
    'Google\\Service\\HangoutsChat\\Resource\\RoomsConversations' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/RoomsConversations.php',
    'Google\\Service\\HangoutsChat\\Resource\\Spaces' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/Spaces.php',
    'Google\\Service\\HangoutsChat\\Resource\\SpacesMembers' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/SpacesMembers.php',
    'Google\\Service\\HangoutsChat\\Resource\\SpacesMessages' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/SpacesMessages.php',
    'Google\\Service\\HangoutsChat\\Resource\\SpacesMessagesAttachments' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/SpacesMessagesAttachments.php',
    'Google\\Service\\HangoutsChat\\Resource\\SpacesMessagesReactions' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/SpacesMessagesReactions.php',
    'Google\\Service\\HangoutsChat\\Resource\\SpacesSpaceEvents' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/SpacesSpaceEvents.php',
    'Google\\Service\\HangoutsChat\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/Users.php',
    'Google\\Service\\HangoutsChat\\Resource\\UsersSpaces' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/UsersSpaces.php',
    'Google\\Service\\HangoutsChat\\Resource\\UsersSpacesThreads' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Resource/UsersSpacesThreads.php',
    'Google\\Service\\HangoutsChat\\RichLinkMetadata' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/RichLinkMetadata.php',
    'Google\\Service\\HangoutsChat\\SearchSpacesResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SearchSpacesResponse.php',
    'Google\\Service\\HangoutsChat\\Section' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Section.php',
    'Google\\Service\\HangoutsChat\\SelectionItems' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SelectionItems.php',
    'Google\\Service\\HangoutsChat\\SetUpSpaceRequest' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SetUpSpaceRequest.php',
    'Google\\Service\\HangoutsChat\\SlashCommand' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SlashCommand.php',
    'Google\\Service\\HangoutsChat\\SlashCommandMetadata' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SlashCommandMetadata.php',
    'Google\\Service\\HangoutsChat\\Space' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Space.php',
    'Google\\Service\\HangoutsChat\\SpaceBatchUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceBatchUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\SpaceDataSource' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceDataSource.php',
    'Google\\Service\\HangoutsChat\\SpaceDetails' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceDetails.php',
    'Google\\Service\\HangoutsChat\\SpaceEvent' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceEvent.php',
    'Google\\Service\\HangoutsChat\\SpaceReadState' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceReadState.php',
    'Google\\Service\\HangoutsChat\\SpaceUpdatedEventData' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/SpaceUpdatedEventData.php',
    'Google\\Service\\HangoutsChat\\Status' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Status.php',
    'Google\\Service\\HangoutsChat\\StringInputs' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/StringInputs.php',
    'Google\\Service\\HangoutsChat\\TextButton' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/TextButton.php',
    'Google\\Service\\HangoutsChat\\TextParagraph' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/TextParagraph.php',
    'Google\\Service\\HangoutsChat\\Thread' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/Thread.php',
    'Google\\Service\\HangoutsChat\\ThreadReadState' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/ThreadReadState.php',
    'Google\\Service\\HangoutsChat\\TimeInput' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/TimeInput.php',
    'Google\\Service\\HangoutsChat\\TimeZone' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/TimeZone.php',
    'Google\\Service\\HangoutsChat\\UpdatedWidget' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/UpdatedWidget.php',
    'Google\\Service\\HangoutsChat\\UploadAttachmentRequest' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/UploadAttachmentRequest.php',
    'Google\\Service\\HangoutsChat\\UploadAttachmentResponse' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/UploadAttachmentResponse.php',
    'Google\\Service\\HangoutsChat\\User' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/User.php',
    'Google\\Service\\HangoutsChat\\UserMentionMetadata' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/UserMentionMetadata.php',
    'Google\\Service\\HangoutsChat\\WidgetMarkup' => $vendorDir . '/google/apiclient-services/src/HangoutsChat/WidgetMarkup.php',
    'Google\\Service\\HomeGraphService' => $vendorDir . '/google/apiclient-services/src/HomeGraphService.php',
    'Google\\Service\\HomeGraphService\\AgentDeviceId' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/AgentDeviceId.php',
    'Google\\Service\\HomeGraphService\\AgentOtherDeviceId' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/AgentOtherDeviceId.php',
    'Google\\Service\\HomeGraphService\\Device' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/Device.php',
    'Google\\Service\\HomeGraphService\\DeviceInfo' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/DeviceInfo.php',
    'Google\\Service\\HomeGraphService\\DeviceNames' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/DeviceNames.php',
    'Google\\Service\\HomeGraphService\\HomegraphEmpty' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/HomegraphEmpty.php',
    'Google\\Service\\HomeGraphService\\QueryRequest' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/QueryRequest.php',
    'Google\\Service\\HomeGraphService\\QueryRequestInput' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/QueryRequestInput.php',
    'Google\\Service\\HomeGraphService\\QueryRequestPayload' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/QueryRequestPayload.php',
    'Google\\Service\\HomeGraphService\\QueryResponse' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/QueryResponse.php',
    'Google\\Service\\HomeGraphService\\QueryResponsePayload' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/QueryResponsePayload.php',
    'Google\\Service\\HomeGraphService\\ReportStateAndNotificationDevice' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/ReportStateAndNotificationDevice.php',
    'Google\\Service\\HomeGraphService\\ReportStateAndNotificationRequest' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/ReportStateAndNotificationRequest.php',
    'Google\\Service\\HomeGraphService\\ReportStateAndNotificationResponse' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/ReportStateAndNotificationResponse.php',
    'Google\\Service\\HomeGraphService\\RequestSyncDevicesRequest' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/RequestSyncDevicesRequest.php',
    'Google\\Service\\HomeGraphService\\RequestSyncDevicesResponse' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/RequestSyncDevicesResponse.php',
    'Google\\Service\\HomeGraphService\\Resource\\AgentUsers' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/Resource/AgentUsers.php',
    'Google\\Service\\HomeGraphService\\Resource\\Devices' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/Resource/Devices.php',
    'Google\\Service\\HomeGraphService\\StateAndNotificationPayload' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/StateAndNotificationPayload.php',
    'Google\\Service\\HomeGraphService\\SyncRequest' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/SyncRequest.php',
    'Google\\Service\\HomeGraphService\\SyncResponse' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/SyncResponse.php',
    'Google\\Service\\HomeGraphService\\SyncResponsePayload' => $vendorDir . '/google/apiclient-services/src/HomeGraphService/SyncResponsePayload.php',
    'Google\\Service\\IAMCredentials' => $vendorDir . '/google/apiclient-services/src/IAMCredentials.php',
    'Google\\Service\\IAMCredentials\\GenerateAccessTokenRequest' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/GenerateAccessTokenRequest.php',
    'Google\\Service\\IAMCredentials\\GenerateAccessTokenResponse' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/GenerateAccessTokenResponse.php',
    'Google\\Service\\IAMCredentials\\GenerateIdTokenRequest' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/GenerateIdTokenRequest.php',
    'Google\\Service\\IAMCredentials\\GenerateIdTokenResponse' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/GenerateIdTokenResponse.php',
    'Google\\Service\\IAMCredentials\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/Resource/Projects.php',
    'Google\\Service\\IAMCredentials\\Resource\\ProjectsServiceAccounts' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/Resource/ProjectsServiceAccounts.php',
    'Google\\Service\\IAMCredentials\\SignBlobRequest' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/SignBlobRequest.php',
    'Google\\Service\\IAMCredentials\\SignBlobResponse' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/SignBlobResponse.php',
    'Google\\Service\\IAMCredentials\\SignJwtRequest' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/SignJwtRequest.php',
    'Google\\Service\\IAMCredentials\\SignJwtResponse' => $vendorDir . '/google/apiclient-services/src/IAMCredentials/SignJwtResponse.php',
    'Google\\Service\\IDS' => $vendorDir . '/google/apiclient-services/src/IDS.php',
    'Google\\Service\\IDS\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/IDS/AuditConfig.php',
    'Google\\Service\\IDS\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/IDS/AuditLogConfig.php',
    'Google\\Service\\IDS\\Binding' => $vendorDir . '/google/apiclient-services/src/IDS/Binding.php',
    'Google\\Service\\IDS\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/IDS/CancelOperationRequest.php',
    'Google\\Service\\IDS\\Endpoint' => $vendorDir . '/google/apiclient-services/src/IDS/Endpoint.php',
    'Google\\Service\\IDS\\Expr' => $vendorDir . '/google/apiclient-services/src/IDS/Expr.php',
    'Google\\Service\\IDS\\IdsEmpty' => $vendorDir . '/google/apiclient-services/src/IDS/IdsEmpty.php',
    'Google\\Service\\IDS\\ListEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/IDS/ListEndpointsResponse.php',
    'Google\\Service\\IDS\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/IDS/ListLocationsResponse.php',
    'Google\\Service\\IDS\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/IDS/ListOperationsResponse.php',
    'Google\\Service\\IDS\\Location' => $vendorDir . '/google/apiclient-services/src/IDS/Location.php',
    'Google\\Service\\IDS\\Operation' => $vendorDir . '/google/apiclient-services/src/IDS/Operation.php',
    'Google\\Service\\IDS\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/IDS/OperationMetadata.php',
    'Google\\Service\\IDS\\Policy' => $vendorDir . '/google/apiclient-services/src/IDS/Policy.php',
    'Google\\Service\\IDS\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/IDS/Resource/Projects.php',
    'Google\\Service\\IDS\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/IDS/Resource/ProjectsLocations.php',
    'Google\\Service\\IDS\\Resource\\ProjectsLocationsEndpoints' => $vendorDir . '/google/apiclient-services/src/IDS/Resource/ProjectsLocationsEndpoints.php',
    'Google\\Service\\IDS\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/IDS/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\IDS\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/IDS/SetIamPolicyRequest.php',
    'Google\\Service\\IDS\\Status' => $vendorDir . '/google/apiclient-services/src/IDS/Status.php',
    'Google\\Service\\IDS\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/IDS/TestIamPermissionsRequest.php',
    'Google\\Service\\IDS\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/IDS/TestIamPermissionsResponse.php',
    'Google\\Service\\Iam' => $vendorDir . '/google/apiclient-services/src/Iam.php',
    'Google\\Service\\Iam\\AdminAuditData' => $vendorDir . '/google/apiclient-services/src/Iam/AdminAuditData.php',
    'Google\\Service\\Iam\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Iam/AuditConfig.php',
    'Google\\Service\\Iam\\AuditData' => $vendorDir . '/google/apiclient-services/src/Iam/AuditData.php',
    'Google\\Service\\Iam\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Iam/AuditLogConfig.php',
    'Google\\Service\\Iam\\AuditableService' => $vendorDir . '/google/apiclient-services/src/Iam/AuditableService.php',
    'Google\\Service\\Iam\\Aws' => $vendorDir . '/google/apiclient-services/src/Iam/Aws.php',
    'Google\\Service\\Iam\\Binding' => $vendorDir . '/google/apiclient-services/src/Iam/Binding.php',
    'Google\\Service\\Iam\\BindingDelta' => $vendorDir . '/google/apiclient-services/src/Iam/BindingDelta.php',
    'Google\\Service\\Iam\\CloudControl2SharedOperationsReconciliationOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/CloudControl2SharedOperationsReconciliationOperationMetadata.php',
    'Google\\Service\\Iam\\CreateRoleRequest' => $vendorDir . '/google/apiclient-services/src/Iam/CreateRoleRequest.php',
    'Google\\Service\\Iam\\CreateServiceAccountKeyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/CreateServiceAccountKeyRequest.php',
    'Google\\Service\\Iam\\CreateServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Iam/CreateServiceAccountRequest.php',
    'Google\\Service\\Iam\\DisableServiceAccountKeyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/DisableServiceAccountKeyRequest.php',
    'Google\\Service\\Iam\\DisableServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Iam/DisableServiceAccountRequest.php',
    'Google\\Service\\Iam\\EnableServiceAccountKeyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/EnableServiceAccountKeyRequest.php',
    'Google\\Service\\Iam\\EnableServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Iam/EnableServiceAccountRequest.php',
    'Google\\Service\\Iam\\Expr' => $vendorDir . '/google/apiclient-services/src/Iam/Expr.php',
    'Google\\Service\\Iam\\GoogleCloudCommonOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleCloudCommonOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamAdminV1AuditData' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamAdminV1AuditData.php',
    'Google\\Service\\Iam\\GoogleIamAdminV1AuditDataPermissionDelta' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamAdminV1AuditDataPermissionDelta.php',
    'Google\\Service\\Iam\\GoogleIamV1BindingDelta' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV1BindingDelta.php',
    'Google\\Service\\Iam\\GoogleIamV1LoggingAuditData' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV1LoggingAuditData.php',
    'Google\\Service\\Iam\\GoogleIamV1PolicyDelta' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV1PolicyDelta.php',
    'Google\\Service\\Iam\\GoogleIamV1betaWorkloadIdentityPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV1betaWorkloadIdentityPoolOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamV2DenyRule' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV2DenyRule.php',
    'Google\\Service\\Iam\\GoogleIamV2ListPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV2ListPoliciesResponse.php',
    'Google\\Service\\Iam\\GoogleIamV2Policy' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV2Policy.php',
    'Google\\Service\\Iam\\GoogleIamV2PolicyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV2PolicyOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamV2PolicyRule' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV2PolicyRule.php',
    'Google\\Service\\Iam\\GoogleIamV3OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV3OperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamV3alphaOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV3alphaOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamV3betaOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV3betaOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleIamV3mainOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleIamV3mainOperationMetadata.php',
    'Google\\Service\\Iam\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleLongrunningOperation.php',
    'Google\\Service\\Iam\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleRpcStatus.php',
    'Google\\Service\\Iam\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/Iam/GoogleTypeExpr.php',
    'Google\\Service\\Iam\\IamEmpty' => $vendorDir . '/google/apiclient-services/src/Iam/IamEmpty.php',
    'Google\\Service\\Iam\\LintPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/LintPolicyRequest.php',
    'Google\\Service\\Iam\\LintPolicyResponse' => $vendorDir . '/google/apiclient-services/src/Iam/LintPolicyResponse.php',
    'Google\\Service\\Iam\\LintResult' => $vendorDir . '/google/apiclient-services/src/Iam/LintResult.php',
    'Google\\Service\\Iam\\ListRolesResponse' => $vendorDir . '/google/apiclient-services/src/Iam/ListRolesResponse.php',
    'Google\\Service\\Iam\\ListServiceAccountKeysResponse' => $vendorDir . '/google/apiclient-services/src/Iam/ListServiceAccountKeysResponse.php',
    'Google\\Service\\Iam\\ListServiceAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Iam/ListServiceAccountsResponse.php',
    'Google\\Service\\Iam\\ListWorkloadIdentityPoolProvidersResponse' => $vendorDir . '/google/apiclient-services/src/Iam/ListWorkloadIdentityPoolProvidersResponse.php',
    'Google\\Service\\Iam\\ListWorkloadIdentityPoolsResponse' => $vendorDir . '/google/apiclient-services/src/Iam/ListWorkloadIdentityPoolsResponse.php',
    'Google\\Service\\Iam\\Oidc' => $vendorDir . '/google/apiclient-services/src/Iam/Oidc.php',
    'Google\\Service\\Iam\\Operation' => $vendorDir . '/google/apiclient-services/src/Iam/Operation.php',
    'Google\\Service\\Iam\\PatchServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Iam/PatchServiceAccountRequest.php',
    'Google\\Service\\Iam\\Permission' => $vendorDir . '/google/apiclient-services/src/Iam/Permission.php',
    'Google\\Service\\Iam\\PermissionDelta' => $vendorDir . '/google/apiclient-services/src/Iam/PermissionDelta.php',
    'Google\\Service\\Iam\\Policy' => $vendorDir . '/google/apiclient-services/src/Iam/Policy.php',
    'Google\\Service\\Iam\\PolicyDelta' => $vendorDir . '/google/apiclient-services/src/Iam/PolicyDelta.php',
    'Google\\Service\\Iam\\PolicyOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/PolicyOperationMetadata.php',
    'Google\\Service\\Iam\\QueryAuditableServicesRequest' => $vendorDir . '/google/apiclient-services/src/Iam/QueryAuditableServicesRequest.php',
    'Google\\Service\\Iam\\QueryAuditableServicesResponse' => $vendorDir . '/google/apiclient-services/src/Iam/QueryAuditableServicesResponse.php',
    'Google\\Service\\Iam\\QueryGrantableRolesRequest' => $vendorDir . '/google/apiclient-services/src/Iam/QueryGrantableRolesRequest.php',
    'Google\\Service\\Iam\\QueryGrantableRolesResponse' => $vendorDir . '/google/apiclient-services/src/Iam/QueryGrantableRolesResponse.php',
    'Google\\Service\\Iam\\QueryTestablePermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Iam/QueryTestablePermissionsRequest.php',
    'Google\\Service\\Iam\\QueryTestablePermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Iam/QueryTestablePermissionsResponse.php',
    'Google\\Service\\Iam\\Resource\\IamPolicies' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/IamPolicies.php',
    'Google\\Service\\Iam\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Locations.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePools' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePools.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsOperations.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsProviders' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsProviders.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsProvidersKeys' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsProvidersKeys.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsProvidersKeysOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsProvidersKeysOperations.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsProvidersOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsProvidersOperations.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsSubjects' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsSubjects.php',
    'Google\\Service\\Iam\\Resource\\LocationsWorkforcePoolsSubjectsOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/LocationsWorkforcePoolsSubjectsOperations.php',
    'Google\\Service\\Iam\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Organizations.php',
    'Google\\Service\\Iam\\Resource\\OrganizationsRoles' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/OrganizationsRoles.php',
    'Google\\Service\\Iam\\Resource\\Permissions' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Permissions.php',
    'Google\\Service\\Iam\\Resource\\Policies' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Policies.php',
    'Google\\Service\\Iam\\Resource\\PoliciesOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/PoliciesOperations.php',
    'Google\\Service\\Iam\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Projects.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocations.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPools' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPools.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPoolsOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPoolsOperations.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPoolsProviders' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPoolsProviders.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPoolsProvidersKeys' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPoolsProvidersKeys.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPoolsProvidersKeysOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPoolsProvidersKeysOperations.php',
    'Google\\Service\\Iam\\Resource\\ProjectsLocationsWorkloadIdentityPoolsProvidersOperations' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsLocationsWorkloadIdentityPoolsProvidersOperations.php',
    'Google\\Service\\Iam\\Resource\\ProjectsRoles' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsRoles.php',
    'Google\\Service\\Iam\\Resource\\ProjectsServiceAccounts' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsServiceAccounts.php',
    'Google\\Service\\Iam\\Resource\\ProjectsServiceAccountsKeys' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/ProjectsServiceAccountsKeys.php',
    'Google\\Service\\Iam\\Resource\\Roles' => $vendorDir . '/google/apiclient-services/src/Iam/Resource/Roles.php',
    'Google\\Service\\Iam\\Role' => $vendorDir . '/google/apiclient-services/src/Iam/Role.php',
    'Google\\Service\\Iam\\Saml' => $vendorDir . '/google/apiclient-services/src/Iam/Saml.php',
    'Google\\Service\\Iam\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Iam/ServiceAccount.php',
    'Google\\Service\\Iam\\ServiceAccountKey' => $vendorDir . '/google/apiclient-services/src/Iam/ServiceAccountKey.php',
    'Google\\Service\\Iam\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/SetIamPolicyRequest.php',
    'Google\\Service\\Iam\\SignBlobRequest' => $vendorDir . '/google/apiclient-services/src/Iam/SignBlobRequest.php',
    'Google\\Service\\Iam\\SignBlobResponse' => $vendorDir . '/google/apiclient-services/src/Iam/SignBlobResponse.php',
    'Google\\Service\\Iam\\SignJwtRequest' => $vendorDir . '/google/apiclient-services/src/Iam/SignJwtRequest.php',
    'Google\\Service\\Iam\\SignJwtResponse' => $vendorDir . '/google/apiclient-services/src/Iam/SignJwtResponse.php',
    'Google\\Service\\Iam\\Status' => $vendorDir . '/google/apiclient-services/src/Iam/Status.php',
    'Google\\Service\\Iam\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Iam/TestIamPermissionsRequest.php',
    'Google\\Service\\Iam\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Iam/TestIamPermissionsResponse.php',
    'Google\\Service\\Iam\\UndeleteRoleRequest' => $vendorDir . '/google/apiclient-services/src/Iam/UndeleteRoleRequest.php',
    'Google\\Service\\Iam\\UndeleteServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Iam/UndeleteServiceAccountRequest.php',
    'Google\\Service\\Iam\\UndeleteServiceAccountResponse' => $vendorDir . '/google/apiclient-services/src/Iam/UndeleteServiceAccountResponse.php',
    'Google\\Service\\Iam\\UndeleteWorkloadIdentityPoolProviderRequest' => $vendorDir . '/google/apiclient-services/src/Iam/UndeleteWorkloadIdentityPoolProviderRequest.php',
    'Google\\Service\\Iam\\UndeleteWorkloadIdentityPoolRequest' => $vendorDir . '/google/apiclient-services/src/Iam/UndeleteWorkloadIdentityPoolRequest.php',
    'Google\\Service\\Iam\\UploadServiceAccountKeyRequest' => $vendorDir . '/google/apiclient-services/src/Iam/UploadServiceAccountKeyRequest.php',
    'Google\\Service\\Iam\\WorkloadIdentityPool' => $vendorDir . '/google/apiclient-services/src/Iam/WorkloadIdentityPool.php',
    'Google\\Service\\Iam\\WorkloadIdentityPoolOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Iam/WorkloadIdentityPoolOperationMetadata.php',
    'Google\\Service\\Iam\\WorkloadIdentityPoolProvider' => $vendorDir . '/google/apiclient-services/src/Iam/WorkloadIdentityPoolProvider.php',
    'Google\\Service\\Ideahub' => $vendorDir . '/google/apiclient-services/src/Ideahub.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaAvailableLocale' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaAvailableLocale.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaIdea' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaIdea.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaIdeaActivity' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaIdeaActivity.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaIdeaState' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaIdeaState.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaListAvailableLocalesResponse' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaListAvailableLocalesResponse.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaListIdeasResponse' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaListIdeasResponse.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaTopic' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaTopic.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1alphaTopicState' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1alphaTopicState.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaAvailableLocale' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaAvailableLocale.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaIdea' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaIdea.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaIdeaActivity' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaIdeaActivity.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaIdeaState' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaIdeaState.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaListAvailableLocalesResponse' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaListAvailableLocalesResponse.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaListIdeasResponse' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaListIdeasResponse.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaTopic' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaTopic.php',
    'Google\\Service\\Ideahub\\GoogleSearchIdeahubV1betaTopicState' => $vendorDir . '/google/apiclient-services/src/Ideahub/GoogleSearchIdeahubV1betaTopicState.php',
    'Google\\Service\\Ideahub\\Resource\\Ideas' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/Ideas.php',
    'Google\\Service\\Ideahub\\Resource\\Platforms' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/Platforms.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsProperties' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsProperties.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsPropertiesIdeaActivities' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsPropertiesIdeaActivities.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsPropertiesIdeaStates' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsPropertiesIdeaStates.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsPropertiesIdeas' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsPropertiesIdeas.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsPropertiesLocales' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsPropertiesLocales.php',
    'Google\\Service\\Ideahub\\Resource\\PlatformsPropertiesTopicStates' => $vendorDir . '/google/apiclient-services/src/Ideahub/Resource/PlatformsPropertiesTopicStates.php',
    'Google\\Service\\IdentityToolkit' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit.php',
    'Google\\Service\\IdentityToolkit\\CreateAuthUriResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/CreateAuthUriResponse.php',
    'Google\\Service\\IdentityToolkit\\DeleteAccountResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/DeleteAccountResponse.php',
    'Google\\Service\\IdentityToolkit\\DownloadAccountResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/DownloadAccountResponse.php',
    'Google\\Service\\IdentityToolkit\\EmailLinkSigninResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/EmailLinkSigninResponse.php',
    'Google\\Service\\IdentityToolkit\\EmailTemplate' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/EmailTemplate.php',
    'Google\\Service\\IdentityToolkit\\GetAccountInfoResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/GetAccountInfoResponse.php',
    'Google\\Service\\IdentityToolkit\\GetOobConfirmationCodeResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/GetOobConfirmationCodeResponse.php',
    'Google\\Service\\IdentityToolkit\\GetRecaptchaParamResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/GetRecaptchaParamResponse.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyCreateAuthUriRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyCreateAuthUriRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyDeleteAccountRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyDeleteAccountRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyDownloadAccountRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyDownloadAccountRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyEmailLinkSigninRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyEmailLinkSigninRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyGetAccountInfoRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyGetAccountInfoRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyGetProjectConfigResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyGetProjectConfigResponse.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyResetPasswordRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyResetPasswordRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySendVerificationCodeRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySendVerificationCodeRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySendVerificationCodeResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySendVerificationCodeResponse.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySetAccountInfoRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySetAccountInfoRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySetProjectConfigRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySetProjectConfigRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySetProjectConfigResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySetProjectConfigResponse.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySignOutUserRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySignOutUserRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySignOutUserResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySignOutUserResponse.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartySignupNewUserRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartySignupNewUserRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyUploadAccountRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyUploadAccountRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyVerifyAssertionRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyVerifyAssertionRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyVerifyCustomTokenRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyVerifyCustomTokenRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyVerifyPasswordRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyVerifyPasswordRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyVerifyPhoneNumberRequest' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyVerifyPhoneNumberRequest.php',
    'Google\\Service\\IdentityToolkit\\IdentitytoolkitRelyingpartyVerifyPhoneNumberResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdentitytoolkitRelyingpartyVerifyPhoneNumberResponse.php',
    'Google\\Service\\IdentityToolkit\\IdpConfig' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/IdpConfig.php',
    'Google\\Service\\IdentityToolkit\\Relyingparty' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/Relyingparty.php',
    'Google\\Service\\IdentityToolkit\\ResetPasswordResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/ResetPasswordResponse.php',
    'Google\\Service\\IdentityToolkit\\Resource\\Relyingparty' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/Resource/Relyingparty.php',
    'Google\\Service\\IdentityToolkit\\SetAccountInfoResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/SetAccountInfoResponse.php',
    'Google\\Service\\IdentityToolkit\\SetAccountInfoResponseProviderUserInfo' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/SetAccountInfoResponseProviderUserInfo.php',
    'Google\\Service\\IdentityToolkit\\SignupNewUserResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/SignupNewUserResponse.php',
    'Google\\Service\\IdentityToolkit\\UploadAccountResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/UploadAccountResponse.php',
    'Google\\Service\\IdentityToolkit\\UploadAccountResponseError' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/UploadAccountResponseError.php',
    'Google\\Service\\IdentityToolkit\\UserInfo' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/UserInfo.php',
    'Google\\Service\\IdentityToolkit\\UserInfoProviderUserInfo' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/UserInfoProviderUserInfo.php',
    'Google\\Service\\IdentityToolkit\\VerifyAssertionResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/VerifyAssertionResponse.php',
    'Google\\Service\\IdentityToolkit\\VerifyCustomTokenResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/VerifyCustomTokenResponse.php',
    'Google\\Service\\IdentityToolkit\\VerifyPasswordResponse' => $vendorDir . '/google/apiclient-services/src/IdentityToolkit/VerifyPasswordResponse.php',
    'Google\\Service\\Indexing' => $vendorDir . '/google/apiclient-services/src/Indexing.php',
    'Google\\Service\\Indexing\\PublishUrlNotificationResponse' => $vendorDir . '/google/apiclient-services/src/Indexing/PublishUrlNotificationResponse.php',
    'Google\\Service\\Indexing\\Resource\\UrlNotifications' => $vendorDir . '/google/apiclient-services/src/Indexing/Resource/UrlNotifications.php',
    'Google\\Service\\Indexing\\UrlNotification' => $vendorDir . '/google/apiclient-services/src/Indexing/UrlNotification.php',
    'Google\\Service\\Indexing\\UrlNotificationMetadata' => $vendorDir . '/google/apiclient-services/src/Indexing/UrlNotificationMetadata.php',
    'Google\\Service\\Integrations' => $vendorDir . '/google/apiclient-services/src/Integrations.php',
    'Google\\Service\\Integrations\\CrmlogErrorCode' => $vendorDir . '/google/apiclient-services/src/Integrations/CrmlogErrorCode.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsCellValue' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsCellValue.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsRow' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsRow.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsTabularData' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsTabularData.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsTemplatesAplosSeriesData' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsTemplatesAplosSeriesData.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsTemplatesAplosSeriesDataRow' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsTemplatesAplosSeriesDataRow.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsTemplatesAplosSeriesListData' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsTemplatesAplosSeriesListData.php',
    'Google\\Service\\Integrations\\EnterpriseCrmCardsTemplatesAplosSeriesListDataSeries' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmCardsTemplatesAplosSeriesListDataSeries.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusAuthconfigAuthConfigTaskParam' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusAuthconfigAuthConfigTaskParam.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoAddress' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoAddress.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoAttributes' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoAttributes.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBaseAlertConfigErrorEnumList' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBaseAlertConfigErrorEnumList.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBaseAlertConfigThresholdValue' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBaseAlertConfigThresholdValue.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBaseFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBaseFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBaseValue' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBaseValue.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBooleanArrayFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBooleanArrayFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBooleanFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBooleanFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBooleanParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBooleanParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoBuganizerNotification' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoBuganizerNotification.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCloudKmsConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCloudKmsConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCloudLoggingDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCloudLoggingDetails.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCloudSchedulerConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCloudSchedulerConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCombinedCondition' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCombinedCondition.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCondition' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCondition.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoConditionResult' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoConditionResult.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoConditionalFailurePolicies' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoConditionalFailurePolicies.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoConnectorsConnection' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoConnectorsConnection.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoConnectorsGenericConnectorTaskConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoConnectorsGenericConnectorTaskConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCoordinate' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCoordinate.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoCustomSuspensionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoCustomSuspensionRequest.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoDoubleArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoDoubleArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoDoubleArrayFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoDoubleArrayFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoDoubleFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoDoubleFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoDoubleParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoDoubleParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoErrorDetail' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoErrorDetail.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventBusProperties' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventBusProperties.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventExecutionDetails.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventExecutionDetailsEventAttemptStats' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventExecutionDetailsEventAttemptStats.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventExecutionSnapshot' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventExecutionSnapshot.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventExecutionSnapshotEventExecutionSnapshotMetadata' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventExecutionSnapshotEventExecutionSnapshotMetadata.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoEventParameters' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoEventParameters.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoExecutionTraceInfo' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoExecutionTraceInfo.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoExternalTraffic' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoExternalTraffic.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoFailurePolicy' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoFailurePolicy.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoField' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoField.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoFieldMappingConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoFieldMappingConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoFunctionType' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoFunctionType.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoIntArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoIntArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoIntArrayFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoIntArrayFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoIntFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoIntFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoIntParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoIntParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoJsonFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoJsonFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoLogSettings' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoLogSettings.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoLoopMetadata' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoLoopMetadata.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoMappedField' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoMappedField.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoNextTask' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoNextTask.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoNextTeardownTask' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoNextTeardownTask.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoNodeIdentifier' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoNodeIdentifier.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoNotification' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoNotification.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryProtoDefinition' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryProtoDefinition.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryValidationRule' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryValidationRule.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleDoubleRange' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleDoubleRange.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleIntRange' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleIntRange.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleStringRegex' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParamSpecEntryValidationRuleStringRegex.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParameterEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParameterEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParameterMap' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParameterMap.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParameterMapEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParameterMapEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParameterMapField' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParameterMapField.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoParameterValueType' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoParameterValueType.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoPropertyEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoPropertyEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoProtoArrayFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoProtoArrayFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoProtoFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoProtoFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoProtoParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoProtoParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoScatterResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoScatterResponse.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSerializedObjectParameter' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSerializedObjectParameter.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoStringArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoStringArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoStringArrayFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoStringArrayFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoStringFunction' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoStringFunction.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoStringParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoStringParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuccessPolicy' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuccessPolicy.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionAuthPermissions' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionAuthPermissions.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionAuthPermissionsGaiaIdentity' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionAuthPermissionsGaiaIdentity.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionExpiration' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionExpiration.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionResolutionInfo' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionResolutionInfo.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoSuspensionResolutionInfoAudit' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoSuspensionResolutionInfoAudit.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskAlertConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskAlertConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskExecutionDetails.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskExecutionDetailsTaskAttemptStats' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskExecutionDetailsTaskAttemptStats.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskMetadata' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskMetadata.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskMetadataAdmin' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskMetadataAdmin.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskUiConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskUiConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTaskUiModuleConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTaskUiModuleConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTeardown' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTeardown.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTeardownTaskConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTeardownTaskConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoToken' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoToken.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTransformExpression' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTransformExpression.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoTriggerCriteria' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoTriggerCriteria.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoValueType' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoValueType.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusProtoWorkflowAlertConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusProtoWorkflowAlertConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusStats' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusStats.php',
    'Google\\Service\\Integrations\\EnterpriseCrmEventbusStatsDimensions' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmEventbusStatsDimensions.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoBooleanParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoBooleanParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoDoubleParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoDoubleParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoEventExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoEventExecutionDetails.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoEventExecutionInfo' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoEventExecutionInfo.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoEventExecutionInfoReplayInfo' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoEventExecutionInfoReplayInfo.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoEventExecutionSnapshot' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoEventExecutionSnapshot.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoEventParameters' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoEventParameters.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoIntParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoIntParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParamSpecEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParamSpecEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParamSpecsMessage' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParamSpecsMessage.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParameterEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParameterEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParameterMap' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParameterMap.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParameterMapEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParameterMapEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParameterMapField' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParameterMapField.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoParameterValueType' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoParameterValueType.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoProtoParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoProtoParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoRollbackStrategy' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoRollbackStrategy.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoSerializedObjectParameter' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoSerializedObjectParameter.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoStringParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoStringParameterArray.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoTaskConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoTaskConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoTaskEntity' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoTaskEntity.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoTriggerConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoTriggerConfig.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoWorkflowParameterEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoWorkflowParameterEntry.php',
    'Google\\Service\\Integrations\\EnterpriseCrmFrontendsEventbusProtoWorkflowParameters' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmFrontendsEventbusProtoWorkflowParameters.php',
    'Google\\Service\\Integrations\\EnterpriseCrmLoggingGwsFieldLimits' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmLoggingGwsFieldLimits.php',
    'Google\\Service\\Integrations\\EnterpriseCrmLoggingGwsSanitizeOptions' => $vendorDir . '/google/apiclient-services/src/Integrations/EnterpriseCrmLoggingGwsSanitizeOptions.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigOauth2AuthCodeFlow' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigOauth2AuthCodeFlow.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigOauth2AuthCodeFlowGoogleManaged' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigOauth2AuthCodeFlowGoogleManaged.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigOauth2ClientCredentials' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigOauth2ClientCredentials.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigOauth2JwtBearer' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigOauth2JwtBearer.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigOauth2JwtBearerJwtClaims' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigOauth2JwtBearerJwtClaims.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigSshPublicKey' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigSshPublicKey.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1AuthConfigUserPassword' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1AuthConfigUserPassword.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1BillingConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1BillingConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1ConfigVariable' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1ConfigVariable.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1Connection' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1Connection.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1ConnectionStatus' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1ConnectionStatus.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1ConnectorVersionInfraConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1ConnectorVersionInfraConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1Destination' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1Destination.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1DestinationConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1DestinationConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EncryptionKey' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EncryptionKey.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EventingConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EventingConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EventingConfigDeadLetterConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EventingConfigDeadLetterConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EventingRuntimeData' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EventingRuntimeData.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EventingRuntimeDataWebhookData' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EventingRuntimeDataWebhookData.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1EventingStatus' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1EventingStatus.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1HPAConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1HPAConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1LockConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1LockConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1LogConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1LogConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1NodeConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1NodeConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1ResourceLimits' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1ResourceLimits.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1ResourceRequests' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1ResourceRequests.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1Secret' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1Secret.php',
    'Google\\Service\\Integrations\\GoogleCloudConnectorsV1SslConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudConnectorsV1SslConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAccessToken' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAccessToken.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaArchiveBundleRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaArchiveBundleRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaArchiveBundleResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaArchiveBundleResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaArchiveIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaArchiveIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaArchiveIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaArchiveIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAssertion' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAssertion.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAssertionResult' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAssertionResult.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAttemptStats' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAttemptStats.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAuthConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAuthConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaAuthToken' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaAuthToken.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaBooleanParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaBooleanParameterArray.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCancelExecutionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCancelExecutionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCancelExecutionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCancelExecutionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCertificate' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCertificate.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaClientCertificate' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaClientCertificate.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaClientConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaClientConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCloudKmsConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCloudKmsConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCloudLoggingConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCloudLoggingConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCloudLoggingDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCloudLoggingDetails.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCloudSchedulerConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCloudSchedulerConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaConditionalFailurePolicies' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaConditionalFailurePolicies.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaConnectionSchemaMetadata' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaConnectionSchemaMetadata.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCoordinate' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCoordinate.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateAppsScriptProjectRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateAppsScriptProjectRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateAppsScriptProjectResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateAppsScriptProjectResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateBundleRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateBundleRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateBundleResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateBundleResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateCloudFunctionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateCloudFunctionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCreateCloudFunctionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCreateCloudFunctionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaCredential' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaCredential.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDeactivateIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDeactivateIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDeactivateIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDeactivateIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDeprovisionClientRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDeprovisionClientRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDoubleParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDoubleParameterArray.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDownloadExecutionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDownloadExecutionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDownloadIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDownloadIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDownloadJsonPackageResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDownloadJsonPackageResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaDownloadTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaDownloadTemplateResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaEnumerateConnectorPlatformRegionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaEnumerateConnectorPlatformRegionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaErrorCatcherConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaErrorCatcherConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaEventParameter' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaEventParameter.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteEventRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteEventRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteEventResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteEventResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteIntegrationsRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteIntegrationsRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteIntegrationsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteIntegrationsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteTestCaseRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteTestCaseRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecuteTestCaseResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecuteTestCaseResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecution' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecution.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecutionDetails.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecutionReplayInfo' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecutionReplayInfo.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecutionSnapshot' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecutionSnapshot.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaExecutionSnapshotExecutionSnapshotMetadata' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaExecutionSnapshotExecutionSnapshotMetadata.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaFailurePolicy' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaFailurePolicy.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaFile' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaFile.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaGenerateTokenResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaGenerateTokenResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaGetBundleResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaGetBundleResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaGetClientMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaGetClientMetadataResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaGetClientResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaGetClientResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaImportTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaImportTemplateRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaImportTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaImportTemplateResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntParameterArray.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegration' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegration.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationAlertConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationAlertConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationAlertConfigThresholdValue' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationAlertConfigThresholdValue.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationBundleConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationBundleConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationConfigParameter' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationConfigParameter.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationParameter' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationParameter.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationTemplateVersion' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationTemplateVersion.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationVersion' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationVersion.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaIntegrationVersionTemplate' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaIntegrationVersionTemplate.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaJwt' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaJwt.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaLiftSuspensionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaLiftSuspensionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaLiftSuspensionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaLiftSuspensionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaLinkAppsScriptProjectRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaLinkAppsScriptProjectRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaLinkAppsScriptProjectResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaLinkAppsScriptProjectResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListAuthConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListAuthConfigsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListCertificatesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListConnectionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListExecutionSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListExecutionSnapshotsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListExecutionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListIntegrationTemplateVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListIntegrationTemplateVersionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListIntegrationVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListIntegrationVersionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListIntegrationsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListIntegrationsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListRuntimeActionSchemasResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListRuntimeActionSchemasResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListRuntimeEntitySchemasResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListRuntimeEntitySchemasResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListSfdcChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListSfdcChannelsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListSfdcInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListSfdcInstancesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListSuspensionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListSuspensionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListTaskEntitiesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListTaskEntitiesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListTemplatesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListTestCaseExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListTestCaseExecutionsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaListTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaListTestCasesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMockConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMockConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestGroupBy' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestGroupBy.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQuery' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQuery.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryComponent' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryComponent.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationMode' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationMode.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationModeJoinConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationModeJoinConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationModeUnionConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsRequestMashQueryOperationModeUnionConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaMonitorExecutionStatsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaMonitorExecutionStatsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaNextTask' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaNextTask.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaOAuth2AuthorizationCode' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaOAuth2AuthorizationCode.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaOAuth2ClientCredentials' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaOAuth2ClientCredentials.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaOAuth2ResourceOwnerCredentials' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaOAuth2ResourceOwnerCredentials.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaOidcToken' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaOidcToken.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaParameterMap' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaParameterMap.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaParameterMapEntry' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaParameterMapEntry.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaParameterMapField' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaParameterMapField.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaProjectProperties' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaProjectProperties.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaProvisionClientRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaProvisionClientRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaPublishIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaPublishIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaPublishIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaPublishIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaReplaceServiceAccountRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaReplaceServiceAccountRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaReplayExecutionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaReplayExecutionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaReplayExecutionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaReplayExecutionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaResolveSuspensionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaResolveSuspensionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaResolveSuspensionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaResolveSuspensionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaRuntimeActionSchema' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaRuntimeActionSchema.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaRuntimeEntitySchema' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaRuntimeEntitySchema.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaScheduleIntegrationsRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaScheduleIntegrationsRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaScheduleIntegrationsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaScheduleIntegrationsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSearchTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSearchTemplatesResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSerializedFile' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSerializedFile.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaServiceAccountCredentials' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaServiceAccountCredentials.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSfdcChannel' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSfdcChannel.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSfdcInstance' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSfdcInstance.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaShareTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaShareTemplateRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaStringParameterArray' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaStringParameterArray.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSuccessPolicy' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSuccessPolicy.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSuspension' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSuspension.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSuspensionApprovalConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSuspensionApprovalConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSuspensionApprovalExpiration' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSuspensionApprovalExpiration.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSuspensionAudit' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSuspensionAudit.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSwitchEncryptionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSwitchEncryptionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaSwitchVariableMaskingRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaSwitchVariableMaskingRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTakeoverEditLockRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTakeoverEditLockRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTakeoverEditLockResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTakeoverEditLockResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTaskConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTaskConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTaskExecutionDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTaskExecutionDetails.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTemplate' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTemplate.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTemplateBundle' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTemplateBundle.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTemplateComponent' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTemplateComponent.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTestCase' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTestCase.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTestIntegrationsRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTestIntegrationsRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTestIntegrationsResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTestIntegrationsResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTestTaskConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTestTaskConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaTriggerConfig' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaTriggerConfig.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUnpublishIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUnpublishIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUnshareTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUnshareTemplateRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUpdateBundleRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUpdateBundleRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUpdateBundleResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUpdateBundleResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUploadIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUploadIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUploadIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUploadIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUploadTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUploadTemplateRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUploadTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUploadTemplateResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUseTemplateRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUseTemplateRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUseTemplateRequestIntegrationDetails' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUseTemplateRequestIntegrationDetails.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUseTemplateResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUseTemplateResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaUsernameAndPassword' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaUsernameAndPassword.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaValidateIntegrationVersionRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaValidateIntegrationVersionRequest.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaValidateIntegrationVersionResponse' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaValidateIntegrationVersionResponse.php',
    'Google\\Service\\Integrations\\GoogleCloudIntegrationsV1alphaValueType' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleCloudIntegrationsV1alphaValueType.php',
    'Google\\Service\\Integrations\\GoogleInternalCloudCrmEventbusV3PostToQueueWithTriggerIdRequest' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleInternalCloudCrmEventbusV3PostToQueueWithTriggerIdRequest.php',
    'Google\\Service\\Integrations\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Integrations/GoogleProtobufEmpty.php',
    'Google\\Service\\Integrations\\IoCloudeventsV1CloudEvent' => $vendorDir . '/google/apiclient-services/src/Integrations/IoCloudeventsV1CloudEvent.php',
    'Google\\Service\\Integrations\\IoCloudeventsV1CloudEventCloudEventAttributeValue' => $vendorDir . '/google/apiclient-services/src/Integrations/IoCloudeventsV1CloudEventCloudEventAttributeValue.php',
    'Google\\Service\\Integrations\\Resource\\Callback' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/Callback.php',
    'Google\\Service\\Integrations\\Resource\\ConnectorPlatformRegions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ConnectorPlatformRegions.php',
    'Google\\Service\\Integrations\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/Projects.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocations.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsAppsScriptProjects' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsAppsScriptProjects.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsAuthConfigs' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsAuthConfigs.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsCertificates' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsCertificates.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsClients' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsClients.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsCloudFunctions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsCloudFunctions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsConnections' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsConnections.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsConnectionsRuntimeActionSchemas' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsConnectionsRuntimeActionSchemas.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsConnectionsRuntimeEntitySchemas' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsConnectionsRuntimeEntitySchemas.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrations' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrations.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrationsExecutions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrationsExecutions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrationsExecutionsSuspensions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrationsExecutionsSuspensions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrationsExecutionsnapshots' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrationsExecutionsnapshots.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrationsVersions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrationsVersions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsIntegrationsVersionsTestCases' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsIntegrationsVersionsTestCases.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProducts' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProducts.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsAuthConfigs' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsAuthConfigs.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsCertificates' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsCertificates.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsCloudFunctions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsCloudFunctions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrations' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrations.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationsExecutions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationsExecutions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationsExecutionsSuspensions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationsExecutionsSuspensions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationsExecutionsnapshots' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationsExecutionsnapshots.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationsVersions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationsVersions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationsVersionsTestCases' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationsVersionsTestCases.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationtemplates' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationtemplates.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsIntegrationtemplatesVersions' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsIntegrationtemplatesVersions.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsSfdcInstances' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsSfdcInstances.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsProductsSfdcInstancesSfdcChannels' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsProductsSfdcInstancesSfdcChannels.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsSfdcInstances' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsSfdcInstances.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsSfdcInstancesSfdcChannels' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsSfdcInstancesSfdcChannels.php',
    'Google\\Service\\Integrations\\Resource\\ProjectsLocationsTemplates' => $vendorDir . '/google/apiclient-services/src/Integrations/Resource/ProjectsLocationsTemplates.php',
    'Google\\Service\\Keep' => $vendorDir . '/google/apiclient-services/src/Keep.php',
    'Google\\Service\\Keep\\Attachment' => $vendorDir . '/google/apiclient-services/src/Keep/Attachment.php',
    'Google\\Service\\Keep\\BatchCreatePermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Keep/BatchCreatePermissionsRequest.php',
    'Google\\Service\\Keep\\BatchCreatePermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Keep/BatchCreatePermissionsResponse.php',
    'Google\\Service\\Keep\\BatchDeletePermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Keep/BatchDeletePermissionsRequest.php',
    'Google\\Service\\Keep\\CreatePermissionRequest' => $vendorDir . '/google/apiclient-services/src/Keep/CreatePermissionRequest.php',
    'Google\\Service\\Keep\\Family' => $vendorDir . '/google/apiclient-services/src/Keep/Family.php',
    'Google\\Service\\Keep\\Group' => $vendorDir . '/google/apiclient-services/src/Keep/Group.php',
    'Google\\Service\\Keep\\KeepEmpty' => $vendorDir . '/google/apiclient-services/src/Keep/KeepEmpty.php',
    'Google\\Service\\Keep\\ListContent' => $vendorDir . '/google/apiclient-services/src/Keep/ListContent.php',
    'Google\\Service\\Keep\\ListItem' => $vendorDir . '/google/apiclient-services/src/Keep/ListItem.php',
    'Google\\Service\\Keep\\ListNotesResponse' => $vendorDir . '/google/apiclient-services/src/Keep/ListNotesResponse.php',
    'Google\\Service\\Keep\\Note' => $vendorDir . '/google/apiclient-services/src/Keep/Note.php',
    'Google\\Service\\Keep\\Permission' => $vendorDir . '/google/apiclient-services/src/Keep/Permission.php',
    'Google\\Service\\Keep\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/Keep/Resource/Media.php',
    'Google\\Service\\Keep\\Resource\\Notes' => $vendorDir . '/google/apiclient-services/src/Keep/Resource/Notes.php',
    'Google\\Service\\Keep\\Resource\\NotesPermissions' => $vendorDir . '/google/apiclient-services/src/Keep/Resource/NotesPermissions.php',
    'Google\\Service\\Keep\\Section' => $vendorDir . '/google/apiclient-services/src/Keep/Section.php',
    'Google\\Service\\Keep\\TextContent' => $vendorDir . '/google/apiclient-services/src/Keep/TextContent.php',
    'Google\\Service\\Keep\\User' => $vendorDir . '/google/apiclient-services/src/Keep/User.php',
    'Google\\Service\\Kgsearch' => $vendorDir . '/google/apiclient-services/src/Kgsearch.php',
    'Google\\Service\\Kgsearch\\Resource\\Entities' => $vendorDir . '/google/apiclient-services/src/Kgsearch/Resource/Entities.php',
    'Google\\Service\\Kgsearch\\SearchResponse' => $vendorDir . '/google/apiclient-services/src/Kgsearch/SearchResponse.php',
    'Google\\Service\\Kmsinventory' => $vendorDir . '/google/apiclient-services/src/Kmsinventory.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsInventoryV1ListCryptoKeysResponse' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsInventoryV1ListCryptoKeysResponse.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsInventoryV1ProtectedResource' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsInventoryV1ProtectedResource.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsInventoryV1ProtectedResourcesSummary' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsInventoryV1ProtectedResourcesSummary.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsInventoryV1SearchProtectedResourcesResponse' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsInventoryV1SearchProtectedResourcesResponse.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1CryptoKey' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1CryptoKey.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1CryptoKeyVersion' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1CryptoKeyVersion.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1CryptoKeyVersionTemplate' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1CryptoKeyVersionTemplate.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1ExternalProtectionLevelOptions' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1ExternalProtectionLevelOptions.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1KeyAccessJustificationsPolicy' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1KeyAccessJustificationsPolicy.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1KeyOperationAttestation' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1KeyOperationAttestation.php',
    'Google\\Service\\Kmsinventory\\GoogleCloudKmsV1KeyOperationAttestationCertificateChains' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/GoogleCloudKmsV1KeyOperationAttestationCertificateChains.php',
    'Google\\Service\\Kmsinventory\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/Organizations.php',
    'Google\\Service\\Kmsinventory\\Resource\\OrganizationsProtectedResources' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/OrganizationsProtectedResources.php',
    'Google\\Service\\Kmsinventory\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/Projects.php',
    'Google\\Service\\Kmsinventory\\Resource\\ProjectsCryptoKeys' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/ProjectsCryptoKeys.php',
    'Google\\Service\\Kmsinventory\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/ProjectsLocations.php',
    'Google\\Service\\Kmsinventory\\Resource\\ProjectsLocationsKeyRings' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/ProjectsLocationsKeyRings.php',
    'Google\\Service\\Kmsinventory\\Resource\\ProjectsLocationsKeyRingsCryptoKeys' => $vendorDir . '/google/apiclient-services/src/Kmsinventory/Resource/ProjectsLocationsKeyRingsCryptoKeys.php',
    'Google\\Service\\Libraryagent' => $vendorDir . '/google/apiclient-services/src/Libraryagent.php',
    'Google\\Service\\Libraryagent\\GoogleExampleLibraryagentV1Book' => $vendorDir . '/google/apiclient-services/src/Libraryagent/GoogleExampleLibraryagentV1Book.php',
    'Google\\Service\\Libraryagent\\GoogleExampleLibraryagentV1ListBooksResponse' => $vendorDir . '/google/apiclient-services/src/Libraryagent/GoogleExampleLibraryagentV1ListBooksResponse.php',
    'Google\\Service\\Libraryagent\\GoogleExampleLibraryagentV1ListShelvesResponse' => $vendorDir . '/google/apiclient-services/src/Libraryagent/GoogleExampleLibraryagentV1ListShelvesResponse.php',
    'Google\\Service\\Libraryagent\\GoogleExampleLibraryagentV1Shelf' => $vendorDir . '/google/apiclient-services/src/Libraryagent/GoogleExampleLibraryagentV1Shelf.php',
    'Google\\Service\\Libraryagent\\Resource\\Shelves' => $vendorDir . '/google/apiclient-services/src/Libraryagent/Resource/Shelves.php',
    'Google\\Service\\Libraryagent\\Resource\\ShelvesBooks' => $vendorDir . '/google/apiclient-services/src/Libraryagent/Resource/ShelvesBooks.php',
    'Google\\Service\\Licensing' => $vendorDir . '/google/apiclient-services/src/Licensing.php',
    'Google\\Service\\Licensing\\LicenseAssignment' => $vendorDir . '/google/apiclient-services/src/Licensing/LicenseAssignment.php',
    'Google\\Service\\Licensing\\LicenseAssignmentInsert' => $vendorDir . '/google/apiclient-services/src/Licensing/LicenseAssignmentInsert.php',
    'Google\\Service\\Licensing\\LicenseAssignmentList' => $vendorDir . '/google/apiclient-services/src/Licensing/LicenseAssignmentList.php',
    'Google\\Service\\Licensing\\LicensingEmpty' => $vendorDir . '/google/apiclient-services/src/Licensing/LicensingEmpty.php',
    'Google\\Service\\Licensing\\Resource\\LicenseAssignments' => $vendorDir . '/google/apiclient-services/src/Licensing/Resource/LicenseAssignments.php',
    'Google\\Service\\Localservices' => $vendorDir . '/google/apiclient-services/src/Localservices.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1AccountReport' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1AccountReport.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1AggregatorInfo' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1BookingLead' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1BookingLead.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1MessageLead' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1MessageLead.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1PhoneLead' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1PhoneLead.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse.php',
    'Google\\Service\\Localservices\\GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse.php',
    'Google\\Service\\Localservices\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Localservices/GoogleTypeTimeZone.php',
    'Google\\Service\\Localservices\\Resource\\AccountReports' => $vendorDir . '/google/apiclient-services/src/Localservices/Resource/AccountReports.php',
    'Google\\Service\\Localservices\\Resource\\DetailedLeadReports' => $vendorDir . '/google/apiclient-services/src/Localservices/Resource/DetailedLeadReports.php',
    'Google\\Service\\Logging' => $vendorDir . '/google/apiclient-services/src/Logging.php',
    'Google\\Service\\Logging\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Logging/AuditConfig.php',
    'Google\\Service\\Logging\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Logging/AuditLogConfig.php',
    'Google\\Service\\Logging\\BigQueryDataset' => $vendorDir . '/google/apiclient-services/src/Logging/BigQueryDataset.php',
    'Google\\Service\\Logging\\BigQueryOptions' => $vendorDir . '/google/apiclient-services/src/Logging/BigQueryOptions.php',
    'Google\\Service\\Logging\\Binding' => $vendorDir . '/google/apiclient-services/src/Logging/Binding.php',
    'Google\\Service\\Logging\\BucketMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/BucketMetadata.php',
    'Google\\Service\\Logging\\BucketOptions' => $vendorDir . '/google/apiclient-services/src/Logging/BucketOptions.php',
    'Google\\Service\\Logging\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Logging/CancelOperationRequest.php',
    'Google\\Service\\Logging\\CmekSettings' => $vendorDir . '/google/apiclient-services/src/Logging/CmekSettings.php',
    'Google\\Service\\Logging\\CopyLogEntriesMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/CopyLogEntriesMetadata.php',
    'Google\\Service\\Logging\\CopyLogEntriesRequest' => $vendorDir . '/google/apiclient-services/src/Logging/CopyLogEntriesRequest.php',
    'Google\\Service\\Logging\\CopyLogEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/CopyLogEntriesResponse.php',
    'Google\\Service\\Logging\\CreateBucketRequest' => $vendorDir . '/google/apiclient-services/src/Logging/CreateBucketRequest.php',
    'Google\\Service\\Logging\\CreateLinkRequest' => $vendorDir . '/google/apiclient-services/src/Logging/CreateLinkRequest.php',
    'Google\\Service\\Logging\\DefaultSinkConfig' => $vendorDir . '/google/apiclient-services/src/Logging/DefaultSinkConfig.php',
    'Google\\Service\\Logging\\DeleteLinkRequest' => $vendorDir . '/google/apiclient-services/src/Logging/DeleteLinkRequest.php',
    'Google\\Service\\Logging\\Explicit' => $vendorDir . '/google/apiclient-services/src/Logging/Explicit.php',
    'Google\\Service\\Logging\\Exponential' => $vendorDir . '/google/apiclient-services/src/Logging/Exponential.php',
    'Google\\Service\\Logging\\Expr' => $vendorDir . '/google/apiclient-services/src/Logging/Expr.php',
    'Google\\Service\\Logging\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Logging/GetIamPolicyRequest.php',
    'Google\\Service\\Logging\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/Logging/GetPolicyOptions.php',
    'Google\\Service\\Logging\\HttpRequest' => $vendorDir . '/google/apiclient-services/src/Logging/HttpRequest.php',
    'Google\\Service\\Logging\\IndexConfig' => $vendorDir . '/google/apiclient-services/src/Logging/IndexConfig.php',
    'Google\\Service\\Logging\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/Logging/LabelDescriptor.php',
    'Google\\Service\\Logging\\Linear' => $vendorDir . '/google/apiclient-services/src/Logging/Linear.php',
    'Google\\Service\\Logging\\Link' => $vendorDir . '/google/apiclient-services/src/Logging/Link.php',
    'Google\\Service\\Logging\\LinkMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/LinkMetadata.php',
    'Google\\Service\\Logging\\ListBucketsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListBucketsResponse.php',
    'Google\\Service\\Logging\\ListExclusionsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListExclusionsResponse.php',
    'Google\\Service\\Logging\\ListLinksResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListLinksResponse.php',
    'Google\\Service\\Logging\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListLocationsResponse.php',
    'Google\\Service\\Logging\\ListLogEntriesRequest' => $vendorDir . '/google/apiclient-services/src/Logging/ListLogEntriesRequest.php',
    'Google\\Service\\Logging\\ListLogEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListLogEntriesResponse.php',
    'Google\\Service\\Logging\\ListLogMetricsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListLogMetricsResponse.php',
    'Google\\Service\\Logging\\ListLogsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListLogsResponse.php',
    'Google\\Service\\Logging\\ListMonitoredResourceDescriptorsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListMonitoredResourceDescriptorsResponse.php',
    'Google\\Service\\Logging\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListOperationsResponse.php',
    'Google\\Service\\Logging\\ListRecentQueriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListRecentQueriesResponse.php',
    'Google\\Service\\Logging\\ListSavedQueriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListSavedQueriesResponse.php',
    'Google\\Service\\Logging\\ListSinksResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListSinksResponse.php',
    'Google\\Service\\Logging\\ListViewsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/ListViewsResponse.php',
    'Google\\Service\\Logging\\Location' => $vendorDir . '/google/apiclient-services/src/Logging/Location.php',
    'Google\\Service\\Logging\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/LocationMetadata.php',
    'Google\\Service\\Logging\\LogBucket' => $vendorDir . '/google/apiclient-services/src/Logging/LogBucket.php',
    'Google\\Service\\Logging\\LogEntry' => $vendorDir . '/google/apiclient-services/src/Logging/LogEntry.php',
    'Google\\Service\\Logging\\LogEntryOperation' => $vendorDir . '/google/apiclient-services/src/Logging/LogEntryOperation.php',
    'Google\\Service\\Logging\\LogEntrySourceLocation' => $vendorDir . '/google/apiclient-services/src/Logging/LogEntrySourceLocation.php',
    'Google\\Service\\Logging\\LogErrorGroup' => $vendorDir . '/google/apiclient-services/src/Logging/LogErrorGroup.php',
    'Google\\Service\\Logging\\LogExclusion' => $vendorDir . '/google/apiclient-services/src/Logging/LogExclusion.php',
    'Google\\Service\\Logging\\LogLine' => $vendorDir . '/google/apiclient-services/src/Logging/LogLine.php',
    'Google\\Service\\Logging\\LogMetric' => $vendorDir . '/google/apiclient-services/src/Logging/LogMetric.php',
    'Google\\Service\\Logging\\LogSink' => $vendorDir . '/google/apiclient-services/src/Logging/LogSink.php',
    'Google\\Service\\Logging\\LogSplit' => $vendorDir . '/google/apiclient-services/src/Logging/LogSplit.php',
    'Google\\Service\\Logging\\LogView' => $vendorDir . '/google/apiclient-services/src/Logging/LogView.php',
    'Google\\Service\\Logging\\LoggingEmpty' => $vendorDir . '/google/apiclient-services/src/Logging/LoggingEmpty.php',
    'Google\\Service\\Logging\\LoggingQuery' => $vendorDir . '/google/apiclient-services/src/Logging/LoggingQuery.php',
    'Google\\Service\\Logging\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/Logging/MetricDescriptor.php',
    'Google\\Service\\Logging\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/MetricDescriptorMetadata.php',
    'Google\\Service\\Logging\\MonitoredResource' => $vendorDir . '/google/apiclient-services/src/Logging/MonitoredResource.php',
    'Google\\Service\\Logging\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/Logging/MonitoredResourceDescriptor.php',
    'Google\\Service\\Logging\\MonitoredResourceMetadata' => $vendorDir . '/google/apiclient-services/src/Logging/MonitoredResourceMetadata.php',
    'Google\\Service\\Logging\\Operation' => $vendorDir . '/google/apiclient-services/src/Logging/Operation.php',
    'Google\\Service\\Logging\\OpsAnalyticsQuery' => $vendorDir . '/google/apiclient-services/src/Logging/OpsAnalyticsQuery.php',
    'Google\\Service\\Logging\\Policy' => $vendorDir . '/google/apiclient-services/src/Logging/Policy.php',
    'Google\\Service\\Logging\\RecentQuery' => $vendorDir . '/google/apiclient-services/src/Logging/RecentQuery.php',
    'Google\\Service\\Logging\\RequestLog' => $vendorDir . '/google/apiclient-services/src/Logging/RequestLog.php',
    'Google\\Service\\Logging\\Resource\\BillingAccounts' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccounts.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsBuckets.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsExclusions' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsExclusions.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocations.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsBuckets.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsBucketsLinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsBucketsLinks.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsBucketsViewsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsBucketsViewsLogs.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsOperations.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsRecentQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsRecentQueries.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLocationsSavedQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLocationsSavedQueries.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsLogs.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsOperations.php',
    'Google\\Service\\Logging\\Resource\\BillingAccountsSinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/BillingAccountsSinks.php',
    'Google\\Service\\Logging\\Resource\\Entries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Entries.php',
    'Google\\Service\\Logging\\Resource\\Exclusions' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Exclusions.php',
    'Google\\Service\\Logging\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Folders.php',
    'Google\\Service\\Logging\\Resource\\FoldersExclusions' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersExclusions.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocations.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsBuckets.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsBucketsLinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsBucketsLinks.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsBucketsViewsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsBucketsViewsLogs.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsOperations.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsRecentQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsRecentQueries.php',
    'Google\\Service\\Logging\\Resource\\FoldersLocationsSavedQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLocationsSavedQueries.php',
    'Google\\Service\\Logging\\Resource\\FoldersLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersLogs.php',
    'Google\\Service\\Logging\\Resource\\FoldersSinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/FoldersSinks.php',
    'Google\\Service\\Logging\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Locations.php',
    'Google\\Service\\Logging\\Resource\\LocationsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/LocationsBuckets.php',
    'Google\\Service\\Logging\\Resource\\LocationsBucketsLinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/LocationsBucketsLinks.php',
    'Google\\Service\\Logging\\Resource\\LocationsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/LocationsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\LocationsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/LocationsOperations.php',
    'Google\\Service\\Logging\\Resource\\Logs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Logs.php',
    'Google\\Service\\Logging\\Resource\\MonitoredResourceDescriptors' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/MonitoredResourceDescriptors.php',
    'Google\\Service\\Logging\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Organizations.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsExclusions' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsExclusions.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocations.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsBuckets.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsBucketsLinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsBucketsLinks.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsBucketsViewsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsBucketsViewsLogs.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsOperations.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsRecentQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsRecentQueries.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLocationsSavedQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLocationsSavedQueries.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsLogs.php',
    'Google\\Service\\Logging\\Resource\\OrganizationsSinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/OrganizationsSinks.php',
    'Google\\Service\\Logging\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Projects.php',
    'Google\\Service\\Logging\\Resource\\ProjectsExclusions' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsExclusions.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocations.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsBuckets' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsBuckets.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsBucketsLinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsBucketsLinks.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsBucketsViews' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsBucketsViews.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsBucketsViewsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsBucketsViewsLogs.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsRecentQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsRecentQueries.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLocationsSavedQueries' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLocationsSavedQueries.php',
    'Google\\Service\\Logging\\Resource\\ProjectsLogs' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsLogs.php',
    'Google\\Service\\Logging\\Resource\\ProjectsMetrics' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsMetrics.php',
    'Google\\Service\\Logging\\Resource\\ProjectsSinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/ProjectsSinks.php',
    'Google\\Service\\Logging\\Resource\\Sinks' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/Sinks.php',
    'Google\\Service\\Logging\\Resource\\V2' => $vendorDir . '/google/apiclient-services/src/Logging/Resource/V2.php',
    'Google\\Service\\Logging\\SavedQuery' => $vendorDir . '/google/apiclient-services/src/Logging/SavedQuery.php',
    'Google\\Service\\Logging\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Logging/SetIamPolicyRequest.php',
    'Google\\Service\\Logging\\Settings' => $vendorDir . '/google/apiclient-services/src/Logging/Settings.php',
    'Google\\Service\\Logging\\SourceLocation' => $vendorDir . '/google/apiclient-services/src/Logging/SourceLocation.php',
    'Google\\Service\\Logging\\SourceReference' => $vendorDir . '/google/apiclient-services/src/Logging/SourceReference.php',
    'Google\\Service\\Logging\\Status' => $vendorDir . '/google/apiclient-services/src/Logging/Status.php',
    'Google\\Service\\Logging\\SummaryField' => $vendorDir . '/google/apiclient-services/src/Logging/SummaryField.php',
    'Google\\Service\\Logging\\SuppressionInfo' => $vendorDir . '/google/apiclient-services/src/Logging/SuppressionInfo.php',
    'Google\\Service\\Logging\\TableFieldSchema' => $vendorDir . '/google/apiclient-services/src/Logging/TableFieldSchema.php',
    'Google\\Service\\Logging\\TableSchema' => $vendorDir . '/google/apiclient-services/src/Logging/TableSchema.php',
    'Google\\Service\\Logging\\TailLogEntriesRequest' => $vendorDir . '/google/apiclient-services/src/Logging/TailLogEntriesRequest.php',
    'Google\\Service\\Logging\\TailLogEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/TailLogEntriesResponse.php',
    'Google\\Service\\Logging\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Logging/TestIamPermissionsRequest.php',
    'Google\\Service\\Logging\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Logging/TestIamPermissionsResponse.php',
    'Google\\Service\\Logging\\UndeleteBucketRequest' => $vendorDir . '/google/apiclient-services/src/Logging/UndeleteBucketRequest.php',
    'Google\\Service\\Logging\\UpdateBucketRequest' => $vendorDir . '/google/apiclient-services/src/Logging/UpdateBucketRequest.php',
    'Google\\Service\\Logging\\WriteLogEntriesRequest' => $vendorDir . '/google/apiclient-services/src/Logging/WriteLogEntriesRequest.php',
    'Google\\Service\\Logging\\WriteLogEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Logging/WriteLogEntriesResponse.php',
    'Google\\Service\\Looker' => $vendorDir . '/google/apiclient-services/src/Looker.php',
    'Google\\Service\\Looker\\AdminSettings' => $vendorDir . '/google/apiclient-services/src/Looker/AdminSettings.php',
    'Google\\Service\\Looker\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Looker/AuditConfig.php',
    'Google\\Service\\Looker\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Looker/AuditLogConfig.php',
    'Google\\Service\\Looker\\Binding' => $vendorDir . '/google/apiclient-services/src/Looker/Binding.php',
    'Google\\Service\\Looker\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Looker/CancelOperationRequest.php',
    'Google\\Service\\Looker\\CustomDomain' => $vendorDir . '/google/apiclient-services/src/Looker/CustomDomain.php',
    'Google\\Service\\Looker\\Date' => $vendorDir . '/google/apiclient-services/src/Looker/Date.php',
    'Google\\Service\\Looker\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/Looker/DenyMaintenancePeriod.php',
    'Google\\Service\\Looker\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Looker/EncryptionConfig.php',
    'Google\\Service\\Looker\\ExportEncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Looker/ExportEncryptionConfig.php',
    'Google\\Service\\Looker\\ExportInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Looker/ExportInstanceRequest.php',
    'Google\\Service\\Looker\\ExportMetadata' => $vendorDir . '/google/apiclient-services/src/Looker/ExportMetadata.php',
    'Google\\Service\\Looker\\ExportMetadataEncryptionKey' => $vendorDir . '/google/apiclient-services/src/Looker/ExportMetadataEncryptionKey.php',
    'Google\\Service\\Looker\\Expr' => $vendorDir . '/google/apiclient-services/src/Looker/Expr.php',
    'Google\\Service\\Looker\\ImportInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Looker/ImportInstanceRequest.php',
    'Google\\Service\\Looker\\Instance' => $vendorDir . '/google/apiclient-services/src/Looker/Instance.php',
    'Google\\Service\\Looker\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Looker/ListInstancesResponse.php',
    'Google\\Service\\Looker\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Looker/ListLocationsResponse.php',
    'Google\\Service\\Looker\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Looker/ListOperationsResponse.php',
    'Google\\Service\\Looker\\Location' => $vendorDir . '/google/apiclient-services/src/Looker/Location.php',
    'Google\\Service\\Looker\\LookerEmpty' => $vendorDir . '/google/apiclient-services/src/Looker/LookerEmpty.php',
    'Google\\Service\\Looker\\MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/Looker/MaintenanceSchedule.php',
    'Google\\Service\\Looker\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/Looker/MaintenanceWindow.php',
    'Google\\Service\\Looker\\OAuthConfig' => $vendorDir . '/google/apiclient-services/src/Looker/OAuthConfig.php',
    'Google\\Service\\Looker\\Operation' => $vendorDir . '/google/apiclient-services/src/Looker/Operation.php',
    'Google\\Service\\Looker\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Looker/OperationMetadata.php',
    'Google\\Service\\Looker\\Policy' => $vendorDir . '/google/apiclient-services/src/Looker/Policy.php',
    'Google\\Service\\Looker\\PscConfig' => $vendorDir . '/google/apiclient-services/src/Looker/PscConfig.php',
    'Google\\Service\\Looker\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Looker/Resource/Projects.php',
    'Google\\Service\\Looker\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Looker/Resource/ProjectsLocations.php',
    'Google\\Service\\Looker\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/Looker/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\Looker\\Resource\\ProjectsLocationsInstancesBackups' => $vendorDir . '/google/apiclient-services/src/Looker/Resource/ProjectsLocationsInstancesBackups.php',
    'Google\\Service\\Looker\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Looker/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Looker\\RestartInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Looker/RestartInstanceRequest.php',
    'Google\\Service\\Looker\\ServiceAttachment' => $vendorDir . '/google/apiclient-services/src/Looker/ServiceAttachment.php',
    'Google\\Service\\Looker\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Looker/SetIamPolicyRequest.php',
    'Google\\Service\\Looker\\Status' => $vendorDir . '/google/apiclient-services/src/Looker/Status.php',
    'Google\\Service\\Looker\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Looker/TestIamPermissionsRequest.php',
    'Google\\Service\\Looker\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Looker/TestIamPermissionsResponse.php',
    'Google\\Service\\Looker\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Looker/TimeOfDay.php',
    'Google\\Service\\Looker\\UserMetadata' => $vendorDir . '/google/apiclient-services/src/Looker/UserMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\AttachTrustRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/AttachTrustRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Backup' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Backup.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Binding' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Binding.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/CancelOperationRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Certificate' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Certificate.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\CheckMigrationPermissionRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/CheckMigrationPermissionRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\CheckMigrationPermissionResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/CheckMigrationPermissionResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DailyCycle' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DailyCycle.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Date' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Date.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DenyMaintenancePeriod.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DetachTrustRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DetachTrustRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DisableMigrationRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DisableMigrationRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Domain' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Domain.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DomainJoinMachineRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DomainJoinMachineRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\DomainJoinMachineResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/DomainJoinMachineResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\EnableMigrationRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/EnableMigrationRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Expr' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Expr.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ExtendSchemaRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ExtendSchemaRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudManagedidentitiesV1OpMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudManagedidentitiesV1OpMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudManagedidentitiesV1alpha1OpMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudManagedidentitiesV1alpha1OpMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudManagedidentitiesV1beta1OpMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudManagedidentitiesV1beta1OpMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1Instance' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1Instance.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1SloExclusion.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\LDAPSSettings' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/LDAPSSettings.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListBackupsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListDomainsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListDomainsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListLocationsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListOperationsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListPeeringsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListPeeringsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ListSqlIntegrationsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ListSqlIntegrationsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Location' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Location.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\MaintenancePolicy' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/MaintenancePolicy.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/MaintenanceWindow.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ManagedidentitiesEmpty' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ManagedidentitiesEmpty.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\OnPremDomainDetails' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/OnPremDomainDetails.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\OnPremDomainSIDDetails' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/OnPremDomainSIDDetails.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Operation' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Operation.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/OperationMetadata.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Peering' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Peering.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Policy' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Policy.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ReconfigureTrustRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ReconfigureTrustRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ResetAdminPasswordRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ResetAdminPasswordRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ResetAdminPasswordResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ResetAdminPasswordResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/Projects.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocations.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobal' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobal.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobalDomains' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobalDomains.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobalDomainsBackups' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobalDomainsBackups.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobalDomainsSqlIntegrations' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobalDomainsSqlIntegrations.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobalOperations' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobalOperations.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Resource\\ProjectsLocationsManagedidentitiesGlobalPeerings' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Resource/ProjectsLocationsManagedidentitiesGlobalPeerings.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\RestoreDomainRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/RestoreDomainRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Schedule' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Schedule.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/SetIamPolicyRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\SqlIntegration' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/SqlIntegration.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Status' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Status.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/TestIamPermissionsRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/TestIamPermissionsResponse.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/TimeOfDay.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\Trust' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/Trust.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\UpdatePolicy' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/UpdatePolicy.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\ValidateTrustRequest' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/ValidateTrustRequest.php',
    'Google\\Service\\ManagedServiceforMicrosoftActiveDirectoryConsumerAPI\\WeeklyCycle' => $vendorDir . '/google/apiclient-services/src/ManagedServiceforMicrosoftActiveDirectoryConsumerAPI/WeeklyCycle.php',
    'Google\\Service\\ManufacturerCenter' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter.php',
    'Google\\Service\\ManufacturerCenter\\Attributes' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Attributes.php',
    'Google\\Service\\ManufacturerCenter\\Capacity' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Capacity.php',
    'Google\\Service\\ManufacturerCenter\\Certification' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Certification.php',
    'Google\\Service\\ManufacturerCenter\\Count' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Count.php',
    'Google\\Service\\ManufacturerCenter\\DestinationStatus' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/DestinationStatus.php',
    'Google\\Service\\ManufacturerCenter\\FeatureDescription' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/FeatureDescription.php',
    'Google\\Service\\ManufacturerCenter\\FloatUnit' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/FloatUnit.php',
    'Google\\Service\\ManufacturerCenter\\GoogleShoppingManufacturersV1ProductCertification' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/GoogleShoppingManufacturersV1ProductCertification.php',
    'Google\\Service\\ManufacturerCenter\\Grocery' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Grocery.php',
    'Google\\Service\\ManufacturerCenter\\Image' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Image.php',
    'Google\\Service\\ManufacturerCenter\\Issue' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Issue.php',
    'Google\\Service\\ManufacturerCenter\\ListProductCertificationsResponse' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/ListProductCertificationsResponse.php',
    'Google\\Service\\ManufacturerCenter\\ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/ListProductsResponse.php',
    'Google\\Service\\ManufacturerCenter\\ManufacturersEmpty' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/ManufacturersEmpty.php',
    'Google\\Service\\ManufacturerCenter\\Nutrition' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Nutrition.php',
    'Google\\Service\\ManufacturerCenter\\Price' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Price.php',
    'Google\\Service\\ManufacturerCenter\\Product' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Product.php',
    'Google\\Service\\ManufacturerCenter\\ProductCertification' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/ProductCertification.php',
    'Google\\Service\\ManufacturerCenter\\ProductDetail' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/ProductDetail.php',
    'Google\\Service\\ManufacturerCenter\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Resource/Accounts.php',
    'Google\\Service\\ManufacturerCenter\\Resource\\AccountsLanguages' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Resource/AccountsLanguages.php',
    'Google\\Service\\ManufacturerCenter\\Resource\\AccountsLanguagesProductCertifications' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Resource/AccountsLanguagesProductCertifications.php',
    'Google\\Service\\ManufacturerCenter\\Resource\\AccountsProducts' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/Resource/AccountsProducts.php',
    'Google\\Service\\ManufacturerCenter\\VoluntaryNutritionFact' => $vendorDir . '/google/apiclient-services/src/ManufacturerCenter/VoluntaryNutritionFact.php',
    'Google\\Service\\MapsPlaces' => $vendorDir . '/google/apiclient-services/src/MapsPlaces.php',
    'Google\\Service\\MapsPlaces\\GoogleGeoTypeViewport' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleGeoTypeViewport.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AuthorAttribution' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AuthorAttribution.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesRequest' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesRequest.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesRequestLocationRestriction' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesRequestLocationRestriction.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponse' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponse.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestion' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestion.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionPlacePrediction' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionPlacePrediction.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1Circle' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1Circle.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContentBlock' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContentBlock.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContent' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContent.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContentJustification' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContentJustification.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContentJustificationBusinessAvailabilityAttributesJustification' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContentJustificationBusinessAvailabilityAttributesJustification.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContentJustificationReviewJustification' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContentJustificationReviewJustification.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedTextHighlightedTextRange' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedTextHighlightedTextRange.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1EVChargeOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1EVChargeOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1FuelOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1FuelOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1FuelOptionsFuelPrice' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1FuelOptionsFuelPrice.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1Int32Range' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1Int32Range.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1Photo' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1Photo.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PhotoMedia' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PhotoMedia.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1Place' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1Place.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceAccessibilityOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceAccessibilityOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceAddressComponent' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceAddressComponent.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceAreaSummary' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceAreaSummary.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceAttribution' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceAttribution.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceGenerativeSummary' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceGenerativeSummary.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceOpeningHours' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceOpeningHours.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceOpeningHoursPeriod' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceOpeningHoursPeriod.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceOpeningHoursSpecialDay' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceOpeningHoursSpecialDay.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceParkingOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceParkingOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlacePaymentOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlacePaymentOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlacePlusCode' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlacePlusCode.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1PlaceSubDestination' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1PlaceSubDestination.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1References' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1References.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1Review' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1Review.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchNearbyRequest' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchNearbyRequest.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchNearbyRequestLocationRestriction' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchNearbyRequestLocationRestriction.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchNearbyResponse' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchNearbyResponse.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextRequest' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextRequest.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextRequestEVOptions' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextRequestEVOptions.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextRequestLocation' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextRequestLocation.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextRequestLocationBias' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextRequestLocationBias.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextRequestLocationRestriction' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextRequestLocationRestriction.php',
    'Google\\Service\\MapsPlaces\\GoogleMapsPlacesV1SearchTextResponse' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleMapsPlacesV1SearchTextResponse.php',
    'Google\\Service\\MapsPlaces\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleTypeDate.php',
    'Google\\Service\\MapsPlaces\\GoogleTypeLatLng' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleTypeLatLng.php',
    'Google\\Service\\MapsPlaces\\GoogleTypeLocalizedText' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleTypeLocalizedText.php',
    'Google\\Service\\MapsPlaces\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/GoogleTypeMoney.php',
    'Google\\Service\\MapsPlaces\\Resource\\Places' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/Resource/Places.php',
    'Google\\Service\\MapsPlaces\\Resource\\PlacesPhotos' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/Resource/PlacesPhotos.php',
    'Google\\Service\\MapsPlaces\\Resource\\Text' => $vendorDir . '/google/apiclient-services/src/MapsPlaces/Resource/Text.php',
    'Google\\Service\\Meet' => $vendorDir . '/google/apiclient-services/src/Meet.php',
    'Google\\Service\\Meet\\ActiveConference' => $vendorDir . '/google/apiclient-services/src/Meet/ActiveConference.php',
    'Google\\Service\\Meet\\AnonymousUser' => $vendorDir . '/google/apiclient-services/src/Meet/AnonymousUser.php',
    'Google\\Service\\Meet\\ConferenceRecord' => $vendorDir . '/google/apiclient-services/src/Meet/ConferenceRecord.php',
    'Google\\Service\\Meet\\DocsDestination' => $vendorDir . '/google/apiclient-services/src/Meet/DocsDestination.php',
    'Google\\Service\\Meet\\DriveDestination' => $vendorDir . '/google/apiclient-services/src/Meet/DriveDestination.php',
    'Google\\Service\\Meet\\EndActiveConferenceRequest' => $vendorDir . '/google/apiclient-services/src/Meet/EndActiveConferenceRequest.php',
    'Google\\Service\\Meet\\ListConferenceRecordsResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListConferenceRecordsResponse.php',
    'Google\\Service\\Meet\\ListParticipantSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListParticipantSessionsResponse.php',
    'Google\\Service\\Meet\\ListParticipantsResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListParticipantsResponse.php',
    'Google\\Service\\Meet\\ListRecordingsResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListRecordingsResponse.php',
    'Google\\Service\\Meet\\ListTranscriptEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListTranscriptEntriesResponse.php',
    'Google\\Service\\Meet\\ListTranscriptsResponse' => $vendorDir . '/google/apiclient-services/src/Meet/ListTranscriptsResponse.php',
    'Google\\Service\\Meet\\MeetEmpty' => $vendorDir . '/google/apiclient-services/src/Meet/MeetEmpty.php',
    'Google\\Service\\Meet\\Participant' => $vendorDir . '/google/apiclient-services/src/Meet/Participant.php',
    'Google\\Service\\Meet\\ParticipantSession' => $vendorDir . '/google/apiclient-services/src/Meet/ParticipantSession.php',
    'Google\\Service\\Meet\\PhoneUser' => $vendorDir . '/google/apiclient-services/src/Meet/PhoneUser.php',
    'Google\\Service\\Meet\\Recording' => $vendorDir . '/google/apiclient-services/src/Meet/Recording.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecords' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecords.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecordsParticipants' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecordsParticipants.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecordsParticipantsParticipantSessions' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecordsParticipantsParticipantSessions.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecordsRecordings' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecordsRecordings.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecordsTranscripts' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecordsTranscripts.php',
    'Google\\Service\\Meet\\Resource\\ConferenceRecordsTranscriptsEntries' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/ConferenceRecordsTranscriptsEntries.php',
    'Google\\Service\\Meet\\Resource\\Spaces' => $vendorDir . '/google/apiclient-services/src/Meet/Resource/Spaces.php',
    'Google\\Service\\Meet\\SignedinUser' => $vendorDir . '/google/apiclient-services/src/Meet/SignedinUser.php',
    'Google\\Service\\Meet\\Space' => $vendorDir . '/google/apiclient-services/src/Meet/Space.php',
    'Google\\Service\\Meet\\SpaceConfig' => $vendorDir . '/google/apiclient-services/src/Meet/SpaceConfig.php',
    'Google\\Service\\Meet\\Transcript' => $vendorDir . '/google/apiclient-services/src/Meet/Transcript.php',
    'Google\\Service\\Meet\\TranscriptEntry' => $vendorDir . '/google/apiclient-services/src/Meet/TranscriptEntry.php',
    'Google\\Service\\Merchant' => $vendorDir . '/google/apiclient-services/src/Merchant.php',
    'Google\\Service\\Merchant\\BestSellersBrandView' => $vendorDir . '/google/apiclient-services/src/Merchant/BestSellersBrandView.php',
    'Google\\Service\\Merchant\\BestSellersProductClusterView' => $vendorDir . '/google/apiclient-services/src/Merchant/BestSellersProductClusterView.php',
    'Google\\Service\\Merchant\\CompetitiveVisibilityBenchmarkView' => $vendorDir . '/google/apiclient-services/src/Merchant/CompetitiveVisibilityBenchmarkView.php',
    'Google\\Service\\Merchant\\CompetitiveVisibilityCompetitorView' => $vendorDir . '/google/apiclient-services/src/Merchant/CompetitiveVisibilityCompetitorView.php',
    'Google\\Service\\Merchant\\CompetitiveVisibilityTopMerchantView' => $vendorDir . '/google/apiclient-services/src/Merchant/CompetitiveVisibilityTopMerchantView.php',
    'Google\\Service\\Merchant\\Date' => $vendorDir . '/google/apiclient-services/src/Merchant/Date.php',
    'Google\\Service\\Merchant\\IssueSeverityPerReportingContext' => $vendorDir . '/google/apiclient-services/src/Merchant/IssueSeverityPerReportingContext.php',
    'Google\\Service\\Merchant\\ItemIssue' => $vendorDir . '/google/apiclient-services/src/Merchant/ItemIssue.php',
    'Google\\Service\\Merchant\\ItemIssueSeverity' => $vendorDir . '/google/apiclient-services/src/Merchant/ItemIssueSeverity.php',
    'Google\\Service\\Merchant\\ItemIssueType' => $vendorDir . '/google/apiclient-services/src/Merchant/ItemIssueType.php',
    'Google\\Service\\Merchant\\NonProductPerformanceView' => $vendorDir . '/google/apiclient-services/src/Merchant/NonProductPerformanceView.php',
    'Google\\Service\\Merchant\\Price' => $vendorDir . '/google/apiclient-services/src/Merchant/Price.php',
    'Google\\Service\\Merchant\\PriceCompetitivenessProductView' => $vendorDir . '/google/apiclient-services/src/Merchant/PriceCompetitivenessProductView.php',
    'Google\\Service\\Merchant\\PriceInsightsProductView' => $vendorDir . '/google/apiclient-services/src/Merchant/PriceInsightsProductView.php',
    'Google\\Service\\Merchant\\ProductChange' => $vendorDir . '/google/apiclient-services/src/Merchant/ProductChange.php',
    'Google\\Service\\Merchant\\ProductPerformanceView' => $vendorDir . '/google/apiclient-services/src/Merchant/ProductPerformanceView.php',
    'Google\\Service\\Merchant\\ProductStatusChangeMessage' => $vendorDir . '/google/apiclient-services/src/Merchant/ProductStatusChangeMessage.php',
    'Google\\Service\\Merchant\\ProductView' => $vendorDir . '/google/apiclient-services/src/Merchant/ProductView.php',
    'Google\\Service\\Merchant\\ReportRow' => $vendorDir . '/google/apiclient-services/src/Merchant/ReportRow.php',
    'Google\\Service\\Merchant\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Merchant/Resource/Accounts.php',
    'Google\\Service\\Merchant\\Resource\\AccountsReports' => $vendorDir . '/google/apiclient-services/src/Merchant/Resource/AccountsReports.php',
    'Google\\Service\\Merchant\\SearchRequest' => $vendorDir . '/google/apiclient-services/src/Merchant/SearchRequest.php',
    'Google\\Service\\Merchant\\SearchResponse' => $vendorDir . '/google/apiclient-services/src/Merchant/SearchResponse.php',
    'Google\\Service\\MigrationCenterAPI' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI.php',
    'Google\\Service\\MigrationCenterAPI\\AddAssetsToGroupRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AddAssetsToGroupRequest.php',
    'Google\\Service\\MigrationCenterAPI\\AggregateAssetsValuesRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregateAssetsValuesRequest.php',
    'Google\\Service\\MigrationCenterAPI\\AggregateAssetsValuesResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregateAssetsValuesResponse.php',
    'Google\\Service\\MigrationCenterAPI\\Aggregation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Aggregation.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationCount' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationCount.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationFrequency' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationFrequency.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationHistogram' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationHistogram.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResult' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResult.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResultCount' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResultCount.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResultFrequency' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResultFrequency.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResultHistogram' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResultHistogram.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResultHistogramBucket' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResultHistogramBucket.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationResultSum' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationResultSum.php',
    'Google\\Service\\MigrationCenterAPI\\AggregationSum' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AggregationSum.php',
    'Google\\Service\\MigrationCenterAPI\\Asset' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Asset.php',
    'Google\\Service\\MigrationCenterAPI\\AssetFrame' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AssetFrame.php',
    'Google\\Service\\MigrationCenterAPI\\AssetList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AssetList.php',
    'Google\\Service\\MigrationCenterAPI\\AssetPerformanceData' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AssetPerformanceData.php',
    'Google\\Service\\MigrationCenterAPI\\AwsEc2PlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AwsEc2PlatformDetails.php',
    'Google\\Service\\MigrationCenterAPI\\AzureVmPlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/AzureVmPlatformDetails.php',
    'Google\\Service\\MigrationCenterAPI\\BatchDeleteAssetsRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/BatchDeleteAssetsRequest.php',
    'Google\\Service\\MigrationCenterAPI\\BatchUpdateAssetsRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/BatchUpdateAssetsRequest.php',
    'Google\\Service\\MigrationCenterAPI\\BatchUpdateAssetsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/BatchUpdateAssetsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\BiosDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/BiosDetails.php',
    'Google\\Service\\MigrationCenterAPI\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/CancelOperationRequest.php',
    'Google\\Service\\MigrationCenterAPI\\ComputeEngineMigrationTarget' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ComputeEngineMigrationTarget.php',
    'Google\\Service\\MigrationCenterAPI\\ComputeEnginePreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ComputeEnginePreferences.php',
    'Google\\Service\\MigrationCenterAPI\\ComputeEngineShapeDescriptor' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ComputeEngineShapeDescriptor.php',
    'Google\\Service\\MigrationCenterAPI\\ComputeStorageDescriptor' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ComputeStorageDescriptor.php',
    'Google\\Service\\MigrationCenterAPI\\CpuUsageSample' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/CpuUsageSample.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregation.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregationCPU' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregationCPU.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregationDisk' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregationDisk.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregationMemory' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregationMemory.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregationNetwork' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregationNetwork.php',
    'Google\\Service\\MigrationCenterAPI\\DailyResourceUsageAggregationStats' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DailyResourceUsageAggregationStats.php',
    'Google\\Service\\MigrationCenterAPI\\Date' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Date.php',
    'Google\\Service\\MigrationCenterAPI\\DateTime' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DateTime.php',
    'Google\\Service\\MigrationCenterAPI\\DiscoveryClient' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiscoveryClient.php',
    'Google\\Service\\MigrationCenterAPI\\DiskEntry' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiskEntry.php',
    'Google\\Service\\MigrationCenterAPI\\DiskEntryList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiskEntryList.php',
    'Google\\Service\\MigrationCenterAPI\\DiskPartition' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiskPartition.php',
    'Google\\Service\\MigrationCenterAPI\\DiskPartitionList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiskPartitionList.php',
    'Google\\Service\\MigrationCenterAPI\\DiskUsageSample' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/DiskUsageSample.php',
    'Google\\Service\\MigrationCenterAPI\\ErrorFrame' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ErrorFrame.php',
    'Google\\Service\\MigrationCenterAPI\\ExecutionReport' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ExecutionReport.php',
    'Google\\Service\\MigrationCenterAPI\\FileValidationReport' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/FileValidationReport.php',
    'Google\\Service\\MigrationCenterAPI\\FitDescriptor' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/FitDescriptor.php',
    'Google\\Service\\MigrationCenterAPI\\FrameViolationEntry' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/FrameViolationEntry.php',
    'Google\\Service\\MigrationCenterAPI\\Frames' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Frames.php',
    'Google\\Service\\MigrationCenterAPI\\FstabEntry' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/FstabEntry.php',
    'Google\\Service\\MigrationCenterAPI\\FstabEntryList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/FstabEntryList.php',
    'Google\\Service\\MigrationCenterAPI\\GCSPayloadInfo' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GCSPayloadInfo.php',
    'Google\\Service\\MigrationCenterAPI\\GenericInsight' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GenericInsight.php',
    'Google\\Service\\MigrationCenterAPI\\GenericPlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GenericPlatformDetails.php',
    'Google\\Service\\MigrationCenterAPI\\GoogleKubernetesEngineMigrationTarget' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GoogleKubernetesEngineMigrationTarget.php',
    'Google\\Service\\MigrationCenterAPI\\Group' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Group.php',
    'Google\\Service\\MigrationCenterAPI\\GuestConfigDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GuestConfigDetails.php',
    'Google\\Service\\MigrationCenterAPI\\GuestInstalledApplication' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GuestInstalledApplication.php',
    'Google\\Service\\MigrationCenterAPI\\GuestInstalledApplicationList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GuestInstalledApplicationList.php',
    'Google\\Service\\MigrationCenterAPI\\GuestOsDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GuestOsDetails.php',
    'Google\\Service\\MigrationCenterAPI\\GuestRuntimeDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/GuestRuntimeDetails.php',
    'Google\\Service\\MigrationCenterAPI\\HostsEntry' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/HostsEntry.php',
    'Google\\Service\\MigrationCenterAPI\\HostsEntryList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/HostsEntryList.php',
    'Google\\Service\\MigrationCenterAPI\\ImportDataFile' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportDataFile.php',
    'Google\\Service\\MigrationCenterAPI\\ImportError' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportError.php',
    'Google\\Service\\MigrationCenterAPI\\ImportJob' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportJob.php',
    'Google\\Service\\MigrationCenterAPI\\ImportRowError' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportRowError.php',
    'Google\\Service\\MigrationCenterAPI\\ImportRowErrorCsvErrorDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportRowErrorCsvErrorDetails.php',
    'Google\\Service\\MigrationCenterAPI\\ImportRowErrorXlsxErrorDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ImportRowErrorXlsxErrorDetails.php',
    'Google\\Service\\MigrationCenterAPI\\InlinePayloadInfo' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/InlinePayloadInfo.php',
    'Google\\Service\\MigrationCenterAPI\\Insight' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Insight.php',
    'Google\\Service\\MigrationCenterAPI\\InsightList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/InsightList.php',
    'Google\\Service\\MigrationCenterAPI\\ListAssetsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListAssetsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListDiscoveryClientsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListDiscoveryClientsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListErrorFramesResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListErrorFramesResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListGroupsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListImportDataFilesResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListImportDataFilesResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListImportJobsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListImportJobsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListLocationsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListOperationsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListPreferenceSetsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListPreferenceSetsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListReportConfigsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListReportConfigsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListReportsResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListReportsResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ListSourcesResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ListSourcesResponse.php',
    'Google\\Service\\MigrationCenterAPI\\Location' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Location.php',
    'Google\\Service\\MigrationCenterAPI\\MachineArchitectureDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachineArchitectureDetails.php',
    'Google\\Service\\MigrationCenterAPI\\MachineDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachineDetails.php',
    'Google\\Service\\MigrationCenterAPI\\MachineDiskDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachineDiskDetails.php',
    'Google\\Service\\MigrationCenterAPI\\MachineNetworkDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachineNetworkDetails.php',
    'Google\\Service\\MigrationCenterAPI\\MachinePreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachinePreferences.php',
    'Google\\Service\\MigrationCenterAPI\\MachineSeries' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MachineSeries.php',
    'Google\\Service\\MigrationCenterAPI\\MemoryUsageSample' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MemoryUsageSample.php',
    'Google\\Service\\MigrationCenterAPI\\MigrationInsight' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MigrationInsight.php',
    'Google\\Service\\MigrationCenterAPI\\MigrationcenterEmpty' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/MigrationcenterEmpty.php',
    'Google\\Service\\MigrationCenterAPI\\Money' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Money.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkAdapterDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkAdapterDetails.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkAdapterList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkAdapterList.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkAddress' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkAddress.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkAddressList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkAddressList.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkConnection' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkConnection.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkConnectionList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkConnectionList.php',
    'Google\\Service\\MigrationCenterAPI\\NetworkUsageSample' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NetworkUsageSample.php',
    'Google\\Service\\MigrationCenterAPI\\NfsExport' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NfsExport.php',
    'Google\\Service\\MigrationCenterAPI\\NfsExportList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/NfsExportList.php',
    'Google\\Service\\MigrationCenterAPI\\OpenFileDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/OpenFileDetails.php',
    'Google\\Service\\MigrationCenterAPI\\OpenFileList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/OpenFileList.php',
    'Google\\Service\\MigrationCenterAPI\\Operation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Operation.php',
    'Google\\Service\\MigrationCenterAPI\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/OperationMetadata.php',
    'Google\\Service\\MigrationCenterAPI\\PayloadFile' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/PayloadFile.php',
    'Google\\Service\\MigrationCenterAPI\\PerformanceSample' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/PerformanceSample.php',
    'Google\\Service\\MigrationCenterAPI\\PhysicalPlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/PhysicalPlatformDetails.php',
    'Google\\Service\\MigrationCenterAPI\\PlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/PlatformDetails.php',
    'Google\\Service\\MigrationCenterAPI\\PreferenceSet' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/PreferenceSet.php',
    'Google\\Service\\MigrationCenterAPI\\RegionPreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RegionPreferences.php',
    'Google\\Service\\MigrationCenterAPI\\RemoveAssetsFromGroupRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RemoveAssetsFromGroupRequest.php',
    'Google\\Service\\MigrationCenterAPI\\Report' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Report.php',
    'Google\\Service\\MigrationCenterAPI\\ReportAssetFramesResponse' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportAssetFramesResponse.php',
    'Google\\Service\\MigrationCenterAPI\\ReportConfig' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportConfig.php',
    'Google\\Service\\MigrationCenterAPI\\ReportConfigGroupPreferenceSetAssignment' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportConfigGroupPreferenceSetAssignment.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummary' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummary.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryAssetAggregateStats' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryAssetAggregateStats.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryChartData' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryChartData.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryChartDataDataPoint' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryChartDataDataPoint.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryComputeEngineFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryComputeEngineFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryGroupFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryGroupFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryGroupPreferenceSetFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryGroupPreferenceSetFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryHistogramChartData' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryHistogramChartData.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryHistogramChartDataBucket' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryHistogramChartDataBucket.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryMachineFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryMachineFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryMachineSeriesAllocation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryMachineSeriesAllocation.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummarySoleTenantFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummarySoleTenantFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummarySoleTenantNodeAllocation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummarySoleTenantNodeAllocation.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryUtilizationChartData' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryUtilizationChartData.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryVmwareEngineFinding' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryVmwareEngineFinding.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryVmwareNode' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryVmwareNode.php',
    'Google\\Service\\MigrationCenterAPI\\ReportSummaryVmwareNodeAllocation' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ReportSummaryVmwareNodeAllocation.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/Projects.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocations.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsAssets' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsAssets.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsDiscoveryClients' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsDiscoveryClients.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsGroups' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsGroups.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsImportJobs' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsImportJobs.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsImportJobsImportDataFiles' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsImportJobsImportDataFiles.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsPreferenceSets' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsPreferenceSets.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsReportConfigs' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsReportConfigs.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsReportConfigsReports' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsReportConfigsReports.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsSources' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsSources.php',
    'Google\\Service\\MigrationCenterAPI\\Resource\\ProjectsLocationsSourcesErrorFrames' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Resource/ProjectsLocationsSourcesErrorFrames.php',
    'Google\\Service\\MigrationCenterAPI\\RunImportJobRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RunImportJobRequest.php',
    'Google\\Service\\MigrationCenterAPI\\RunningProcess' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RunningProcess.php',
    'Google\\Service\\MigrationCenterAPI\\RunningProcessList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RunningProcessList.php',
    'Google\\Service\\MigrationCenterAPI\\RunningService' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RunningService.php',
    'Google\\Service\\MigrationCenterAPI\\RunningServiceList' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RunningServiceList.php',
    'Google\\Service\\MigrationCenterAPI\\RuntimeNetworkInfo' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/RuntimeNetworkInfo.php',
    'Google\\Service\\MigrationCenterAPI\\Selinux' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Selinux.php',
    'Google\\Service\\MigrationCenterAPI\\SendDiscoveryClientHeartbeatRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/SendDiscoveryClientHeartbeatRequest.php',
    'Google\\Service\\MigrationCenterAPI\\Settings' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Settings.php',
    'Google\\Service\\MigrationCenterAPI\\SoleTenancyPreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/SoleTenancyPreferences.php',
    'Google\\Service\\MigrationCenterAPI\\SoleTenantNodeType' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/SoleTenantNodeType.php',
    'Google\\Service\\MigrationCenterAPI\\Source' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Source.php',
    'Google\\Service\\MigrationCenterAPI\\Status' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/Status.php',
    'Google\\Service\\MigrationCenterAPI\\TimeZone' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/TimeZone.php',
    'Google\\Service\\MigrationCenterAPI\\UpdateAssetRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/UpdateAssetRequest.php',
    'Google\\Service\\MigrationCenterAPI\\UploadFileInfo' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/UploadFileInfo.php',
    'Google\\Service\\MigrationCenterAPI\\ValidateImportJobRequest' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ValidateImportJobRequest.php',
    'Google\\Service\\MigrationCenterAPI\\ValidationReport' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/ValidationReport.php',
    'Google\\Service\\MigrationCenterAPI\\VirtualMachineArchitectureDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VirtualMachineArchitectureDetails.php',
    'Google\\Service\\MigrationCenterAPI\\VirtualMachineDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VirtualMachineDetails.php',
    'Google\\Service\\MigrationCenterAPI\\VirtualMachineDiskDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VirtualMachineDiskDetails.php',
    'Google\\Service\\MigrationCenterAPI\\VirtualMachineNetworkDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VirtualMachineNetworkDetails.php',
    'Google\\Service\\MigrationCenterAPI\\VirtualMachinePreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VirtualMachinePreferences.php',
    'Google\\Service\\MigrationCenterAPI\\VmwareDiskConfig' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VmwareDiskConfig.php',
    'Google\\Service\\MigrationCenterAPI\\VmwareEngineMigrationTarget' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VmwareEngineMigrationTarget.php',
    'Google\\Service\\MigrationCenterAPI\\VmwareEnginePreferences' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VmwareEnginePreferences.php',
    'Google\\Service\\MigrationCenterAPI\\VmwarePlatformDetails' => $vendorDir . '/google/apiclient-services/src/MigrationCenterAPI/VmwarePlatformDetails.php',
    'Google\\Service\\Monitoring' => $vendorDir . '/google/apiclient-services/src/Monitoring.php',
    'Google\\Service\\Monitoring\\Aggregation' => $vendorDir . '/google/apiclient-services/src/Monitoring/Aggregation.php',
    'Google\\Service\\Monitoring\\AlertPolicy' => $vendorDir . '/google/apiclient-services/src/Monitoring/AlertPolicy.php',
    'Google\\Service\\Monitoring\\AlertStrategy' => $vendorDir . '/google/apiclient-services/src/Monitoring/AlertStrategy.php',
    'Google\\Service\\Monitoring\\AppEngine' => $vendorDir . '/google/apiclient-services/src/Monitoring/AppEngine.php',
    'Google\\Service\\Monitoring\\AvailabilityCriteria' => $vendorDir . '/google/apiclient-services/src/Monitoring/AvailabilityCriteria.php',
    'Google\\Service\\Monitoring\\BasicAuthentication' => $vendorDir . '/google/apiclient-services/src/Monitoring/BasicAuthentication.php',
    'Google\\Service\\Monitoring\\BasicService' => $vendorDir . '/google/apiclient-services/src/Monitoring/BasicService.php',
    'Google\\Service\\Monitoring\\BasicSli' => $vendorDir . '/google/apiclient-services/src/Monitoring/BasicSli.php',
    'Google\\Service\\Monitoring\\BucketOptions' => $vendorDir . '/google/apiclient-services/src/Monitoring/BucketOptions.php',
    'Google\\Service\\Monitoring\\CloudEndpoints' => $vendorDir . '/google/apiclient-services/src/Monitoring/CloudEndpoints.php',
    'Google\\Service\\Monitoring\\CloudFunctionV2Target' => $vendorDir . '/google/apiclient-services/src/Monitoring/CloudFunctionV2Target.php',
    'Google\\Service\\Monitoring\\CloudRun' => $vendorDir . '/google/apiclient-services/src/Monitoring/CloudRun.php',
    'Google\\Service\\Monitoring\\ClusterIstio' => $vendorDir . '/google/apiclient-services/src/Monitoring/ClusterIstio.php',
    'Google\\Service\\Monitoring\\CollectdPayload' => $vendorDir . '/google/apiclient-services/src/Monitoring/CollectdPayload.php',
    'Google\\Service\\Monitoring\\CollectdPayloadError' => $vendorDir . '/google/apiclient-services/src/Monitoring/CollectdPayloadError.php',
    'Google\\Service\\Monitoring\\CollectdValue' => $vendorDir . '/google/apiclient-services/src/Monitoring/CollectdValue.php',
    'Google\\Service\\Monitoring\\CollectdValueError' => $vendorDir . '/google/apiclient-services/src/Monitoring/CollectdValueError.php',
    'Google\\Service\\Monitoring\\Condition' => $vendorDir . '/google/apiclient-services/src/Monitoring/Condition.php',
    'Google\\Service\\Monitoring\\ContentMatcher' => $vendorDir . '/google/apiclient-services/src/Monitoring/ContentMatcher.php',
    'Google\\Service\\Monitoring\\CreateCollectdTimeSeriesRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/CreateCollectdTimeSeriesRequest.php',
    'Google\\Service\\Monitoring\\CreateCollectdTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/CreateCollectdTimeSeriesResponse.php',
    'Google\\Service\\Monitoring\\CreateTimeSeriesRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/CreateTimeSeriesRequest.php',
    'Google\\Service\\Monitoring\\CreateTimeSeriesSummary' => $vendorDir . '/google/apiclient-services/src/Monitoring/CreateTimeSeriesSummary.php',
    'Google\\Service\\Monitoring\\Criteria' => $vendorDir . '/google/apiclient-services/src/Monitoring/Criteria.php',
    'Google\\Service\\Monitoring\\Custom' => $vendorDir . '/google/apiclient-services/src/Monitoring/Custom.php',
    'Google\\Service\\Monitoring\\Distribution' => $vendorDir . '/google/apiclient-services/src/Monitoring/Distribution.php',
    'Google\\Service\\Monitoring\\DistributionCut' => $vendorDir . '/google/apiclient-services/src/Monitoring/DistributionCut.php',
    'Google\\Service\\Monitoring\\Documentation' => $vendorDir . '/google/apiclient-services/src/Monitoring/Documentation.php',
    'Google\\Service\\Monitoring\\DroppedLabels' => $vendorDir . '/google/apiclient-services/src/Monitoring/DroppedLabels.php',
    'Google\\Service\\Monitoring\\Error' => $vendorDir . '/google/apiclient-services/src/Monitoring/Error.php',
    'Google\\Service\\Monitoring\\Exemplar' => $vendorDir . '/google/apiclient-services/src/Monitoring/Exemplar.php',
    'Google\\Service\\Monitoring\\Explicit' => $vendorDir . '/google/apiclient-services/src/Monitoring/Explicit.php',
    'Google\\Service\\Monitoring\\Exponential' => $vendorDir . '/google/apiclient-services/src/Monitoring/Exponential.php',
    'Google\\Service\\Monitoring\\Field' => $vendorDir . '/google/apiclient-services/src/Monitoring/Field.php',
    'Google\\Service\\Monitoring\\ForecastOptions' => $vendorDir . '/google/apiclient-services/src/Monitoring/ForecastOptions.php',
    'Google\\Service\\Monitoring\\GetNotificationChannelVerificationCodeRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/GetNotificationChannelVerificationCodeRequest.php',
    'Google\\Service\\Monitoring\\GetNotificationChannelVerificationCodeResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/GetNotificationChannelVerificationCodeResponse.php',
    'Google\\Service\\Monitoring\\GkeNamespace' => $vendorDir . '/google/apiclient-services/src/Monitoring/GkeNamespace.php',
    'Google\\Service\\Monitoring\\GkeService' => $vendorDir . '/google/apiclient-services/src/Monitoring/GkeService.php',
    'Google\\Service\\Monitoring\\GkeWorkload' => $vendorDir . '/google/apiclient-services/src/Monitoring/GkeWorkload.php',
    'Google\\Service\\Monitoring\\GoogleMonitoringV3Range' => $vendorDir . '/google/apiclient-services/src/Monitoring/GoogleMonitoringV3Range.php',
    'Google\\Service\\Monitoring\\Group' => $vendorDir . '/google/apiclient-services/src/Monitoring/Group.php',
    'Google\\Service\\Monitoring\\HttpCheck' => $vendorDir . '/google/apiclient-services/src/Monitoring/HttpCheck.php',
    'Google\\Service\\Monitoring\\InternalChecker' => $vendorDir . '/google/apiclient-services/src/Monitoring/InternalChecker.php',
    'Google\\Service\\Monitoring\\IstioCanonicalService' => $vendorDir . '/google/apiclient-services/src/Monitoring/IstioCanonicalService.php',
    'Google\\Service\\Monitoring\\JsonPathMatcher' => $vendorDir . '/google/apiclient-services/src/Monitoring/JsonPathMatcher.php',
    'Google\\Service\\Monitoring\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/LabelDescriptor.php',
    'Google\\Service\\Monitoring\\LabelValue' => $vendorDir . '/google/apiclient-services/src/Monitoring/LabelValue.php',
    'Google\\Service\\Monitoring\\LatencyCriteria' => $vendorDir . '/google/apiclient-services/src/Monitoring/LatencyCriteria.php',
    'Google\\Service\\Monitoring\\Linear' => $vendorDir . '/google/apiclient-services/src/Monitoring/Linear.php',
    'Google\\Service\\Monitoring\\Link' => $vendorDir . '/google/apiclient-services/src/Monitoring/Link.php',
    'Google\\Service\\Monitoring\\ListAlertPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListAlertPoliciesResponse.php',
    'Google\\Service\\Monitoring\\ListGroupMembersResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListGroupMembersResponse.php',
    'Google\\Service\\Monitoring\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListGroupsResponse.php',
    'Google\\Service\\Monitoring\\ListMetricDescriptorsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListMetricDescriptorsResponse.php',
    'Google\\Service\\Monitoring\\ListMonitoredResourceDescriptorsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListMonitoredResourceDescriptorsResponse.php',
    'Google\\Service\\Monitoring\\ListNotificationChannelDescriptorsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListNotificationChannelDescriptorsResponse.php',
    'Google\\Service\\Monitoring\\ListNotificationChannelsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListNotificationChannelsResponse.php',
    'Google\\Service\\Monitoring\\ListServiceLevelObjectivesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListServiceLevelObjectivesResponse.php',
    'Google\\Service\\Monitoring\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListServicesResponse.php',
    'Google\\Service\\Monitoring\\ListSnoozesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListSnoozesResponse.php',
    'Google\\Service\\Monitoring\\ListTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListTimeSeriesResponse.php',
    'Google\\Service\\Monitoring\\ListUptimeCheckConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListUptimeCheckConfigsResponse.php',
    'Google\\Service\\Monitoring\\ListUptimeCheckIpsResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/ListUptimeCheckIpsResponse.php',
    'Google\\Service\\Monitoring\\LogMatch' => $vendorDir . '/google/apiclient-services/src/Monitoring/LogMatch.php',
    'Google\\Service\\Monitoring\\MeshIstio' => $vendorDir . '/google/apiclient-services/src/Monitoring/MeshIstio.php',
    'Google\\Service\\Monitoring\\Metric' => $vendorDir . '/google/apiclient-services/src/Monitoring/Metric.php',
    'Google\\Service\\Monitoring\\MetricAbsence' => $vendorDir . '/google/apiclient-services/src/Monitoring/MetricAbsence.php',
    'Google\\Service\\Monitoring\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/MetricDescriptor.php',
    'Google\\Service\\Monitoring\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/Monitoring/MetricDescriptorMetadata.php',
    'Google\\Service\\Monitoring\\MetricRange' => $vendorDir . '/google/apiclient-services/src/Monitoring/MetricRange.php',
    'Google\\Service\\Monitoring\\MetricThreshold' => $vendorDir . '/google/apiclient-services/src/Monitoring/MetricThreshold.php',
    'Google\\Service\\Monitoring\\MonitoredResource' => $vendorDir . '/google/apiclient-services/src/Monitoring/MonitoredResource.php',
    'Google\\Service\\Monitoring\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/MonitoredResourceDescriptor.php',
    'Google\\Service\\Monitoring\\MonitoredResourceMetadata' => $vendorDir . '/google/apiclient-services/src/Monitoring/MonitoredResourceMetadata.php',
    'Google\\Service\\Monitoring\\MonitoringEmpty' => $vendorDir . '/google/apiclient-services/src/Monitoring/MonitoringEmpty.php',
    'Google\\Service\\Monitoring\\MonitoringQueryLanguageCondition' => $vendorDir . '/google/apiclient-services/src/Monitoring/MonitoringQueryLanguageCondition.php',
    'Google\\Service\\Monitoring\\MutationRecord' => $vendorDir . '/google/apiclient-services/src/Monitoring/MutationRecord.php',
    'Google\\Service\\Monitoring\\NotificationChannel' => $vendorDir . '/google/apiclient-services/src/Monitoring/NotificationChannel.php',
    'Google\\Service\\Monitoring\\NotificationChannelDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/NotificationChannelDescriptor.php',
    'Google\\Service\\Monitoring\\NotificationChannelStrategy' => $vendorDir . '/google/apiclient-services/src/Monitoring/NotificationChannelStrategy.php',
    'Google\\Service\\Monitoring\\NotificationRateLimit' => $vendorDir . '/google/apiclient-services/src/Monitoring/NotificationRateLimit.php',
    'Google\\Service\\Monitoring\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Monitoring/OperationMetadata.php',
    'Google\\Service\\Monitoring\\Option' => $vendorDir . '/google/apiclient-services/src/Monitoring/Option.php',
    'Google\\Service\\Monitoring\\PerformanceThreshold' => $vendorDir . '/google/apiclient-services/src/Monitoring/PerformanceThreshold.php',
    'Google\\Service\\Monitoring\\PingConfig' => $vendorDir . '/google/apiclient-services/src/Monitoring/PingConfig.php',
    'Google\\Service\\Monitoring\\Point' => $vendorDir . '/google/apiclient-services/src/Monitoring/Point.php',
    'Google\\Service\\Monitoring\\PointData' => $vendorDir . '/google/apiclient-services/src/Monitoring/PointData.php',
    'Google\\Service\\Monitoring\\PrometheusQueryLanguageCondition' => $vendorDir . '/google/apiclient-services/src/Monitoring/PrometheusQueryLanguageCondition.php',
    'Google\\Service\\Monitoring\\QueryTimeSeriesRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/QueryTimeSeriesRequest.php',
    'Google\\Service\\Monitoring\\QueryTimeSeriesResponse' => $vendorDir . '/google/apiclient-services/src/Monitoring/QueryTimeSeriesResponse.php',
    'Google\\Service\\Monitoring\\Range' => $vendorDir . '/google/apiclient-services/src/Monitoring/Range.php',
    'Google\\Service\\Monitoring\\RequestBasedSli' => $vendorDir . '/google/apiclient-services/src/Monitoring/RequestBasedSli.php',
    'Google\\Service\\Monitoring\\ResourceGroup' => $vendorDir . '/google/apiclient-services/src/Monitoring/ResourceGroup.php',
    'Google\\Service\\Monitoring\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/Folders.php',
    'Google\\Service\\Monitoring\\Resource\\FoldersTimeSeries' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/FoldersTimeSeries.php',
    'Google\\Service\\Monitoring\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/Organizations.php',
    'Google\\Service\\Monitoring\\Resource\\OrganizationsTimeSeries' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/OrganizationsTimeSeries.php',
    'Google\\Service\\Monitoring\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/Projects.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsAlertPolicies' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsAlertPolicies.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsCollectdTimeSeries' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsCollectdTimeSeries.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsGroups' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsGroups.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsGroupsMembers' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsGroupsMembers.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsMetricDescriptors' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsMetricDescriptors.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsMonitoredResourceDescriptors' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsMonitoredResourceDescriptors.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsNotificationChannelDescriptors' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsNotificationChannelDescriptors.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsNotificationChannels' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsNotificationChannels.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsSnoozes' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsSnoozes.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsTimeSeries' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsTimeSeries.php',
    'Google\\Service\\Monitoring\\Resource\\ProjectsUptimeCheckConfigs' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ProjectsUptimeCheckConfigs.php',
    'Google\\Service\\Monitoring\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/Services.php',
    'Google\\Service\\Monitoring\\Resource\\ServicesServiceLevelObjectives' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/ServicesServiceLevelObjectives.php',
    'Google\\Service\\Monitoring\\Resource\\UptimeCheckIps' => $vendorDir . '/google/apiclient-services/src/Monitoring/Resource/UptimeCheckIps.php',
    'Google\\Service\\Monitoring\\ResponseStatusCode' => $vendorDir . '/google/apiclient-services/src/Monitoring/ResponseStatusCode.php',
    'Google\\Service\\Monitoring\\SendNotificationChannelVerificationCodeRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/SendNotificationChannelVerificationCodeRequest.php',
    'Google\\Service\\Monitoring\\Service' => $vendorDir . '/google/apiclient-services/src/Monitoring/Service.php',
    'Google\\Service\\Monitoring\\ServiceAgentAuthentication' => $vendorDir . '/google/apiclient-services/src/Monitoring/ServiceAgentAuthentication.php',
    'Google\\Service\\Monitoring\\ServiceLevelIndicator' => $vendorDir . '/google/apiclient-services/src/Monitoring/ServiceLevelIndicator.php',
    'Google\\Service\\Monitoring\\ServiceLevelObjective' => $vendorDir . '/google/apiclient-services/src/Monitoring/ServiceLevelObjective.php',
    'Google\\Service\\Monitoring\\Snooze' => $vendorDir . '/google/apiclient-services/src/Monitoring/Snooze.php',
    'Google\\Service\\Monitoring\\SourceContext' => $vendorDir . '/google/apiclient-services/src/Monitoring/SourceContext.php',
    'Google\\Service\\Monitoring\\SpanContext' => $vendorDir . '/google/apiclient-services/src/Monitoring/SpanContext.php',
    'Google\\Service\\Monitoring\\Status' => $vendorDir . '/google/apiclient-services/src/Monitoring/Status.php',
    'Google\\Service\\Monitoring\\SyntheticMonitorTarget' => $vendorDir . '/google/apiclient-services/src/Monitoring/SyntheticMonitorTarget.php',
    'Google\\Service\\Monitoring\\TcpCheck' => $vendorDir . '/google/apiclient-services/src/Monitoring/TcpCheck.php',
    'Google\\Service\\Monitoring\\Telemetry' => $vendorDir . '/google/apiclient-services/src/Monitoring/Telemetry.php',
    'Google\\Service\\Monitoring\\TimeInterval' => $vendorDir . '/google/apiclient-services/src/Monitoring/TimeInterval.php',
    'Google\\Service\\Monitoring\\TimeSeries' => $vendorDir . '/google/apiclient-services/src/Monitoring/TimeSeries.php',
    'Google\\Service\\Monitoring\\TimeSeriesData' => $vendorDir . '/google/apiclient-services/src/Monitoring/TimeSeriesData.php',
    'Google\\Service\\Monitoring\\TimeSeriesDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/TimeSeriesDescriptor.php',
    'Google\\Service\\Monitoring\\TimeSeriesRatio' => $vendorDir . '/google/apiclient-services/src/Monitoring/TimeSeriesRatio.php',
    'Google\\Service\\Monitoring\\Trigger' => $vendorDir . '/google/apiclient-services/src/Monitoring/Trigger.php',
    'Google\\Service\\Monitoring\\Type' => $vendorDir . '/google/apiclient-services/src/Monitoring/Type.php',
    'Google\\Service\\Monitoring\\TypedValue' => $vendorDir . '/google/apiclient-services/src/Monitoring/TypedValue.php',
    'Google\\Service\\Monitoring\\UptimeCheckConfig' => $vendorDir . '/google/apiclient-services/src/Monitoring/UptimeCheckConfig.php',
    'Google\\Service\\Monitoring\\UptimeCheckIp' => $vendorDir . '/google/apiclient-services/src/Monitoring/UptimeCheckIp.php',
    'Google\\Service\\Monitoring\\ValueDescriptor' => $vendorDir . '/google/apiclient-services/src/Monitoring/ValueDescriptor.php',
    'Google\\Service\\Monitoring\\VerifyNotificationChannelRequest' => $vendorDir . '/google/apiclient-services/src/Monitoring/VerifyNotificationChannelRequest.php',
    'Google\\Service\\Monitoring\\WindowsBasedSli' => $vendorDir . '/google/apiclient-services/src/Monitoring/WindowsBasedSli.php',
    'Google\\Service\\MyBusinessAccountManagement' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement.php',
    'Google\\Service\\MyBusinessAccountManagement\\AcceptInvitationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/AcceptInvitationRequest.php',
    'Google\\Service\\MyBusinessAccountManagement\\Account' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Account.php',
    'Google\\Service\\MyBusinessAccountManagement\\Admin' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Admin.php',
    'Google\\Service\\MyBusinessAccountManagement\\DeclineInvitationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/DeclineInvitationRequest.php',
    'Google\\Service\\MyBusinessAccountManagement\\Invitation' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Invitation.php',
    'Google\\Service\\MyBusinessAccountManagement\\ListAccountAdminsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/ListAccountAdminsResponse.php',
    'Google\\Service\\MyBusinessAccountManagement\\ListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/ListAccountsResponse.php',
    'Google\\Service\\MyBusinessAccountManagement\\ListInvitationsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/ListInvitationsResponse.php',
    'Google\\Service\\MyBusinessAccountManagement\\ListLocationAdminsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/ListLocationAdminsResponse.php',
    'Google\\Service\\MyBusinessAccountManagement\\MybusinessaccountmanagementEmpty' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/MybusinessaccountmanagementEmpty.php',
    'Google\\Service\\MyBusinessAccountManagement\\OrganizationInfo' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/OrganizationInfo.php',
    'Google\\Service\\MyBusinessAccountManagement\\PostalAddress' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/PostalAddress.php',
    'Google\\Service\\MyBusinessAccountManagement\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Resource/Accounts.php',
    'Google\\Service\\MyBusinessAccountManagement\\Resource\\AccountsAdmins' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Resource/AccountsAdmins.php',
    'Google\\Service\\MyBusinessAccountManagement\\Resource\\AccountsInvitations' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Resource/AccountsInvitations.php',
    'Google\\Service\\MyBusinessAccountManagement\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Resource/Locations.php',
    'Google\\Service\\MyBusinessAccountManagement\\Resource\\LocationsAdmins' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/Resource/LocationsAdmins.php',
    'Google\\Service\\MyBusinessAccountManagement\\TargetLocation' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/TargetLocation.php',
    'Google\\Service\\MyBusinessAccountManagement\\TransferLocationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessAccountManagement/TransferLocationRequest.php',
    'Google\\Service\\MyBusinessBusinessCalls' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls.php',
    'Google\\Service\\MyBusinessBusinessCalls\\AggregateMetrics' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/AggregateMetrics.php',
    'Google\\Service\\MyBusinessBusinessCalls\\BusinessCallsInsights' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/BusinessCallsInsights.php',
    'Google\\Service\\MyBusinessBusinessCalls\\BusinessCallsSettings' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/BusinessCallsSettings.php',
    'Google\\Service\\MyBusinessBusinessCalls\\Date' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/Date.php',
    'Google\\Service\\MyBusinessBusinessCalls\\HourlyMetrics' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/HourlyMetrics.php',
    'Google\\Service\\MyBusinessBusinessCalls\\ListBusinessCallsInsightsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/ListBusinessCallsInsightsResponse.php',
    'Google\\Service\\MyBusinessBusinessCalls\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/Resource/Locations.php',
    'Google\\Service\\MyBusinessBusinessCalls\\Resource\\LocationsBusinesscallsinsights' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/Resource/LocationsBusinesscallsinsights.php',
    'Google\\Service\\MyBusinessBusinessCalls\\WeekDayMetrics' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessCalls/WeekDayMetrics.php',
    'Google\\Service\\MyBusinessBusinessInformation' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation.php',
    'Google\\Service\\MyBusinessBusinessInformation\\AdWordsLocationExtensions' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/AdWordsLocationExtensions.php',
    'Google\\Service\\MyBusinessBusinessInformation\\AssociateLocationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/AssociateLocationRequest.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Attribute' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Attribute.php',
    'Google\\Service\\MyBusinessBusinessInformation\\AttributeMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/AttributeMetadata.php',
    'Google\\Service\\MyBusinessBusinessInformation\\AttributeValueMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/AttributeValueMetadata.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Attributes' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Attributes.php',
    'Google\\Service\\MyBusinessBusinessInformation\\BatchGetCategoriesResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/BatchGetCategoriesResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\BusinessHours' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/BusinessHours.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Categories' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Categories.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Category' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Category.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Chain' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Chain.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ChainName' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ChainName.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ChainUri' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ChainUri.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ClearLocationAssociationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ClearLocationAssociationRequest.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Date' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Date.php',
    'Google\\Service\\MyBusinessBusinessInformation\\FreeFormServiceItem' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/FreeFormServiceItem.php',
    'Google\\Service\\MyBusinessBusinessInformation\\GoogleLocation' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/GoogleLocation.php',
    'Google\\Service\\MyBusinessBusinessInformation\\GoogleUpdatedLocation' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/GoogleUpdatedLocation.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Label' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Label.php',
    'Google\\Service\\MyBusinessBusinessInformation\\LatLng' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/LatLng.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ListAttributeMetadataResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ListAttributeMetadataResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ListCategoriesResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ListCategoriesResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ListLocationsResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Location' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Location.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Metadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Metadata.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Money' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Money.php',
    'Google\\Service\\MyBusinessBusinessInformation\\MoreHours' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/MoreHours.php',
    'Google\\Service\\MyBusinessBusinessInformation\\MoreHoursType' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/MoreHoursType.php',
    'Google\\Service\\MyBusinessBusinessInformation\\MybusinessbusinessinformationEmpty' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/MybusinessbusinessinformationEmpty.php',
    'Google\\Service\\MyBusinessBusinessInformation\\OpenInfo' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/OpenInfo.php',
    'Google\\Service\\MyBusinessBusinessInformation\\PhoneNumbers' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/PhoneNumbers.php',
    'Google\\Service\\MyBusinessBusinessInformation\\PlaceInfo' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/PlaceInfo.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Places' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Places.php',
    'Google\\Service\\MyBusinessBusinessInformation\\PostalAddress' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/PostalAddress.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Profile' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Profile.php',
    'Google\\Service\\MyBusinessBusinessInformation\\RelationshipData' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/RelationshipData.php',
    'Google\\Service\\MyBusinessBusinessInformation\\RelevantLocation' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/RelevantLocation.php',
    'Google\\Service\\MyBusinessBusinessInformation\\RepeatedEnumAttributeValue' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/RepeatedEnumAttributeValue.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/Accounts.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\AccountsLocations' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/AccountsLocations.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\Attributes' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/Attributes.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\Categories' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/Categories.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\Chains' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/Chains.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\GoogleLocations' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/GoogleLocations.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/Locations.php',
    'Google\\Service\\MyBusinessBusinessInformation\\Resource\\LocationsAttributes' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/Resource/LocationsAttributes.php',
    'Google\\Service\\MyBusinessBusinessInformation\\SearchChainsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/SearchChainsResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\SearchGoogleLocationsRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/SearchGoogleLocationsRequest.php',
    'Google\\Service\\MyBusinessBusinessInformation\\SearchGoogleLocationsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/SearchGoogleLocationsResponse.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ServiceAreaBusiness' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ServiceAreaBusiness.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ServiceItem' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ServiceItem.php',
    'Google\\Service\\MyBusinessBusinessInformation\\ServiceType' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/ServiceType.php',
    'Google\\Service\\MyBusinessBusinessInformation\\SpecialHourPeriod' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/SpecialHourPeriod.php',
    'Google\\Service\\MyBusinessBusinessInformation\\SpecialHours' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/SpecialHours.php',
    'Google\\Service\\MyBusinessBusinessInformation\\StructuredServiceItem' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/StructuredServiceItem.php',
    'Google\\Service\\MyBusinessBusinessInformation\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/TimeOfDay.php',
    'Google\\Service\\MyBusinessBusinessInformation\\TimePeriod' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/TimePeriod.php',
    'Google\\Service\\MyBusinessBusinessInformation\\UriAttributeValue' => $vendorDir . '/google/apiclient-services/src/MyBusinessBusinessInformation/UriAttributeValue.php',
    'Google\\Service\\MyBusinessLodging' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging.php',
    'Google\\Service\\MyBusinessLodging\\Accessibility' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Accessibility.php',
    'Google\\Service\\MyBusinessLodging\\Activities' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Activities.php',
    'Google\\Service\\MyBusinessLodging\\Business' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Business.php',
    'Google\\Service\\MyBusinessLodging\\Connectivity' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Connectivity.php',
    'Google\\Service\\MyBusinessLodging\\EcoCertification' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/EcoCertification.php',
    'Google\\Service\\MyBusinessLodging\\EnergyEfficiency' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/EnergyEfficiency.php',
    'Google\\Service\\MyBusinessLodging\\EnhancedCleaning' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/EnhancedCleaning.php',
    'Google\\Service\\MyBusinessLodging\\Families' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Families.php',
    'Google\\Service\\MyBusinessLodging\\FoodAndDrink' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/FoodAndDrink.php',
    'Google\\Service\\MyBusinessLodging\\GetGoogleUpdatedLodgingResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/GetGoogleUpdatedLodgingResponse.php',
    'Google\\Service\\MyBusinessLodging\\GuestUnitFeatures' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/GuestUnitFeatures.php',
    'Google\\Service\\MyBusinessLodging\\GuestUnitType' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/GuestUnitType.php',
    'Google\\Service\\MyBusinessLodging\\HealthAndSafety' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/HealthAndSafety.php',
    'Google\\Service\\MyBusinessLodging\\Housekeeping' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Housekeeping.php',
    'Google\\Service\\MyBusinessLodging\\IncreasedFoodSafety' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/IncreasedFoodSafety.php',
    'Google\\Service\\MyBusinessLodging\\LanguageSpoken' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LanguageSpoken.php',
    'Google\\Service\\MyBusinessLodging\\LivingArea' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingArea.php',
    'Google\\Service\\MyBusinessLodging\\LivingAreaAccessibility' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingAreaAccessibility.php',
    'Google\\Service\\MyBusinessLodging\\LivingAreaEating' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingAreaEating.php',
    'Google\\Service\\MyBusinessLodging\\LivingAreaFeatures' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingAreaFeatures.php',
    'Google\\Service\\MyBusinessLodging\\LivingAreaLayout' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingAreaLayout.php',
    'Google\\Service\\MyBusinessLodging\\LivingAreaSleeping' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LivingAreaSleeping.php',
    'Google\\Service\\MyBusinessLodging\\Lodging' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Lodging.php',
    'Google\\Service\\MyBusinessLodging\\LodgingMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/LodgingMetadata.php',
    'Google\\Service\\MyBusinessLodging\\MinimizedContact' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/MinimizedContact.php',
    'Google\\Service\\MyBusinessLodging\\Parking' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Parking.php',
    'Google\\Service\\MyBusinessLodging\\PaymentOptions' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/PaymentOptions.php',
    'Google\\Service\\MyBusinessLodging\\PersonalProtection' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/PersonalProtection.php',
    'Google\\Service\\MyBusinessLodging\\Pets' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Pets.php',
    'Google\\Service\\MyBusinessLodging\\PhysicalDistancing' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/PhysicalDistancing.php',
    'Google\\Service\\MyBusinessLodging\\Policies' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Policies.php',
    'Google\\Service\\MyBusinessLodging\\Pools' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Pools.php',
    'Google\\Service\\MyBusinessLodging\\Property' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Property.php',
    'Google\\Service\\MyBusinessLodging\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Resource/Locations.php',
    'Google\\Service\\MyBusinessLodging\\Resource\\LocationsLodging' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Resource/LocationsLodging.php',
    'Google\\Service\\MyBusinessLodging\\Services' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Services.php',
    'Google\\Service\\MyBusinessLodging\\Sustainability' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Sustainability.php',
    'Google\\Service\\MyBusinessLodging\\SustainabilityCertifications' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/SustainabilityCertifications.php',
    'Google\\Service\\MyBusinessLodging\\SustainableSourcing' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/SustainableSourcing.php',
    'Google\\Service\\MyBusinessLodging\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/TimeOfDay.php',
    'Google\\Service\\MyBusinessLodging\\Transportation' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Transportation.php',
    'Google\\Service\\MyBusinessLodging\\ViewsFromUnit' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/ViewsFromUnit.php',
    'Google\\Service\\MyBusinessLodging\\WasteReduction' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/WasteReduction.php',
    'Google\\Service\\MyBusinessLodging\\WaterConservation' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/WaterConservation.php',
    'Google\\Service\\MyBusinessLodging\\Wellness' => $vendorDir . '/google/apiclient-services/src/MyBusinessLodging/Wellness.php',
    'Google\\Service\\MyBusinessNotificationSettings' => $vendorDir . '/google/apiclient-services/src/MyBusinessNotificationSettings.php',
    'Google\\Service\\MyBusinessNotificationSettings\\NotificationSetting' => $vendorDir . '/google/apiclient-services/src/MyBusinessNotificationSettings/NotificationSetting.php',
    'Google\\Service\\MyBusinessNotificationSettings\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/MyBusinessNotificationSettings/Resource/Accounts.php',
    'Google\\Service\\MyBusinessPlaceActions' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions.php',
    'Google\\Service\\MyBusinessPlaceActions\\AvailableDay' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/AvailableDay.php',
    'Google\\Service\\MyBusinessPlaceActions\\Date' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/Date.php',
    'Google\\Service\\MyBusinessPlaceActions\\FeeDetails' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/FeeDetails.php',
    'Google\\Service\\MyBusinessPlaceActions\\FixedFee' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/FixedFee.php',
    'Google\\Service\\MyBusinessPlaceActions\\FulfillmentOption' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/FulfillmentOption.php',
    'Google\\Service\\MyBusinessPlaceActions\\ListPlaceActionLinksResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/ListPlaceActionLinksResponse.php',
    'Google\\Service\\MyBusinessPlaceActions\\ListPlaceActionTypeMetadataResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/ListPlaceActionTypeMetadataResponse.php',
    'Google\\Service\\MyBusinessPlaceActions\\MinimumFee' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/MinimumFee.php',
    'Google\\Service\\MyBusinessPlaceActions\\Money' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/Money.php',
    'Google\\Service\\MyBusinessPlaceActions\\MybusinessplaceactionsEmpty' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/MybusinessplaceactionsEmpty.php',
    'Google\\Service\\MyBusinessPlaceActions\\NoFee' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/NoFee.php',
    'Google\\Service\\MyBusinessPlaceActions\\OrderOnlineMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/OrderOnlineMetadata.php',
    'Google\\Service\\MyBusinessPlaceActions\\PlaceActionLink' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/PlaceActionLink.php',
    'Google\\Service\\MyBusinessPlaceActions\\PlaceActionTypeMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/PlaceActionTypeMetadata.php',
    'Google\\Service\\MyBusinessPlaceActions\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/Resource/Locations.php',
    'Google\\Service\\MyBusinessPlaceActions\\Resource\\LocationsPlaceActionLinks' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/Resource/LocationsPlaceActionLinks.php',
    'Google\\Service\\MyBusinessPlaceActions\\Resource\\PlaceActionTypeMetadata' => $vendorDir . '/google/apiclient-services/src/MyBusinessPlaceActions/Resource/PlaceActionTypeMetadata.php',
    'Google\\Service\\MyBusinessQA' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA.php',
    'Google\\Service\\MyBusinessQA\\Answer' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Answer.php',
    'Google\\Service\\MyBusinessQA\\Author' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Author.php',
    'Google\\Service\\MyBusinessQA\\ListAnswersResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/ListAnswersResponse.php',
    'Google\\Service\\MyBusinessQA\\ListQuestionsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/ListQuestionsResponse.php',
    'Google\\Service\\MyBusinessQA\\MybusinessqandaEmpty' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/MybusinessqandaEmpty.php',
    'Google\\Service\\MyBusinessQA\\Question' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Question.php',
    'Google\\Service\\MyBusinessQA\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Resource/Locations.php',
    'Google\\Service\\MyBusinessQA\\Resource\\LocationsQuestions' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Resource/LocationsQuestions.php',
    'Google\\Service\\MyBusinessQA\\Resource\\LocationsQuestionsAnswers' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/Resource/LocationsQuestionsAnswers.php',
    'Google\\Service\\MyBusinessQA\\UpsertAnswerRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessQA/UpsertAnswerRequest.php',
    'Google\\Service\\MyBusinessVerifications' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications.php',
    'Google\\Service\\MyBusinessVerifications\\AddressVerificationData' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/AddressVerificationData.php',
    'Google\\Service\\MyBusinessVerifications\\CompleteVerificationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/CompleteVerificationRequest.php',
    'Google\\Service\\MyBusinessVerifications\\CompleteVerificationResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/CompleteVerificationResponse.php',
    'Google\\Service\\MyBusinessVerifications\\ComplyWithGuidelines' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/ComplyWithGuidelines.php',
    'Google\\Service\\MyBusinessVerifications\\EmailVerificationData' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/EmailVerificationData.php',
    'Google\\Service\\MyBusinessVerifications\\FetchVerificationOptionsRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/FetchVerificationOptionsRequest.php',
    'Google\\Service\\MyBusinessVerifications\\FetchVerificationOptionsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/FetchVerificationOptionsResponse.php',
    'Google\\Service\\MyBusinessVerifications\\GenerateVerificationTokenRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/GenerateVerificationTokenRequest.php',
    'Google\\Service\\MyBusinessVerifications\\GenerateVerificationTokenResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/GenerateVerificationTokenResponse.php',
    'Google\\Service\\MyBusinessVerifications\\ListVerificationsResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/ListVerificationsResponse.php',
    'Google\\Service\\MyBusinessVerifications\\Location' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Location.php',
    'Google\\Service\\MyBusinessVerifications\\PostalAddress' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/PostalAddress.php',
    'Google\\Service\\MyBusinessVerifications\\ResolveOwnershipConflict' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/ResolveOwnershipConflict.php',
    'Google\\Service\\MyBusinessVerifications\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Resource/Locations.php',
    'Google\\Service\\MyBusinessVerifications\\Resource\\LocationsVerifications' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Resource/LocationsVerifications.php',
    'Google\\Service\\MyBusinessVerifications\\Resource\\VerificationTokens' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Resource/VerificationTokens.php',
    'Google\\Service\\MyBusinessVerifications\\ServiceBusinessContext' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/ServiceBusinessContext.php',
    'Google\\Service\\MyBusinessVerifications\\Verification' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Verification.php',
    'Google\\Service\\MyBusinessVerifications\\VerificationOption' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/VerificationOption.php',
    'Google\\Service\\MyBusinessVerifications\\VerificationToken' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/VerificationToken.php',
    'Google\\Service\\MyBusinessVerifications\\Verify' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/Verify.php',
    'Google\\Service\\MyBusinessVerifications\\VerifyLocationRequest' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/VerifyLocationRequest.php',
    'Google\\Service\\MyBusinessVerifications\\VerifyLocationResponse' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/VerifyLocationResponse.php',
    'Google\\Service\\MyBusinessVerifications\\VoiceOfMerchantState' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/VoiceOfMerchantState.php',
    'Google\\Service\\MyBusinessVerifications\\WaitForVoiceOfMerchant' => $vendorDir . '/google/apiclient-services/src/MyBusinessVerifications/WaitForVoiceOfMerchant.php',
    'Google\\Service\\NetworkManagement' => $vendorDir . '/google/apiclient-services/src/NetworkManagement.php',
    'Google\\Service\\NetworkManagement\\AbortInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/AbortInfo.php',
    'Google\\Service\\NetworkManagement\\AppEngineVersionEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/AppEngineVersionEndpoint.php',
    'Google\\Service\\NetworkManagement\\AppEngineVersionInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/AppEngineVersionInfo.php',
    'Google\\Service\\NetworkManagement\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/AuditConfig.php',
    'Google\\Service\\NetworkManagement\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/AuditLogConfig.php',
    'Google\\Service\\NetworkManagement\\Binding' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Binding.php',
    'Google\\Service\\NetworkManagement\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CancelOperationRequest.php',
    'Google\\Service\\NetworkManagement\\CloudFunctionEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CloudFunctionEndpoint.php',
    'Google\\Service\\NetworkManagement\\CloudFunctionInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CloudFunctionInfo.php',
    'Google\\Service\\NetworkManagement\\CloudRunRevisionEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CloudRunRevisionEndpoint.php',
    'Google\\Service\\NetworkManagement\\CloudRunRevisionInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CloudRunRevisionInfo.php',
    'Google\\Service\\NetworkManagement\\CloudSQLInstanceInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/CloudSQLInstanceInfo.php',
    'Google\\Service\\NetworkManagement\\ConnectivityTest' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ConnectivityTest.php',
    'Google\\Service\\NetworkManagement\\DeliverInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/DeliverInfo.php',
    'Google\\Service\\NetworkManagement\\DropInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/DropInfo.php',
    'Google\\Service\\NetworkManagement\\EdgeLocation' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/EdgeLocation.php',
    'Google\\Service\\NetworkManagement\\Endpoint' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Endpoint.php',
    'Google\\Service\\NetworkManagement\\EndpointInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/EndpointInfo.php',
    'Google\\Service\\NetworkManagement\\Expr' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Expr.php',
    'Google\\Service\\NetworkManagement\\FirewallInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/FirewallInfo.php',
    'Google\\Service\\NetworkManagement\\ForwardInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ForwardInfo.php',
    'Google\\Service\\NetworkManagement\\ForwardingRuleInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ForwardingRuleInfo.php',
    'Google\\Service\\NetworkManagement\\GKEMasterInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/GKEMasterInfo.php',
    'Google\\Service\\NetworkManagement\\GoogleServiceInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/GoogleServiceInfo.php',
    'Google\\Service\\NetworkManagement\\InstanceInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/InstanceInfo.php',
    'Google\\Service\\NetworkManagement\\LatencyDistribution' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/LatencyDistribution.php',
    'Google\\Service\\NetworkManagement\\LatencyPercentile' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/LatencyPercentile.php',
    'Google\\Service\\NetworkManagement\\ListConnectivityTestsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ListConnectivityTestsResponse.php',
    'Google\\Service\\NetworkManagement\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ListLocationsResponse.php',
    'Google\\Service\\NetworkManagement\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ListOperationsResponse.php',
    'Google\\Service\\NetworkManagement\\LoadBalancerBackend' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/LoadBalancerBackend.php',
    'Google\\Service\\NetworkManagement\\LoadBalancerBackendInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/LoadBalancerBackendInfo.php',
    'Google\\Service\\NetworkManagement\\LoadBalancerInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/LoadBalancerInfo.php',
    'Google\\Service\\NetworkManagement\\Location' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Location.php',
    'Google\\Service\\NetworkManagement\\NatInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/NatInfo.php',
    'Google\\Service\\NetworkManagement\\NetworkInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/NetworkInfo.php',
    'Google\\Service\\NetworkManagement\\NetworkmanagementEmpty' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/NetworkmanagementEmpty.php',
    'Google\\Service\\NetworkManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Operation.php',
    'Google\\Service\\NetworkManagement\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/OperationMetadata.php',
    'Google\\Service\\NetworkManagement\\Policy' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Policy.php',
    'Google\\Service\\NetworkManagement\\ProbingDetails' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ProbingDetails.php',
    'Google\\Service\\NetworkManagement\\ProxyConnectionInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ProxyConnectionInfo.php',
    'Google\\Service\\NetworkManagement\\ReachabilityDetails' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ReachabilityDetails.php',
    'Google\\Service\\NetworkManagement\\RedisInstanceInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/RedisInstanceInfo.php',
    'Google\\Service\\NetworkManagement\\RerunConnectivityTestRequest' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/RerunConnectivityTestRequest.php',
    'Google\\Service\\NetworkManagement\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Resource/Projects.php',
    'Google\\Service\\NetworkManagement\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Resource/ProjectsLocations.php',
    'Google\\Service\\NetworkManagement\\Resource\\ProjectsLocationsNetworkmanagementGlobal' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Resource/ProjectsLocationsNetworkmanagementGlobal.php',
    'Google\\Service\\NetworkManagement\\Resource\\ProjectsLocationsNetworkmanagementGlobalConnectivityTests' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Resource/ProjectsLocationsNetworkmanagementGlobalConnectivityTests.php',
    'Google\\Service\\NetworkManagement\\Resource\\ProjectsLocationsNetworkmanagementGlobalOperations' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Resource/ProjectsLocationsNetworkmanagementGlobalOperations.php',
    'Google\\Service\\NetworkManagement\\RouteInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/RouteInfo.php',
    'Google\\Service\\NetworkManagement\\ServerlessNegInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/ServerlessNegInfo.php',
    'Google\\Service\\NetworkManagement\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/SetIamPolicyRequest.php',
    'Google\\Service\\NetworkManagement\\Status' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Status.php',
    'Google\\Service\\NetworkManagement\\Step' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Step.php',
    'Google\\Service\\NetworkManagement\\StorageBucketInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/StorageBucketInfo.php',
    'Google\\Service\\NetworkManagement\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/TestIamPermissionsRequest.php',
    'Google\\Service\\NetworkManagement\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/TestIamPermissionsResponse.php',
    'Google\\Service\\NetworkManagement\\Trace' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/Trace.php',
    'Google\\Service\\NetworkManagement\\VpcConnectorInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/VpcConnectorInfo.php',
    'Google\\Service\\NetworkManagement\\VpnGatewayInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/VpnGatewayInfo.php',
    'Google\\Service\\NetworkManagement\\VpnTunnelInfo' => $vendorDir . '/google/apiclient-services/src/NetworkManagement/VpnTunnelInfo.php',
    'Google\\Service\\NetworkSecurity' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity.php',
    'Google\\Service\\NetworkSecurity\\AddAddressGroupItemsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/AddAddressGroupItemsRequest.php',
    'Google\\Service\\NetworkSecurity\\AddressGroup' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/AddressGroup.php',
    'Google\\Service\\NetworkSecurity\\AuthorizationPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/AuthorizationPolicy.php',
    'Google\\Service\\NetworkSecurity\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/CancelOperationRequest.php',
    'Google\\Service\\NetworkSecurity\\CertificateProviderInstance' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/CertificateProviderInstance.php',
    'Google\\Service\\NetworkSecurity\\ClientTlsPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ClientTlsPolicy.php',
    'Google\\Service\\NetworkSecurity\\CloneAddressGroupItemsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/CloneAddressGroupItemsRequest.php',
    'Google\\Service\\NetworkSecurity\\Destination' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Destination.php',
    'Google\\Service\\NetworkSecurity\\Expr' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Expr.php',
    'Google\\Service\\NetworkSecurity\\FirewallEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/FirewallEndpoint.php',
    'Google\\Service\\NetworkSecurity\\FirewallEndpointAssociation' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/FirewallEndpointAssociation.php',
    'Google\\Service\\NetworkSecurity\\FirewallEndpointAssociationReference' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/FirewallEndpointAssociationReference.php',
    'Google\\Service\\NetworkSecurity\\GatewaySecurityPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GatewaySecurityPolicy.php',
    'Google\\Service\\NetworkSecurity\\GatewaySecurityPolicyRule' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GatewaySecurityPolicyRule.php',
    'Google\\Service\\NetworkSecurity\\GoogleCloudNetworksecurityV1CertificateProvider' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleCloudNetworksecurityV1CertificateProvider.php',
    'Google\\Service\\NetworkSecurity\\GoogleCloudNetworksecurityV1GrpcEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleCloudNetworksecurityV1GrpcEndpoint.php',
    'Google\\Service\\NetworkSecurity\\GoogleCloudNetworksecurityV1beta1CertificateProvider' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleCloudNetworksecurityV1beta1CertificateProvider.php',
    'Google\\Service\\NetworkSecurity\\GoogleCloudNetworksecurityV1beta1GrpcEndpoint' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleCloudNetworksecurityV1beta1GrpcEndpoint.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1AuditConfig.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1Binding.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1Policy.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1SetIamPolicyRequest.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1TestIamPermissionsRequest.php',
    'Google\\Service\\NetworkSecurity\\GoogleIamV1TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/GoogleIamV1TestIamPermissionsResponse.php',
    'Google\\Service\\NetworkSecurity\\HttpHeaderMatch' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/HttpHeaderMatch.php',
    'Google\\Service\\NetworkSecurity\\ListAddressGroupReferencesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListAddressGroupReferencesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListAddressGroupReferencesResponseAddressGroupReference' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListAddressGroupReferencesResponseAddressGroupReference.php',
    'Google\\Service\\NetworkSecurity\\ListAddressGroupsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListAddressGroupsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListAuthorizationPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListAuthorizationPoliciesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListClientTlsPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListClientTlsPoliciesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListFirewallEndpointAssociationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListFirewallEndpointAssociationsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListFirewallEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListFirewallEndpointsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListGatewaySecurityPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListGatewaySecurityPoliciesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListGatewaySecurityPolicyRulesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListGatewaySecurityPolicyRulesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListLocationsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListOperationsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListSecurityProfileGroupsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListSecurityProfileGroupsResponse.php',
    'Google\\Service\\NetworkSecurity\\ListSecurityProfilesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListSecurityProfilesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListServerTlsPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListServerTlsPoliciesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListTlsInspectionPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListTlsInspectionPoliciesResponse.php',
    'Google\\Service\\NetworkSecurity\\ListUrlListsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ListUrlListsResponse.php',
    'Google\\Service\\NetworkSecurity\\Location' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Location.php',
    'Google\\Service\\NetworkSecurity\\MTLSPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/MTLSPolicy.php',
    'Google\\Service\\NetworkSecurity\\NetworksecurityEmpty' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/NetworksecurityEmpty.php',
    'Google\\Service\\NetworkSecurity\\Operation' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Operation.php',
    'Google\\Service\\NetworkSecurity\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/OperationMetadata.php',
    'Google\\Service\\NetworkSecurity\\RemoveAddressGroupItemsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/RemoveAddressGroupItemsRequest.php',
    'Google\\Service\\NetworkSecurity\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/Organizations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocationsAddressGroups' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocationsAddressGroups.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocationsFirewallEndpoints' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocationsFirewallEndpoints.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocationsOperations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocationsSecurityProfileGroups' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocationsSecurityProfileGroups.php',
    'Google\\Service\\NetworkSecurity\\Resource\\OrganizationsLocationsSecurityProfiles' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/OrganizationsLocationsSecurityProfiles.php',
    'Google\\Service\\NetworkSecurity\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/Projects.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsAddressGroups' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsAddressGroups.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsAuthorizationPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsAuthorizationPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsAuthzPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsAuthzPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsClientTlsPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsClientTlsPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsFirewallEndpointAssociations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsFirewallEndpointAssociations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsGatewaySecurityPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsGatewaySecurityPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsGatewaySecurityPoliciesRules' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsGatewaySecurityPoliciesRules.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsServerTlsPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsServerTlsPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsTlsInspectionPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsTlsInspectionPolicies.php',
    'Google\\Service\\NetworkSecurity\\Resource\\ProjectsLocationsUrlLists' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Resource/ProjectsLocationsUrlLists.php',
    'Google\\Service\\NetworkSecurity\\Rule' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Rule.php',
    'Google\\Service\\NetworkSecurity\\SecurityProfile' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/SecurityProfile.php',
    'Google\\Service\\NetworkSecurity\\SecurityProfileGroup' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/SecurityProfileGroup.php',
    'Google\\Service\\NetworkSecurity\\ServerTlsPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ServerTlsPolicy.php',
    'Google\\Service\\NetworkSecurity\\SeverityOverride' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/SeverityOverride.php',
    'Google\\Service\\NetworkSecurity\\Source' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Source.php',
    'Google\\Service\\NetworkSecurity\\Status' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/Status.php',
    'Google\\Service\\NetworkSecurity\\ThreatOverride' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ThreatOverride.php',
    'Google\\Service\\NetworkSecurity\\ThreatPreventionProfile' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ThreatPreventionProfile.php',
    'Google\\Service\\NetworkSecurity\\TlsInspectionPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/TlsInspectionPolicy.php',
    'Google\\Service\\NetworkSecurity\\UrlList' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/UrlList.php',
    'Google\\Service\\NetworkSecurity\\ValidationCA' => $vendorDir . '/google/apiclient-services/src/NetworkSecurity/ValidationCA.php',
    'Google\\Service\\NetworkServices' => $vendorDir . '/google/apiclient-services/src/NetworkServices.php',
    'Google\\Service\\NetworkServices\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/NetworkServices/AuditConfig.php',
    'Google\\Service\\NetworkServices\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/NetworkServices/AuditLogConfig.php',
    'Google\\Service\\NetworkServices\\Binding' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Binding.php',
    'Google\\Service\\NetworkServices\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/NetworkServices/CancelOperationRequest.php',
    'Google\\Service\\NetworkServices\\EndpointMatcher' => $vendorDir . '/google/apiclient-services/src/NetworkServices/EndpointMatcher.php',
    'Google\\Service\\NetworkServices\\EndpointMatcherMetadataLabelMatcher' => $vendorDir . '/google/apiclient-services/src/NetworkServices/EndpointMatcherMetadataLabelMatcher.php',
    'Google\\Service\\NetworkServices\\EndpointMatcherMetadataLabelMatcherMetadataLabels' => $vendorDir . '/google/apiclient-services/src/NetworkServices/EndpointMatcherMetadataLabelMatcherMetadataLabels.php',
    'Google\\Service\\NetworkServices\\EndpointPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/EndpointPolicy.php',
    'Google\\Service\\NetworkServices\\Expr' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Expr.php',
    'Google\\Service\\NetworkServices\\ExtensionChain' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ExtensionChain.php',
    'Google\\Service\\NetworkServices\\ExtensionChainExtension' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ExtensionChainExtension.php',
    'Google\\Service\\NetworkServices\\ExtensionChainMatchCondition' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ExtensionChainMatchCondition.php',
    'Google\\Service\\NetworkServices\\Gateway' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Gateway.php',
    'Google\\Service\\NetworkServices\\GrpcRoute' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRoute.php',
    'Google\\Service\\NetworkServices\\GrpcRouteDestination' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteDestination.php',
    'Google\\Service\\NetworkServices\\GrpcRouteFaultInjectionPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteFaultInjectionPolicy.php',
    'Google\\Service\\NetworkServices\\GrpcRouteFaultInjectionPolicyAbort' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteFaultInjectionPolicyAbort.php',
    'Google\\Service\\NetworkServices\\GrpcRouteFaultInjectionPolicyDelay' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteFaultInjectionPolicyDelay.php',
    'Google\\Service\\NetworkServices\\GrpcRouteHeaderMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteHeaderMatch.php',
    'Google\\Service\\NetworkServices\\GrpcRouteMethodMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteMethodMatch.php',
    'Google\\Service\\NetworkServices\\GrpcRouteRetryPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteRetryPolicy.php',
    'Google\\Service\\NetworkServices\\GrpcRouteRouteAction' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteRouteAction.php',
    'Google\\Service\\NetworkServices\\GrpcRouteRouteMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteRouteMatch.php',
    'Google\\Service\\NetworkServices\\GrpcRouteRouteRule' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteRouteRule.php',
    'Google\\Service\\NetworkServices\\GrpcRouteStatefulSessionAffinityPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/GrpcRouteStatefulSessionAffinityPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRoute' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRoute.php',
    'Google\\Service\\NetworkServices\\HttpRouteCorsPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteCorsPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRouteDestination' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteDestination.php',
    'Google\\Service\\NetworkServices\\HttpRouteFaultInjectionPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteFaultInjectionPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRouteFaultInjectionPolicyAbort' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteFaultInjectionPolicyAbort.php',
    'Google\\Service\\NetworkServices\\HttpRouteFaultInjectionPolicyDelay' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteFaultInjectionPolicyDelay.php',
    'Google\\Service\\NetworkServices\\HttpRouteHeaderMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteHeaderMatch.php',
    'Google\\Service\\NetworkServices\\HttpRouteHeaderMatchIntegerRange' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteHeaderMatchIntegerRange.php',
    'Google\\Service\\NetworkServices\\HttpRouteHeaderModifier' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteHeaderModifier.php',
    'Google\\Service\\NetworkServices\\HttpRouteHttpDirectResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteHttpDirectResponse.php',
    'Google\\Service\\NetworkServices\\HttpRouteQueryParameterMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteQueryParameterMatch.php',
    'Google\\Service\\NetworkServices\\HttpRouteRedirect' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRedirect.php',
    'Google\\Service\\NetworkServices\\HttpRouteRequestMirrorPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRequestMirrorPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRouteRetryPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRetryPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRouteRouteAction' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRouteAction.php',
    'Google\\Service\\NetworkServices\\HttpRouteRouteMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRouteMatch.php',
    'Google\\Service\\NetworkServices\\HttpRouteRouteRule' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteRouteRule.php',
    'Google\\Service\\NetworkServices\\HttpRouteStatefulSessionAffinityPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteStatefulSessionAffinityPolicy.php',
    'Google\\Service\\NetworkServices\\HttpRouteURLRewrite' => $vendorDir . '/google/apiclient-services/src/NetworkServices/HttpRouteURLRewrite.php',
    'Google\\Service\\NetworkServices\\LbRouteExtension' => $vendorDir . '/google/apiclient-services/src/NetworkServices/LbRouteExtension.php',
    'Google\\Service\\NetworkServices\\LbTrafficExtension' => $vendorDir . '/google/apiclient-services/src/NetworkServices/LbTrafficExtension.php',
    'Google\\Service\\NetworkServices\\ListEndpointPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListEndpointPoliciesResponse.php',
    'Google\\Service\\NetworkServices\\ListGatewaysResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListGatewaysResponse.php',
    'Google\\Service\\NetworkServices\\ListGrpcRoutesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListGrpcRoutesResponse.php',
    'Google\\Service\\NetworkServices\\ListHttpRoutesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListHttpRoutesResponse.php',
    'Google\\Service\\NetworkServices\\ListLbRouteExtensionsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListLbRouteExtensionsResponse.php',
    'Google\\Service\\NetworkServices\\ListLbTrafficExtensionsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListLbTrafficExtensionsResponse.php',
    'Google\\Service\\NetworkServices\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListLocationsResponse.php',
    'Google\\Service\\NetworkServices\\ListMeshesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListMeshesResponse.php',
    'Google\\Service\\NetworkServices\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListOperationsResponse.php',
    'Google\\Service\\NetworkServices\\ListServiceBindingsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListServiceBindingsResponse.php',
    'Google\\Service\\NetworkServices\\ListServiceLbPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListServiceLbPoliciesResponse.php',
    'Google\\Service\\NetworkServices\\ListTcpRoutesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListTcpRoutesResponse.php',
    'Google\\Service\\NetworkServices\\ListTlsRoutesResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ListTlsRoutesResponse.php',
    'Google\\Service\\NetworkServices\\Location' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Location.php',
    'Google\\Service\\NetworkServices\\Mesh' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Mesh.php',
    'Google\\Service\\NetworkServices\\NetworkservicesEmpty' => $vendorDir . '/google/apiclient-services/src/NetworkServices/NetworkservicesEmpty.php',
    'Google\\Service\\NetworkServices\\Operation' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Operation.php',
    'Google\\Service\\NetworkServices\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/NetworkServices/OperationMetadata.php',
    'Google\\Service\\NetworkServices\\Policy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Policy.php',
    'Google\\Service\\NetworkServices\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/Projects.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocations.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsEdgeCacheKeysets' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsEdgeCacheKeysets.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsEdgeCacheOrigins' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsEdgeCacheOrigins.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsEdgeCacheServices' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsEdgeCacheServices.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsEndpointPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsEndpointPolicies.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsGateways' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsGateways.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsGrpcRoutes' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsGrpcRoutes.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsHttpRoutes' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsHttpRoutes.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsLbRouteExtensions' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsLbRouteExtensions.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsLbTrafficExtensions' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsLbTrafficExtensions.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMeshes' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMeshes.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMulticastConsumerAssociations' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMulticastConsumerAssociations.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMulticastDomainActivations' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMulticastDomainActivations.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMulticastDomains' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMulticastDomains.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMulticastGroupDefinitions' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMulticastGroupDefinitions.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsMulticastGroups' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsMulticastGroups.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsServiceBindings' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsServiceBindings.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsServiceLbPolicies' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsServiceLbPolicies.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsTcpRoutes' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsTcpRoutes.php',
    'Google\\Service\\NetworkServices\\Resource\\ProjectsLocationsTlsRoutes' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Resource/ProjectsLocationsTlsRoutes.php',
    'Google\\Service\\NetworkServices\\ServiceBinding' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ServiceBinding.php',
    'Google\\Service\\NetworkServices\\ServiceLbPolicy' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ServiceLbPolicy.php',
    'Google\\Service\\NetworkServices\\ServiceLbPolicyAutoCapacityDrain' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ServiceLbPolicyAutoCapacityDrain.php',
    'Google\\Service\\NetworkServices\\ServiceLbPolicyFailoverConfig' => $vendorDir . '/google/apiclient-services/src/NetworkServices/ServiceLbPolicyFailoverConfig.php',
    'Google\\Service\\NetworkServices\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/NetworkServices/SetIamPolicyRequest.php',
    'Google\\Service\\NetworkServices\\Status' => $vendorDir . '/google/apiclient-services/src/NetworkServices/Status.php',
    'Google\\Service\\NetworkServices\\TcpRoute' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TcpRoute.php',
    'Google\\Service\\NetworkServices\\TcpRouteRouteAction' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TcpRouteRouteAction.php',
    'Google\\Service\\NetworkServices\\TcpRouteRouteDestination' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TcpRouteRouteDestination.php',
    'Google\\Service\\NetworkServices\\TcpRouteRouteMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TcpRouteRouteMatch.php',
    'Google\\Service\\NetworkServices\\TcpRouteRouteRule' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TcpRouteRouteRule.php',
    'Google\\Service\\NetworkServices\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TestIamPermissionsRequest.php',
    'Google\\Service\\NetworkServices\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TestIamPermissionsResponse.php',
    'Google\\Service\\NetworkServices\\TlsRoute' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TlsRoute.php',
    'Google\\Service\\NetworkServices\\TlsRouteRouteAction' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TlsRouteRouteAction.php',
    'Google\\Service\\NetworkServices\\TlsRouteRouteDestination' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TlsRouteRouteDestination.php',
    'Google\\Service\\NetworkServices\\TlsRouteRouteMatch' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TlsRouteRouteMatch.php',
    'Google\\Service\\NetworkServices\\TlsRouteRouteRule' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TlsRouteRouteRule.php',
    'Google\\Service\\NetworkServices\\TrafficPortSelector' => $vendorDir . '/google/apiclient-services/src/NetworkServices/TrafficPortSelector.php',
    'Google\\Service\\Networkconnectivity' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity.php',
    'Google\\Service\\Networkconnectivity\\AcceptHubSpokeRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AcceptHubSpokeRequest.php',
    'Google\\Service\\Networkconnectivity\\AcceptHubSpokeResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AcceptHubSpokeResponse.php',
    'Google\\Service\\Networkconnectivity\\AcceptSpokeRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AcceptSpokeRequest.php',
    'Google\\Service\\Networkconnectivity\\AttributeValue' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AttributeValue.php',
    'Google\\Service\\Networkconnectivity\\Attributes' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Attributes.php',
    'Google\\Service\\Networkconnectivity\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AuditConfig.php',
    'Google\\Service\\Networkconnectivity\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AuditLogConfig.php',
    'Google\\Service\\Networkconnectivity\\AutoAccept' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/AutoAccept.php',
    'Google\\Service\\Networkconnectivity\\BillingView' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/BillingView.php',
    'Google\\Service\\Networkconnectivity\\Binding' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Binding.php',
    'Google\\Service\\Networkconnectivity\\ConsumerPscConfig' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ConsumerPscConfig.php',
    'Google\\Service\\Networkconnectivity\\ConsumerPscConnection' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ConsumerPscConnection.php',
    'Google\\Service\\Networkconnectivity\\Distribution' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Distribution.php',
    'Google\\Service\\Networkconnectivity\\Exemplar' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Exemplar.php',
    'Google\\Service\\Networkconnectivity\\ExplicitBuckets' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ExplicitBuckets.php',
    'Google\\Service\\Networkconnectivity\\ExponentialBuckets' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ExponentialBuckets.php',
    'Google\\Service\\Networkconnectivity\\Expr' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Expr.php',
    'Google\\Service\\Networkconnectivity\\Filter' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Filter.php',
    'Google\\Service\\Networkconnectivity\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\Networkconnectivity\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Networkconnectivity\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/GoogleLongrunningOperation.php',
    'Google\\Service\\Networkconnectivity\\GoogleRpcErrorInfo' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/GoogleRpcErrorInfo.php',
    'Google\\Service\\Networkconnectivity\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/GoogleRpcStatus.php',
    'Google\\Service\\Networkconnectivity\\Group' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Group.php',
    'Google\\Service\\Networkconnectivity\\HttpRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/HttpRequest.php',
    'Google\\Service\\Networkconnectivity\\Hub' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Hub.php',
    'Google\\Service\\Networkconnectivity\\InterconnectAttachment' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/InterconnectAttachment.php',
    'Google\\Service\\Networkconnectivity\\InternalRange' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/InternalRange.php',
    'Google\\Service\\Networkconnectivity\\LinearBuckets' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LinearBuckets.php',
    'Google\\Service\\Networkconnectivity\\LinkedInterconnectAttachments' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LinkedInterconnectAttachments.php',
    'Google\\Service\\Networkconnectivity\\LinkedRouterApplianceInstances' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LinkedRouterApplianceInstances.php',
    'Google\\Service\\Networkconnectivity\\LinkedVpcNetwork' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LinkedVpcNetwork.php',
    'Google\\Service\\Networkconnectivity\\LinkedVpnTunnels' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LinkedVpnTunnels.php',
    'Google\\Service\\Networkconnectivity\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListGroupsResponse.php',
    'Google\\Service\\Networkconnectivity\\ListHubSpokesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListHubSpokesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListHubsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListHubsResponse.php',
    'Google\\Service\\Networkconnectivity\\ListInternalRangesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListInternalRangesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListLocationsResponse.php',
    'Google\\Service\\Networkconnectivity\\ListPolicyBasedRoutesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListPolicyBasedRoutesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListRegionalEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListRegionalEndpointsResponse.php',
    'Google\\Service\\Networkconnectivity\\ListRouteTablesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListRouteTablesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListRoutesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListRoutesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListServiceClassesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListServiceClassesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListServiceConnectionMapsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListServiceConnectionMapsResponse.php',
    'Google\\Service\\Networkconnectivity\\ListServiceConnectionPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListServiceConnectionPoliciesResponse.php',
    'Google\\Service\\Networkconnectivity\\ListServiceConnectionTokensResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListServiceConnectionTokensResponse.php',
    'Google\\Service\\Networkconnectivity\\ListSpokesResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ListSpokesResponse.php',
    'Google\\Service\\Networkconnectivity\\Location' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Location.php',
    'Google\\Service\\Networkconnectivity\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LocationMetadata.php',
    'Google\\Service\\Networkconnectivity\\LogEntry' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LogEntry.php',
    'Google\\Service\\Networkconnectivity\\LogEntryOperation' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LogEntryOperation.php',
    'Google\\Service\\Networkconnectivity\\LogEntrySourceLocation' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/LogEntrySourceLocation.php',
    'Google\\Service\\Networkconnectivity\\MetricValue' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/MetricValue.php',
    'Google\\Service\\Networkconnectivity\\MetricValueSet' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/MetricValueSet.php',
    'Google\\Service\\Networkconnectivity\\Money' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Money.php',
    'Google\\Service\\Networkconnectivity\\NetworkconnectivityEmpty' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/NetworkconnectivityEmpty.php',
    'Google\\Service\\Networkconnectivity\\NextHopInterconnectAttachment' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/NextHopInterconnectAttachment.php',
    'Google\\Service\\Networkconnectivity\\NextHopRouterApplianceInstance' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/NextHopRouterApplianceInstance.php',
    'Google\\Service\\Networkconnectivity\\NextHopVPNTunnel' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/NextHopVPNTunnel.php',
    'Google\\Service\\Networkconnectivity\\NextHopVpcNetwork' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/NextHopVpcNetwork.php',
    'Google\\Service\\Networkconnectivity\\Operation' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Operation.php',
    'Google\\Service\\Networkconnectivity\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/OperationMetadata.php',
    'Google\\Service\\Networkconnectivity\\Policy' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Policy.php',
    'Google\\Service\\Networkconnectivity\\PolicyBasedRoute' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/PolicyBasedRoute.php',
    'Google\\Service\\Networkconnectivity\\ProducerPscConfig' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ProducerPscConfig.php',
    'Google\\Service\\Networkconnectivity\\PscConfig' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/PscConfig.php',
    'Google\\Service\\Networkconnectivity\\PscConnection' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/PscConnection.php',
    'Google\\Service\\Networkconnectivity\\QuotaProperties' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/QuotaProperties.php',
    'Google\\Service\\Networkconnectivity\\RegionalEndpoint' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RegionalEndpoint.php',
    'Google\\Service\\Networkconnectivity\\RejectHubSpokeRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RejectHubSpokeRequest.php',
    'Google\\Service\\Networkconnectivity\\RejectHubSpokeResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RejectHubSpokeResponse.php',
    'Google\\Service\\Networkconnectivity\\RejectSpokeRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RejectSpokeRequest.php',
    'Google\\Service\\Networkconnectivity\\ReportRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ReportRequest.php',
    'Google\\Service\\Networkconnectivity\\ResourceInfo' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ResourceInfo.php',
    'Google\\Service\\Networkconnectivity\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/Projects.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocations.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsInternalRanges' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsInternalRanges.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobal' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobal.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobalHubs' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobalHubs.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobalHubsGroups' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobalHubsGroups.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobalHubsRouteTables' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobalHubsRouteTables.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobalHubsRouteTablesRoutes' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobalHubsRouteTablesRoutes.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsNetworkconnectivityGlobalPolicyBasedRoutes' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsNetworkconnectivityGlobalPolicyBasedRoutes.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsRegionalEndpoints' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsRegionalEndpoints.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsServiceClasses' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsServiceClasses.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsServiceConnectionMaps' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsServiceConnectionMaps.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsServiceConnectionPolicies' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsServiceConnectionPolicies.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsServiceConnectionTokens' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsServiceConnectionTokens.php',
    'Google\\Service\\Networkconnectivity\\Resource\\ProjectsLocationsSpokes' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Resource/ProjectsLocationsSpokes.php',
    'Google\\Service\\Networkconnectivity\\Route' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Route.php',
    'Google\\Service\\Networkconnectivity\\RouteTable' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RouteTable.php',
    'Google\\Service\\Networkconnectivity\\RouterApplianceInstance' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RouterApplianceInstance.php',
    'Google\\Service\\Networkconnectivity\\RoutingVPC' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/RoutingVPC.php',
    'Google\\Service\\Networkconnectivity\\ServiceClass' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ServiceClass.php',
    'Google\\Service\\Networkconnectivity\\ServiceConnectionMap' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ServiceConnectionMap.php',
    'Google\\Service\\Networkconnectivity\\ServiceConnectionPolicy' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ServiceConnectionPolicy.php',
    'Google\\Service\\Networkconnectivity\\ServiceConnectionToken' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/ServiceConnectionToken.php',
    'Google\\Service\\Networkconnectivity\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/SetIamPolicyRequest.php',
    'Google\\Service\\Networkconnectivity\\Spoke' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Spoke.php',
    'Google\\Service\\Networkconnectivity\\SpokeStateCount' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/SpokeStateCount.php',
    'Google\\Service\\Networkconnectivity\\SpokeStateReasonCount' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/SpokeStateReasonCount.php',
    'Google\\Service\\Networkconnectivity\\SpokeSummary' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/SpokeSummary.php',
    'Google\\Service\\Networkconnectivity\\SpokeTypeCount' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/SpokeTypeCount.php',
    'Google\\Service\\Networkconnectivity\\StateReason' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/StateReason.php',
    'Google\\Service\\Networkconnectivity\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/TestIamPermissionsRequest.php',
    'Google\\Service\\Networkconnectivity\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/TestIamPermissionsResponse.php',
    'Google\\Service\\Networkconnectivity\\TraceSpan' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/TraceSpan.php',
    'Google\\Service\\Networkconnectivity\\TruncatableString' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/TruncatableString.php',
    'Google\\Service\\Networkconnectivity\\VirtualMachine' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/VirtualMachine.php',
    'Google\\Service\\Networkconnectivity\\Warnings' => $vendorDir . '/google/apiclient-services/src/Networkconnectivity/Warnings.php',
    'Google\\Service\\OSConfig' => $vendorDir . '/google/apiclient-services/src/OSConfig.php',
    'Google\\Service\\OSConfig\\AptSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/AptSettings.php',
    'Google\\Service\\OSConfig\\CVSSv3' => $vendorDir . '/google/apiclient-services/src/OSConfig/CVSSv3.php',
    'Google\\Service\\OSConfig\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/OSConfig/CancelOperationRequest.php',
    'Google\\Service\\OSConfig\\CancelPatchJobRequest' => $vendorDir . '/google/apiclient-services/src/OSConfig/CancelPatchJobRequest.php',
    'Google\\Service\\OSConfig\\Date' => $vendorDir . '/google/apiclient-services/src/OSConfig/Date.php',
    'Google\\Service\\OSConfig\\ExecStep' => $vendorDir . '/google/apiclient-services/src/OSConfig/ExecStep.php',
    'Google\\Service\\OSConfig\\ExecStepConfig' => $vendorDir . '/google/apiclient-services/src/OSConfig/ExecStepConfig.php',
    'Google\\Service\\OSConfig\\ExecutePatchJobRequest' => $vendorDir . '/google/apiclient-services/src/OSConfig/ExecutePatchJobRequest.php',
    'Google\\Service\\OSConfig\\FixedOrPercent' => $vendorDir . '/google/apiclient-services/src/OSConfig/FixedOrPercent.php',
    'Google\\Service\\OSConfig\\GcsObject' => $vendorDir . '/google/apiclient-services/src/OSConfig/GcsObject.php',
    'Google\\Service\\OSConfig\\GooSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/GooSettings.php',
    'Google\\Service\\OSConfig\\GoogleCloudOsconfigV1OSPolicyAssignmentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/OSConfig/GoogleCloudOsconfigV1OSPolicyAssignmentOperationMetadata.php',
    'Google\\Service\\OSConfig\\Inventory' => $vendorDir . '/google/apiclient-services/src/OSConfig/Inventory.php',
    'Google\\Service\\OSConfig\\InventoryItem' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryItem.php',
    'Google\\Service\\OSConfig\\InventoryOsInfo' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryOsInfo.php',
    'Google\\Service\\OSConfig\\InventorySoftwarePackage' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventorySoftwarePackage.php',
    'Google\\Service\\OSConfig\\InventoryVersionedPackage' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryVersionedPackage.php',
    'Google\\Service\\OSConfig\\InventoryWindowsApplication' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryWindowsApplication.php',
    'Google\\Service\\OSConfig\\InventoryWindowsQuickFixEngineeringPackage' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryWindowsQuickFixEngineeringPackage.php',
    'Google\\Service\\OSConfig\\InventoryWindowsUpdatePackage' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryWindowsUpdatePackage.php',
    'Google\\Service\\OSConfig\\InventoryWindowsUpdatePackageWindowsUpdateCategory' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryWindowsUpdatePackageWindowsUpdateCategory.php',
    'Google\\Service\\OSConfig\\InventoryZypperPatch' => $vendorDir . '/google/apiclient-services/src/OSConfig/InventoryZypperPatch.php',
    'Google\\Service\\OSConfig\\ListInventoriesResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListInventoriesResponse.php',
    'Google\\Service\\OSConfig\\ListOSPolicyAssignmentReportsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListOSPolicyAssignmentReportsResponse.php',
    'Google\\Service\\OSConfig\\ListOSPolicyAssignmentRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListOSPolicyAssignmentRevisionsResponse.php',
    'Google\\Service\\OSConfig\\ListOSPolicyAssignmentsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListOSPolicyAssignmentsResponse.php',
    'Google\\Service\\OSConfig\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListOperationsResponse.php',
    'Google\\Service\\OSConfig\\ListPatchDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListPatchDeploymentsResponse.php',
    'Google\\Service\\OSConfig\\ListPatchJobInstanceDetailsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListPatchJobInstanceDetailsResponse.php',
    'Google\\Service\\OSConfig\\ListPatchJobsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListPatchJobsResponse.php',
    'Google\\Service\\OSConfig\\ListVulnerabilityReportsResponse' => $vendorDir . '/google/apiclient-services/src/OSConfig/ListVulnerabilityReportsResponse.php',
    'Google\\Service\\OSConfig\\MonthlySchedule' => $vendorDir . '/google/apiclient-services/src/OSConfig/MonthlySchedule.php',
    'Google\\Service\\OSConfig\\OSPolicy' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicy.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignment' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignment.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentInstanceFilter' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentInstanceFilter.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentInstanceFilterInventory' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentInstanceFilterInventory.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentLabelSet' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentLabelSet.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentOperationMetadata' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentOperationMetadata.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentReport' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentReport.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentReportOSPolicyCompliance' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentReportOSPolicyCompliance.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceCompliance' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceCompliance.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceComplianceExecResourceOutput' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceComplianceExecResourceOutput.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceComplianceOSPolicyResourceConfigStep' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentReportOSPolicyComplianceOSPolicyResourceComplianceOSPolicyResourceConfigStep.php',
    'Google\\Service\\OSConfig\\OSPolicyAssignmentRollout' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyAssignmentRollout.php',
    'Google\\Service\\OSConfig\\OSPolicyInventoryFilter' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyInventoryFilter.php',
    'Google\\Service\\OSConfig\\OSPolicyResource' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResource.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceExecResource' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceExecResource.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceExecResourceExec' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceExecResourceExec.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceFile' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceFile.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceFileGcs' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceFileGcs.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceFileRemote' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceFileRemote.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceFileResource' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceFileResource.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceGroup' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceGroup.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResource' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResource.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceAPT' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceAPT.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceDeb' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceDeb.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceGooGet' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceGooGet.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceMSI' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceMSI.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceRPM' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceRPM.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceYUM' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceYUM.php',
    'Google\\Service\\OSConfig\\OSPolicyResourcePackageResourceZypper' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourcePackageResourceZypper.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceRepositoryResource' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceRepositoryResource.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceRepositoryResourceAptRepository' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceRepositoryResourceAptRepository.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceRepositoryResourceGooRepository' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceRepositoryResourceGooRepository.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceRepositoryResourceYumRepository' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceRepositoryResourceYumRepository.php',
    'Google\\Service\\OSConfig\\OSPolicyResourceRepositoryResourceZypperRepository' => $vendorDir . '/google/apiclient-services/src/OSConfig/OSPolicyResourceRepositoryResourceZypperRepository.php',
    'Google\\Service\\OSConfig\\OneTimeSchedule' => $vendorDir . '/google/apiclient-services/src/OSConfig/OneTimeSchedule.php',
    'Google\\Service\\OSConfig\\Operation' => $vendorDir . '/google/apiclient-services/src/OSConfig/Operation.php',
    'Google\\Service\\OSConfig\\OsconfigEmpty' => $vendorDir . '/google/apiclient-services/src/OSConfig/OsconfigEmpty.php',
    'Google\\Service\\OSConfig\\PatchConfig' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchConfig.php',
    'Google\\Service\\OSConfig\\PatchDeployment' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchDeployment.php',
    'Google\\Service\\OSConfig\\PatchInstanceFilter' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchInstanceFilter.php',
    'Google\\Service\\OSConfig\\PatchInstanceFilterGroupLabel' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchInstanceFilterGroupLabel.php',
    'Google\\Service\\OSConfig\\PatchJob' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchJob.php',
    'Google\\Service\\OSConfig\\PatchJobInstanceDetails' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchJobInstanceDetails.php',
    'Google\\Service\\OSConfig\\PatchJobInstanceDetailsSummary' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchJobInstanceDetailsSummary.php',
    'Google\\Service\\OSConfig\\PatchRollout' => $vendorDir . '/google/apiclient-services/src/OSConfig/PatchRollout.php',
    'Google\\Service\\OSConfig\\PausePatchDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/OSConfig/PausePatchDeploymentRequest.php',
    'Google\\Service\\OSConfig\\ProjectFeatureSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/ProjectFeatureSettings.php',
    'Google\\Service\\OSConfig\\RecurringSchedule' => $vendorDir . '/google/apiclient-services/src/OSConfig/RecurringSchedule.php',
    'Google\\Service\\OSConfig\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/Operations.php',
    'Google\\Service\\OSConfig\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/Projects.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocations.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsInstances' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsInstances.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsInstancesInventories' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsInstancesInventories.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsInstancesOsPolicyAssignments' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsInstancesOsPolicyAssignments.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsInstancesOsPolicyAssignmentsReports' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsInstancesOsPolicyAssignmentsReports.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsInstancesVulnerabilityReports' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsInstancesVulnerabilityReports.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsOsPolicyAssignments' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsOsPolicyAssignments.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsOsPolicyAssignmentsOperations' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsOsPolicyAssignmentsOperations.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsLocationsOsconfigGlobal' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsLocationsOsconfigGlobal.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsPatchDeployments' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsPatchDeployments.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsPatchJobs' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsPatchJobs.php',
    'Google\\Service\\OSConfig\\Resource\\ProjectsPatchJobsInstanceDetails' => $vendorDir . '/google/apiclient-services/src/OSConfig/Resource/ProjectsPatchJobsInstanceDetails.php',
    'Google\\Service\\OSConfig\\ResumePatchDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/OSConfig/ResumePatchDeploymentRequest.php',
    'Google\\Service\\OSConfig\\Status' => $vendorDir . '/google/apiclient-services/src/OSConfig/Status.php',
    'Google\\Service\\OSConfig\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/OSConfig/TimeOfDay.php',
    'Google\\Service\\OSConfig\\TimeZone' => $vendorDir . '/google/apiclient-services/src/OSConfig/TimeZone.php',
    'Google\\Service\\OSConfig\\VulnerabilityReport' => $vendorDir . '/google/apiclient-services/src/OSConfig/VulnerabilityReport.php',
    'Google\\Service\\OSConfig\\VulnerabilityReportVulnerability' => $vendorDir . '/google/apiclient-services/src/OSConfig/VulnerabilityReportVulnerability.php',
    'Google\\Service\\OSConfig\\VulnerabilityReportVulnerabilityDetails' => $vendorDir . '/google/apiclient-services/src/OSConfig/VulnerabilityReportVulnerabilityDetails.php',
    'Google\\Service\\OSConfig\\VulnerabilityReportVulnerabilityDetailsReference' => $vendorDir . '/google/apiclient-services/src/OSConfig/VulnerabilityReportVulnerabilityDetailsReference.php',
    'Google\\Service\\OSConfig\\VulnerabilityReportVulnerabilityItem' => $vendorDir . '/google/apiclient-services/src/OSConfig/VulnerabilityReportVulnerabilityItem.php',
    'Google\\Service\\OSConfig\\WeekDayOfMonth' => $vendorDir . '/google/apiclient-services/src/OSConfig/WeekDayOfMonth.php',
    'Google\\Service\\OSConfig\\WeeklySchedule' => $vendorDir . '/google/apiclient-services/src/OSConfig/WeeklySchedule.php',
    'Google\\Service\\OSConfig\\WindowsUpdateSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/WindowsUpdateSettings.php',
    'Google\\Service\\OSConfig\\YumSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/YumSettings.php',
    'Google\\Service\\OSConfig\\ZypperSettings' => $vendorDir . '/google/apiclient-services/src/OSConfig/ZypperSettings.php',
    'Google\\Service\\Oauth2' => $vendorDir . '/google/apiclient-services/src/Oauth2.php',
    'Google\\Service\\Oauth2\\Resource\\Userinfo' => $vendorDir . '/google/apiclient-services/src/Oauth2/Resource/Userinfo.php',
    'Google\\Service\\Oauth2\\Resource\\UserinfoV2' => $vendorDir . '/google/apiclient-services/src/Oauth2/Resource/UserinfoV2.php',
    'Google\\Service\\Oauth2\\Resource\\UserinfoV2Me' => $vendorDir . '/google/apiclient-services/src/Oauth2/Resource/UserinfoV2Me.php',
    'Google\\Service\\Oauth2\\Tokeninfo' => $vendorDir . '/google/apiclient-services/src/Oauth2/Tokeninfo.php',
    'Google\\Service\\Oauth2\\Userinfo' => $vendorDir . '/google/apiclient-services/src/Oauth2/Userinfo.php',
    'Google\\Service\\OnDemandScanning' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning.php',
    'Google\\Service\\OnDemandScanning\\AliasContext' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AliasContext.php',
    'Google\\Service\\OnDemandScanning\\AnalysisCompleted' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalysisCompleted.php',
    'Google\\Service\\OnDemandScanning\\AnalyzePackagesMetadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalyzePackagesMetadata.php',
    'Google\\Service\\OnDemandScanning\\AnalyzePackagesMetadataV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalyzePackagesMetadataV1.php',
    'Google\\Service\\OnDemandScanning\\AnalyzePackagesRequestV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalyzePackagesRequestV1.php',
    'Google\\Service\\OnDemandScanning\\AnalyzePackagesResponse' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalyzePackagesResponse.php',
    'Google\\Service\\OnDemandScanning\\AnalyzePackagesResponseV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AnalyzePackagesResponseV1.php',
    'Google\\Service\\OnDemandScanning\\Artifact' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Artifact.php',
    'Google\\Service\\OnDemandScanning\\AttestationOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/AttestationOccurrence.php',
    'Google\\Service\\OnDemandScanning\\Binary' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Binary.php',
    'Google\\Service\\OnDemandScanning\\BinarySourceInfo' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BinarySourceInfo.php',
    'Google\\Service\\OnDemandScanning\\BuildDefinition' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BuildDefinition.php',
    'Google\\Service\\OnDemandScanning\\BuildMetadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BuildMetadata.php',
    'Google\\Service\\OnDemandScanning\\BuildOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BuildOccurrence.php',
    'Google\\Service\\OnDemandScanning\\BuildProvenance' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BuildProvenance.php',
    'Google\\Service\\OnDemandScanning\\BuilderConfig' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/BuilderConfig.php',
    'Google\\Service\\OnDemandScanning\\CVSS' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/CVSS.php',
    'Google\\Service\\OnDemandScanning\\Category' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Category.php',
    'Google\\Service\\OnDemandScanning\\CloudRepoSourceContext' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/CloudRepoSourceContext.php',
    'Google\\Service\\OnDemandScanning\\Command' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Command.php',
    'Google\\Service\\OnDemandScanning\\Completeness' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Completeness.php',
    'Google\\Service\\OnDemandScanning\\ComplianceOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ComplianceOccurrence.php',
    'Google\\Service\\OnDemandScanning\\ComplianceVersion' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ComplianceVersion.php',
    'Google\\Service\\OnDemandScanning\\DSSEAttestationOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/DSSEAttestationOccurrence.php',
    'Google\\Service\\OnDemandScanning\\DeploymentOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/DeploymentOccurrence.php',
    'Google\\Service\\OnDemandScanning\\DiscoveryOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/DiscoveryOccurrence.php',
    'Google\\Service\\OnDemandScanning\\Envelope' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Envelope.php',
    'Google\\Service\\OnDemandScanning\\EnvelopeSignature' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/EnvelopeSignature.php',
    'Google\\Service\\OnDemandScanning\\FileHashes' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/FileHashes.php',
    'Google\\Service\\OnDemandScanning\\FileLocation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/FileLocation.php',
    'Google\\Service\\OnDemandScanning\\Fingerprint' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Fingerprint.php',
    'Google\\Service\\OnDemandScanning\\GerritSourceContext' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GerritSourceContext.php',
    'Google\\Service\\OnDemandScanning\\GitSourceContext' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GitSourceContext.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1FileLocation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1FileLocation.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaBuilder' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaBuilder.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaCompleteness' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaCompleteness.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaConfigSource' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaConfigSource.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaInvocation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaInvocation.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaMaterial' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaMaterial.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenance02SlsaMetadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenance02SlsaMetadata.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.php',
    'Google\\Service\\OnDemandScanning\\GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.php',
    'Google\\Service\\OnDemandScanning\\Hash' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Hash.php',
    'Google\\Service\\OnDemandScanning\\Identity' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Identity.php',
    'Google\\Service\\OnDemandScanning\\ImageOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ImageOccurrence.php',
    'Google\\Service\\OnDemandScanning\\InTotoProvenance' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/InTotoProvenance.php',
    'Google\\Service\\OnDemandScanning\\InTotoSlsaProvenanceV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/InTotoSlsaProvenanceV1.php',
    'Google\\Service\\OnDemandScanning\\InTotoStatement' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/InTotoStatement.php',
    'Google\\Service\\OnDemandScanning\\Justification' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Justification.php',
    'Google\\Service\\OnDemandScanning\\Jwt' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Jwt.php',
    'Google\\Service\\OnDemandScanning\\LanguagePackageDependency' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/LanguagePackageDependency.php',
    'Google\\Service\\OnDemandScanning\\Layer' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Layer.php',
    'Google\\Service\\OnDemandScanning\\License' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/License.php',
    'Google\\Service\\OnDemandScanning\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ListOperationsResponse.php',
    'Google\\Service\\OnDemandScanning\\ListVulnerabilitiesResponseV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ListVulnerabilitiesResponseV1.php',
    'Google\\Service\\OnDemandScanning\\Location' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Location.php',
    'Google\\Service\\OnDemandScanning\\Maintainer' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Maintainer.php',
    'Google\\Service\\OnDemandScanning\\Material' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Material.php',
    'Google\\Service\\OnDemandScanning\\Metadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Metadata.php',
    'Google\\Service\\OnDemandScanning\\NonCompliantFile' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/NonCompliantFile.php',
    'Google\\Service\\OnDemandScanning\\Occurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Occurrence.php',
    'Google\\Service\\OnDemandScanning\\OndemandscanningEmpty' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/OndemandscanningEmpty.php',
    'Google\\Service\\OnDemandScanning\\Operation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Operation.php',
    'Google\\Service\\OnDemandScanning\\PackageData' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/PackageData.php',
    'Google\\Service\\OnDemandScanning\\PackageIssue' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/PackageIssue.php',
    'Google\\Service\\OnDemandScanning\\PackageOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/PackageOccurrence.php',
    'Google\\Service\\OnDemandScanning\\PackageVersion' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/PackageVersion.php',
    'Google\\Service\\OnDemandScanning\\ProjectRepoId' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ProjectRepoId.php',
    'Google\\Service\\OnDemandScanning\\ProvenanceBuilder' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ProvenanceBuilder.php',
    'Google\\Service\\OnDemandScanning\\Recipe' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Recipe.php',
    'Google\\Service\\OnDemandScanning\\RelatedUrl' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/RelatedUrl.php',
    'Google\\Service\\OnDemandScanning\\Remediation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Remediation.php',
    'Google\\Service\\OnDemandScanning\\RepoId' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/RepoId.php',
    'Google\\Service\\OnDemandScanning\\ResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/ResourceDescriptor.php',
    'Google\\Service\\OnDemandScanning\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Resource/Projects.php',
    'Google\\Service\\OnDemandScanning\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Resource/ProjectsLocations.php',
    'Google\\Service\\OnDemandScanning\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\OnDemandScanning\\Resource\\ProjectsLocationsScans' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Resource/ProjectsLocationsScans.php',
    'Google\\Service\\OnDemandScanning\\Resource\\ProjectsLocationsScansVulnerabilities' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Resource/ProjectsLocationsScansVulnerabilities.php',
    'Google\\Service\\OnDemandScanning\\RunDetails' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/RunDetails.php',
    'Google\\Service\\OnDemandScanning\\SBOMReferenceOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SBOMReferenceOccurrence.php',
    'Google\\Service\\OnDemandScanning\\SBOMStatus' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SBOMStatus.php',
    'Google\\Service\\OnDemandScanning\\SbomReferenceIntotoPayload' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SbomReferenceIntotoPayload.php',
    'Google\\Service\\OnDemandScanning\\SbomReferenceIntotoPredicate' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SbomReferenceIntotoPredicate.php',
    'Google\\Service\\OnDemandScanning\\Signature' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Signature.php',
    'Google\\Service\\OnDemandScanning\\SlsaBuilder' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaBuilder.php',
    'Google\\Service\\OnDemandScanning\\SlsaCompleteness' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaCompleteness.php',
    'Google\\Service\\OnDemandScanning\\SlsaMetadata' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaMetadata.php',
    'Google\\Service\\OnDemandScanning\\SlsaProvenance' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaProvenance.php',
    'Google\\Service\\OnDemandScanning\\SlsaProvenance02' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaProvenance02.php',
    'Google\\Service\\OnDemandScanning\\SlsaProvenanceV1' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaProvenanceV1.php',
    'Google\\Service\\OnDemandScanning\\SlsaProvenanceZeroTwo' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaProvenanceZeroTwo.php',
    'Google\\Service\\OnDemandScanning\\SlsaRecipe' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SlsaRecipe.php',
    'Google\\Service\\OnDemandScanning\\Source' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Source.php',
    'Google\\Service\\OnDemandScanning\\SourceContext' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/SourceContext.php',
    'Google\\Service\\OnDemandScanning\\Status' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Status.php',
    'Google\\Service\\OnDemandScanning\\Subject' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Subject.php',
    'Google\\Service\\OnDemandScanning\\UpgradeDistribution' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/UpgradeDistribution.php',
    'Google\\Service\\OnDemandScanning\\UpgradeOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/UpgradeOccurrence.php',
    'Google\\Service\\OnDemandScanning\\Version' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/Version.php',
    'Google\\Service\\OnDemandScanning\\VexAssessment' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/VexAssessment.php',
    'Google\\Service\\OnDemandScanning\\VulnerabilityAttestation' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/VulnerabilityAttestation.php',
    'Google\\Service\\OnDemandScanning\\VulnerabilityOccurrence' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/VulnerabilityOccurrence.php',
    'Google\\Service\\OnDemandScanning\\WindowsUpdate' => $vendorDir . '/google/apiclient-services/src/OnDemandScanning/WindowsUpdate.php',
    'Google\\Service\\OrgPolicyAPI' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2AlternatePolicySpec' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2AlternatePolicySpec.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2Constraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2Constraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ConstraintBooleanConstraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ConstraintBooleanConstraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ConstraintGoogleDefinedCustomConstraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ConstraintGoogleDefinedCustomConstraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ConstraintGoogleManagedConstraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ConstraintGoogleManagedConstraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ConstraintListConstraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ConstraintListConstraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2CustomConstraint' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2CustomConstraint.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ListConstraintsResponse' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ListConstraintsResponse.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ListCustomConstraintsResponse' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ListCustomConstraintsResponse.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2ListPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2ListPoliciesResponse.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2Policy' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2Policy.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2PolicySpec' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2PolicySpec.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2PolicySpecPolicyRule' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2PolicySpecPolicyRule.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleProtobufEmpty.php',
    'Google\\Service\\OrgPolicyAPI\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/GoogleTypeExpr.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/Folders.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\FoldersConstraints' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/FoldersConstraints.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\FoldersPolicies' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/FoldersPolicies.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/Organizations.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\OrganizationsConstraints' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/OrganizationsConstraints.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\OrganizationsCustomConstraints' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/OrganizationsCustomConstraints.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\OrganizationsPolicies' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/OrganizationsPolicies.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/Projects.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\ProjectsConstraints' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/ProjectsConstraints.php',
    'Google\\Service\\OrgPolicyAPI\\Resource\\ProjectsPolicies' => $vendorDir . '/google/apiclient-services/src/OrgPolicyAPI/Resource/ProjectsPolicies.php',
    'Google\\Service\\PagespeedInsights' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights.php',
    'Google\\Service\\PagespeedInsights\\AuditRefs' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/AuditRefs.php',
    'Google\\Service\\PagespeedInsights\\Bucket' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/Bucket.php',
    'Google\\Service\\PagespeedInsights\\Categories' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/Categories.php',
    'Google\\Service\\PagespeedInsights\\CategoryGroupV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/CategoryGroupV5.php',
    'Google\\Service\\PagespeedInsights\\ConfigSettings' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/ConfigSettings.php',
    'Google\\Service\\PagespeedInsights\\Environment' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/Environment.php',
    'Google\\Service\\PagespeedInsights\\I18n' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/I18n.php',
    'Google\\Service\\PagespeedInsights\\LhrEntity' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/LhrEntity.php',
    'Google\\Service\\PagespeedInsights\\LighthouseAuditResultV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/LighthouseAuditResultV5.php',
    'Google\\Service\\PagespeedInsights\\LighthouseCategoryV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/LighthouseCategoryV5.php',
    'Google\\Service\\PagespeedInsights\\LighthouseResultV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/LighthouseResultV5.php',
    'Google\\Service\\PagespeedInsights\\MetricSavings' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/MetricSavings.php',
    'Google\\Service\\PagespeedInsights\\PagespeedApiLoadingExperienceV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/PagespeedApiLoadingExperienceV5.php',
    'Google\\Service\\PagespeedInsights\\PagespeedApiPagespeedResponseV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/PagespeedApiPagespeedResponseV5.php',
    'Google\\Service\\PagespeedInsights\\PagespeedVersion' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/PagespeedVersion.php',
    'Google\\Service\\PagespeedInsights\\RendererFormattedStrings' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/RendererFormattedStrings.php',
    'Google\\Service\\PagespeedInsights\\Resource\\Pagespeedapi' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/Resource/Pagespeedapi.php',
    'Google\\Service\\PagespeedInsights\\RuntimeError' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/RuntimeError.php',
    'Google\\Service\\PagespeedInsights\\StackPack' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/StackPack.php',
    'Google\\Service\\PagespeedInsights\\Timing' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/Timing.php',
    'Google\\Service\\PagespeedInsights\\UserPageLoadMetricV5' => $vendorDir . '/google/apiclient-services/src/PagespeedInsights/UserPageLoadMetricV5.php',
    'Google\\Service\\PaymentsResellerSubscription' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Amount' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Amount.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1CancelSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1CancelSubscriptionRequest.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1CancelSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1CancelSubscriptionResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Duration' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Duration.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionRequest.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionRequestLineItemEntitlementDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionRequestLineItemEntitlementDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1EntitleSubscriptionResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ExtendSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ExtendSubscriptionRequest.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ExtendSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ExtendSubscriptionResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Extension' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Extension.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1FindEligiblePromotionsRequest' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1FindEligiblePromotionsRequest.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1FindEligiblePromotionsResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1FindEligiblePromotionsResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1FiniteBillingCycleDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1FiniteBillingCycleDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1GoogleOnePayload' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1GoogleOnePayload.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ListProductsResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ListPromotionsResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ListPromotionsResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Location' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Location.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Product' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Product.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ProductBundleDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ProductBundleDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ProductBundleDetailsBundleElement' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ProductBundleDetailsBundleElement.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ProductPayload' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ProductPayload.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ProductPriceConfig' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ProductPriceConfig.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Promotion' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Promotion.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1PromotionIntroductoryPricingDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1PromotionIntroductoryPricingDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1PromotionIntroductoryPricingDetailsIntroductoryPricingSpec' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1PromotionIntroductoryPricingDetailsIntroductoryPricingSpec.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1ServicePeriod' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1ServicePeriod.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1Subscription' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1Subscription.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionCancellationDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionCancellationDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItem' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItem.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItemBundleDetailsBundleElementDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItemBundleDetailsBundleElementDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItemOneTimeRecurrenceDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionLineItemOneTimeRecurrenceDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionPromotionSpec' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionPromotionSpec.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1SubscriptionUpgradeDowngradeDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1SubscriptionUpgradeDowngradeDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1UndoCancelSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1UndoCancelSubscriptionRequest.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1UndoCancelSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1UndoCancelSubscriptionResponse.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleCloudPaymentsResellerSubscriptionV1YoutubePayload' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleCloudPaymentsResellerSubscriptionV1YoutubePayload.php',
    'Google\\Service\\PaymentsResellerSubscription\\GoogleTypeLocalizedText' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/GoogleTypeLocalizedText.php',
    'Google\\Service\\PaymentsResellerSubscription\\ProductBundleDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/ProductBundleDetails.php',
    'Google\\Service\\PaymentsResellerSubscription\\Resource\\Partners' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/Resource/Partners.php',
    'Google\\Service\\PaymentsResellerSubscription\\Resource\\PartnersProducts' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/Resource/PartnersProducts.php',
    'Google\\Service\\PaymentsResellerSubscription\\Resource\\PartnersPromotions' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/Resource/PartnersPromotions.php',
    'Google\\Service\\PaymentsResellerSubscription\\Resource\\PartnersSubscriptions' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/Resource/PartnersSubscriptions.php',
    'Google\\Service\\PaymentsResellerSubscription\\SubscriptionLineItemBundleDetails' => $vendorDir . '/google/apiclient-services/src/PaymentsResellerSubscription/SubscriptionLineItemBundleDetails.php',
    'Google\\Service\\PeopleService' => $vendorDir . '/google/apiclient-services/src/PeopleService.php',
    'Google\\Service\\PeopleService\\Address' => $vendorDir . '/google/apiclient-services/src/PeopleService/Address.php',
    'Google\\Service\\PeopleService\\AgeRangeType' => $vendorDir . '/google/apiclient-services/src/PeopleService/AgeRangeType.php',
    'Google\\Service\\PeopleService\\BatchCreateContactsRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchCreateContactsRequest.php',
    'Google\\Service\\PeopleService\\BatchCreateContactsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchCreateContactsResponse.php',
    'Google\\Service\\PeopleService\\BatchDeleteContactsRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchDeleteContactsRequest.php',
    'Google\\Service\\PeopleService\\BatchGetContactGroupsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchGetContactGroupsResponse.php',
    'Google\\Service\\PeopleService\\BatchUpdateContactsRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchUpdateContactsRequest.php',
    'Google\\Service\\PeopleService\\BatchUpdateContactsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/BatchUpdateContactsResponse.php',
    'Google\\Service\\PeopleService\\Biography' => $vendorDir . '/google/apiclient-services/src/PeopleService/Biography.php',
    'Google\\Service\\PeopleService\\Birthday' => $vendorDir . '/google/apiclient-services/src/PeopleService/Birthday.php',
    'Google\\Service\\PeopleService\\BraggingRights' => $vendorDir . '/google/apiclient-services/src/PeopleService/BraggingRights.php',
    'Google\\Service\\PeopleService\\CalendarUrl' => $vendorDir . '/google/apiclient-services/src/PeopleService/CalendarUrl.php',
    'Google\\Service\\PeopleService\\ClientData' => $vendorDir . '/google/apiclient-services/src/PeopleService/ClientData.php',
    'Google\\Service\\PeopleService\\ContactGroup' => $vendorDir . '/google/apiclient-services/src/PeopleService/ContactGroup.php',
    'Google\\Service\\PeopleService\\ContactGroupMembership' => $vendorDir . '/google/apiclient-services/src/PeopleService/ContactGroupMembership.php',
    'Google\\Service\\PeopleService\\ContactGroupMetadata' => $vendorDir . '/google/apiclient-services/src/PeopleService/ContactGroupMetadata.php',
    'Google\\Service\\PeopleService\\ContactGroupResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ContactGroupResponse.php',
    'Google\\Service\\PeopleService\\ContactToCreate' => $vendorDir . '/google/apiclient-services/src/PeopleService/ContactToCreate.php',
    'Google\\Service\\PeopleService\\CopyOtherContactToMyContactsGroupRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/CopyOtherContactToMyContactsGroupRequest.php',
    'Google\\Service\\PeopleService\\CoverPhoto' => $vendorDir . '/google/apiclient-services/src/PeopleService/CoverPhoto.php',
    'Google\\Service\\PeopleService\\CreateContactGroupRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/CreateContactGroupRequest.php',
    'Google\\Service\\PeopleService\\Date' => $vendorDir . '/google/apiclient-services/src/PeopleService/Date.php',
    'Google\\Service\\PeopleService\\DeleteContactPhotoResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/DeleteContactPhotoResponse.php',
    'Google\\Service\\PeopleService\\DomainMembership' => $vendorDir . '/google/apiclient-services/src/PeopleService/DomainMembership.php',
    'Google\\Service\\PeopleService\\EmailAddress' => $vendorDir . '/google/apiclient-services/src/PeopleService/EmailAddress.php',
    'Google\\Service\\PeopleService\\Event' => $vendorDir . '/google/apiclient-services/src/PeopleService/Event.php',
    'Google\\Service\\PeopleService\\ExternalId' => $vendorDir . '/google/apiclient-services/src/PeopleService/ExternalId.php',
    'Google\\Service\\PeopleService\\FieldMetadata' => $vendorDir . '/google/apiclient-services/src/PeopleService/FieldMetadata.php',
    'Google\\Service\\PeopleService\\FileAs' => $vendorDir . '/google/apiclient-services/src/PeopleService/FileAs.php',
    'Google\\Service\\PeopleService\\Gender' => $vendorDir . '/google/apiclient-services/src/PeopleService/Gender.php',
    'Google\\Service\\PeopleService\\GetPeopleResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/GetPeopleResponse.php',
    'Google\\Service\\PeopleService\\GroupClientData' => $vendorDir . '/google/apiclient-services/src/PeopleService/GroupClientData.php',
    'Google\\Service\\PeopleService\\ImClient' => $vendorDir . '/google/apiclient-services/src/PeopleService/ImClient.php',
    'Google\\Service\\PeopleService\\Interest' => $vendorDir . '/google/apiclient-services/src/PeopleService/Interest.php',
    'Google\\Service\\PeopleService\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ListConnectionsResponse.php',
    'Google\\Service\\PeopleService\\ListContactGroupsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ListContactGroupsResponse.php',
    'Google\\Service\\PeopleService\\ListDirectoryPeopleResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ListDirectoryPeopleResponse.php',
    'Google\\Service\\PeopleService\\ListOtherContactsResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ListOtherContactsResponse.php',
    'Google\\Service\\PeopleService\\Locale' => $vendorDir . '/google/apiclient-services/src/PeopleService/Locale.php',
    'Google\\Service\\PeopleService\\Location' => $vendorDir . '/google/apiclient-services/src/PeopleService/Location.php',
    'Google\\Service\\PeopleService\\Membership' => $vendorDir . '/google/apiclient-services/src/PeopleService/Membership.php',
    'Google\\Service\\PeopleService\\MiscKeyword' => $vendorDir . '/google/apiclient-services/src/PeopleService/MiscKeyword.php',
    'Google\\Service\\PeopleService\\ModifyContactGroupMembersRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/ModifyContactGroupMembersRequest.php',
    'Google\\Service\\PeopleService\\ModifyContactGroupMembersResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/ModifyContactGroupMembersResponse.php',
    'Google\\Service\\PeopleService\\Name' => $vendorDir . '/google/apiclient-services/src/PeopleService/Name.php',
    'Google\\Service\\PeopleService\\Nickname' => $vendorDir . '/google/apiclient-services/src/PeopleService/Nickname.php',
    'Google\\Service\\PeopleService\\Occupation' => $vendorDir . '/google/apiclient-services/src/PeopleService/Occupation.php',
    'Google\\Service\\PeopleService\\Organization' => $vendorDir . '/google/apiclient-services/src/PeopleService/Organization.php',
    'Google\\Service\\PeopleService\\PeopleEmpty' => $vendorDir . '/google/apiclient-services/src/PeopleService/PeopleEmpty.php',
    'Google\\Service\\PeopleService\\Person' => $vendorDir . '/google/apiclient-services/src/PeopleService/Person.php',
    'Google\\Service\\PeopleService\\PersonMetadata' => $vendorDir . '/google/apiclient-services/src/PeopleService/PersonMetadata.php',
    'Google\\Service\\PeopleService\\PersonResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/PersonResponse.php',
    'Google\\Service\\PeopleService\\PhoneNumber' => $vendorDir . '/google/apiclient-services/src/PeopleService/PhoneNumber.php',
    'Google\\Service\\PeopleService\\Photo' => $vendorDir . '/google/apiclient-services/src/PeopleService/Photo.php',
    'Google\\Service\\PeopleService\\ProfileMetadata' => $vendorDir . '/google/apiclient-services/src/PeopleService/ProfileMetadata.php',
    'Google\\Service\\PeopleService\\Relation' => $vendorDir . '/google/apiclient-services/src/PeopleService/Relation.php',
    'Google\\Service\\PeopleService\\RelationshipInterest' => $vendorDir . '/google/apiclient-services/src/PeopleService/RelationshipInterest.php',
    'Google\\Service\\PeopleService\\RelationshipStatus' => $vendorDir . '/google/apiclient-services/src/PeopleService/RelationshipStatus.php',
    'Google\\Service\\PeopleService\\Residence' => $vendorDir . '/google/apiclient-services/src/PeopleService/Residence.php',
    'Google\\Service\\PeopleService\\Resource\\ContactGroups' => $vendorDir . '/google/apiclient-services/src/PeopleService/Resource/ContactGroups.php',
    'Google\\Service\\PeopleService\\Resource\\ContactGroupsMembers' => $vendorDir . '/google/apiclient-services/src/PeopleService/Resource/ContactGroupsMembers.php',
    'Google\\Service\\PeopleService\\Resource\\OtherContacts' => $vendorDir . '/google/apiclient-services/src/PeopleService/Resource/OtherContacts.php',
    'Google\\Service\\PeopleService\\Resource\\People' => $vendorDir . '/google/apiclient-services/src/PeopleService/Resource/People.php',
    'Google\\Service\\PeopleService\\Resource\\PeopleConnections' => $vendorDir . '/google/apiclient-services/src/PeopleService/Resource/PeopleConnections.php',
    'Google\\Service\\PeopleService\\SearchDirectoryPeopleResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/SearchDirectoryPeopleResponse.php',
    'Google\\Service\\PeopleService\\SearchResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/SearchResponse.php',
    'Google\\Service\\PeopleService\\SearchResult' => $vendorDir . '/google/apiclient-services/src/PeopleService/SearchResult.php',
    'Google\\Service\\PeopleService\\SipAddress' => $vendorDir . '/google/apiclient-services/src/PeopleService/SipAddress.php',
    'Google\\Service\\PeopleService\\Skill' => $vendorDir . '/google/apiclient-services/src/PeopleService/Skill.php',
    'Google\\Service\\PeopleService\\Source' => $vendorDir . '/google/apiclient-services/src/PeopleService/Source.php',
    'Google\\Service\\PeopleService\\Status' => $vendorDir . '/google/apiclient-services/src/PeopleService/Status.php',
    'Google\\Service\\PeopleService\\Tagline' => $vendorDir . '/google/apiclient-services/src/PeopleService/Tagline.php',
    'Google\\Service\\PeopleService\\UpdateContactGroupRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/UpdateContactGroupRequest.php',
    'Google\\Service\\PeopleService\\UpdateContactPhotoRequest' => $vendorDir . '/google/apiclient-services/src/PeopleService/UpdateContactPhotoRequest.php',
    'Google\\Service\\PeopleService\\UpdateContactPhotoResponse' => $vendorDir . '/google/apiclient-services/src/PeopleService/UpdateContactPhotoResponse.php',
    'Google\\Service\\PeopleService\\Url' => $vendorDir . '/google/apiclient-services/src/PeopleService/Url.php',
    'Google\\Service\\PeopleService\\UserDefined' => $vendorDir . '/google/apiclient-services/src/PeopleService/UserDefined.php',
    'Google\\Service\\PlayGrouping' => $vendorDir . '/google/apiclient-services/src/PlayGrouping.php',
    'Google\\Service\\PlayGrouping\\CreateOrUpdateTagsRequest' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/CreateOrUpdateTagsRequest.php',
    'Google\\Service\\PlayGrouping\\CreateOrUpdateTagsResponse' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/CreateOrUpdateTagsResponse.php',
    'Google\\Service\\PlayGrouping\\Resource\\Apps' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/Resource/Apps.php',
    'Google\\Service\\PlayGrouping\\Resource\\AppsTokens' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/Resource/AppsTokens.php',
    'Google\\Service\\PlayGrouping\\Resource\\AppsTokensTags' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/Resource/AppsTokensTags.php',
    'Google\\Service\\PlayGrouping\\Tag' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/Tag.php',
    'Google\\Service\\PlayGrouping\\VerifyTokenRequest' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/VerifyTokenRequest.php',
    'Google\\Service\\PlayGrouping\\VerifyTokenResponse' => $vendorDir . '/google/apiclient-services/src/PlayGrouping/VerifyTokenResponse.php',
    'Google\\Service\\PlayIntegrity' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity.php',
    'Google\\Service\\PlayIntegrity\\AccountActivity' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/AccountActivity.php',
    'Google\\Service\\PlayIntegrity\\AccountDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/AccountDetails.php',
    'Google\\Service\\PlayIntegrity\\AccountRiskVerdict' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/AccountRiskVerdict.php',
    'Google\\Service\\PlayIntegrity\\AppAccessRiskVerdict' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/AppAccessRiskVerdict.php',
    'Google\\Service\\PlayIntegrity\\AppIntegrity' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/AppIntegrity.php',
    'Google\\Service\\PlayIntegrity\\DecodeIntegrityTokenRequest' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/DecodeIntegrityTokenRequest.php',
    'Google\\Service\\PlayIntegrity\\DecodeIntegrityTokenResponse' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/DecodeIntegrityTokenResponse.php',
    'Google\\Service\\PlayIntegrity\\DeviceIntegrity' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/DeviceIntegrity.php',
    'Google\\Service\\PlayIntegrity\\DeviceRecall' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/DeviceRecall.php',
    'Google\\Service\\PlayIntegrity\\EnvironmentDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/EnvironmentDetails.php',
    'Google\\Service\\PlayIntegrity\\GuidanceDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/GuidanceDetails.php',
    'Google\\Service\\PlayIntegrity\\RecentDeviceActivity' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/RecentDeviceActivity.php',
    'Google\\Service\\PlayIntegrity\\RequestDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/RequestDetails.php',
    'Google\\Service\\PlayIntegrity\\Resource\\DeviceRecall' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/Resource/DeviceRecall.php',
    'Google\\Service\\PlayIntegrity\\Resource\\V1' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/Resource/V1.php',
    'Google\\Service\\PlayIntegrity\\TestingDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/TestingDetails.php',
    'Google\\Service\\PlayIntegrity\\TokenPayloadExternal' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/TokenPayloadExternal.php',
    'Google\\Service\\PlayIntegrity\\UserRemediationDetails' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/UserRemediationDetails.php',
    'Google\\Service\\PlayIntegrity\\Values' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/Values.php',
    'Google\\Service\\PlayIntegrity\\WriteDates' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/WriteDates.php',
    'Google\\Service\\PlayIntegrity\\WriteDeviceRecallRequest' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/WriteDeviceRecallRequest.php',
    'Google\\Service\\PlayIntegrity\\WriteDeviceRecallResponse' => $vendorDir . '/google/apiclient-services/src/PlayIntegrity/WriteDeviceRecallResponse.php',
    'Google\\Service\\PlayableLocations' => $vendorDir . '/google/apiclient-services/src/PlayableLocations.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3Impression' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3Impression.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3LogImpressionsRequest' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3LogImpressionsRequest.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3LogImpressionsResponse' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3LogImpressionsResponse.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3LogPlayerReportsRequest' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3LogPlayerReportsRequest.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3LogPlayerReportsResponse' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3LogPlayerReportsResponse.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3PlayerReport' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3PlayerReport.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SampleAreaFilter' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SampleAreaFilter.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SampleCriterion' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SampleCriterion.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SampleFilter' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SampleFilter.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SamplePlayableLocation' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SamplePlayableLocation.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SamplePlayableLocationList' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SamplePlayableLocationList.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponse' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponse.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsPlayablelocationsV3SampleSpacingOptions' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsPlayablelocationsV3SampleSpacingOptions.php',
    'Google\\Service\\PlayableLocations\\GoogleMapsUnityClientInfo' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleMapsUnityClientInfo.php',
    'Google\\Service\\PlayableLocations\\GoogleTypeLatLng' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/GoogleTypeLatLng.php',
    'Google\\Service\\PlayableLocations\\Resource\\V3' => $vendorDir . '/google/apiclient-services/src/PlayableLocations/Resource/V3.php',
    'Google\\Service\\Playcustomapp' => $vendorDir . '/google/apiclient-services/src/Playcustomapp.php',
    'Google\\Service\\Playcustomapp\\CustomApp' => $vendorDir . '/google/apiclient-services/src/Playcustomapp/CustomApp.php',
    'Google\\Service\\Playcustomapp\\Organization' => $vendorDir . '/google/apiclient-services/src/Playcustomapp/Organization.php',
    'Google\\Service\\Playcustomapp\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/Playcustomapp/Resource/Accounts.php',
    'Google\\Service\\Playcustomapp\\Resource\\AccountsCustomApps' => $vendorDir . '/google/apiclient-services/src/Playcustomapp/Resource/AccountsCustomApps.php',
    'Google\\Service\\Playdeveloperreporting' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1Anomaly' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1Anomaly.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1AnrRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1AnrRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1App' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1App.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1AppVersion' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1AppVersion.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1CrashRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1CrashRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1DecimalConfidenceInterval' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1DecimalConfidenceInterval.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1DeviceId' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1DeviceId.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1DeviceModelSummary' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1DeviceModelSummary.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1DimensionValue' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1DimensionValue.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ErrorCountMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ErrorCountMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ErrorIssue' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ErrorIssue.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ErrorReport' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ErrorReport.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ExcessiveWakeupRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ExcessiveWakeupRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1FreshnessInfo' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1FreshnessInfo.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1FreshnessInfoFreshness' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1FreshnessInfoFreshness.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ListAnomaliesResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ListAnomaliesResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1MetricValue' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1MetricValue.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1MetricsRow' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1MetricsRow.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1OsVersion' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1OsVersion.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryErrorCountMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryErrorCountMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryErrorCountMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryErrorCountMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QuerySlowRenderingRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QuerySlowRenderingRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QuerySlowRenderingRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QuerySlowRenderingRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QuerySlowStartRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QuerySlowStartRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QuerySlowStartRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QuerySlowStartRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetRequest' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetRequest.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1Release' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1Release.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1ReleaseFilterOptions' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1ReleaseFilterOptions.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1SearchAccessibleAppsResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1SearchAccessibleAppsResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1SearchErrorIssuesResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1SearchErrorIssuesResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1SearchErrorReportsResponse' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1SearchErrorReportsResponse.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1SlowRenderingRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1SlowRenderingRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1StuckBackgroundWakelockRateMetricSet' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1StuckBackgroundWakelockRateMetricSet.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1TimelineSpec' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1TimelineSpec.php',
    'Google\\Service\\Playdeveloperreporting\\GooglePlayDeveloperReportingV1beta1Track' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GooglePlayDeveloperReportingV1beta1Track.php',
    'Google\\Service\\Playdeveloperreporting\\GoogleTypeDateTime' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GoogleTypeDateTime.php',
    'Google\\Service\\Playdeveloperreporting\\GoogleTypeDecimal' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GoogleTypeDecimal.php',
    'Google\\Service\\Playdeveloperreporting\\GoogleTypeTimeZone' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/GoogleTypeTimeZone.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\Anomalies' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/Anomalies.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\Apps' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/Apps.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\Vitals' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/Vitals.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsAnrrate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsAnrrate.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsCrashrate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsCrashrate.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsErrors' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsErrors.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsErrorsCounts' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsErrorsCounts.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsErrorsIssues' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsErrorsIssues.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsErrorsReports' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsErrorsReports.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsExcessivewakeuprate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsExcessivewakeuprate.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsSlowrenderingrate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsSlowrenderingrate.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsSlowstartrate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsSlowstartrate.php',
    'Google\\Service\\Playdeveloperreporting\\Resource\\VitalsStuckbackgroundwakelockrate' => $vendorDir . '/google/apiclient-services/src/Playdeveloperreporting/Resource/VitalsStuckbackgroundwakelockrate.php',
    'Google\\Service\\PolicyAnalyzer' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer.php',
    'Google\\Service\\PolicyAnalyzer\\GoogleCloudPolicyanalyzerV1Activity' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/GoogleCloudPolicyanalyzerV1Activity.php',
    'Google\\Service\\PolicyAnalyzer\\GoogleCloudPolicyanalyzerV1ObservationPeriod' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/GoogleCloudPolicyanalyzerV1ObservationPeriod.php',
    'Google\\Service\\PolicyAnalyzer\\GoogleCloudPolicyanalyzerV1QueryActivityResponse' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/GoogleCloudPolicyanalyzerV1QueryActivityResponse.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/Folders.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\FoldersLocations' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/FoldersLocations.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\FoldersLocationsActivityTypes' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/FoldersLocationsActivityTypes.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\FoldersLocationsActivityTypesActivities' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/FoldersLocationsActivityTypesActivities.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/Organizations.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/OrganizationsLocations.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\OrganizationsLocationsActivityTypes' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/OrganizationsLocationsActivityTypes.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\OrganizationsLocationsActivityTypesActivities' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/OrganizationsLocationsActivityTypesActivities.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/Projects.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/ProjectsLocations.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\ProjectsLocationsActivityTypes' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/ProjectsLocationsActivityTypes.php',
    'Google\\Service\\PolicyAnalyzer\\Resource\\ProjectsLocationsActivityTypesActivities' => $vendorDir . '/google/apiclient-services/src/PolicyAnalyzer/Resource/ProjectsLocationsActivityTypesActivities.php',
    'Google\\Service\\PolicySimulator' => $vendorDir . '/google/apiclient-services/src/PolicySimulator.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2AlternatePolicySpec' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2AlternatePolicySpec.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2CustomConstraint' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2CustomConstraint.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2Policy' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2Policy.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2PolicySpec' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2PolicySpec.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2PolicySpecPolicyRule' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2PolicySpecPolicyRule.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1AccessStateDiff' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1AccessStateDiff.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1AccessTuple' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1AccessTuple.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1BindingExplanation' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1BindingExplanation.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1BindingExplanationAnnotatedMembership' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1BindingExplanationAnnotatedMembership.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ExplainedAccess' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ExplainedAccess.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ExplainedPolicy' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ExplainedPolicy.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ListReplayResultsResponse' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ListReplayResultsResponse.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyOverlayCustomConstraintOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyOverlayCustomConstraintOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyOverlayPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyOverlayPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyViolation' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyViolation.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1Replay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1Replay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ReplayConfig' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ReplayConfig.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ReplayDiff' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ReplayDiff.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ReplayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ReplayOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ReplayResult' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ReplayResult.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ReplayResultsSummary' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ReplayResultsSummary.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1ResourceContext' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1ResourceContext.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaCreateOrgPolicyViolationsPreviewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaCreateOrgPolicyViolationsPreviewOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaGenerateOrgPolicyViolationsPreviewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaGenerateOrgPolicyViolationsPreviewOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlayCustomConstraintOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlayCustomConstraintOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlayPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaOrgPolicyOverlayPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaOrgPolicyViolationsPreview' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaOrgPolicyViolationsPreview.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1alphaOrgPolicyViolationsPreviewResourceCounts' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1alphaOrgPolicyViolationsPreviewResourceCounts.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1beta1Replay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1beta1Replay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1beta1ReplayConfig' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1beta1ReplayConfig.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1beta1ReplayOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1beta1ReplayOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1beta1ReplayResultsSummary' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1beta1ReplayResultsSummary.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaCreateOrgPolicyViolationsPreviewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaCreateOrgPolicyViolationsPreviewOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaGenerateOrgPolicyViolationsPreviewOperationMetadata' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaGenerateOrgPolicyViolationsPreviewOperationMetadata.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.php',
    'Google\\Service\\PolicySimulator\\GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts.php',
    'Google\\Service\\PolicySimulator\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleIamV1AuditConfig.php',
    'Google\\Service\\PolicySimulator\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\PolicySimulator\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleIamV1Binding.php',
    'Google\\Service\\PolicySimulator\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleIamV1Policy.php',
    'Google\\Service\\PolicySimulator\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\PolicySimulator\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleLongrunningOperation.php',
    'Google\\Service\\PolicySimulator\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleRpcStatus.php',
    'Google\\Service\\PolicySimulator\\GoogleTypeDate' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleTypeDate.php',
    'Google\\Service\\PolicySimulator\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/GoogleTypeExpr.php',
    'Google\\Service\\PolicySimulator\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/Folders.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocations.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocationsOrgPolicyViolationsPreviews' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocationsOrgPolicyViolationsPreviews.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocationsOrgPolicyViolationsPreviewsOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocationsOrgPolicyViolationsPreviewsOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocationsReplays' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocationsReplays.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocationsReplaysOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocationsReplaysOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\FoldersLocationsReplaysResults' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/FoldersLocationsReplaysResults.php',
    'Google\\Service\\PolicySimulator\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/Operations.php',
    'Google\\Service\\PolicySimulator\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/Organizations.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocations.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsOrgPolicyViolationsPreviews' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsOrgPolicyViolationsPreviews.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsOrgPolicyViolationsPreviewsOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsOrgPolicyViolationsPreviewsOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsOrgPolicyViolationsPreviewsOrgPolicyViolations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsOrgPolicyViolationsPreviewsOrgPolicyViolations.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsReplays' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsReplays.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsReplaysOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsReplaysOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\OrganizationsLocationsReplaysResults' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/OrganizationsLocationsReplaysResults.php',
    'Google\\Service\\PolicySimulator\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/Projects.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocations.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocationsOrgPolicyViolationsPreviews' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocationsOrgPolicyViolationsPreviews.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocationsOrgPolicyViolationsPreviewsOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocationsOrgPolicyViolationsPreviewsOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocationsReplays' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocationsReplays.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocationsReplaysOperations' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocationsReplaysOperations.php',
    'Google\\Service\\PolicySimulator\\Resource\\ProjectsLocationsReplaysResults' => $vendorDir . '/google/apiclient-services/src/PolicySimulator/Resource/ProjectsLocationsReplaysResults.php',
    'Google\\Service\\PolicyTroubleshooter' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1AccessTuple' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1AccessTuple.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1BindingExplanation' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1BindingExplanation.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1BindingExplanationAnnotatedMembership' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1BindingExplanationAnnotatedMembership.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1ExplainedPolicy' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1ExplainedPolicy.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyRequest.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyResponse' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyResponse.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleIamV1AuditConfig' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleIamV1AuditConfig.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleIamV1AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleIamV1AuditLogConfig.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleIamV1Binding' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleIamV1Binding.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleIamV1Policy' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleIamV1Policy.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleRpcStatus.php',
    'Google\\Service\\PolicyTroubleshooter\\GoogleTypeExpr' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/GoogleTypeExpr.php',
    'Google\\Service\\PolicyTroubleshooter\\Resource\\Iam' => $vendorDir . '/google/apiclient-services/src/PolicyTroubleshooter/Resource/Iam.php',
    'Google\\Service\\Pollen' => $vendorDir . '/google/apiclient-services/src/Pollen.php',
    'Google\\Service\\Pollen\\Color' => $vendorDir . '/google/apiclient-services/src/Pollen/Color.php',
    'Google\\Service\\Pollen\\Date' => $vendorDir . '/google/apiclient-services/src/Pollen/Date.php',
    'Google\\Service\\Pollen\\DayInfo' => $vendorDir . '/google/apiclient-services/src/Pollen/DayInfo.php',
    'Google\\Service\\Pollen\\HttpBody' => $vendorDir . '/google/apiclient-services/src/Pollen/HttpBody.php',
    'Google\\Service\\Pollen\\IndexInfo' => $vendorDir . '/google/apiclient-services/src/Pollen/IndexInfo.php',
    'Google\\Service\\Pollen\\LookupForecastResponse' => $vendorDir . '/google/apiclient-services/src/Pollen/LookupForecastResponse.php',
    'Google\\Service\\Pollen\\PlantDescription' => $vendorDir . '/google/apiclient-services/src/Pollen/PlantDescription.php',
    'Google\\Service\\Pollen\\PlantInfo' => $vendorDir . '/google/apiclient-services/src/Pollen/PlantInfo.php',
    'Google\\Service\\Pollen\\PollenTypeInfo' => $vendorDir . '/google/apiclient-services/src/Pollen/PollenTypeInfo.php',
    'Google\\Service\\Pollen\\Resource\\Forecast' => $vendorDir . '/google/apiclient-services/src/Pollen/Resource/Forecast.php',
    'Google\\Service\\Pollen\\Resource\\MapTypes' => $vendorDir . '/google/apiclient-services/src/Pollen/Resource/MapTypes.php',
    'Google\\Service\\Pollen\\Resource\\MapTypesHeatmapTiles' => $vendorDir . '/google/apiclient-services/src/Pollen/Resource/MapTypesHeatmapTiles.php',
    'Google\\Service\\PolyService' => $vendorDir . '/google/apiclient-services/src/PolyService.php',
    'Google\\Service\\PolyService\\Asset' => $vendorDir . '/google/apiclient-services/src/PolyService/Asset.php',
    'Google\\Service\\PolyService\\AssetImportMessage' => $vendorDir . '/google/apiclient-services/src/PolyService/AssetImportMessage.php',
    'Google\\Service\\PolyService\\Format' => $vendorDir . '/google/apiclient-services/src/PolyService/Format.php',
    'Google\\Service\\PolyService\\FormatComplexity' => $vendorDir . '/google/apiclient-services/src/PolyService/FormatComplexity.php',
    'Google\\Service\\PolyService\\ImageError' => $vendorDir . '/google/apiclient-services/src/PolyService/ImageError.php',
    'Google\\Service\\PolyService\\ListAssetsResponse' => $vendorDir . '/google/apiclient-services/src/PolyService/ListAssetsResponse.php',
    'Google\\Service\\PolyService\\ListLikedAssetsResponse' => $vendorDir . '/google/apiclient-services/src/PolyService/ListLikedAssetsResponse.php',
    'Google\\Service\\PolyService\\ListUserAssetsResponse' => $vendorDir . '/google/apiclient-services/src/PolyService/ListUserAssetsResponse.php',
    'Google\\Service\\PolyService\\ObjParseError' => $vendorDir . '/google/apiclient-services/src/PolyService/ObjParseError.php',
    'Google\\Service\\PolyService\\PolyFile' => $vendorDir . '/google/apiclient-services/src/PolyService/PolyFile.php',
    'Google\\Service\\PolyService\\PresentationParams' => $vendorDir . '/google/apiclient-services/src/PolyService/PresentationParams.php',
    'Google\\Service\\PolyService\\Quaternion' => $vendorDir . '/google/apiclient-services/src/PolyService/Quaternion.php',
    'Google\\Service\\PolyService\\RemixInfo' => $vendorDir . '/google/apiclient-services/src/PolyService/RemixInfo.php',
    'Google\\Service\\PolyService\\Resource\\Assets' => $vendorDir . '/google/apiclient-services/src/PolyService/Resource/Assets.php',
    'Google\\Service\\PolyService\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/PolyService/Resource/Users.php',
    'Google\\Service\\PolyService\\Resource\\UsersAssets' => $vendorDir . '/google/apiclient-services/src/PolyService/Resource/UsersAssets.php',
    'Google\\Service\\PolyService\\Resource\\UsersLikedassets' => $vendorDir . '/google/apiclient-services/src/PolyService/Resource/UsersLikedassets.php',
    'Google\\Service\\PolyService\\StartAssetImportResponse' => $vendorDir . '/google/apiclient-services/src/PolyService/StartAssetImportResponse.php',
    'Google\\Service\\PolyService\\UserAsset' => $vendorDir . '/google/apiclient-services/src/PolyService/UserAsset.php',
    'Google\\Service\\PostmasterTools' => $vendorDir . '/google/apiclient-services/src/PostmasterTools.php',
    'Google\\Service\\PostmasterTools\\DeliveryError' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/DeliveryError.php',
    'Google\\Service\\PostmasterTools\\Domain' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/Domain.php',
    'Google\\Service\\PostmasterTools\\FeedbackLoop' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/FeedbackLoop.php',
    'Google\\Service\\PostmasterTools\\IpReputation' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/IpReputation.php',
    'Google\\Service\\PostmasterTools\\ListDomainsResponse' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/ListDomainsResponse.php',
    'Google\\Service\\PostmasterTools\\ListTrafficStatsResponse' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/ListTrafficStatsResponse.php',
    'Google\\Service\\PostmasterTools\\Resource\\Domains' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/Resource/Domains.php',
    'Google\\Service\\PostmasterTools\\Resource\\DomainsTrafficStats' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/Resource/DomainsTrafficStats.php',
    'Google\\Service\\PostmasterTools\\TrafficStats' => $vendorDir . '/google/apiclient-services/src/PostmasterTools/TrafficStats.php',
    'Google\\Service\\PublicCertificateAuthority' => $vendorDir . '/google/apiclient-services/src/PublicCertificateAuthority.php',
    'Google\\Service\\PublicCertificateAuthority\\ExternalAccountKey' => $vendorDir . '/google/apiclient-services/src/PublicCertificateAuthority/ExternalAccountKey.php',
    'Google\\Service\\PublicCertificateAuthority\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/PublicCertificateAuthority/Resource/Projects.php',
    'Google\\Service\\PublicCertificateAuthority\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PublicCertificateAuthority/Resource/ProjectsLocations.php',
    'Google\\Service\\PublicCertificateAuthority\\Resource\\ProjectsLocationsExternalAccountKeys' => $vendorDir . '/google/apiclient-services/src/PublicCertificateAuthority/Resource/ProjectsLocationsExternalAccountKeys.php',
    'Google\\Service\\Pubsub' => $vendorDir . '/google/apiclient-services/src/Pubsub.php',
    'Google\\Service\\PubsubLite' => $vendorDir . '/google/apiclient-services/src/PubsubLite.php',
    'Google\\Service\\PubsubLite\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/CancelOperationRequest.php',
    'Google\\Service\\PubsubLite\\Capacity' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Capacity.php',
    'Google\\Service\\PubsubLite\\CommitCursorRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/CommitCursorRequest.php',
    'Google\\Service\\PubsubLite\\CommitCursorResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/CommitCursorResponse.php',
    'Google\\Service\\PubsubLite\\ComputeHeadCursorRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeHeadCursorRequest.php',
    'Google\\Service\\PubsubLite\\ComputeHeadCursorResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeHeadCursorResponse.php',
    'Google\\Service\\PubsubLite\\ComputeMessageStatsRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeMessageStatsRequest.php',
    'Google\\Service\\PubsubLite\\ComputeMessageStatsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeMessageStatsResponse.php',
    'Google\\Service\\PubsubLite\\ComputeTimeCursorRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeTimeCursorRequest.php',
    'Google\\Service\\PubsubLite\\ComputeTimeCursorResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ComputeTimeCursorResponse.php',
    'Google\\Service\\PubsubLite\\Cursor' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Cursor.php',
    'Google\\Service\\PubsubLite\\DeliveryConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/DeliveryConfig.php',
    'Google\\Service\\PubsubLite\\ExportConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ExportConfig.php',
    'Google\\Service\\PubsubLite\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListOperationsResponse.php',
    'Google\\Service\\PubsubLite\\ListPartitionCursorsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListPartitionCursorsResponse.php',
    'Google\\Service\\PubsubLite\\ListReservationTopicsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListReservationTopicsResponse.php',
    'Google\\Service\\PubsubLite\\ListReservationsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListReservationsResponse.php',
    'Google\\Service\\PubsubLite\\ListSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListSubscriptionsResponse.php',
    'Google\\Service\\PubsubLite\\ListTopicSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListTopicSubscriptionsResponse.php',
    'Google\\Service\\PubsubLite\\ListTopicsResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ListTopicsResponse.php',
    'Google\\Service\\PubsubLite\\Operation' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Operation.php',
    'Google\\Service\\PubsubLite\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/PubsubLite/OperationMetadata.php',
    'Google\\Service\\PubsubLite\\PartitionConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/PartitionConfig.php',
    'Google\\Service\\PubsubLite\\PartitionCursor' => $vendorDir . '/google/apiclient-services/src/PubsubLite/PartitionCursor.php',
    'Google\\Service\\PubsubLite\\PubSubConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/PubSubConfig.php',
    'Google\\Service\\PubsubLite\\PubsubliteEmpty' => $vendorDir . '/google/apiclient-services/src/PubsubLite/PubsubliteEmpty.php',
    'Google\\Service\\PubsubLite\\Reservation' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Reservation.php',
    'Google\\Service\\PubsubLite\\ReservationConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/ReservationConfig.php',
    'Google\\Service\\PubsubLite\\Resource\\Admin' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/Admin.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjects' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjects.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocations.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsOperations.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsReservations' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsReservations.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsReservationsTopics' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsReservationsTopics.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsSubscriptions' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsSubscriptions.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsTopics' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsTopics.php',
    'Google\\Service\\PubsubLite\\Resource\\AdminProjectsLocationsTopicsSubscriptions' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/AdminProjectsLocationsTopicsSubscriptions.php',
    'Google\\Service\\PubsubLite\\Resource\\Cursor' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/Cursor.php',
    'Google\\Service\\PubsubLite\\Resource\\CursorProjects' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/CursorProjects.php',
    'Google\\Service\\PubsubLite\\Resource\\CursorProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/CursorProjectsLocations.php',
    'Google\\Service\\PubsubLite\\Resource\\CursorProjectsLocationsSubscriptions' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/CursorProjectsLocationsSubscriptions.php',
    'Google\\Service\\PubsubLite\\Resource\\CursorProjectsLocationsSubscriptionsCursors' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/CursorProjectsLocationsSubscriptionsCursors.php',
    'Google\\Service\\PubsubLite\\Resource\\TopicStats' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/TopicStats.php',
    'Google\\Service\\PubsubLite\\Resource\\TopicStatsProjects' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/TopicStatsProjects.php',
    'Google\\Service\\PubsubLite\\Resource\\TopicStatsProjectsLocations' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/TopicStatsProjectsLocations.php',
    'Google\\Service\\PubsubLite\\Resource\\TopicStatsProjectsLocationsTopics' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Resource/TopicStatsProjectsLocationsTopics.php',
    'Google\\Service\\PubsubLite\\RetentionConfig' => $vendorDir . '/google/apiclient-services/src/PubsubLite/RetentionConfig.php',
    'Google\\Service\\PubsubLite\\SeekSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/PubsubLite/SeekSubscriptionRequest.php',
    'Google\\Service\\PubsubLite\\SeekSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/PubsubLite/SeekSubscriptionResponse.php',
    'Google\\Service\\PubsubLite\\Status' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Status.php',
    'Google\\Service\\PubsubLite\\Subscription' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Subscription.php',
    'Google\\Service\\PubsubLite\\TimeTarget' => $vendorDir . '/google/apiclient-services/src/PubsubLite/TimeTarget.php',
    'Google\\Service\\PubsubLite\\Topic' => $vendorDir . '/google/apiclient-services/src/PubsubLite/Topic.php',
    'Google\\Service\\PubsubLite\\TopicPartitions' => $vendorDir . '/google/apiclient-services/src/PubsubLite/TopicPartitions.php',
    'Google\\Service\\Pubsub\\AcknowledgeRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/AcknowledgeRequest.php',
    'Google\\Service\\Pubsub\\AnalyticsHubSubscriptionInfo' => $vendorDir . '/google/apiclient-services/src/Pubsub/AnalyticsHubSubscriptionInfo.php',
    'Google\\Service\\Pubsub\\AvroConfig' => $vendorDir . '/google/apiclient-services/src/Pubsub/AvroConfig.php',
    'Google\\Service\\Pubsub\\AwsKinesis' => $vendorDir . '/google/apiclient-services/src/Pubsub/AwsKinesis.php',
    'Google\\Service\\Pubsub\\BigQueryConfig' => $vendorDir . '/google/apiclient-services/src/Pubsub/BigQueryConfig.php',
    'Google\\Service\\Pubsub\\Binding' => $vendorDir . '/google/apiclient-services/src/Pubsub/Binding.php',
    'Google\\Service\\Pubsub\\CloudStorageConfig' => $vendorDir . '/google/apiclient-services/src/Pubsub/CloudStorageConfig.php',
    'Google\\Service\\Pubsub\\CommitSchemaRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/CommitSchemaRequest.php',
    'Google\\Service\\Pubsub\\CreateSnapshotRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/CreateSnapshotRequest.php',
    'Google\\Service\\Pubsub\\DeadLetterPolicy' => $vendorDir . '/google/apiclient-services/src/Pubsub/DeadLetterPolicy.php',
    'Google\\Service\\Pubsub\\DetachSubscriptionResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/DetachSubscriptionResponse.php',
    'Google\\Service\\Pubsub\\ExpirationPolicy' => $vendorDir . '/google/apiclient-services/src/Pubsub/ExpirationPolicy.php',
    'Google\\Service\\Pubsub\\Expr' => $vendorDir . '/google/apiclient-services/src/Pubsub/Expr.php',
    'Google\\Service\\Pubsub\\IngestionDataSourceSettings' => $vendorDir . '/google/apiclient-services/src/Pubsub/IngestionDataSourceSettings.php',
    'Google\\Service\\Pubsub\\ListSchemaRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListSchemaRevisionsResponse.php',
    'Google\\Service\\Pubsub\\ListSchemasResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListSchemasResponse.php',
    'Google\\Service\\Pubsub\\ListSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListSnapshotsResponse.php',
    'Google\\Service\\Pubsub\\ListSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListSubscriptionsResponse.php',
    'Google\\Service\\Pubsub\\ListTopicSnapshotsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListTopicSnapshotsResponse.php',
    'Google\\Service\\Pubsub\\ListTopicSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListTopicSubscriptionsResponse.php',
    'Google\\Service\\Pubsub\\ListTopicsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ListTopicsResponse.php',
    'Google\\Service\\Pubsub\\MessageStoragePolicy' => $vendorDir . '/google/apiclient-services/src/Pubsub/MessageStoragePolicy.php',
    'Google\\Service\\Pubsub\\ModifyAckDeadlineRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/ModifyAckDeadlineRequest.php',
    'Google\\Service\\Pubsub\\ModifyPushConfigRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/ModifyPushConfigRequest.php',
    'Google\\Service\\Pubsub\\NoWrapper' => $vendorDir . '/google/apiclient-services/src/Pubsub/NoWrapper.php',
    'Google\\Service\\Pubsub\\OidcToken' => $vendorDir . '/google/apiclient-services/src/Pubsub/OidcToken.php',
    'Google\\Service\\Pubsub\\Policy' => $vendorDir . '/google/apiclient-services/src/Pubsub/Policy.php',
    'Google\\Service\\Pubsub\\PublishRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/PublishRequest.php',
    'Google\\Service\\Pubsub\\PublishResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/PublishResponse.php',
    'Google\\Service\\Pubsub\\PubsubEmpty' => $vendorDir . '/google/apiclient-services/src/Pubsub/PubsubEmpty.php',
    'Google\\Service\\Pubsub\\PubsubMessage' => $vendorDir . '/google/apiclient-services/src/Pubsub/PubsubMessage.php',
    'Google\\Service\\Pubsub\\PubsubWrapper' => $vendorDir . '/google/apiclient-services/src/Pubsub/PubsubWrapper.php',
    'Google\\Service\\Pubsub\\PullRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/PullRequest.php',
    'Google\\Service\\Pubsub\\PullResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/PullResponse.php',
    'Google\\Service\\Pubsub\\PushConfig' => $vendorDir . '/google/apiclient-services/src/Pubsub/PushConfig.php',
    'Google\\Service\\Pubsub\\ReceivedMessage' => $vendorDir . '/google/apiclient-services/src/Pubsub/ReceivedMessage.php',
    'Google\\Service\\Pubsub\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/Projects.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsSchemas' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsSchemas.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsSnapshots' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsSnapshots.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsSubscriptions' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsSubscriptions.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsTopics' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsTopics.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsTopicsSnapshots' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsTopicsSnapshots.php',
    'Google\\Service\\Pubsub\\Resource\\ProjectsTopicsSubscriptions' => $vendorDir . '/google/apiclient-services/src/Pubsub/Resource/ProjectsTopicsSubscriptions.php',
    'Google\\Service\\Pubsub\\RetryPolicy' => $vendorDir . '/google/apiclient-services/src/Pubsub/RetryPolicy.php',
    'Google\\Service\\Pubsub\\RollbackSchemaRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/RollbackSchemaRequest.php',
    'Google\\Service\\Pubsub\\Schema' => $vendorDir . '/google/apiclient-services/src/Pubsub/Schema.php',
    'Google\\Service\\Pubsub\\SchemaSettings' => $vendorDir . '/google/apiclient-services/src/Pubsub/SchemaSettings.php',
    'Google\\Service\\Pubsub\\SeekRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/SeekRequest.php',
    'Google\\Service\\Pubsub\\SeekResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/SeekResponse.php',
    'Google\\Service\\Pubsub\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/SetIamPolicyRequest.php',
    'Google\\Service\\Pubsub\\Snapshot' => $vendorDir . '/google/apiclient-services/src/Pubsub/Snapshot.php',
    'Google\\Service\\Pubsub\\Subscription' => $vendorDir . '/google/apiclient-services/src/Pubsub/Subscription.php',
    'Google\\Service\\Pubsub\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/TestIamPermissionsRequest.php',
    'Google\\Service\\Pubsub\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/TestIamPermissionsResponse.php',
    'Google\\Service\\Pubsub\\TextConfig' => $vendorDir . '/google/apiclient-services/src/Pubsub/TextConfig.php',
    'Google\\Service\\Pubsub\\Topic' => $vendorDir . '/google/apiclient-services/src/Pubsub/Topic.php',
    'Google\\Service\\Pubsub\\UpdateSnapshotRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/UpdateSnapshotRequest.php',
    'Google\\Service\\Pubsub\\UpdateSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/UpdateSubscriptionRequest.php',
    'Google\\Service\\Pubsub\\UpdateTopicRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/UpdateTopicRequest.php',
    'Google\\Service\\Pubsub\\ValidateMessageRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/ValidateMessageRequest.php',
    'Google\\Service\\Pubsub\\ValidateMessageResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ValidateMessageResponse.php',
    'Google\\Service\\Pubsub\\ValidateSchemaRequest' => $vendorDir . '/google/apiclient-services/src/Pubsub/ValidateSchemaRequest.php',
    'Google\\Service\\Pubsub\\ValidateSchemaResponse' => $vendorDir . '/google/apiclient-services/src/Pubsub/ValidateSchemaResponse.php',
    'Google\\Service\\RapidMigrationAssessment' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment.php',
    'Google\\Service\\RapidMigrationAssessment\\Annotation' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Annotation.php',
    'Google\\Service\\RapidMigrationAssessment\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/CancelOperationRequest.php',
    'Google\\Service\\RapidMigrationAssessment\\Collector' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Collector.php',
    'Google\\Service\\RapidMigrationAssessment\\GuestOsScan' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/GuestOsScan.php',
    'Google\\Service\\RapidMigrationAssessment\\ListCollectorsResponse' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/ListCollectorsResponse.php',
    'Google\\Service\\RapidMigrationAssessment\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/ListLocationsResponse.php',
    'Google\\Service\\RapidMigrationAssessment\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/ListOperationsResponse.php',
    'Google\\Service\\RapidMigrationAssessment\\Location' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Location.php',
    'Google\\Service\\RapidMigrationAssessment\\Operation' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Operation.php',
    'Google\\Service\\RapidMigrationAssessment\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/OperationMetadata.php',
    'Google\\Service\\RapidMigrationAssessment\\PauseCollectorRequest' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/PauseCollectorRequest.php',
    'Google\\Service\\RapidMigrationAssessment\\RapidmigrationassessmentEmpty' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/RapidmigrationassessmentEmpty.php',
    'Google\\Service\\RapidMigrationAssessment\\RegisterCollectorRequest' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/RegisterCollectorRequest.php',
    'Google\\Service\\RapidMigrationAssessment\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Resource/Projects.php',
    'Google\\Service\\RapidMigrationAssessment\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Resource/ProjectsLocations.php',
    'Google\\Service\\RapidMigrationAssessment\\Resource\\ProjectsLocationsAnnotations' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Resource/ProjectsLocationsAnnotations.php',
    'Google\\Service\\RapidMigrationAssessment\\Resource\\ProjectsLocationsCollectors' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Resource/ProjectsLocationsCollectors.php',
    'Google\\Service\\RapidMigrationAssessment\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\RapidMigrationAssessment\\ResumeCollectorRequest' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/ResumeCollectorRequest.php',
    'Google\\Service\\RapidMigrationAssessment\\Status' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/Status.php',
    'Google\\Service\\RapidMigrationAssessment\\VSphereScan' => $vendorDir . '/google/apiclient-services/src/RapidMigrationAssessment/VSphereScan.php',
    'Google\\Service\\RealTimeBidding' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding.php',
    'Google\\Service\\RealTimeBidding\\ActivatePretargetingConfigRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ActivatePretargetingConfigRequest.php',
    'Google\\Service\\RealTimeBidding\\AdTechnologyProviders' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AdTechnologyProviders.php',
    'Google\\Service\\RealTimeBidding\\AddTargetedAppsRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AddTargetedAppsRequest.php',
    'Google\\Service\\RealTimeBidding\\AddTargetedPublishersRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AddTargetedPublishersRequest.php',
    'Google\\Service\\RealTimeBidding\\AddTargetedSitesRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AddTargetedSitesRequest.php',
    'Google\\Service\\RealTimeBidding\\AdvertiserAndBrand' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AdvertiserAndBrand.php',
    'Google\\Service\\RealTimeBidding\\AppTargeting' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/AppTargeting.php',
    'Google\\Service\\RealTimeBidding\\BatchApprovePublisherConnectionsRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/BatchApprovePublisherConnectionsRequest.php',
    'Google\\Service\\RealTimeBidding\\BatchApprovePublisherConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/BatchApprovePublisherConnectionsResponse.php',
    'Google\\Service\\RealTimeBidding\\BatchRejectPublisherConnectionsRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/BatchRejectPublisherConnectionsRequest.php',
    'Google\\Service\\RealTimeBidding\\BatchRejectPublisherConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/BatchRejectPublisherConnectionsResponse.php',
    'Google\\Service\\RealTimeBidding\\Bidder' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Bidder.php',
    'Google\\Service\\RealTimeBidding\\Buyer' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Buyer.php',
    'Google\\Service\\RealTimeBidding\\CloseUserListRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/CloseUserListRequest.php',
    'Google\\Service\\RealTimeBidding\\Creative' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Creative.php',
    'Google\\Service\\RealTimeBidding\\CreativeDimensions' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/CreativeDimensions.php',
    'Google\\Service\\RealTimeBidding\\CreativeServingDecision' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/CreativeServingDecision.php',
    'Google\\Service\\RealTimeBidding\\Date' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Date.php',
    'Google\\Service\\RealTimeBidding\\DestinationNotCrawlableEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DestinationNotCrawlableEvidence.php',
    'Google\\Service\\RealTimeBidding\\DestinationNotWorkingEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DestinationNotWorkingEvidence.php',
    'Google\\Service\\RealTimeBidding\\DestinationUrlEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DestinationUrlEvidence.php',
    'Google\\Service\\RealTimeBidding\\DomainCallEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DomainCallEvidence.php',
    'Google\\Service\\RealTimeBidding\\DomainCalls' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DomainCalls.php',
    'Google\\Service\\RealTimeBidding\\DownloadSizeEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/DownloadSizeEvidence.php',
    'Google\\Service\\RealTimeBidding\\Endpoint' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Endpoint.php',
    'Google\\Service\\RealTimeBidding\\GetRemarketingTagResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/GetRemarketingTagResponse.php',
    'Google\\Service\\RealTimeBidding\\HtmlContent' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/HtmlContent.php',
    'Google\\Service\\RealTimeBidding\\HttpCallEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/HttpCallEvidence.php',
    'Google\\Service\\RealTimeBidding\\HttpCookieEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/HttpCookieEvidence.php',
    'Google\\Service\\RealTimeBidding\\Image' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Image.php',
    'Google\\Service\\RealTimeBidding\\ListBiddersResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListBiddersResponse.php',
    'Google\\Service\\RealTimeBidding\\ListBuyersResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListBuyersResponse.php',
    'Google\\Service\\RealTimeBidding\\ListCreativesResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListCreativesResponse.php',
    'Google\\Service\\RealTimeBidding\\ListEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListEndpointsResponse.php',
    'Google\\Service\\RealTimeBidding\\ListPretargetingConfigsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListPretargetingConfigsResponse.php',
    'Google\\Service\\RealTimeBidding\\ListPublisherConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListPublisherConnectionsResponse.php',
    'Google\\Service\\RealTimeBidding\\ListUserListsResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/ListUserListsResponse.php',
    'Google\\Service\\RealTimeBidding\\MediaFile' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/MediaFile.php',
    'Google\\Service\\RealTimeBidding\\NativeContent' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/NativeContent.php',
    'Google\\Service\\RealTimeBidding\\NumericTargetingDimension' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/NumericTargetingDimension.php',
    'Google\\Service\\RealTimeBidding\\OpenUserListRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/OpenUserListRequest.php',
    'Google\\Service\\RealTimeBidding\\PolicyCompliance' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/PolicyCompliance.php',
    'Google\\Service\\RealTimeBidding\\PolicyTopicEntry' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/PolicyTopicEntry.php',
    'Google\\Service\\RealTimeBidding\\PolicyTopicEvidence' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/PolicyTopicEvidence.php',
    'Google\\Service\\RealTimeBidding\\PretargetingConfig' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/PretargetingConfig.php',
    'Google\\Service\\RealTimeBidding\\PublisherConnection' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/PublisherConnection.php',
    'Google\\Service\\RealTimeBidding\\RealtimebiddingEmpty' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/RealtimebiddingEmpty.php',
    'Google\\Service\\RealTimeBidding\\RemoveTargetedAppsRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/RemoveTargetedAppsRequest.php',
    'Google\\Service\\RealTimeBidding\\RemoveTargetedPublishersRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/RemoveTargetedPublishersRequest.php',
    'Google\\Service\\RealTimeBidding\\RemoveTargetedSitesRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/RemoveTargetedSitesRequest.php',
    'Google\\Service\\RealTimeBidding\\Resource\\Bidders' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/Bidders.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BiddersCreatives' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BiddersCreatives.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BiddersEndpoints' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BiddersEndpoints.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BiddersPretargetingConfigs' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BiddersPretargetingConfigs.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BiddersPublisherConnections' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BiddersPublisherConnections.php',
    'Google\\Service\\RealTimeBidding\\Resource\\Buyers' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/Buyers.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BuyersCreatives' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BuyersCreatives.php',
    'Google\\Service\\RealTimeBidding\\Resource\\BuyersUserLists' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/Resource/BuyersUserLists.php',
    'Google\\Service\\RealTimeBidding\\StringTargetingDimension' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/StringTargetingDimension.php',
    'Google\\Service\\RealTimeBidding\\SuspendPretargetingConfigRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/SuspendPretargetingConfigRequest.php',
    'Google\\Service\\RealTimeBidding\\UrlDownloadSize' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/UrlDownloadSize.php',
    'Google\\Service\\RealTimeBidding\\UrlRestriction' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/UrlRestriction.php',
    'Google\\Service\\RealTimeBidding\\UserList' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/UserList.php',
    'Google\\Service\\RealTimeBidding\\VideoContent' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/VideoContent.php',
    'Google\\Service\\RealTimeBidding\\VideoMetadata' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/VideoMetadata.php',
    'Google\\Service\\RealTimeBidding\\WatchCreativesRequest' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/WatchCreativesRequest.php',
    'Google\\Service\\RealTimeBidding\\WatchCreativesResponse' => $vendorDir . '/google/apiclient-services/src/RealTimeBidding/WatchCreativesResponse.php',
    'Google\\Service\\RecaptchaEnterprise' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AccountVerificationInfo' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AccountVerificationInfo.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AddIpOverrideRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AddIpOverrideRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AndroidKeySettings' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AndroidKeySettings.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AppleDeveloperId' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AppleDeveloperId.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1Assessment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1Assessment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1AssessmentEnvironment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1AssessmentEnvironment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ChallengeMetrics' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ChallengeMetrics.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1EndpointVerificationInfo' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1EndpointVerificationInfo.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1Event' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1Event.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ExpressKeySettings' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ExpressKeySettings.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionAllowAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionAllowAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionBlockAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionBlockAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionIncludeRecaptchaScriptAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionIncludeRecaptchaScriptAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionRedirectAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionRedirectAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionSetHeaderAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionSetHeaderAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallActionSubstituteAction' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallActionSubstituteAction.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallPolicy' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallPolicy.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentBehavioralTrustVerdict' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentBehavioralTrustVerdict.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentCardTestingVerdict' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentCardTestingVerdict.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudSignals' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudSignals.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudSignalsCardSignals' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudSignalsCardSignals.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1IOSKeySettings' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1IOSKeySettings.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1IpOverrideData' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1IpOverrideData.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1Key' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1Key.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ListKeysResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ListKeysResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1Metrics' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1Metrics.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1PhoneFraudAssessment' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1PhoneFraudAssessment.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1PrivatePasswordLeakVerification' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1PrivatePasswordLeakVerification.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RelatedAccountGroup' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RelatedAccountGroup.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RelatedAccountGroupMembership' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RelatedAccountGroupMembership.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1RiskAnalysis' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1RiskAnalysis.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ScoreDistribution' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ScoreDistribution.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1ScoreMetrics' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1ScoreMetrics.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1SmsTollFraudVerdict' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1SmsTollFraudVerdict.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TestingOptions' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TestingOptions.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TokenProperties' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TokenProperties.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionData' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionData.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionDataAddress' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionDataItem' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionDataItem.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionDataUser' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionDataUser.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1TransactionEvent' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1TransactionEvent.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1UserId' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1UserId.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1UserInfo' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1UserInfo.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1WafSettings' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1WafSettings.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleCloudRecaptchaenterpriseV1WebKeySettings' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleCloudRecaptchaenterpriseV1WebKeySettings.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleProtobufEmpty.php',
    'Google\\Service\\RecaptchaEnterprise\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/GoogleRpcStatus.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/Projects.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsAssessments' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsAssessments.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsFirewallpolicies' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsFirewallpolicies.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsKeys' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsKeys.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsRelatedaccountgroupmemberships' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsRelatedaccountgroupmemberships.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsRelatedaccountgroups' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsRelatedaccountgroups.php',
    'Google\\Service\\RecaptchaEnterprise\\Resource\\ProjectsRelatedaccountgroupsMemberships' => $vendorDir . '/google/apiclient-services/src/RecaptchaEnterprise/Resource/ProjectsRelatedaccountgroupsMemberships.php',
    'Google\\Service\\RecommendationsAI' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI.php',
    'Google\\Service\\RecommendationsAI\\GoogleApiHttpBody' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleApiHttpBody.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1alphaRejoinCatalogMetadata' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1alphaRejoinCatalogMetadata.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1alphaRejoinCatalogResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1alphaRejoinCatalogResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1alphaTuningMetadata' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1alphaTuningMetadata.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1alphaTuningResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1alphaTuningResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1BigQuerySource' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1BigQuerySource.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1Catalog' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1Catalog.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1CatalogInlineSource' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1CatalogInlineSource.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1CatalogItem' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1CatalogItem.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1CatalogItemCategoryHierarchy' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1CatalogItemCategoryHierarchy.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1CatalogItemLevelConfig' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1CatalogItemLevelConfig.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1CreatePredictionApiKeyRegistrationRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1CreatePredictionApiKeyRegistrationRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1EventDetail' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1EventDetail.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1FeatureMap' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1FeatureMap.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1FeatureMapFloatList' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1FeatureMapFloatList.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1FeatureMapStringList' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1FeatureMapStringList.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1GcsSource.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1Image' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1Image.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportCatalogItemsRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportCatalogItemsRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportCatalogItemsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportCatalogItemsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportErrorsConfig' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportErrorsConfig.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportMetadata' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportMetadata.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportUserEventsRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ImportUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ImportUserEventsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1InputConfig.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ListCatalogsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ListCatalogsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ListUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ListUserEventsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PredictRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PredictRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PredictResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PredictResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PredictResponsePredictionResult' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PredictResponsePredictionResult.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ProductCatalogItem' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ProductCatalogItem.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ProductCatalogItemExactPrice' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ProductCatalogItemExactPrice.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ProductCatalogItemPriceRange' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ProductCatalogItemPriceRange.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ProductDetail' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ProductDetail.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1ProductEventDetail' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1ProductEventDetail.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PurchaseTransaction' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PurchaseTransaction.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PurgeUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PurgeUserEventsMetadata.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PurgeUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PurgeUserEventsRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1PurgeUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1PurgeUserEventsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1RejoinUserEventsMetadata' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1RejoinUserEventsMetadata.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1RejoinUserEventsRequest' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1RejoinUserEventsRequest.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1RejoinUserEventsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1RejoinUserEventsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1UserEvent' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1UserEvent.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1UserEventImportSummary' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1UserEventImportSummary.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1UserEventInlineSource' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1UserEventInlineSource.php',
    'Google\\Service\\RecommendationsAI\\GoogleCloudRecommendationengineV1beta1UserInfo' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleCloudRecommendationengineV1beta1UserInfo.php',
    'Google\\Service\\RecommendationsAI\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\RecommendationsAI\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleLongrunningOperation.php',
    'Google\\Service\\RecommendationsAI\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleProtobufEmpty.php',
    'Google\\Service\\RecommendationsAI\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/GoogleRpcStatus.php',
    'Google\\Service\\RecommendationsAI\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/Projects.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocations.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogs' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogs.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsCatalogItems' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsCatalogItems.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsEventStores' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsEventStores.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsEventStoresOperations' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsEventStoresOperations.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsEventStoresPlacements' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsEventStoresPlacements.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsEventStoresPredictionApiKeyRegistrations' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsEventStoresPredictionApiKeyRegistrations.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsEventStoresUserEvents' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsEventStoresUserEvents.php',
    'Google\\Service\\RecommendationsAI\\Resource\\ProjectsLocationsCatalogsOperations' => $vendorDir . '/google/apiclient-services/src/RecommendationsAI/Resource/ProjectsLocationsCatalogsOperations.php',
    'Google\\Service\\Recommender' => $vendorDir . '/google/apiclient-services/src/Recommender.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1CostProjection' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1CostProjection.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1Impact' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1Impact.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1Insight' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1Insight.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1InsightRecommendationReference' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1InsightRecommendationReference.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1InsightStateInfo' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1InsightStateInfo.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1InsightTypeConfig' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1InsightTypeConfig.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1InsightTypeGenerationConfig' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1InsightTypeGenerationConfig.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1ListInsightsResponse' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1ListInsightsResponse.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1ListRecommendationsResponse' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1ListRecommendationsResponse.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1MarkInsightAcceptedRequest' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1MarkInsightAcceptedRequest.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1MarkRecommendationClaimedRequest' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1MarkRecommendationClaimedRequest.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1MarkRecommendationDismissedRequest' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1MarkRecommendationDismissedRequest.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1MarkRecommendationFailedRequest' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1MarkRecommendationFailedRequest.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1MarkRecommendationSucceededRequest' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1MarkRecommendationSucceededRequest.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1Operation' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1Operation.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1OperationGroup' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1OperationGroup.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1Recommendation' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1Recommendation.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1RecommendationContent' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1RecommendationContent.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1RecommendationInsightReference' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1RecommendationInsightReference.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1RecommendationStateInfo' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1RecommendationStateInfo.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1RecommenderConfig' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1RecommenderConfig.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1RecommenderGenerationConfig' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1RecommenderGenerationConfig.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1ReliabilityProjection' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1ReliabilityProjection.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1SecurityProjection' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1SecurityProjection.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1SustainabilityProjection' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1SustainabilityProjection.php',
    'Google\\Service\\Recommender\\GoogleCloudRecommenderV1ValueMatcher' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleCloudRecommenderV1ValueMatcher.php',
    'Google\\Service\\Recommender\\GoogleTypeMoney' => $vendorDir . '/google/apiclient-services/src/Recommender/GoogleTypeMoney.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccounts' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccounts.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccountsLocations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccountsLocations.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccountsLocationsInsightTypes' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccountsLocationsInsightTypes.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccountsLocationsInsightTypesInsights' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccountsLocationsInsightTypesInsights.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccountsLocationsRecommenders' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccountsLocationsRecommenders.php',
    'Google\\Service\\Recommender\\Resource\\BillingAccountsLocationsRecommendersRecommendations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/BillingAccountsLocationsRecommendersRecommendations.php',
    'Google\\Service\\Recommender\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/Folders.php',
    'Google\\Service\\Recommender\\Resource\\FoldersLocations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/FoldersLocations.php',
    'Google\\Service\\Recommender\\Resource\\FoldersLocationsInsightTypes' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/FoldersLocationsInsightTypes.php',
    'Google\\Service\\Recommender\\Resource\\FoldersLocationsInsightTypesInsights' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/FoldersLocationsInsightTypesInsights.php',
    'Google\\Service\\Recommender\\Resource\\FoldersLocationsRecommenders' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/FoldersLocationsRecommenders.php',
    'Google\\Service\\Recommender\\Resource\\FoldersLocationsRecommendersRecommendations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/FoldersLocationsRecommendersRecommendations.php',
    'Google\\Service\\Recommender\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/Organizations.php',
    'Google\\Service\\Recommender\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/OrganizationsLocations.php',
    'Google\\Service\\Recommender\\Resource\\OrganizationsLocationsInsightTypes' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/OrganizationsLocationsInsightTypes.php',
    'Google\\Service\\Recommender\\Resource\\OrganizationsLocationsInsightTypesInsights' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/OrganizationsLocationsInsightTypesInsights.php',
    'Google\\Service\\Recommender\\Resource\\OrganizationsLocationsRecommenders' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/OrganizationsLocationsRecommenders.php',
    'Google\\Service\\Recommender\\Resource\\OrganizationsLocationsRecommendersRecommendations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/OrganizationsLocationsRecommendersRecommendations.php',
    'Google\\Service\\Recommender\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/Projects.php',
    'Google\\Service\\Recommender\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/ProjectsLocations.php',
    'Google\\Service\\Recommender\\Resource\\ProjectsLocationsInsightTypes' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/ProjectsLocationsInsightTypes.php',
    'Google\\Service\\Recommender\\Resource\\ProjectsLocationsInsightTypesInsights' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/ProjectsLocationsInsightTypesInsights.php',
    'Google\\Service\\Recommender\\Resource\\ProjectsLocationsRecommenders' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/ProjectsLocationsRecommenders.php',
    'Google\\Service\\Recommender\\Resource\\ProjectsLocationsRecommendersRecommendations' => $vendorDir . '/google/apiclient-services/src/Recommender/Resource/ProjectsLocationsRecommendersRecommendations.php',
    'Google\\Service\\RemoteBuildExecution' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Action' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Action.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ActionCacheUpdateCapabilities' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ActionCacheUpdateCapabilities.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ActionResult' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ActionResult.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchReadBlobsRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchReadBlobsRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchReadBlobsResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchReadBlobsResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchReadBlobsResponseResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchReadBlobsResponseResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchUpdateBlobsRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchUpdateBlobsRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchUpdateBlobsRequestRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchUpdateBlobsRequestRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchUpdateBlobsResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchUpdateBlobsResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2BatchUpdateBlobsResponseResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2BatchUpdateBlobsResponseResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2CacheCapabilities' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2CacheCapabilities.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Command' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Command.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2CommandEnvironmentVariable' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2CommandEnvironmentVariable.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Digest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Digest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Directory' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Directory.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2DirectoryNode' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2DirectoryNode.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecuteOperationMetadata' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecuteOperationMetadata.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecuteRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecuteRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecuteResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecuteResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecutedActionMetadata' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecutedActionMetadata.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecutionCapabilities' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecutionCapabilities.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ExecutionPolicy' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ExecutionPolicy.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2FileNode' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2FileNode.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2FindMissingBlobsRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2FindMissingBlobsRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2FindMissingBlobsResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2FindMissingBlobsResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2GetTreeResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2GetTreeResponse.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2LogFile' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2LogFile.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2NodeProperties' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2NodeProperties.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2NodeProperty' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2NodeProperty.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2OutputDirectory' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2OutputDirectory.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2OutputFile' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2OutputFile.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2OutputSymlink' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2OutputSymlink.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Platform' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Platform.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2PlatformProperty' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2PlatformProperty.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2PriorityCapabilities' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2PriorityCapabilities.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2PriorityCapabilitiesPriorityRange' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2PriorityCapabilitiesPriorityRange.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2RequestMetadata' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2RequestMetadata.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ResultsCachePolicy' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ResultsCachePolicy.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ServerCapabilities' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ServerCapabilities.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2SymlinkNode' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2SymlinkNode.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2ToolDetails' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2ToolDetails.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2Tree' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2Tree.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelRemoteExecutionV2WaitExecutionRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelRemoteExecutionV2WaitExecutionRequest.php',
    'Google\\Service\\RemoteBuildExecution\\BuildBazelSemverSemVer' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/BuildBazelSemverSemVer.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotCommandDurations' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotCommandDurations.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotCommandEvents' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotCommandEvents.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotCommandStatus' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotCommandStatus.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotResourceUsage' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotResourceUsage.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotResourceUsageIOStats' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotResourceUsageIOStats.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildbotResourceUsageStat' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildbotResourceUsageStat.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaAutoscale' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaAutoscale.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateWorkerPoolRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateWorkerPoolRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaDeleteInstanceRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaDeleteInstanceRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaDeleteWorkerPoolRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaDeleteWorkerPoolRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicy' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicy.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicyFeature' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicyFeature.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaGetInstanceRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaGetInstanceRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaGetWorkerPoolRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaGetWorkerPoolRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesResponse.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsResponse' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsResponse.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateInstanceRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateWorkerPoolRequest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateWorkerPoolRequest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2AdminTemp' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2AdminTemp.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2Blob' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2Blob.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandOutputs' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandOutputs.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandOverhead' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandOverhead.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandResult' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandResult.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandTask' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandTask.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandTaskInputs' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandTaskInputs.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandTaskInputsEnvironmentVariable' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandTaskInputsEnvironmentVariable.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandTaskOutputs' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandTaskOutputs.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2CommandTaskTimeouts' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2CommandTaskTimeouts.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2Digest' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2Digest.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2Directory' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2Directory.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2DirectoryMetadata' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2DirectoryMetadata.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleDevtoolsRemoteworkersV1test2FileMetadata' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleDevtoolsRemoteworkersV1test2FileMetadata.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleLongrunningOperation.php',
    'Google\\Service\\RemoteBuildExecution\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/GoogleRpcStatus.php',
    'Google\\Service\\RemoteBuildExecution\\Resource\\ActionResults' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/Resource/ActionResults.php',
    'Google\\Service\\RemoteBuildExecution\\Resource\\Actions' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/Resource/Actions.php',
    'Google\\Service\\RemoteBuildExecution\\Resource\\Blobs' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/Resource/Blobs.php',
    'Google\\Service\\RemoteBuildExecution\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/Resource/Operations.php',
    'Google\\Service\\RemoteBuildExecution\\Resource\\V2' => $vendorDir . '/google/apiclient-services/src/RemoteBuildExecution/Resource/V2.php',
    'Google\\Service\\Reports' => $vendorDir . '/google/apiclient-services/src/Reports.php',
    'Google\\Service\\Reports\\Activities' => $vendorDir . '/google/apiclient-services/src/Reports/Activities.php',
    'Google\\Service\\Reports\\Activity' => $vendorDir . '/google/apiclient-services/src/Reports/Activity.php',
    'Google\\Service\\Reports\\ActivityActor' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityActor.php',
    'Google\\Service\\Reports\\ActivityEvents' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityEvents.php',
    'Google\\Service\\Reports\\ActivityEventsParameters' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityEventsParameters.php',
    'Google\\Service\\Reports\\ActivityEventsParametersMessageValue' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityEventsParametersMessageValue.php',
    'Google\\Service\\Reports\\ActivityEventsParametersMultiMessageValue' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityEventsParametersMultiMessageValue.php',
    'Google\\Service\\Reports\\ActivityId' => $vendorDir . '/google/apiclient-services/src/Reports/ActivityId.php',
    'Google\\Service\\Reports\\Channel' => $vendorDir . '/google/apiclient-services/src/Reports/Channel.php',
    'Google\\Service\\Reports\\NestedParameter' => $vendorDir . '/google/apiclient-services/src/Reports/NestedParameter.php',
    'Google\\Service\\Reports\\Resource\\Activities' => $vendorDir . '/google/apiclient-services/src/Reports/Resource/Activities.php',
    'Google\\Service\\Reports\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/Reports/Resource/Channels.php',
    'Google\\Service\\Reports\\Resource\\CustomerUsageReports' => $vendorDir . '/google/apiclient-services/src/Reports/Resource/CustomerUsageReports.php',
    'Google\\Service\\Reports\\Resource\\EntityUsageReports' => $vendorDir . '/google/apiclient-services/src/Reports/Resource/EntityUsageReports.php',
    'Google\\Service\\Reports\\Resource\\UserUsageReport' => $vendorDir . '/google/apiclient-services/src/Reports/Resource/UserUsageReport.php',
    'Google\\Service\\Reports\\UsageReport' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReport.php',
    'Google\\Service\\Reports\\UsageReportEntity' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReportEntity.php',
    'Google\\Service\\Reports\\UsageReportParameters' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReportParameters.php',
    'Google\\Service\\Reports\\UsageReports' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReports.php',
    'Google\\Service\\Reports\\UsageReportsWarnings' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReportsWarnings.php',
    'Google\\Service\\Reports\\UsageReportsWarningsData' => $vendorDir . '/google/apiclient-services/src/Reports/UsageReportsWarningsData.php',
    'Google\\Service\\Reseller' => $vendorDir . '/google/apiclient-services/src/Reseller.php',
    'Google\\Service\\Reseller\\Address' => $vendorDir . '/google/apiclient-services/src/Reseller/Address.php',
    'Google\\Service\\Reseller\\ChangePlanRequest' => $vendorDir . '/google/apiclient-services/src/Reseller/ChangePlanRequest.php',
    'Google\\Service\\Reseller\\Customer' => $vendorDir . '/google/apiclient-services/src/Reseller/Customer.php',
    'Google\\Service\\Reseller\\PrimaryAdmin' => $vendorDir . '/google/apiclient-services/src/Reseller/PrimaryAdmin.php',
    'Google\\Service\\Reseller\\RenewalSettings' => $vendorDir . '/google/apiclient-services/src/Reseller/RenewalSettings.php',
    'Google\\Service\\Reseller\\ResellernotifyGetwatchdetailsResponse' => $vendorDir . '/google/apiclient-services/src/Reseller/ResellernotifyGetwatchdetailsResponse.php',
    'Google\\Service\\Reseller\\ResellernotifyResource' => $vendorDir . '/google/apiclient-services/src/Reseller/ResellernotifyResource.php',
    'Google\\Service\\Reseller\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/Reseller/Resource/Customers.php',
    'Google\\Service\\Reseller\\Resource\\Resellernotify' => $vendorDir . '/google/apiclient-services/src/Reseller/Resource/Resellernotify.php',
    'Google\\Service\\Reseller\\Resource\\Subscriptions' => $vendorDir . '/google/apiclient-services/src/Reseller/Resource/Subscriptions.php',
    'Google\\Service\\Reseller\\Seats' => $vendorDir . '/google/apiclient-services/src/Reseller/Seats.php',
    'Google\\Service\\Reseller\\Subscription' => $vendorDir . '/google/apiclient-services/src/Reseller/Subscription.php',
    'Google\\Service\\Reseller\\SubscriptionPlan' => $vendorDir . '/google/apiclient-services/src/Reseller/SubscriptionPlan.php',
    'Google\\Service\\Reseller\\SubscriptionPlanCommitmentInterval' => $vendorDir . '/google/apiclient-services/src/Reseller/SubscriptionPlanCommitmentInterval.php',
    'Google\\Service\\Reseller\\SubscriptionTransferInfo' => $vendorDir . '/google/apiclient-services/src/Reseller/SubscriptionTransferInfo.php',
    'Google\\Service\\Reseller\\SubscriptionTrialSettings' => $vendorDir . '/google/apiclient-services/src/Reseller/SubscriptionTrialSettings.php',
    'Google\\Service\\Reseller\\Subscriptions' => $vendorDir . '/google/apiclient-services/src/Reseller/Subscriptions.php',
    'Google\\Service\\Resource' => $vendorDir . '/google/apiclient/src/Service/Resource.php',
    'Google\\Service\\ResourceSettings' => $vendorDir . '/google/apiclient-services/src/ResourceSettings.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1ListSettingsResponse' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1ListSettingsResponse.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1Setting' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1Setting.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1SettingMetadata' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1SettingMetadata.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1Value' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1Value.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1ValueEnumValue' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1ValueEnumValue.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1ValueStringMap' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1ValueStringMap.php',
    'Google\\Service\\ResourceSettings\\GoogleCloudResourcesettingsV1ValueStringSet' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/GoogleCloudResourcesettingsV1ValueStringSet.php',
    'Google\\Service\\ResourceSettings\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/Folders.php',
    'Google\\Service\\ResourceSettings\\Resource\\FoldersSettings' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/FoldersSettings.php',
    'Google\\Service\\ResourceSettings\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/Organizations.php',
    'Google\\Service\\ResourceSettings\\Resource\\OrganizationsSettings' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/OrganizationsSettings.php',
    'Google\\Service\\ResourceSettings\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/Projects.php',
    'Google\\Service\\ResourceSettings\\Resource\\ProjectsSettings' => $vendorDir . '/google/apiclient-services/src/ResourceSettings/Resource/ProjectsSettings.php',
    'Google\\Service\\SA360' => $vendorDir . '/google/apiclient-services/src/SA360.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAdScheduleInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAdScheduleInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAdTextAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAdTextAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAgeRangeInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAgeRangeInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAssetInteractionTarget' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAssetInteractionTarget.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAssetUsage' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAssetUsage.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonAudienceInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonAudienceInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonBusinessProfileLocation' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonBusinessProfileLocation.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonCallToActionAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonCallToActionAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonCustomParameter' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonCustomParameter.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonDeviceInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonDeviceInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonEnhancedCpc' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonEnhancedCpc.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonFrequencyCapEntry' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonFrequencyCapEntry.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonGenderInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonGenderInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonImageAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonImageAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonImageDimension' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonImageDimension.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonKeyword' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonKeyword.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonKeywordInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonKeywordInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonLanguageInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonLanguageInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonListingGroupInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonListingGroupInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonLocationGroupInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonLocationGroupInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonLocationInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonLocationInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonManualCpa' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonManualCpa.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonManualCpc' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonManualCpc.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonManualCpm' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonManualCpm.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonMaximizeConversionValue' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonMaximizeConversionValue.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonMaximizeConversions' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonMaximizeConversions.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonMetrics' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonMetrics.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonMobileAppAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonMobileAppAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonPercentCpc' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonPercentCpc.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonRealTimeBiddingSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonRealTimeBiddingSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonSegments' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonSegments.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetCpa' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetCpa.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetCpm' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetCpm.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetImpressionShare' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetImpressionShare.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetOutrankShare' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetOutrankShare.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetRestriction' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetRestriction.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetRoas' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetRoas.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetSpend' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetSpend.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTargetingSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTargetingSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTextAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTextAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonTextLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonTextLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUnifiedCallAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUnifiedCallAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUnifiedCalloutAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUnifiedCalloutAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUnifiedLocationAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUnifiedLocationAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUnifiedPageFeedAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUnifiedPageFeedAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUnifiedSitelinkAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUnifiedSitelinkAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonUserListInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonUserListInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonValue' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonValue.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonWebpageConditionInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonWebpageConditionInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonWebpageInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonWebpageInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0CommonYoutubeVideoAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0CommonYoutubeVideoAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsErrorCode' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsErrorCode.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsErrorDetails' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsErrorDetails.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsErrorLocation' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsErrorLocation.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsQuotaErrorDetails' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsQuotaErrorDetails.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsSearchAds360Error' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsSearchAds360Error.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ErrorsSearchAds360Failure' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ErrorsSearchAds360Failure.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetImpressionShare' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetImpressionShare.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAd' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAd.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroup' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroup.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupAd' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupAd.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupAdLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupAdLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupAssetSet' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupAssetSet.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupAudienceView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupAudienceView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupBidModifier' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupBidModifier.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupCriterion' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupCriterion.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupCriterionQualityInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupCriterionQualityInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAdGroupLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAdGroupLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAgeRangeView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAgeRangeView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroup' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroup.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroupAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroupAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroupAssetCombinationData' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroupAssetCombinationData.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroupSignal' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroupSignal.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetSet' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetSet.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAssetSetAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAssetSetAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesAudience' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesAudience.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesBiddingStrategy' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesBiddingStrategy.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaign' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaign.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignAssetSet' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignAssetSet.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignAudienceView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignAudienceView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignBudget' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignBudget.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignCriterion' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignCriterion.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignGeoTargetTypeSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignGeoTargetTypeSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignOptimizationGoalSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignOptimizationGoalSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignSelectiveOptimization' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignSelectiveOptimization.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCampaignTrackingSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCampaignTrackingSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCartDataSalesView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCartDataSalesView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversion' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversion.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionAction' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionAction.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionActionAttributionModelSettings' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionActionAttributionModelSettings.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionActionFloodlightSettings' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionActionFloodlightSettings.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionActionValueSettings' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionActionValueSettings.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionCustomVariable' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionCustomVariable.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesConversionTrackingSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesConversionTrackingSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomColumn' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomColumn.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomer' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomer.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomerAsset' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomerAsset.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomerAssetSet' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomerAssetSet.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomerClient' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomerClient.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesCustomerManagerLink' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesCustomerManagerLink.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesGenderView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesGenderView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesGeoTargetConstant' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesGeoTargetConstant.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesKeywordView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesKeywordView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesLabel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesLabel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesLanguageConstant' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesLanguageConstant.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimension' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimension.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionPath' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionPath.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductBiddingCategory' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductBiddingCategory.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductBrand' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductBrand.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductChannel' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductChannel.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductCondition' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductCondition.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductCustomAttribute' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductCustomAttribute.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductItemId' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductItemId.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductType' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesListingGroupFilterDimensionProductType.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesLocationView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesLocationView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesProductGroupView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesProductGroupView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesSearchAds360Field' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesSearchAds360Field.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesShoppingPerformanceView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesShoppingPerformanceView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesUserList' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesUserList.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesVisit' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesVisit.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ResourcesWebpageView' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ResourcesWebpageView.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesConversionCustomDimensionHeader' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesConversionCustomDimensionHeader.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesCustomColumnHeader' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesCustomColumnHeader.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesListAccessibleCustomersResponse' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesListAccessibleCustomersResponse.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesListCustomColumnsResponse' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesListCustomColumnsResponse.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesRawEventConversionDimensionHeader' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesRawEventConversionDimensionHeader.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchAds360Row' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchAds360Row.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsRequest' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsRequest.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360Request' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360Request.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360Response' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360Response.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360StreamRequest' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360StreamRequest.php',
    'Google\\Service\\SA360\\GoogleAdsSearchads360V0ServicesSearchSearchAds360StreamResponse' => $vendorDir . '/google/apiclient-services/src/SA360/GoogleAdsSearchads360V0ServicesSearchSearchAds360StreamResponse.php',
    'Google\\Service\\SA360\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/SA360/Resource/Customers.php',
    'Google\\Service\\SA360\\Resource\\CustomersCustomColumns' => $vendorDir . '/google/apiclient-services/src/SA360/Resource/CustomersCustomColumns.php',
    'Google\\Service\\SA360\\Resource\\CustomersSearchAds360' => $vendorDir . '/google/apiclient-services/src/SA360/Resource/CustomersSearchAds360.php',
    'Google\\Service\\SA360\\Resource\\SearchAds360Fields' => $vendorDir . '/google/apiclient-services/src/SA360/Resource/SearchAds360Fields.php',
    'Google\\Service\\SASPortalTesting' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Customers.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersDeployments' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersDeployments.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersDeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersDeploymentsDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersNodes' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersNodes.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersNodesDeployments' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersNodesDeployments.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersNodesDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersNodesDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\CustomersNodesNodes' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/CustomersNodesNodes.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Deployments' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Deployments.php',
    'Google\\Service\\SASPortalTesting\\Resource\\DeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/DeploymentsDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Installer' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Installer.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Nodes' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Nodes.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesDeployments' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesDeployments.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesDeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesDeploymentsDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesNodes' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesNodes.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesNodesDeployments' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesNodesDeployments.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesNodesDevices' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesNodesDevices.php',
    'Google\\Service\\SASPortalTesting\\Resource\\NodesNodesNodes' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/NodesNodesNodes.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Policies' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Policies.php',
    'Google\\Service\\SASPortalTesting\\Resource\\Provisioning' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/Resource/Provisioning.php',
    'Google\\Service\\SASPortalTesting\\SasPortalAssignment' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalAssignment.php',
    'Google\\Service\\SASPortalTesting\\SasPortalChannelWithScore' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalChannelWithScore.php',
    'Google\\Service\\SASPortalTesting\\SasPortalCheckHasProvisionedDeploymentResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalCheckHasProvisionedDeploymentResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalCreateSignedDeviceRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalCreateSignedDeviceRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalCustomer' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalCustomer.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeployment' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeployment.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeploymentAssociation' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeploymentAssociation.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDevice' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDevice.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeviceAirInterface' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeviceAirInterface.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeviceConfig' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeviceConfig.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeviceGrant' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeviceGrant.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeviceMetadata.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDeviceModel' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDeviceModel.php',
    'Google\\Service\\SASPortalTesting\\SasPortalDpaMoveList' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalDpaMoveList.php',
    'Google\\Service\\SASPortalTesting\\SasPortalEmpty' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalEmpty.php',
    'Google\\Service\\SASPortalTesting\\SasPortalFrequencyRange' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalFrequencyRange.php',
    'Google\\Service\\SASPortalTesting\\SasPortalGcpProjectDeployment' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalGcpProjectDeployment.php',
    'Google\\Service\\SASPortalTesting\\SasPortalGenerateSecretRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalGenerateSecretRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalGenerateSecretResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalGenerateSecretResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalGetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalGetPolicyRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalInstallationParams' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalInstallationParams.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListCustomersResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListDeploymentsResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListDevicesResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListGcpProjectDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListGcpProjectDeploymentsResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListLegacyOrganizationsResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListLegacyOrganizationsResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalListNodesResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalListNodesResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMigrateOrganizationMetadata' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMigrateOrganizationMetadata.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMigrateOrganizationRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMigrateOrganizationRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMigrateOrganizationResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMigrateOrganizationResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMoveDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMoveDeploymentRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMoveDeviceRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMoveDeviceRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalMoveNodeRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalMoveNodeRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalNode' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalNode.php',
    'Google\\Service\\SASPortalTesting\\SasPortalNrqzValidation' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalNrqzValidation.php',
    'Google\\Service\\SASPortalTesting\\SasPortalOperation' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalOperation.php',
    'Google\\Service\\SASPortalTesting\\SasPortalOrganization' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalOrganization.php',
    'Google\\Service\\SASPortalTesting\\SasPortalPolicy' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalPolicy.php',
    'Google\\Service\\SASPortalTesting\\SasPortalProvisionDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalProvisionDeploymentRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalProvisionDeploymentResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalProvisionDeploymentResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalSetPolicyRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalSetupSasAnalyticsMetadata' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalSetupSasAnalyticsMetadata.php',
    'Google\\Service\\SASPortalTesting\\SasPortalSetupSasAnalyticsRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalSetupSasAnalyticsRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalSetupSasAnalyticsResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalSetupSasAnalyticsResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalSignDeviceRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalSignDeviceRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalStatus' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalStatus.php',
    'Google\\Service\\SASPortalTesting\\SasPortalTestPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalTestPermissionsRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalTestPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalTestPermissionsResponse.php',
    'Google\\Service\\SASPortalTesting\\SasPortalUpdateSignedDeviceRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalUpdateSignedDeviceRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalValidateInstallerRequest' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalValidateInstallerRequest.php',
    'Google\\Service\\SASPortalTesting\\SasPortalValidateInstallerResponse' => $vendorDir . '/google/apiclient-services/src/SASPortalTesting/SasPortalValidateInstallerResponse.php',
    'Google\\Service\\SQLAdmin' => $vendorDir . '/google/apiclient-services/src/SQLAdmin.php',
    'Google\\Service\\SQLAdmin\\AclEntry' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/AclEntry.php',
    'Google\\Service\\SQLAdmin\\AcquireSsrsLeaseContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/AcquireSsrsLeaseContext.php',
    'Google\\Service\\SQLAdmin\\AdvancedMachineFeatures' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/AdvancedMachineFeatures.php',
    'Google\\Service\\SQLAdmin\\ApiWarning' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ApiWarning.php',
    'Google\\Service\\SQLAdmin\\AvailableDatabaseVersion' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/AvailableDatabaseVersion.php',
    'Google\\Service\\SQLAdmin\\BackupConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupConfiguration.php',
    'Google\\Service\\SQLAdmin\\BackupContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupContext.php',
    'Google\\Service\\SQLAdmin\\BackupReencryptionConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupReencryptionConfig.php',
    'Google\\Service\\SQLAdmin\\BackupRetentionSettings' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupRetentionSettings.php',
    'Google\\Service\\SQLAdmin\\BackupRun' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupRun.php',
    'Google\\Service\\SQLAdmin\\BackupRunsListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BackupRunsListResponse.php',
    'Google\\Service\\SQLAdmin\\BinLogCoordinates' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/BinLogCoordinates.php',
    'Google\\Service\\SQLAdmin\\CloneContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/CloneContext.php',
    'Google\\Service\\SQLAdmin\\ConnectSettings' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ConnectSettings.php',
    'Google\\Service\\SQLAdmin\\DataCacheConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DataCacheConfig.php',
    'Google\\Service\\SQLAdmin\\Database' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Database.php',
    'Google\\Service\\SQLAdmin\\DatabaseFlags' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DatabaseFlags.php',
    'Google\\Service\\SQLAdmin\\DatabaseInstance' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DatabaseInstance.php',
    'Google\\Service\\SQLAdmin\\DatabaseInstanceFailoverReplica' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DatabaseInstanceFailoverReplica.php',
    'Google\\Service\\SQLAdmin\\DatabasesListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DatabasesListResponse.php',
    'Google\\Service\\SQLAdmin\\DemoteContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DemoteContext.php',
    'Google\\Service\\SQLAdmin\\DemoteMasterConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DemoteMasterConfiguration.php',
    'Google\\Service\\SQLAdmin\\DemoteMasterContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DemoteMasterContext.php',
    'Google\\Service\\SQLAdmin\\DemoteMasterMySqlReplicaConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DemoteMasterMySqlReplicaConfiguration.php',
    'Google\\Service\\SQLAdmin\\DenyMaintenancePeriod' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DenyMaintenancePeriod.php',
    'Google\\Service\\SQLAdmin\\DiskEncryptionConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DiskEncryptionConfiguration.php',
    'Google\\Service\\SQLAdmin\\DiskEncryptionStatus' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/DiskEncryptionStatus.php',
    'Google\\Service\\SQLAdmin\\ExportContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContext.php',
    'Google\\Service\\SQLAdmin\\ExportContextBakExportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContextBakExportOptions.php',
    'Google\\Service\\SQLAdmin\\ExportContextCsvExportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContextCsvExportOptions.php',
    'Google\\Service\\SQLAdmin\\ExportContextSqlExportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContextSqlExportOptions.php',
    'Google\\Service\\SQLAdmin\\ExportContextSqlExportOptionsMysqlExportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContextSqlExportOptionsMysqlExportOptions.php',
    'Google\\Service\\SQLAdmin\\ExportContextSqlExportOptionsPostgresExportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ExportContextSqlExportOptionsPostgresExportOptions.php',
    'Google\\Service\\SQLAdmin\\FailoverContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/FailoverContext.php',
    'Google\\Service\\SQLAdmin\\Flag' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Flag.php',
    'Google\\Service\\SQLAdmin\\FlagsListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/FlagsListResponse.php',
    'Google\\Service\\SQLAdmin\\GeminiInstanceConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/GeminiInstanceConfig.php',
    'Google\\Service\\SQLAdmin\\GenerateEphemeralCertRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/GenerateEphemeralCertRequest.php',
    'Google\\Service\\SQLAdmin\\GenerateEphemeralCertResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/GenerateEphemeralCertResponse.php',
    'Google\\Service\\SQLAdmin\\ImportContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContext.php',
    'Google\\Service\\SQLAdmin\\ImportContextBakImportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContextBakImportOptions.php',
    'Google\\Service\\SQLAdmin\\ImportContextBakImportOptionsEncryptionOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContextBakImportOptionsEncryptionOptions.php',
    'Google\\Service\\SQLAdmin\\ImportContextCsvImportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContextCsvImportOptions.php',
    'Google\\Service\\SQLAdmin\\ImportContextSqlImportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContextSqlImportOptions.php',
    'Google\\Service\\SQLAdmin\\ImportContextSqlImportOptionsPostgresImportOptions' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ImportContextSqlImportOptionsPostgresImportOptions.php',
    'Google\\Service\\SQLAdmin\\InsightsConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InsightsConfig.php',
    'Google\\Service\\SQLAdmin\\InstanceReference' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstanceReference.php',
    'Google\\Service\\SQLAdmin\\InstancesAcquireSsrsLeaseRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesAcquireSsrsLeaseRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesCloneRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesCloneRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesDemoteMasterRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesDemoteMasterRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesDemoteRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesDemoteRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesExportRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesExportRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesFailoverRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesFailoverRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesImportRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesImportRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesListResponse.php',
    'Google\\Service\\SQLAdmin\\InstancesListServerCasResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesListServerCasResponse.php',
    'Google\\Service\\SQLAdmin\\InstancesListServerCertificatesResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesListServerCertificatesResponse.php',
    'Google\\Service\\SQLAdmin\\InstancesReencryptRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesReencryptRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesRestoreBackupRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesRestoreBackupRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesRotateServerCaRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesRotateServerCaRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesRotateServerCertificateRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesRotateServerCertificateRequest.php',
    'Google\\Service\\SQLAdmin\\InstancesTruncateLogRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/InstancesTruncateLogRequest.php',
    'Google\\Service\\SQLAdmin\\IpConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/IpConfiguration.php',
    'Google\\Service\\SQLAdmin\\IpMapping' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/IpMapping.php',
    'Google\\Service\\SQLAdmin\\LocationPreference' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/LocationPreference.php',
    'Google\\Service\\SQLAdmin\\MaintenanceWindow' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/MaintenanceWindow.php',
    'Google\\Service\\SQLAdmin\\MySqlReplicaConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/MySqlReplicaConfiguration.php',
    'Google\\Service\\SQLAdmin\\MySqlSyncConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/MySqlSyncConfig.php',
    'Google\\Service\\SQLAdmin\\OnPremisesConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/OnPremisesConfiguration.php',
    'Google\\Service\\SQLAdmin\\Operation' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Operation.php',
    'Google\\Service\\SQLAdmin\\OperationError' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/OperationError.php',
    'Google\\Service\\SQLAdmin\\OperationErrors' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/OperationErrors.php',
    'Google\\Service\\SQLAdmin\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/OperationMetadata.php',
    'Google\\Service\\SQLAdmin\\OperationsListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/OperationsListResponse.php',
    'Google\\Service\\SQLAdmin\\PasswordStatus' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/PasswordStatus.php',
    'Google\\Service\\SQLAdmin\\PasswordValidationPolicy' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/PasswordValidationPolicy.php',
    'Google\\Service\\SQLAdmin\\PerformDiskShrinkContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/PerformDiskShrinkContext.php',
    'Google\\Service\\SQLAdmin\\PscConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/PscConfig.php',
    'Google\\Service\\SQLAdmin\\ReplicaConfiguration' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ReplicaConfiguration.php',
    'Google\\Service\\SQLAdmin\\ReplicationCluster' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/ReplicationCluster.php',
    'Google\\Service\\SQLAdmin\\Reschedule' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Reschedule.php',
    'Google\\Service\\SQLAdmin\\Resource\\BackupRuns' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/BackupRuns.php',
    'Google\\Service\\SQLAdmin\\Resource\\Connect' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Connect.php',
    'Google\\Service\\SQLAdmin\\Resource\\Databases' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Databases.php',
    'Google\\Service\\SQLAdmin\\Resource\\Flags' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Flags.php',
    'Google\\Service\\SQLAdmin\\Resource\\Instances' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Instances.php',
    'Google\\Service\\SQLAdmin\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Operations.php',
    'Google\\Service\\SQLAdmin\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Projects.php',
    'Google\\Service\\SQLAdmin\\Resource\\ProjectsInstances' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/ProjectsInstances.php',
    'Google\\Service\\SQLAdmin\\Resource\\ProjectsInstancesCreateEphemeral' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/ProjectsInstancesCreateEphemeral.php',
    'Google\\Service\\SQLAdmin\\Resource\\SslCerts' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/SslCerts.php',
    'Google\\Service\\SQLAdmin\\Resource\\Tiers' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Tiers.php',
    'Google\\Service\\SQLAdmin\\Resource\\Users' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Resource/Users.php',
    'Google\\Service\\SQLAdmin\\RestoreBackupContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/RestoreBackupContext.php',
    'Google\\Service\\SQLAdmin\\RotateServerCaContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/RotateServerCaContext.php',
    'Google\\Service\\SQLAdmin\\RotateServerCertificateContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/RotateServerCertificateContext.php',
    'Google\\Service\\SQLAdmin\\Settings' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Settings.php',
    'Google\\Service\\SQLAdmin\\SqlActiveDirectoryConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlActiveDirectoryConfig.php',
    'Google\\Service\\SQLAdmin\\SqlExternalSyncSettingError' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlExternalSyncSettingError.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesAcquireSsrsLeaseResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesAcquireSsrsLeaseResponse.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesGetDiskShrinkConfigResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesGetDiskShrinkConfigResponse.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesGetLatestRecoveryTimeResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesGetLatestRecoveryTimeResponse.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesReleaseSsrsLeaseResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesReleaseSsrsLeaseResponse.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesRescheduleMaintenanceRequestBody' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesRescheduleMaintenanceRequestBody.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesResetReplicaSizeRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesResetReplicaSizeRequest.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesStartExternalSyncRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesStartExternalSyncRequest.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesVerifyExternalSyncSettingsRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesVerifyExternalSyncSettingsRequest.php',
    'Google\\Service\\SQLAdmin\\SqlInstancesVerifyExternalSyncSettingsResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlInstancesVerifyExternalSyncSettingsResponse.php',
    'Google\\Service\\SQLAdmin\\SqlOutOfDiskReport' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlOutOfDiskReport.php',
    'Google\\Service\\SQLAdmin\\SqlScheduledMaintenance' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlScheduledMaintenance.php',
    'Google\\Service\\SQLAdmin\\SqlServerAuditConfig' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlServerAuditConfig.php',
    'Google\\Service\\SQLAdmin\\SqlServerDatabaseDetails' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlServerDatabaseDetails.php',
    'Google\\Service\\SQLAdmin\\SqlServerUserDetails' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqlServerUserDetails.php',
    'Google\\Service\\SQLAdmin\\SqladminEmpty' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SqladminEmpty.php',
    'Google\\Service\\SQLAdmin\\SslCert' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCert.php',
    'Google\\Service\\SQLAdmin\\SslCertDetail' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCertDetail.php',
    'Google\\Service\\SQLAdmin\\SslCertsCreateEphemeralRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCertsCreateEphemeralRequest.php',
    'Google\\Service\\SQLAdmin\\SslCertsInsertRequest' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCertsInsertRequest.php',
    'Google\\Service\\SQLAdmin\\SslCertsInsertResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCertsInsertResponse.php',
    'Google\\Service\\SQLAdmin\\SslCertsListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SslCertsListResponse.php',
    'Google\\Service\\SQLAdmin\\SyncFlags' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/SyncFlags.php',
    'Google\\Service\\SQLAdmin\\Tier' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/Tier.php',
    'Google\\Service\\SQLAdmin\\TiersListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/TiersListResponse.php',
    'Google\\Service\\SQLAdmin\\TruncateLogContext' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/TruncateLogContext.php',
    'Google\\Service\\SQLAdmin\\User' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/User.php',
    'Google\\Service\\SQLAdmin\\UserPasswordValidationPolicy' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/UserPasswordValidationPolicy.php',
    'Google\\Service\\SQLAdmin\\UsersListResponse' => $vendorDir . '/google/apiclient-services/src/SQLAdmin/UsersListResponse.php',
    'Google\\Service\\Safebrowsing' => $vendorDir . '/google/apiclient-services/src/Safebrowsing.php',
    'Google\\Service\\Safebrowsing\\Checksum' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Checksum.php',
    'Google\\Service\\Safebrowsing\\ClientInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ClientInfo.php',
    'Google\\Service\\Safebrowsing\\Constraints' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Constraints.php',
    'Google\\Service\\Safebrowsing\\FetchThreatListUpdatesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FetchThreatListUpdatesRequest.php',
    'Google\\Service\\Safebrowsing\\FetchThreatListUpdatesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FetchThreatListUpdatesResponse.php',
    'Google\\Service\\Safebrowsing\\FindFullHashesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FindFullHashesRequest.php',
    'Google\\Service\\Safebrowsing\\FindFullHashesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FindFullHashesResponse.php',
    'Google\\Service\\Safebrowsing\\FindThreatMatchesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FindThreatMatchesRequest.php',
    'Google\\Service\\Safebrowsing\\FindThreatMatchesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/FindThreatMatchesResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleProtobufEmpty.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4Checksum' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4Checksum.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ClientInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ClientInfo.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequest.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequestListUpdateRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequestListUpdateRequest.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequestListUpdateRequestConstraints' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FetchThreatListUpdatesRequestListUpdateRequestConstraints.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FetchThreatListUpdatesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FetchThreatListUpdatesResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FetchThreatListUpdatesResponseListUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FetchThreatListUpdatesResponseListUpdateResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FindFullHashesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FindFullHashesRequest.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FindFullHashesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FindFullHashesResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FindThreatMatchesRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FindThreatMatchesRequest.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4FindThreatMatchesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4FindThreatMatchesResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ListThreatListsResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ListThreatListsResponse.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4RawHashes' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4RawHashes.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4RawIndices' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4RawIndices.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4RiceDeltaEncoding' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4RiceDeltaEncoding.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatEntry' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatEntry.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatEntryMetadata' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatEntryMetadata.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatEntryMetadataMetadataEntry' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatEntryMetadataMetadataEntry.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatEntrySet' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatEntrySet.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatHit' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatHit.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatHitThreatSource' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatHitThreatSource.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatHitUserInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatHitUserInfo.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatInfo.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatListDescriptor' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatListDescriptor.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV4ThreatMatch' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV4ThreatMatch.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV5FullHash' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV5FullHash.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV5FullHashFullHashDetail' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV5FullHashFullHashDetail.php',
    'Google\\Service\\Safebrowsing\\GoogleSecuritySafebrowsingV5SearchHashesResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/GoogleSecuritySafebrowsingV5SearchHashesResponse.php',
    'Google\\Service\\Safebrowsing\\ListThreatListsResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ListThreatListsResponse.php',
    'Google\\Service\\Safebrowsing\\ListUpdateRequest' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ListUpdateRequest.php',
    'Google\\Service\\Safebrowsing\\ListUpdateResponse' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ListUpdateResponse.php',
    'Google\\Service\\Safebrowsing\\MetadataEntry' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/MetadataEntry.php',
    'Google\\Service\\Safebrowsing\\RawHashes' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/RawHashes.php',
    'Google\\Service\\Safebrowsing\\RawIndices' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/RawIndices.php',
    'Google\\Service\\Safebrowsing\\Resource\\EncodedFullHashes' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/EncodedFullHashes.php',
    'Google\\Service\\Safebrowsing\\Resource\\EncodedUpdates' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/EncodedUpdates.php',
    'Google\\Service\\Safebrowsing\\Resource\\FullHashes' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/FullHashes.php',
    'Google\\Service\\Safebrowsing\\Resource\\Hashes' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/Hashes.php',
    'Google\\Service\\Safebrowsing\\Resource\\ThreatHits' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/ThreatHits.php',
    'Google\\Service\\Safebrowsing\\Resource\\ThreatListUpdates' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/ThreatListUpdates.php',
    'Google\\Service\\Safebrowsing\\Resource\\ThreatLists' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/ThreatLists.php',
    'Google\\Service\\Safebrowsing\\Resource\\ThreatMatches' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/Resource/ThreatMatches.php',
    'Google\\Service\\Safebrowsing\\RiceDeltaEncoding' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/RiceDeltaEncoding.php',
    'Google\\Service\\Safebrowsing\\SafebrowsingEmpty' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/SafebrowsingEmpty.php',
    'Google\\Service\\Safebrowsing\\ThreatEntry' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatEntry.php',
    'Google\\Service\\Safebrowsing\\ThreatEntryMetadata' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatEntryMetadata.php',
    'Google\\Service\\Safebrowsing\\ThreatEntrySet' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatEntrySet.php',
    'Google\\Service\\Safebrowsing\\ThreatHit' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatHit.php',
    'Google\\Service\\Safebrowsing\\ThreatInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatInfo.php',
    'Google\\Service\\Safebrowsing\\ThreatListDescriptor' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatListDescriptor.php',
    'Google\\Service\\Safebrowsing\\ThreatMatch' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatMatch.php',
    'Google\\Service\\Safebrowsing\\ThreatSource' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/ThreatSource.php',
    'Google\\Service\\Safebrowsing\\UserInfo' => $vendorDir . '/google/apiclient-services/src/Safebrowsing/UserInfo.php',
    'Google\\Service\\Sasportal' => $vendorDir . '/google/apiclient-services/src/Sasportal.php',
    'Google\\Service\\Sasportal\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/Customers.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersDeployments' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersDeployments.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersDeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersDeploymentsDevices.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersDevices.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersNodes' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersNodes.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersNodesDeployments' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersNodesDeployments.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersNodesDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersNodesDevices.php',
    'Google\\Service\\Sasportal\\Resource\\CustomersNodesNodes' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/CustomersNodesNodes.php',
    'Google\\Service\\Sasportal\\Resource\\Deployments' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/Deployments.php',
    'Google\\Service\\Sasportal\\Resource\\DeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/DeploymentsDevices.php',
    'Google\\Service\\Sasportal\\Resource\\Installer' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/Installer.php',
    'Google\\Service\\Sasportal\\Resource\\Nodes' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/Nodes.php',
    'Google\\Service\\Sasportal\\Resource\\NodesDeployments' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesDeployments.php',
    'Google\\Service\\Sasportal\\Resource\\NodesDeploymentsDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesDeploymentsDevices.php',
    'Google\\Service\\Sasportal\\Resource\\NodesDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesDevices.php',
    'Google\\Service\\Sasportal\\Resource\\NodesNodes' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesNodes.php',
    'Google\\Service\\Sasportal\\Resource\\NodesNodesDeployments' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesNodesDeployments.php',
    'Google\\Service\\Sasportal\\Resource\\NodesNodesDevices' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesNodesDevices.php',
    'Google\\Service\\Sasportal\\Resource\\NodesNodesNodes' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/NodesNodesNodes.php',
    'Google\\Service\\Sasportal\\Resource\\Policies' => $vendorDir . '/google/apiclient-services/src/Sasportal/Resource/Policies.php',
    'Google\\Service\\Sasportal\\SasPortalAssignment' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalAssignment.php',
    'Google\\Service\\Sasportal\\SasPortalChannelWithScore' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalChannelWithScore.php',
    'Google\\Service\\Sasportal\\SasPortalCheckHasProvisionedDeploymentResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalCheckHasProvisionedDeploymentResponse.php',
    'Google\\Service\\Sasportal\\SasPortalCreateSignedDeviceRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalCreateSignedDeviceRequest.php',
    'Google\\Service\\Sasportal\\SasPortalCustomer' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalCustomer.php',
    'Google\\Service\\Sasportal\\SasPortalDeployment' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeployment.php',
    'Google\\Service\\Sasportal\\SasPortalDeploymentAssociation' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeploymentAssociation.php',
    'Google\\Service\\Sasportal\\SasPortalDevice' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDevice.php',
    'Google\\Service\\Sasportal\\SasPortalDeviceAirInterface' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeviceAirInterface.php',
    'Google\\Service\\Sasportal\\SasPortalDeviceConfig' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeviceConfig.php',
    'Google\\Service\\Sasportal\\SasPortalDeviceGrant' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeviceGrant.php',
    'Google\\Service\\Sasportal\\SasPortalDeviceMetadata' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeviceMetadata.php',
    'Google\\Service\\Sasportal\\SasPortalDeviceModel' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDeviceModel.php',
    'Google\\Service\\Sasportal\\SasPortalDpaMoveList' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalDpaMoveList.php',
    'Google\\Service\\Sasportal\\SasPortalEmpty' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalEmpty.php',
    'Google\\Service\\Sasportal\\SasPortalFrequencyRange' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalFrequencyRange.php',
    'Google\\Service\\Sasportal\\SasPortalGcpProjectDeployment' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalGcpProjectDeployment.php',
    'Google\\Service\\Sasportal\\SasPortalGenerateSecretRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalGenerateSecretRequest.php',
    'Google\\Service\\Sasportal\\SasPortalGenerateSecretResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalGenerateSecretResponse.php',
    'Google\\Service\\Sasportal\\SasPortalGetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalGetPolicyRequest.php',
    'Google\\Service\\Sasportal\\SasPortalInstallationParams' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalInstallationParams.php',
    'Google\\Service\\Sasportal\\SasPortalListCustomersResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListCustomersResponse.php',
    'Google\\Service\\Sasportal\\SasPortalListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListDeploymentsResponse.php',
    'Google\\Service\\Sasportal\\SasPortalListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListDevicesResponse.php',
    'Google\\Service\\Sasportal\\SasPortalListGcpProjectDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListGcpProjectDeploymentsResponse.php',
    'Google\\Service\\Sasportal\\SasPortalListLegacyOrganizationsResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListLegacyOrganizationsResponse.php',
    'Google\\Service\\Sasportal\\SasPortalListNodesResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalListNodesResponse.php',
    'Google\\Service\\Sasportal\\SasPortalMigrateOrganizationMetadata' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMigrateOrganizationMetadata.php',
    'Google\\Service\\Sasportal\\SasPortalMigrateOrganizationRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMigrateOrganizationRequest.php',
    'Google\\Service\\Sasportal\\SasPortalMigrateOrganizationResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMigrateOrganizationResponse.php',
    'Google\\Service\\Sasportal\\SasPortalMoveDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMoveDeploymentRequest.php',
    'Google\\Service\\Sasportal\\SasPortalMoveDeviceRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMoveDeviceRequest.php',
    'Google\\Service\\Sasportal\\SasPortalMoveNodeRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalMoveNodeRequest.php',
    'Google\\Service\\Sasportal\\SasPortalNode' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalNode.php',
    'Google\\Service\\Sasportal\\SasPortalNrqzValidation' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalNrqzValidation.php',
    'Google\\Service\\Sasportal\\SasPortalOperation' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalOperation.php',
    'Google\\Service\\Sasportal\\SasPortalOrganization' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalOrganization.php',
    'Google\\Service\\Sasportal\\SasPortalPolicy' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalPolicy.php',
    'Google\\Service\\Sasportal\\SasPortalProvisionDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalProvisionDeploymentRequest.php',
    'Google\\Service\\Sasportal\\SasPortalProvisionDeploymentResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalProvisionDeploymentResponse.php',
    'Google\\Service\\Sasportal\\SasPortalSetPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalSetPolicyRequest.php',
    'Google\\Service\\Sasportal\\SasPortalSetupSasAnalyticsMetadata' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalSetupSasAnalyticsMetadata.php',
    'Google\\Service\\Sasportal\\SasPortalSetupSasAnalyticsRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalSetupSasAnalyticsRequest.php',
    'Google\\Service\\Sasportal\\SasPortalSetupSasAnalyticsResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalSetupSasAnalyticsResponse.php',
    'Google\\Service\\Sasportal\\SasPortalSignDeviceRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalSignDeviceRequest.php',
    'Google\\Service\\Sasportal\\SasPortalStatus' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalStatus.php',
    'Google\\Service\\Sasportal\\SasPortalTestPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalTestPermissionsRequest.php',
    'Google\\Service\\Sasportal\\SasPortalTestPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalTestPermissionsResponse.php',
    'Google\\Service\\Sasportal\\SasPortalUpdateSignedDeviceRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalUpdateSignedDeviceRequest.php',
    'Google\\Service\\Sasportal\\SasPortalValidateInstallerRequest' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalValidateInstallerRequest.php',
    'Google\\Service\\Sasportal\\SasPortalValidateInstallerResponse' => $vendorDir . '/google/apiclient-services/src/Sasportal/SasPortalValidateInstallerResponse.php',
    'Google\\Service\\Script' => $vendorDir . '/google/apiclient-services/src/Script.php',
    'Google\\Service\\Script\\Content' => $vendorDir . '/google/apiclient-services/src/Script/Content.php',
    'Google\\Service\\Script\\CreateProjectRequest' => $vendorDir . '/google/apiclient-services/src/Script/CreateProjectRequest.php',
    'Google\\Service\\Script\\Deployment' => $vendorDir . '/google/apiclient-services/src/Script/Deployment.php',
    'Google\\Service\\Script\\DeploymentConfig' => $vendorDir . '/google/apiclient-services/src/Script/DeploymentConfig.php',
    'Google\\Service\\Script\\EntryPoint' => $vendorDir . '/google/apiclient-services/src/Script/EntryPoint.php',
    'Google\\Service\\Script\\ExecuteStreamResponse' => $vendorDir . '/google/apiclient-services/src/Script/ExecuteStreamResponse.php',
    'Google\\Service\\Script\\ExecutionError' => $vendorDir . '/google/apiclient-services/src/Script/ExecutionError.php',
    'Google\\Service\\Script\\ExecutionRequest' => $vendorDir . '/google/apiclient-services/src/Script/ExecutionRequest.php',
    'Google\\Service\\Script\\ExecutionResponse' => $vendorDir . '/google/apiclient-services/src/Script/ExecutionResponse.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeAddOnEntryPoint' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeAddOnEntryPoint.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeExecutionApiConfig' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeExecutionApiConfig.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeExecutionApiEntryPoint' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeExecutionApiEntryPoint.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeFunction' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeFunction.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeFunctionSet' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeFunctionSet.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeProcess' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeProcess.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeUser' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeUser.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeWebAppConfig' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeWebAppConfig.php',
    'Google\\Service\\Script\\GoogleAppsScriptTypeWebAppEntryPoint' => $vendorDir . '/google/apiclient-services/src/Script/GoogleAppsScriptTypeWebAppEntryPoint.php',
    'Google\\Service\\Script\\ListDeploymentsResponse' => $vendorDir . '/google/apiclient-services/src/Script/ListDeploymentsResponse.php',
    'Google\\Service\\Script\\ListScriptProcessesResponse' => $vendorDir . '/google/apiclient-services/src/Script/ListScriptProcessesResponse.php',
    'Google\\Service\\Script\\ListUserProcessesResponse' => $vendorDir . '/google/apiclient-services/src/Script/ListUserProcessesResponse.php',
    'Google\\Service\\Script\\ListValue' => $vendorDir . '/google/apiclient-services/src/Script/ListValue.php',
    'Google\\Service\\Script\\ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/Script/ListVersionsResponse.php',
    'Google\\Service\\Script\\Metrics' => $vendorDir . '/google/apiclient-services/src/Script/Metrics.php',
    'Google\\Service\\Script\\MetricsValue' => $vendorDir . '/google/apiclient-services/src/Script/MetricsValue.php',
    'Google\\Service\\Script\\Operation' => $vendorDir . '/google/apiclient-services/src/Script/Operation.php',
    'Google\\Service\\Script\\Project' => $vendorDir . '/google/apiclient-services/src/Script/Project.php',
    'Google\\Service\\Script\\Resource\\Processes' => $vendorDir . '/google/apiclient-services/src/Script/Resource/Processes.php',
    'Google\\Service\\Script\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Script/Resource/Projects.php',
    'Google\\Service\\Script\\Resource\\ProjectsDeployments' => $vendorDir . '/google/apiclient-services/src/Script/Resource/ProjectsDeployments.php',
    'Google\\Service\\Script\\Resource\\ProjectsVersions' => $vendorDir . '/google/apiclient-services/src/Script/Resource/ProjectsVersions.php',
    'Google\\Service\\Script\\Resource\\Scripts' => $vendorDir . '/google/apiclient-services/src/Script/Resource/Scripts.php',
    'Google\\Service\\Script\\ScriptEmpty' => $vendorDir . '/google/apiclient-services/src/Script/ScriptEmpty.php',
    'Google\\Service\\Script\\ScriptExecutionResult' => $vendorDir . '/google/apiclient-services/src/Script/ScriptExecutionResult.php',
    'Google\\Service\\Script\\ScriptFile' => $vendorDir . '/google/apiclient-services/src/Script/ScriptFile.php',
    'Google\\Service\\Script\\ScriptStackTraceElement' => $vendorDir . '/google/apiclient-services/src/Script/ScriptStackTraceElement.php',
    'Google\\Service\\Script\\Status' => $vendorDir . '/google/apiclient-services/src/Script/Status.php',
    'Google\\Service\\Script\\Struct' => $vendorDir . '/google/apiclient-services/src/Script/Struct.php',
    'Google\\Service\\Script\\UpdateDeploymentRequest' => $vendorDir . '/google/apiclient-services/src/Script/UpdateDeploymentRequest.php',
    'Google\\Service\\Script\\Value' => $vendorDir . '/google/apiclient-services/src/Script/Value.php',
    'Google\\Service\\Script\\Version' => $vendorDir . '/google/apiclient-services/src/Script/Version.php',
    'Google\\Service\\SearchConsole' => $vendorDir . '/google/apiclient-services/src/SearchConsole.php',
    'Google\\Service\\SearchConsole\\AmpInspectionResult' => $vendorDir . '/google/apiclient-services/src/SearchConsole/AmpInspectionResult.php',
    'Google\\Service\\SearchConsole\\AmpIssue' => $vendorDir . '/google/apiclient-services/src/SearchConsole/AmpIssue.php',
    'Google\\Service\\SearchConsole\\ApiDataRow' => $vendorDir . '/google/apiclient-services/src/SearchConsole/ApiDataRow.php',
    'Google\\Service\\SearchConsole\\ApiDimensionFilter' => $vendorDir . '/google/apiclient-services/src/SearchConsole/ApiDimensionFilter.php',
    'Google\\Service\\SearchConsole\\ApiDimensionFilterGroup' => $vendorDir . '/google/apiclient-services/src/SearchConsole/ApiDimensionFilterGroup.php',
    'Google\\Service\\SearchConsole\\BlockedResource' => $vendorDir . '/google/apiclient-services/src/SearchConsole/BlockedResource.php',
    'Google\\Service\\SearchConsole\\DetectedItems' => $vendorDir . '/google/apiclient-services/src/SearchConsole/DetectedItems.php',
    'Google\\Service\\SearchConsole\\Image' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Image.php',
    'Google\\Service\\SearchConsole\\IndexStatusInspectionResult' => $vendorDir . '/google/apiclient-services/src/SearchConsole/IndexStatusInspectionResult.php',
    'Google\\Service\\SearchConsole\\InspectUrlIndexRequest' => $vendorDir . '/google/apiclient-services/src/SearchConsole/InspectUrlIndexRequest.php',
    'Google\\Service\\SearchConsole\\InspectUrlIndexResponse' => $vendorDir . '/google/apiclient-services/src/SearchConsole/InspectUrlIndexResponse.php',
    'Google\\Service\\SearchConsole\\Item' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Item.php',
    'Google\\Service\\SearchConsole\\MobileFriendlyIssue' => $vendorDir . '/google/apiclient-services/src/SearchConsole/MobileFriendlyIssue.php',
    'Google\\Service\\SearchConsole\\MobileUsabilityInspectionResult' => $vendorDir . '/google/apiclient-services/src/SearchConsole/MobileUsabilityInspectionResult.php',
    'Google\\Service\\SearchConsole\\MobileUsabilityIssue' => $vendorDir . '/google/apiclient-services/src/SearchConsole/MobileUsabilityIssue.php',
    'Google\\Service\\SearchConsole\\ResourceIssue' => $vendorDir . '/google/apiclient-services/src/SearchConsole/ResourceIssue.php',
    'Google\\Service\\SearchConsole\\Resource\\Searchanalytics' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/Searchanalytics.php',
    'Google\\Service\\SearchConsole\\Resource\\Sitemaps' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/Sitemaps.php',
    'Google\\Service\\SearchConsole\\Resource\\Sites' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/Sites.php',
    'Google\\Service\\SearchConsole\\Resource\\UrlInspection' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/UrlInspection.php',
    'Google\\Service\\SearchConsole\\Resource\\UrlInspectionIndex' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/UrlInspectionIndex.php',
    'Google\\Service\\SearchConsole\\Resource\\UrlTestingTools' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/UrlTestingTools.php',
    'Google\\Service\\SearchConsole\\Resource\\UrlTestingToolsMobileFriendlyTest' => $vendorDir . '/google/apiclient-services/src/SearchConsole/Resource/UrlTestingToolsMobileFriendlyTest.php',
    'Google\\Service\\SearchConsole\\RichResultsInspectionResult' => $vendorDir . '/google/apiclient-services/src/SearchConsole/RichResultsInspectionResult.php',
    'Google\\Service\\SearchConsole\\RichResultsIssue' => $vendorDir . '/google/apiclient-services/src/SearchConsole/RichResultsIssue.php',
    'Google\\Service\\SearchConsole\\RunMobileFriendlyTestRequest' => $vendorDir . '/google/apiclient-services/src/SearchConsole/RunMobileFriendlyTestRequest.php',
    'Google\\Service\\SearchConsole\\RunMobileFriendlyTestResponse' => $vendorDir . '/google/apiclient-services/src/SearchConsole/RunMobileFriendlyTestResponse.php',
    'Google\\Service\\SearchConsole\\SearchAnalyticsQueryRequest' => $vendorDir . '/google/apiclient-services/src/SearchConsole/SearchAnalyticsQueryRequest.php',
    'Google\\Service\\SearchConsole\\SearchAnalyticsQueryResponse' => $vendorDir . '/google/apiclient-services/src/SearchConsole/SearchAnalyticsQueryResponse.php',
    'Google\\Service\\SearchConsole\\SitemapsListResponse' => $vendorDir . '/google/apiclient-services/src/SearchConsole/SitemapsListResponse.php',
    'Google\\Service\\SearchConsole\\SitesListResponse' => $vendorDir . '/google/apiclient-services/src/SearchConsole/SitesListResponse.php',
    'Google\\Service\\SearchConsole\\TestStatus' => $vendorDir . '/google/apiclient-services/src/SearchConsole/TestStatus.php',
    'Google\\Service\\SearchConsole\\UrlInspectionResult' => $vendorDir . '/google/apiclient-services/src/SearchConsole/UrlInspectionResult.php',
    'Google\\Service\\SearchConsole\\WmxSite' => $vendorDir . '/google/apiclient-services/src/SearchConsole/WmxSite.php',
    'Google\\Service\\SearchConsole\\WmxSitemap' => $vendorDir . '/google/apiclient-services/src/SearchConsole/WmxSitemap.php',
    'Google\\Service\\SearchConsole\\WmxSitemapContent' => $vendorDir . '/google/apiclient-services/src/SearchConsole/WmxSitemapContent.php',
    'Google\\Service\\SecretManager' => $vendorDir . '/google/apiclient-services/src/SecretManager.php',
    'Google\\Service\\SecretManager\\AccessSecretVersionResponse' => $vendorDir . '/google/apiclient-services/src/SecretManager/AccessSecretVersionResponse.php',
    'Google\\Service\\SecretManager\\AddSecretVersionRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/AddSecretVersionRequest.php',
    'Google\\Service\\SecretManager\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/SecretManager/AuditConfig.php',
    'Google\\Service\\SecretManager\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/SecretManager/AuditLogConfig.php',
    'Google\\Service\\SecretManager\\Automatic' => $vendorDir . '/google/apiclient-services/src/SecretManager/Automatic.php',
    'Google\\Service\\SecretManager\\AutomaticStatus' => $vendorDir . '/google/apiclient-services/src/SecretManager/AutomaticStatus.php',
    'Google\\Service\\SecretManager\\Binding' => $vendorDir . '/google/apiclient-services/src/SecretManager/Binding.php',
    'Google\\Service\\SecretManager\\CustomerManagedEncryption' => $vendorDir . '/google/apiclient-services/src/SecretManager/CustomerManagedEncryption.php',
    'Google\\Service\\SecretManager\\CustomerManagedEncryptionStatus' => $vendorDir . '/google/apiclient-services/src/SecretManager/CustomerManagedEncryptionStatus.php',
    'Google\\Service\\SecretManager\\DestroySecretVersionRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/DestroySecretVersionRequest.php',
    'Google\\Service\\SecretManager\\DisableSecretVersionRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/DisableSecretVersionRequest.php',
    'Google\\Service\\SecretManager\\EnableSecretVersionRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/EnableSecretVersionRequest.php',
    'Google\\Service\\SecretManager\\Expr' => $vendorDir . '/google/apiclient-services/src/SecretManager/Expr.php',
    'Google\\Service\\SecretManager\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/SecretManager/ListLocationsResponse.php',
    'Google\\Service\\SecretManager\\ListSecretVersionsResponse' => $vendorDir . '/google/apiclient-services/src/SecretManager/ListSecretVersionsResponse.php',
    'Google\\Service\\SecretManager\\ListSecretsResponse' => $vendorDir . '/google/apiclient-services/src/SecretManager/ListSecretsResponse.php',
    'Google\\Service\\SecretManager\\Location' => $vendorDir . '/google/apiclient-services/src/SecretManager/Location.php',
    'Google\\Service\\SecretManager\\Policy' => $vendorDir . '/google/apiclient-services/src/SecretManager/Policy.php',
    'Google\\Service\\SecretManager\\Replica' => $vendorDir . '/google/apiclient-services/src/SecretManager/Replica.php',
    'Google\\Service\\SecretManager\\ReplicaStatus' => $vendorDir . '/google/apiclient-services/src/SecretManager/ReplicaStatus.php',
    'Google\\Service\\SecretManager\\Replication' => $vendorDir . '/google/apiclient-services/src/SecretManager/Replication.php',
    'Google\\Service\\SecretManager\\ReplicationStatus' => $vendorDir . '/google/apiclient-services/src/SecretManager/ReplicationStatus.php',
    'Google\\Service\\SecretManager\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/Projects.php',
    'Google\\Service\\SecretManager\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/ProjectsLocations.php',
    'Google\\Service\\SecretManager\\Resource\\ProjectsLocationsSecrets' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/ProjectsLocationsSecrets.php',
    'Google\\Service\\SecretManager\\Resource\\ProjectsLocationsSecretsVersions' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/ProjectsLocationsSecretsVersions.php',
    'Google\\Service\\SecretManager\\Resource\\ProjectsSecrets' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/ProjectsSecrets.php',
    'Google\\Service\\SecretManager\\Resource\\ProjectsSecretsVersions' => $vendorDir . '/google/apiclient-services/src/SecretManager/Resource/ProjectsSecretsVersions.php',
    'Google\\Service\\SecretManager\\Rotation' => $vendorDir . '/google/apiclient-services/src/SecretManager/Rotation.php',
    'Google\\Service\\SecretManager\\Secret' => $vendorDir . '/google/apiclient-services/src/SecretManager/Secret.php',
    'Google\\Service\\SecretManager\\SecretPayload' => $vendorDir . '/google/apiclient-services/src/SecretManager/SecretPayload.php',
    'Google\\Service\\SecretManager\\SecretVersion' => $vendorDir . '/google/apiclient-services/src/SecretManager/SecretVersion.php',
    'Google\\Service\\SecretManager\\SecretmanagerEmpty' => $vendorDir . '/google/apiclient-services/src/SecretManager/SecretmanagerEmpty.php',
    'Google\\Service\\SecretManager\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/SetIamPolicyRequest.php',
    'Google\\Service\\SecretManager\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/SecretManager/TestIamPermissionsRequest.php',
    'Google\\Service\\SecretManager\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/SecretManager/TestIamPermissionsResponse.php',
    'Google\\Service\\SecretManager\\Topic' => $vendorDir . '/google/apiclient-services/src/SecretManager/Topic.php',
    'Google\\Service\\SecretManager\\UserManaged' => $vendorDir . '/google/apiclient-services/src/SecretManager/UserManaged.php',
    'Google\\Service\\SecretManager\\UserManagedStatus' => $vendorDir . '/google/apiclient-services/src/SecretManager/UserManagedStatus.php',
    'Google\\Service\\SecurityCommandCenter' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter.php',
    'Google\\Service\\SecurityCommandCenter\\Access' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Access.php',
    'Google\\Service\\SecurityCommandCenter\\AccessReview' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AccessReview.php',
    'Google\\Service\\SecurityCommandCenter\\AdaptiveProtection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AdaptiveProtection.php',
    'Google\\Service\\SecurityCommandCenter\\Application' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Application.php',
    'Google\\Service\\SecurityCommandCenter\\Asset' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Asset.php',
    'Google\\Service\\SecurityCommandCenter\\AssetDiscoveryConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AssetDiscoveryConfig.php',
    'Google\\Service\\SecurityCommandCenter\\AssociatedFinding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AssociatedFinding.php',
    'Google\\Service\\SecurityCommandCenter\\Attack' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Attack.php',
    'Google\\Service\\SecurityCommandCenter\\AttackExposure' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AttackExposure.php',
    'Google\\Service\\SecurityCommandCenter\\AttackPath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AttackPath.php',
    'Google\\Service\\SecurityCommandCenter\\AttackPathEdge' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AttackPathEdge.php',
    'Google\\Service\\SecurityCommandCenter\\AttackPathNode' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AttackPathNode.php',
    'Google\\Service\\SecurityCommandCenter\\AttackStepNode' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AttackStepNode.php',
    'Google\\Service\\SecurityCommandCenter\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AuditConfig.php',
    'Google\\Service\\SecurityCommandCenter\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AuditLogConfig.php',
    'Google\\Service\\SecurityCommandCenter\\AwsAccount' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AwsAccount.php',
    'Google\\Service\\SecurityCommandCenter\\AwsMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AwsMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\AwsOrganization' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AwsOrganization.php',
    'Google\\Service\\SecurityCommandCenter\\AwsOrganizationalUnit' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AwsOrganizationalUnit.php',
    'Google\\Service\\SecurityCommandCenter\\AzureManagementGroup' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AzureManagementGroup.php',
    'Google\\Service\\SecurityCommandCenter\\AzureMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AzureMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\AzureResourceGroup' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AzureResourceGroup.php',
    'Google\\Service\\SecurityCommandCenter\\AzureSubscription' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AzureSubscription.php',
    'Google\\Service\\SecurityCommandCenter\\AzureTenant' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/AzureTenant.php',
    'Google\\Service\\SecurityCommandCenter\\BackupDisasterRecovery' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/BackupDisasterRecovery.php',
    'Google\\Service\\SecurityCommandCenter\\BatchCreateResourceValueConfigsRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/BatchCreateResourceValueConfigsRequest.php',
    'Google\\Service\\SecurityCommandCenter\\BatchCreateResourceValueConfigsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/BatchCreateResourceValueConfigsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\Binding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Binding.php',
    'Google\\Service\\SecurityCommandCenter\\BulkMuteFindingsRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/BulkMuteFindingsRequest.php',
    'Google\\Service\\SecurityCommandCenter\\CloudArmor' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CloudArmor.php',
    'Google\\Service\\SecurityCommandCenter\\CloudDlpDataProfile' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CloudDlpDataProfile.php',
    'Google\\Service\\SecurityCommandCenter\\CloudDlpInspection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CloudDlpInspection.php',
    'Google\\Service\\SecurityCommandCenter\\CloudLoggingEntry' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CloudLoggingEntry.php',
    'Google\\Service\\SecurityCommandCenter\\Compliance' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Compliance.php',
    'Google\\Service\\SecurityCommandCenter\\ComplianceSnapshot' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ComplianceSnapshot.php',
    'Google\\Service\\SecurityCommandCenter\\Connection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Connection.php',
    'Google\\Service\\SecurityCommandCenter\\Contact' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Contact.php',
    'Google\\Service\\SecurityCommandCenter\\ContactDetails' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ContactDetails.php',
    'Google\\Service\\SecurityCommandCenter\\Container' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Container.php',
    'Google\\Service\\SecurityCommandCenter\\CreateResourceValueConfigRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CreateResourceValueConfigRequest.php',
    'Google\\Service\\SecurityCommandCenter\\CustomModuleValidationError' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CustomModuleValidationError.php',
    'Google\\Service\\SecurityCommandCenter\\CustomModuleValidationErrors' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/CustomModuleValidationErrors.php',
    'Google\\Service\\SecurityCommandCenter\\Cve' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Cve.php',
    'Google\\Service\\SecurityCommandCenter\\Cvssv3' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Cvssv3.php',
    'Google\\Service\\SecurityCommandCenter\\DataAccessEvent' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/DataAccessEvent.php',
    'Google\\Service\\SecurityCommandCenter\\DataFlowEvent' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/DataFlowEvent.php',
    'Google\\Service\\SecurityCommandCenter\\Database' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Database.php',
    'Google\\Service\\SecurityCommandCenter\\Detection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Detection.php',
    'Google\\Service\\SecurityCommandCenter\\DiskPath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/DiskPath.php',
    'Google\\Service\\SecurityCommandCenter\\DynamicMuteRecord' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/DynamicMuteRecord.php',
    'Google\\Service\\SecurityCommandCenter\\Edge' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Edge.php',
    'Google\\Service\\SecurityCommandCenter\\EffectiveEventThreatDetectionCustomModule' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/EffectiveEventThreatDetectionCustomModule.php',
    'Google\\Service\\SecurityCommandCenter\\EnvironmentVariable' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/EnvironmentVariable.php',
    'Google\\Service\\SecurityCommandCenter\\EventThreatDetectionCustomModule' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/EventThreatDetectionCustomModule.php',
    'Google\\Service\\SecurityCommandCenter\\ExfilResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ExfilResource.php',
    'Google\\Service\\SecurityCommandCenter\\Exfiltration' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Exfiltration.php',
    'Google\\Service\\SecurityCommandCenter\\Expr' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Expr.php',
    'Google\\Service\\SecurityCommandCenter\\Finding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Finding.php',
    'Google\\Service\\SecurityCommandCenter\\Folder' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Folder.php',
    'Google\\Service\\SecurityCommandCenter\\GcpMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GcpMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\Geolocation' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Geolocation.php',
    'Google\\Service\\SecurityCommandCenter\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GetIamPolicyRequest.php',
    'Google\\Service\\SecurityCommandCenter\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GetPolicyOptions.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1BigQueryExport' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1BigQueryExport.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1Binding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1Binding.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1BulkMuteFindingsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1BulkMuteFindingsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1CustomConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1CustomConfig.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1CustomOutputSpec' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1CustomOutputSpec.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1ExposedResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1ExposedResource.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1ExposurePath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1ExposurePath.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1ExternalSystem' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1ExternalSystem.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1MuteConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1MuteConfig.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1NotificationMessage' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1NotificationMessage.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1Property' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1Property.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1Resource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1Resource.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1ResourceSelector' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1ResourceSelector.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1ResourceValueConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1ResourceValueConfig.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1RunAssetDiscoveryResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1RunAssetDiscoveryResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1Finding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1Finding.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1Folder' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1Folder.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1NotificationMessage' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1NotificationMessage.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1Resource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1Resource.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1RunAssetDiscoveryResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1RunAssetDiscoveryResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV1p1beta1SecurityMarks' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV1p1beta1SecurityMarks.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Access' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Access.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AccessReview' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AccessReview.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AdaptiveProtection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AdaptiveProtection.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Application' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Application.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Attack' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Attack.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AttackExposure' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AttackExposure.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AwsAccount' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AwsAccount.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AwsMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AwsMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AwsOrganization' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AwsOrganization.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AwsOrganizationalUnit' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AwsOrganizationalUnit.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AzureManagementGroup' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AzureManagementGroup.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AzureMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AzureMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AzureResourceGroup' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AzureResourceGroup.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AzureSubscription' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AzureSubscription.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2AzureTenant' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2AzureTenant.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2BackupDisasterRecovery' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2BackupDisasterRecovery.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2BigQueryExport' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2BigQueryExport.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Binding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Binding.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2BulkMuteFindingsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2BulkMuteFindingsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2CloudArmor' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2CloudArmor.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2CloudDlpDataProfile' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2CloudDlpDataProfile.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2CloudDlpInspection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2CloudDlpInspection.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2CloudLoggingEntry' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2CloudLoggingEntry.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Compliance' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Compliance.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Connection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Connection.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Contact' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Contact.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ContactDetails' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ContactDetails.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Container' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Container.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Cve' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Cve.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Cvssv3' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Cvssv3.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2DataAccessEvent' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2DataAccessEvent.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2DataFlowEvent' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2DataFlowEvent.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Database' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Database.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Detection' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Detection.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2DiskPath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2DiskPath.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2DynamicMuteRecord' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2DynamicMuteRecord.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2EnvironmentVariable' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2EnvironmentVariable.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ExfilResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ExfilResource.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Exfiltration' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Exfiltration.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ExternalSystem' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ExternalSystem.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2File' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2File.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Finding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Finding.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Folder' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Folder.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Geolocation' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Geolocation.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2GroupMembership' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2GroupMembership.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2IamBinding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2IamBinding.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Indicator' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Indicator.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2KernelRootkit' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2KernelRootkit.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Kubernetes' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Kubernetes.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Label' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Label.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2LoadBalancer' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2LoadBalancer.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2LogEntry' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2LogEntry.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2MemoryHashSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2MemoryHashSignature.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2MitreAttack' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2MitreAttack.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2MuteConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2MuteConfig.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2MuteInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2MuteInfo.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Node' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Node.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2NodePool' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2NodePool.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Notebook' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Notebook.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2NotificationMessage' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2NotificationMessage.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Object' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Object.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2OrgPolicy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2OrgPolicy.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Package' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Package.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Pod' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Pod.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2PolicyDriftDetails' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2PolicyDriftDetails.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Process' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Process.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ProcessSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ProcessSignature.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Reference' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Reference.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Requests' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Requests.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Resource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Resource.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ResourcePath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ResourcePath.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ResourcePathNode' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ResourcePathNode.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ResourceValueConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ResourceValueConfig.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Role' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Role.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2SecurityBulletin' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2SecurityBulletin.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2SecurityMarks' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2SecurityMarks.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2SecurityPolicy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2SecurityPolicy.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2SecurityPosture' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2SecurityPosture.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2StaticMute' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2StaticMute.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Subject' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Subject.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2TicketInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2TicketInfo.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2ToxicCombination' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2ToxicCombination.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2Vulnerability' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2Vulnerability.php',
    'Google\\Service\\SecurityCommandCenter\\GoogleCloudSecuritycenterV2YaraRuleSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GoogleCloudSecuritycenterV2YaraRuleSignature.php',
    'Google\\Service\\SecurityCommandCenter\\GroupAssetsRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupAssetsRequest.php',
    'Google\\Service\\SecurityCommandCenter\\GroupAssetsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupAssetsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GroupFindingsRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupFindingsRequest.php',
    'Google\\Service\\SecurityCommandCenter\\GroupFindingsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupFindingsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\GroupMembership' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupMembership.php',
    'Google\\Service\\SecurityCommandCenter\\GroupResult' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/GroupResult.php',
    'Google\\Service\\SecurityCommandCenter\\IamBinding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/IamBinding.php',
    'Google\\Service\\SecurityCommandCenter\\IamPolicy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/IamPolicy.php',
    'Google\\Service\\SecurityCommandCenter\\Indicator' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Indicator.php',
    'Google\\Service\\SecurityCommandCenter\\KernelRootkit' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/KernelRootkit.php',
    'Google\\Service\\SecurityCommandCenter\\Kubernetes' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Kubernetes.php',
    'Google\\Service\\SecurityCommandCenter\\Label' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Label.php',
    'Google\\Service\\SecurityCommandCenter\\ListAssetsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListAssetsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListAssetsResult' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListAssetsResult.php',
    'Google\\Service\\SecurityCommandCenter\\ListAttackPathsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListAttackPathsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListBigQueryExportsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListBigQueryExportsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListDescendantEventThreatDetectionCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListDescendantEventThreatDetectionCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListDescendantSecurityHealthAnalyticsCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListDescendantSecurityHealthAnalyticsCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListEffectiveEventThreatDetectionCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListEffectiveEventThreatDetectionCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListEffectiveSecurityHealthAnalyticsCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListEffectiveSecurityHealthAnalyticsCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListEventThreatDetectionCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListEventThreatDetectionCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListFindingsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListFindingsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListFindingsResult' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListFindingsResult.php',
    'Google\\Service\\SecurityCommandCenter\\ListMuteConfigsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListMuteConfigsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListNotificationConfigsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListNotificationConfigsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListOperationsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListResourceValueConfigsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListResourceValueConfigsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListSecurityHealthAnalyticsCustomModulesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListSecurityHealthAnalyticsCustomModulesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListSourcesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListSourcesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ListValuedResourcesResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ListValuedResourcesResponse.php',
    'Google\\Service\\SecurityCommandCenter\\LoadBalancer' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/LoadBalancer.php',
    'Google\\Service\\SecurityCommandCenter\\LogEntry' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/LogEntry.php',
    'Google\\Service\\SecurityCommandCenter\\MemoryHashSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/MemoryHashSignature.php',
    'Google\\Service\\SecurityCommandCenter\\MitreAttack' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/MitreAttack.php',
    'Google\\Service\\SecurityCommandCenter\\MuteInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/MuteInfo.php',
    'Google\\Service\\SecurityCommandCenter\\Node' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Node.php',
    'Google\\Service\\SecurityCommandCenter\\NodePool' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/NodePool.php',
    'Google\\Service\\SecurityCommandCenter\\Notebook' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Notebook.php',
    'Google\\Service\\SecurityCommandCenter\\NotificationConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/NotificationConfig.php',
    'Google\\Service\\SecurityCommandCenter\\Operation' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Operation.php',
    'Google\\Service\\SecurityCommandCenter\\OrgPolicy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/OrgPolicy.php',
    'Google\\Service\\SecurityCommandCenter\\OrganizationSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/OrganizationSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Package' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Package.php',
    'Google\\Service\\SecurityCommandCenter\\PathNode' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/PathNode.php',
    'Google\\Service\\SecurityCommandCenter\\PathNodeAssociatedFinding' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/PathNodeAssociatedFinding.php',
    'Google\\Service\\SecurityCommandCenter\\Pod' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Pod.php',
    'Google\\Service\\SecurityCommandCenter\\Policy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Policy.php',
    'Google\\Service\\SecurityCommandCenter\\PolicyDriftDetails' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/PolicyDriftDetails.php',
    'Google\\Service\\SecurityCommandCenter\\Position' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Position.php',
    'Google\\Service\\SecurityCommandCenter\\Process' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Process.php',
    'Google\\Service\\SecurityCommandCenter\\ProcessSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ProcessSignature.php',
    'Google\\Service\\SecurityCommandCenter\\Reference' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Reference.php',
    'Google\\Service\\SecurityCommandCenter\\Requests' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Requests.php',
    'Google\\Service\\SecurityCommandCenter\\ResourcePath' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ResourcePath.php',
    'Google\\Service\\SecurityCommandCenter\\ResourcePathNode' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ResourcePathNode.php',
    'Google\\Service\\SecurityCommandCenter\\ResourceValueConfigMetadata' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ResourceValueConfigMetadata.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/Folders.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersAssets' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersAssets.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersBigQueryExports' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersBigQueryExports.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersEventThreatDetectionSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersEventThreatDetectionSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersEventThreatDetectionSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersEventThreatDetectionSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersEventThreatDetectionSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersEventThreatDetectionSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersLocations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersLocations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersLocationsMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersLocationsMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersNotificationConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersNotificationConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSecurityHealthAnalyticsSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSecurityHealthAnalyticsSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSecurityHealthAnalyticsSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSecurityHealthAnalyticsSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSecurityHealthAnalyticsSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSecurityHealthAnalyticsSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSourcesFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSourcesFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\FoldersSourcesFindingsExternalSystems' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/FoldersSourcesFindingsExternalSystems.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\Organizations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/Organizations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsAssets' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsAssets.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsBigQueryExports' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsBigQueryExports.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsEventThreatDetectionSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsEventThreatDetectionSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsEventThreatDetectionSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsEventThreatDetectionSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsEventThreatDetectionSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsEventThreatDetectionSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsLocations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsLocations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsLocationsMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsLocationsMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsNotificationConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsNotificationConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsOperations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsOperations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsResourceValueConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsResourceValueConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSecurityHealthAnalyticsSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSecurityHealthAnalyticsSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSecurityHealthAnalyticsSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSecurityHealthAnalyticsSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSecurityHealthAnalyticsSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSecurityHealthAnalyticsSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsAttackExposureResults' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsAttackExposureResults.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsAttackExposureResultsAttackPaths' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsAttackExposureResultsAttackPaths.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsAttackExposureResultsValuedResources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsAttackExposureResultsValuedResources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsAttackPaths' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsAttackPaths.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsValuedResources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsValuedResources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSimulationsValuedResourcesAttackPaths' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSimulationsValuedResourcesAttackPaths.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSourcesFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSourcesFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsSourcesFindingsExternalSystems' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsSourcesFindingsExternalSystems.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\OrganizationsValuedResources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/OrganizationsValuedResources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/Projects.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsAssets' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsAssets.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsBigQueryExports' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsBigQueryExports.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsEventThreatDetectionSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsEventThreatDetectionSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsEventThreatDetectionSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsEventThreatDetectionSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsEventThreatDetectionSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsEventThreatDetectionSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsLocations.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsLocationsMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsLocationsMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsMuteConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsMuteConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsNotificationConfigs' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsNotificationConfigs.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSecurityHealthAnalyticsSettings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSecurityHealthAnalyticsSettings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSecurityHealthAnalyticsSettingsCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSecurityHealthAnalyticsSettingsCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSecurityHealthAnalyticsSettingsEffectiveCustomModules' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSecurityHealthAnalyticsSettingsEffectiveCustomModules.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSources' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSources.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSourcesFindings' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSourcesFindings.php',
    'Google\\Service\\SecurityCommandCenter\\Resource\\ProjectsSourcesFindingsExternalSystems' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Resource/ProjectsSourcesFindingsExternalSystems.php',
    'Google\\Service\\SecurityCommandCenter\\Role' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Role.php',
    'Google\\Service\\SecurityCommandCenter\\RunAssetDiscoveryRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/RunAssetDiscoveryRequest.php',
    'Google\\Service\\SecurityCommandCenter\\SecurityBulletin' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecurityBulletin.php',
    'Google\\Service\\SecurityCommandCenter\\SecurityCenterProperties' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecurityCenterProperties.php',
    'Google\\Service\\SecurityCommandCenter\\SecurityMarks' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecurityMarks.php',
    'Google\\Service\\SecurityCommandCenter\\SecurityPolicy' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecurityPolicy.php',
    'Google\\Service\\SecurityCommandCenter\\SecurityPosture' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecurityPosture.php',
    'Google\\Service\\SecurityCommandCenter\\SecuritycenterEmpty' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecuritycenterEmpty.php',
    'Google\\Service\\SecurityCommandCenter\\SecuritycenterFile' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecuritycenterFile.php',
    'Google\\Service\\SecurityCommandCenter\\SecuritycenterObject' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecuritycenterObject.php',
    'Google\\Service\\SecurityCommandCenter\\SecuritycenterResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SecuritycenterResource.php',
    'Google\\Service\\SecurityCommandCenter\\ServiceAccountDelegationInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ServiceAccountDelegationInfo.php',
    'Google\\Service\\SecurityCommandCenter\\SetFindingStateRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SetFindingStateRequest.php',
    'Google\\Service\\SecurityCommandCenter\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SetIamPolicyRequest.php',
    'Google\\Service\\SecurityCommandCenter\\SetMuteRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SetMuteRequest.php',
    'Google\\Service\\SecurityCommandCenter\\SimulateSecurityHealthAnalyticsCustomModuleRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SimulateSecurityHealthAnalyticsCustomModuleRequest.php',
    'Google\\Service\\SecurityCommandCenter\\SimulateSecurityHealthAnalyticsCustomModuleResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SimulateSecurityHealthAnalyticsCustomModuleResponse.php',
    'Google\\Service\\SecurityCommandCenter\\SimulatedResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SimulatedResource.php',
    'Google\\Service\\SecurityCommandCenter\\SimulatedResult' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/SimulatedResult.php',
    'Google\\Service\\SecurityCommandCenter\\Simulation' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Simulation.php',
    'Google\\Service\\SecurityCommandCenter\\Source' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Source.php',
    'Google\\Service\\SecurityCommandCenter\\StaticMute' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/StaticMute.php',
    'Google\\Service\\SecurityCommandCenter\\Status' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Status.php',
    'Google\\Service\\SecurityCommandCenter\\StreamingConfig' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/StreamingConfig.php',
    'Google\\Service\\SecurityCommandCenter\\Subject' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Subject.php',
    'Google\\Service\\SecurityCommandCenter\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/TestIamPermissionsRequest.php',
    'Google\\Service\\SecurityCommandCenter\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/TestIamPermissionsResponse.php',
    'Google\\Service\\SecurityCommandCenter\\TicketInfo' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/TicketInfo.php',
    'Google\\Service\\SecurityCommandCenter\\ToxicCombination' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ToxicCombination.php',
    'Google\\Service\\SecurityCommandCenter\\ValidateEventThreatDetectionCustomModuleRequest' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ValidateEventThreatDetectionCustomModuleRequest.php',
    'Google\\Service\\SecurityCommandCenter\\ValidateEventThreatDetectionCustomModuleResponse' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ValidateEventThreatDetectionCustomModuleResponse.php',
    'Google\\Service\\SecurityCommandCenter\\ValuedResource' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/ValuedResource.php',
    'Google\\Service\\SecurityCommandCenter\\Vulnerability' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/Vulnerability.php',
    'Google\\Service\\SecurityCommandCenter\\VulnerabilityCountBySeverity' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/VulnerabilityCountBySeverity.php',
    'Google\\Service\\SecurityCommandCenter\\VulnerabilitySnapshot' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/VulnerabilitySnapshot.php',
    'Google\\Service\\SecurityCommandCenter\\YaraRuleSignature' => $vendorDir . '/google/apiclient-services/src/SecurityCommandCenter/YaraRuleSignature.php',
    'Google\\Service\\SemanticTile' => $vendorDir . '/google/apiclient-services/src/SemanticTile.php',
    'Google\\Service\\SemanticTile\\Area' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Area.php',
    'Google\\Service\\SemanticTile\\BasemapZOrder' => $vendorDir . '/google/apiclient-services/src/SemanticTile/BasemapZOrder.php',
    'Google\\Service\\SemanticTile\\ExtrudedArea' => $vendorDir . '/google/apiclient-services/src/SemanticTile/ExtrudedArea.php',
    'Google\\Service\\SemanticTile\\Feature' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Feature.php',
    'Google\\Service\\SemanticTile\\FeatureTile' => $vendorDir . '/google/apiclient-services/src/SemanticTile/FeatureTile.php',
    'Google\\Service\\SemanticTile\\FirstDerivativeElevationGrid' => $vendorDir . '/google/apiclient-services/src/SemanticTile/FirstDerivativeElevationGrid.php',
    'Google\\Service\\SemanticTile\\Geometry' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Geometry.php',
    'Google\\Service\\SemanticTile\\Line' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Line.php',
    'Google\\Service\\SemanticTile\\ModeledVolume' => $vendorDir . '/google/apiclient-services/src/SemanticTile/ModeledVolume.php',
    'Google\\Service\\SemanticTile\\ProviderInfo' => $vendorDir . '/google/apiclient-services/src/SemanticTile/ProviderInfo.php',
    'Google\\Service\\SemanticTile\\Relation' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Relation.php',
    'Google\\Service\\SemanticTile\\Resource\\Featuretiles' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Resource/Featuretiles.php',
    'Google\\Service\\SemanticTile\\Resource\\Terraintiles' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Resource/Terraintiles.php',
    'Google\\Service\\SemanticTile\\RoadInfo' => $vendorDir . '/google/apiclient-services/src/SemanticTile/RoadInfo.php',
    'Google\\Service\\SemanticTile\\Row' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Row.php',
    'Google\\Service\\SemanticTile\\SecondDerivativeElevationGrid' => $vendorDir . '/google/apiclient-services/src/SemanticTile/SecondDerivativeElevationGrid.php',
    'Google\\Service\\SemanticTile\\SegmentInfo' => $vendorDir . '/google/apiclient-services/src/SemanticTile/SegmentInfo.php',
    'Google\\Service\\SemanticTile\\TerrainTile' => $vendorDir . '/google/apiclient-services/src/SemanticTile/TerrainTile.php',
    'Google\\Service\\SemanticTile\\TileCoordinates' => $vendorDir . '/google/apiclient-services/src/SemanticTile/TileCoordinates.php',
    'Google\\Service\\SemanticTile\\TriangleStrip' => $vendorDir . '/google/apiclient-services/src/SemanticTile/TriangleStrip.php',
    'Google\\Service\\SemanticTile\\Vertex2DList' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Vertex2DList.php',
    'Google\\Service\\SemanticTile\\Vertex3DList' => $vendorDir . '/google/apiclient-services/src/SemanticTile/Vertex3DList.php',
    'Google\\Service\\ServerlessVPCAccess' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess.php',
    'Google\\Service\\ServerlessVPCAccess\\Connector' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Connector.php',
    'Google\\Service\\ServerlessVPCAccess\\ListConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/ListConnectorsResponse.php',
    'Google\\Service\\ServerlessVPCAccess\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/ListLocationsResponse.php',
    'Google\\Service\\ServerlessVPCAccess\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/ListOperationsResponse.php',
    'Google\\Service\\ServerlessVPCAccess\\Location' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Location.php',
    'Google\\Service\\ServerlessVPCAccess\\Operation' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Operation.php',
    'Google\\Service\\ServerlessVPCAccess\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/OperationMetadata.php',
    'Google\\Service\\ServerlessVPCAccess\\OperationMetadataV1Alpha1' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/OperationMetadataV1Alpha1.php',
    'Google\\Service\\ServerlessVPCAccess\\OperationMetadataV1Beta1' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/OperationMetadataV1Beta1.php',
    'Google\\Service\\ServerlessVPCAccess\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Resource/Projects.php',
    'Google\\Service\\ServerlessVPCAccess\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Resource/ProjectsLocations.php',
    'Google\\Service\\ServerlessVPCAccess\\Resource\\ProjectsLocationsConnectors' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Resource/ProjectsLocationsConnectors.php',
    'Google\\Service\\ServerlessVPCAccess\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\ServerlessVPCAccess\\Status' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Status.php',
    'Google\\Service\\ServerlessVPCAccess\\Subnet' => $vendorDir . '/google/apiclient-services/src/ServerlessVPCAccess/Subnet.php',
    'Google\\Service\\ServiceConsumerManagement' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement.php',
    'Google\\Service\\ServiceConsumerManagement\\AddTenantProjectRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/AddTenantProjectRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\Api' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Api.php',
    'Google\\Service\\ServiceConsumerManagement\\ApplyTenantProjectConfigRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ApplyTenantProjectConfigRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\AttachTenantProjectRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/AttachTenantProjectRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\AuthProvider' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/AuthProvider.php',
    'Google\\Service\\ServiceConsumerManagement\\AuthRequirement' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/AuthRequirement.php',
    'Google\\Service\\ServiceConsumerManagement\\Authentication' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Authentication.php',
    'Google\\Service\\ServiceConsumerManagement\\AuthenticationRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/AuthenticationRule.php',
    'Google\\Service\\ServiceConsumerManagement\\Backend' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Backend.php',
    'Google\\Service\\ServiceConsumerManagement\\BackendRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/BackendRule.php',
    'Google\\Service\\ServiceConsumerManagement\\Billing' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Billing.php',
    'Google\\Service\\ServiceConsumerManagement\\BillingConfig' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/BillingConfig.php',
    'Google\\Service\\ServiceConsumerManagement\\BillingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/BillingDestination.php',
    'Google\\Service\\ServiceConsumerManagement\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CancelOperationRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\ClientLibrarySettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ClientLibrarySettings.php',
    'Google\\Service\\ServiceConsumerManagement\\CommonLanguageSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CommonLanguageSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\Context' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Context.php',
    'Google\\Service\\ServiceConsumerManagement\\ContextRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ContextRule.php',
    'Google\\Service\\ServiceConsumerManagement\\Control' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Control.php',
    'Google\\Service\\ServiceConsumerManagement\\CppSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CppSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\CreateTenancyUnitRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CreateTenancyUnitRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\CustomError' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CustomError.php',
    'Google\\Service\\ServiceConsumerManagement\\CustomErrorRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CustomErrorRule.php',
    'Google\\Service\\ServiceConsumerManagement\\CustomHttpPattern' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/CustomHttpPattern.php',
    'Google\\Service\\ServiceConsumerManagement\\DeleteTenantProjectRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/DeleteTenantProjectRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\Documentation' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Documentation.php',
    'Google\\Service\\ServiceConsumerManagement\\DocumentationRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/DocumentationRule.php',
    'Google\\Service\\ServiceConsumerManagement\\DotnetSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/DotnetSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\Endpoint' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Endpoint.php',
    'Google\\Service\\ServiceConsumerManagement\\Enum' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Enum.php',
    'Google\\Service\\ServiceConsumerManagement\\EnumValue' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/EnumValue.php',
    'Google\\Service\\ServiceConsumerManagement\\Field' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Field.php',
    'Google\\Service\\ServiceConsumerManagement\\FieldPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/FieldPolicy.php',
    'Google\\Service\\ServiceConsumerManagement\\GoSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/GoSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\Http' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Http.php',
    'Google\\Service\\ServiceConsumerManagement\\HttpRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/HttpRule.php',
    'Google\\Service\\ServiceConsumerManagement\\JavaSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/JavaSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\JwtLocation' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/JwtLocation.php',
    'Google\\Service\\ServiceConsumerManagement\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/LabelDescriptor.php',
    'Google\\Service\\ServiceConsumerManagement\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ListOperationsResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\ListTenancyUnitsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ListTenancyUnitsResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\LogDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/LogDescriptor.php',
    'Google\\Service\\ServiceConsumerManagement\\Logging' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Logging.php',
    'Google\\Service\\ServiceConsumerManagement\\LoggingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/LoggingDestination.php',
    'Google\\Service\\ServiceConsumerManagement\\LongRunning' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/LongRunning.php',
    'Google\\Service\\ServiceConsumerManagement\\Method' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Method.php',
    'Google\\Service\\ServiceConsumerManagement\\MethodPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MethodPolicy.php',
    'Google\\Service\\ServiceConsumerManagement\\MethodSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MethodSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MetricDescriptor.php',
    'Google\\Service\\ServiceConsumerManagement\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MetricDescriptorMetadata.php',
    'Google\\Service\\ServiceConsumerManagement\\MetricRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MetricRule.php',
    'Google\\Service\\ServiceConsumerManagement\\Mixin' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Mixin.php',
    'Google\\Service\\ServiceConsumerManagement\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MonitoredResourceDescriptor.php',
    'Google\\Service\\ServiceConsumerManagement\\Monitoring' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Monitoring.php',
    'Google\\Service\\ServiceConsumerManagement\\MonitoringDestination' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/MonitoringDestination.php',
    'Google\\Service\\ServiceConsumerManagement\\NodeSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/NodeSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\OAuthRequirements' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/OAuthRequirements.php',
    'Google\\Service\\ServiceConsumerManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Operation.php',
    'Google\\Service\\ServiceConsumerManagement\\Option' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Option.php',
    'Google\\Service\\ServiceConsumerManagement\\Page' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Page.php',
    'Google\\Service\\ServiceConsumerManagement\\PhpSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/PhpSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\PolicyBinding' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/PolicyBinding.php',
    'Google\\Service\\ServiceConsumerManagement\\Publishing' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Publishing.php',
    'Google\\Service\\ServiceConsumerManagement\\PythonSettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/PythonSettings.php',
    'Google\\Service\\ServiceConsumerManagement\\Quota' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Quota.php',
    'Google\\Service\\ServiceConsumerManagement\\QuotaLimit' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/QuotaLimit.php',
    'Google\\Service\\ServiceConsumerManagement\\RemoveTenantProjectRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/RemoveTenantProjectRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Resource/Operations.php',
    'Google\\Service\\ServiceConsumerManagement\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Resource/Services.php',
    'Google\\Service\\ServiceConsumerManagement\\Resource\\ServicesTenancyUnits' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Resource/ServicesTenancyUnits.php',
    'Google\\Service\\ServiceConsumerManagement\\RubySettings' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/RubySettings.php',
    'Google\\Service\\ServiceConsumerManagement\\SearchTenancyUnitsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SearchTenancyUnitsResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\Service' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Service.php',
    'Google\\Service\\ServiceConsumerManagement\\ServiceAccountConfig' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ServiceAccountConfig.php',
    'Google\\Service\\ServiceConsumerManagement\\ServiceconsumermanagementEmpty' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/ServiceconsumermanagementEmpty.php',
    'Google\\Service\\ServiceConsumerManagement\\SourceContext' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SourceContext.php',
    'Google\\Service\\ServiceConsumerManagement\\SourceInfo' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SourceInfo.php',
    'Google\\Service\\ServiceConsumerManagement\\Status' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Status.php',
    'Google\\Service\\ServiceConsumerManagement\\SystemParameter' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SystemParameter.php',
    'Google\\Service\\ServiceConsumerManagement\\SystemParameterRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SystemParameterRule.php',
    'Google\\Service\\ServiceConsumerManagement\\SystemParameters' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/SystemParameters.php',
    'Google\\Service\\ServiceConsumerManagement\\TenancyUnit' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/TenancyUnit.php',
    'Google\\Service\\ServiceConsumerManagement\\TenantProjectConfig' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/TenantProjectConfig.php',
    'Google\\Service\\ServiceConsumerManagement\\TenantProjectPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/TenantProjectPolicy.php',
    'Google\\Service\\ServiceConsumerManagement\\TenantResource' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/TenantResource.php',
    'Google\\Service\\ServiceConsumerManagement\\Type' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Type.php',
    'Google\\Service\\ServiceConsumerManagement\\UndeleteTenantProjectRequest' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/UndeleteTenantProjectRequest.php',
    'Google\\Service\\ServiceConsumerManagement\\Usage' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/Usage.php',
    'Google\\Service\\ServiceConsumerManagement\\UsageRule' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/UsageRule.php',
    'Google\\Service\\ServiceConsumerManagement\\V1AddVisibilityLabelsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1AddVisibilityLabelsResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1BatchCreateProducerOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1BatchCreateProducerOverridesResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1DisableConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1DisableConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1EnableConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1EnableConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1GenerateServiceIdentityResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1GenerateServiceIdentityResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1ImportProducerOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1ImportProducerOverridesResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1ImportProducerQuotaPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1ImportProducerQuotaPoliciesResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1ProducerQuotaPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1ProducerQuotaPolicy.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1QuotaOverride' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1QuotaOverride.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1RefreshConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1RefreshConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1Beta1ServiceIdentity' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1Beta1ServiceIdentity.php',
    'Google\\Service\\ServiceConsumerManagement\\V1DefaultIdentity' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1DefaultIdentity.php',
    'Google\\Service\\ServiceConsumerManagement\\V1DisableConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1DisableConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1EnableConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1EnableConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1GenerateDefaultIdentityResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1GenerateDefaultIdentityResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1GenerateServiceAccountResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1GenerateServiceAccountResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1RefreshConsumerResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1RefreshConsumerResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1RemoveVisibilityLabelsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1RemoveVisibilityLabelsResponse.php',
    'Google\\Service\\ServiceConsumerManagement\\V1ServiceAccount' => $vendorDir . '/google/apiclient-services/src/ServiceConsumerManagement/V1ServiceAccount.php',
    'Google\\Service\\ServiceControl' => $vendorDir . '/google/apiclient-services/src/ServiceControl.php',
    'Google\\Service\\ServiceControl\\Api' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Api.php',
    'Google\\Service\\ServiceControl\\AttributeContext' => $vendorDir . '/google/apiclient-services/src/ServiceControl/AttributeContext.php',
    'Google\\Service\\ServiceControl\\AuditLog' => $vendorDir . '/google/apiclient-services/src/ServiceControl/AuditLog.php',
    'Google\\Service\\ServiceControl\\Auth' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Auth.php',
    'Google\\Service\\ServiceControl\\AuthenticationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/AuthenticationInfo.php',
    'Google\\Service\\ServiceControl\\AuthorizationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/AuthorizationInfo.php',
    'Google\\Service\\ServiceControl\\CheckRequest' => $vendorDir . '/google/apiclient-services/src/ServiceControl/CheckRequest.php',
    'Google\\Service\\ServiceControl\\CheckResponse' => $vendorDir . '/google/apiclient-services/src/ServiceControl/CheckResponse.php',
    'Google\\Service\\ServiceControl\\EsfMigrationServerOverride' => $vendorDir . '/google/apiclient-services/src/ServiceControl/EsfMigrationServerOverride.php',
    'Google\\Service\\ServiceControl\\FirstPartyPrincipal' => $vendorDir . '/google/apiclient-services/src/ServiceControl/FirstPartyPrincipal.php',
    'Google\\Service\\ServiceControl\\OrgPolicyViolationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/OrgPolicyViolationInfo.php',
    'Google\\Service\\ServiceControl\\Peer' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Peer.php',
    'Google\\Service\\ServiceControl\\PolicyViolationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/PolicyViolationInfo.php',
    'Google\\Service\\ServiceControl\\ReportRequest' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ReportRequest.php',
    'Google\\Service\\ServiceControl\\ReportResponse' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ReportResponse.php',
    'Google\\Service\\ServiceControl\\Request' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Request.php',
    'Google\\Service\\ServiceControl\\RequestMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceControl/RequestMetadata.php',
    'Google\\Service\\ServiceControl\\ResourceInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ResourceInfo.php',
    'Google\\Service\\ServiceControl\\ResourceLocation' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ResourceLocation.php',
    'Google\\Service\\ServiceControl\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Resource/Services.php',
    'Google\\Service\\ServiceControl\\Response' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Response.php',
    'Google\\Service\\ServiceControl\\ServiceAccountDelegationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ServiceAccountDelegationInfo.php',
    'Google\\Service\\ServiceControl\\ServiceDelegationHistory' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ServiceDelegationHistory.php',
    'Google\\Service\\ServiceControl\\ServiceMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ServiceMetadata.php',
    'Google\\Service\\ServiceControl\\ServicecontrolResource' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ServicecontrolResource.php',
    'Google\\Service\\ServiceControl\\SpanContext' => $vendorDir . '/google/apiclient-services/src/ServiceControl/SpanContext.php',
    'Google\\Service\\ServiceControl\\Status' => $vendorDir . '/google/apiclient-services/src/ServiceControl/Status.php',
    'Google\\Service\\ServiceControl\\ThirdPartyPrincipal' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ThirdPartyPrincipal.php',
    'Google\\Service\\ServiceControl\\V2HttpRequest' => $vendorDir . '/google/apiclient-services/src/ServiceControl/V2HttpRequest.php',
    'Google\\Service\\ServiceControl\\V2LogEntry' => $vendorDir . '/google/apiclient-services/src/ServiceControl/V2LogEntry.php',
    'Google\\Service\\ServiceControl\\V2LogEntryOperation' => $vendorDir . '/google/apiclient-services/src/ServiceControl/V2LogEntryOperation.php',
    'Google\\Service\\ServiceControl\\V2LogEntrySourceLocation' => $vendorDir . '/google/apiclient-services/src/ServiceControl/V2LogEntrySourceLocation.php',
    'Google\\Service\\ServiceControl\\V2ResourceEvent' => $vendorDir . '/google/apiclient-services/src/ServiceControl/V2ResourceEvent.php',
    'Google\\Service\\ServiceControl\\ViolationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceControl/ViolationInfo.php',
    'Google\\Service\\ServiceDirectory' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory.php',
    'Google\\Service\\ServiceDirectory\\Binding' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Binding.php',
    'Google\\Service\\ServiceDirectory\\Endpoint' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Endpoint.php',
    'Google\\Service\\ServiceDirectory\\Expr' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Expr.php',
    'Google\\Service\\ServiceDirectory\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/GetIamPolicyRequest.php',
    'Google\\Service\\ServiceDirectory\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/GetPolicyOptions.php',
    'Google\\Service\\ServiceDirectory\\ListEndpointsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ListEndpointsResponse.php',
    'Google\\Service\\ServiceDirectory\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ListLocationsResponse.php',
    'Google\\Service\\ServiceDirectory\\ListNamespacesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ListNamespacesResponse.php',
    'Google\\Service\\ServiceDirectory\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ListServicesResponse.php',
    'Google\\Service\\ServiceDirectory\\Location' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Location.php',
    'Google\\Service\\ServiceDirectory\\Policy' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Policy.php',
    'Google\\Service\\ServiceDirectory\\ResolveServiceRequest' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ResolveServiceRequest.php',
    'Google\\Service\\ServiceDirectory\\ResolveServiceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ResolveServiceResponse.php',
    'Google\\Service\\ServiceDirectory\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Resource/Projects.php',
    'Google\\Service\\ServiceDirectory\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Resource/ProjectsLocations.php',
    'Google\\Service\\ServiceDirectory\\Resource\\ProjectsLocationsNamespaces' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Resource/ProjectsLocationsNamespaces.php',
    'Google\\Service\\ServiceDirectory\\Resource\\ProjectsLocationsNamespacesServices' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Resource/ProjectsLocationsNamespacesServices.php',
    'Google\\Service\\ServiceDirectory\\Resource\\ProjectsLocationsNamespacesServicesEndpoints' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Resource/ProjectsLocationsNamespacesServicesEndpoints.php',
    'Google\\Service\\ServiceDirectory\\Service' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/Service.php',
    'Google\\Service\\ServiceDirectory\\ServicedirectoryEmpty' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ServicedirectoryEmpty.php',
    'Google\\Service\\ServiceDirectory\\ServicedirectoryNamespace' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/ServicedirectoryNamespace.php',
    'Google\\Service\\ServiceDirectory\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/SetIamPolicyRequest.php',
    'Google\\Service\\ServiceDirectory\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/TestIamPermissionsRequest.php',
    'Google\\Service\\ServiceDirectory\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceDirectory/TestIamPermissionsResponse.php',
    'Google\\Service\\ServiceManagement' => $vendorDir . '/google/apiclient-services/src/ServiceManagement.php',
    'Google\\Service\\ServiceManagement\\Advice' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Advice.php',
    'Google\\Service\\ServiceManagement\\Api' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Api.php',
    'Google\\Service\\ServiceManagement\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/AuditConfig.php',
    'Google\\Service\\ServiceManagement\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/AuditLogConfig.php',
    'Google\\Service\\ServiceManagement\\AuthProvider' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/AuthProvider.php',
    'Google\\Service\\ServiceManagement\\AuthRequirement' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/AuthRequirement.php',
    'Google\\Service\\ServiceManagement\\Authentication' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Authentication.php',
    'Google\\Service\\ServiceManagement\\AuthenticationRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/AuthenticationRule.php',
    'Google\\Service\\ServiceManagement\\Backend' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Backend.php',
    'Google\\Service\\ServiceManagement\\BackendRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/BackendRule.php',
    'Google\\Service\\ServiceManagement\\Billing' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Billing.php',
    'Google\\Service\\ServiceManagement\\BillingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/BillingDestination.php',
    'Google\\Service\\ServiceManagement\\Binding' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Binding.php',
    'Google\\Service\\ServiceManagement\\ChangeReport' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ChangeReport.php',
    'Google\\Service\\ServiceManagement\\ClientLibrarySettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ClientLibrarySettings.php',
    'Google\\Service\\ServiceManagement\\CommonLanguageSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/CommonLanguageSettings.php',
    'Google\\Service\\ServiceManagement\\ConfigChange' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ConfigChange.php',
    'Google\\Service\\ServiceManagement\\ConfigFile' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ConfigFile.php',
    'Google\\Service\\ServiceManagement\\ConfigRef' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ConfigRef.php',
    'Google\\Service\\ServiceManagement\\ConfigSource' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ConfigSource.php',
    'Google\\Service\\ServiceManagement\\Context' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Context.php',
    'Google\\Service\\ServiceManagement\\ContextRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ContextRule.php',
    'Google\\Service\\ServiceManagement\\Control' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Control.php',
    'Google\\Service\\ServiceManagement\\CppSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/CppSettings.php',
    'Google\\Service\\ServiceManagement\\CustomError' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/CustomError.php',
    'Google\\Service\\ServiceManagement\\CustomErrorRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/CustomErrorRule.php',
    'Google\\Service\\ServiceManagement\\CustomHttpPattern' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/CustomHttpPattern.php',
    'Google\\Service\\ServiceManagement\\DeleteServiceStrategy' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/DeleteServiceStrategy.php',
    'Google\\Service\\ServiceManagement\\Diagnostic' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Diagnostic.php',
    'Google\\Service\\ServiceManagement\\Documentation' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Documentation.php',
    'Google\\Service\\ServiceManagement\\DocumentationRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/DocumentationRule.php',
    'Google\\Service\\ServiceManagement\\DotnetSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/DotnetSettings.php',
    'Google\\Service\\ServiceManagement\\EnableServiceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/EnableServiceResponse.php',
    'Google\\Service\\ServiceManagement\\Endpoint' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Endpoint.php',
    'Google\\Service\\ServiceManagement\\Enum' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Enum.php',
    'Google\\Service\\ServiceManagement\\EnumValue' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/EnumValue.php',
    'Google\\Service\\ServiceManagement\\ExperimentalFeatures' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ExperimentalFeatures.php',
    'Google\\Service\\ServiceManagement\\Expr' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Expr.php',
    'Google\\Service\\ServiceManagement\\Field' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Field.php',
    'Google\\Service\\ServiceManagement\\FieldPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/FieldPolicy.php',
    'Google\\Service\\ServiceManagement\\FlowErrorDetails' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/FlowErrorDetails.php',
    'Google\\Service\\ServiceManagement\\GenerateConfigReportRequest' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/GenerateConfigReportRequest.php',
    'Google\\Service\\ServiceManagement\\GenerateConfigReportResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/GenerateConfigReportResponse.php',
    'Google\\Service\\ServiceManagement\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/GetIamPolicyRequest.php',
    'Google\\Service\\ServiceManagement\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/GetPolicyOptions.php',
    'Google\\Service\\ServiceManagement\\GoSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/GoSettings.php',
    'Google\\Service\\ServiceManagement\\Http' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Http.php',
    'Google\\Service\\ServiceManagement\\HttpRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/HttpRule.php',
    'Google\\Service\\ServiceManagement\\JavaSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/JavaSettings.php',
    'Google\\Service\\ServiceManagement\\JwtLocation' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/JwtLocation.php',
    'Google\\Service\\ServiceManagement\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/LabelDescriptor.php',
    'Google\\Service\\ServiceManagement\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ListOperationsResponse.php',
    'Google\\Service\\ServiceManagement\\ListServiceConfigsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ListServiceConfigsResponse.php',
    'Google\\Service\\ServiceManagement\\ListServiceRolloutsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ListServiceRolloutsResponse.php',
    'Google\\Service\\ServiceManagement\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ListServicesResponse.php',
    'Google\\Service\\ServiceManagement\\LogDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/LogDescriptor.php',
    'Google\\Service\\ServiceManagement\\Logging' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Logging.php',
    'Google\\Service\\ServiceManagement\\LoggingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/LoggingDestination.php',
    'Google\\Service\\ServiceManagement\\LongRunning' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/LongRunning.php',
    'Google\\Service\\ServiceManagement\\ManagedService' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ManagedService.php',
    'Google\\Service\\ServiceManagement\\Method' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Method.php',
    'Google\\Service\\ServiceManagement\\MethodPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MethodPolicy.php',
    'Google\\Service\\ServiceManagement\\MethodSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MethodSettings.php',
    'Google\\Service\\ServiceManagement\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MetricDescriptor.php',
    'Google\\Service\\ServiceManagement\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MetricDescriptorMetadata.php',
    'Google\\Service\\ServiceManagement\\MetricRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MetricRule.php',
    'Google\\Service\\ServiceManagement\\Mixin' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Mixin.php',
    'Google\\Service\\ServiceManagement\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MonitoredResourceDescriptor.php',
    'Google\\Service\\ServiceManagement\\Monitoring' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Monitoring.php',
    'Google\\Service\\ServiceManagement\\MonitoringDestination' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/MonitoringDestination.php',
    'Google\\Service\\ServiceManagement\\NodeSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/NodeSettings.php',
    'Google\\Service\\ServiceManagement\\OAuthRequirements' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/OAuthRequirements.php',
    'Google\\Service\\ServiceManagement\\Operation' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Operation.php',
    'Google\\Service\\ServiceManagement\\OperationInfo' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/OperationInfo.php',
    'Google\\Service\\ServiceManagement\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/OperationMetadata.php',
    'Google\\Service\\ServiceManagement\\Option' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Option.php',
    'Google\\Service\\ServiceManagement\\Page' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Page.php',
    'Google\\Service\\ServiceManagement\\PhpSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/PhpSettings.php',
    'Google\\Service\\ServiceManagement\\Policy' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Policy.php',
    'Google\\Service\\ServiceManagement\\Publishing' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Publishing.php',
    'Google\\Service\\ServiceManagement\\PythonSettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/PythonSettings.php',
    'Google\\Service\\ServiceManagement\\Quota' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Quota.php',
    'Google\\Service\\ServiceManagement\\QuotaLimit' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/QuotaLimit.php',
    'Google\\Service\\ServiceManagement\\ResourceReference' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/ResourceReference.php',
    'Google\\Service\\ServiceManagement\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Resource/Operations.php',
    'Google\\Service\\ServiceManagement\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Resource/Services.php',
    'Google\\Service\\ServiceManagement\\Resource\\ServicesConfigs' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Resource/ServicesConfigs.php',
    'Google\\Service\\ServiceManagement\\Resource\\ServicesConsumers' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Resource/ServicesConsumers.php',
    'Google\\Service\\ServiceManagement\\Resource\\ServicesRollouts' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Resource/ServicesRollouts.php',
    'Google\\Service\\ServiceManagement\\Rollout' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Rollout.php',
    'Google\\Service\\ServiceManagement\\RubySettings' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/RubySettings.php',
    'Google\\Service\\ServiceManagement\\Service' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Service.php',
    'Google\\Service\\ServiceManagement\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SetIamPolicyRequest.php',
    'Google\\Service\\ServiceManagement\\SourceContext' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SourceContext.php',
    'Google\\Service\\ServiceManagement\\SourceInfo' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SourceInfo.php',
    'Google\\Service\\ServiceManagement\\Status' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Status.php',
    'Google\\Service\\ServiceManagement\\Step' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Step.php',
    'Google\\Service\\ServiceManagement\\SubmitConfigSourceRequest' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SubmitConfigSourceRequest.php',
    'Google\\Service\\ServiceManagement\\SubmitConfigSourceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SubmitConfigSourceResponse.php',
    'Google\\Service\\ServiceManagement\\SystemParameter' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SystemParameter.php',
    'Google\\Service\\ServiceManagement\\SystemParameterRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SystemParameterRule.php',
    'Google\\Service\\ServiceManagement\\SystemParameters' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/SystemParameters.php',
    'Google\\Service\\ServiceManagement\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/TestIamPermissionsRequest.php',
    'Google\\Service\\ServiceManagement\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/TestIamPermissionsResponse.php',
    'Google\\Service\\ServiceManagement\\TrafficPercentStrategy' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/TrafficPercentStrategy.php',
    'Google\\Service\\ServiceManagement\\Type' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Type.php',
    'Google\\Service\\ServiceManagement\\UndeleteServiceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/UndeleteServiceResponse.php',
    'Google\\Service\\ServiceManagement\\Usage' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/Usage.php',
    'Google\\Service\\ServiceManagement\\UsageRule' => $vendorDir . '/google/apiclient-services/src/ServiceManagement/UsageRule.php',
    'Google\\Service\\ServiceNetworking' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking.php',
    'Google\\Service\\ServiceNetworking\\AddDnsRecordSetMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddDnsRecordSetMetadata.php',
    'Google\\Service\\ServiceNetworking\\AddDnsRecordSetRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddDnsRecordSetRequest.php',
    'Google\\Service\\ServiceNetworking\\AddDnsZoneMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddDnsZoneMetadata.php',
    'Google\\Service\\ServiceNetworking\\AddDnsZoneRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddDnsZoneRequest.php',
    'Google\\Service\\ServiceNetworking\\AddDnsZoneResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddDnsZoneResponse.php',
    'Google\\Service\\ServiceNetworking\\AddRolesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddRolesMetadata.php',
    'Google\\Service\\ServiceNetworking\\AddRolesRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddRolesRequest.php',
    'Google\\Service\\ServiceNetworking\\AddRolesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddRolesResponse.php',
    'Google\\Service\\ServiceNetworking\\AddSubnetworkRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AddSubnetworkRequest.php',
    'Google\\Service\\ServiceNetworking\\Api' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Api.php',
    'Google\\Service\\ServiceNetworking\\AuthProvider' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AuthProvider.php',
    'Google\\Service\\ServiceNetworking\\AuthRequirement' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AuthRequirement.php',
    'Google\\Service\\ServiceNetworking\\Authentication' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Authentication.php',
    'Google\\Service\\ServiceNetworking\\AuthenticationRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/AuthenticationRule.php',
    'Google\\Service\\ServiceNetworking\\Backend' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Backend.php',
    'Google\\Service\\ServiceNetworking\\BackendRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/BackendRule.php',
    'Google\\Service\\ServiceNetworking\\Billing' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Billing.php',
    'Google\\Service\\ServiceNetworking\\BillingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/BillingDestination.php',
    'Google\\Service\\ServiceNetworking\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CancelOperationRequest.php',
    'Google\\Service\\ServiceNetworking\\ClientLibrarySettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ClientLibrarySettings.php',
    'Google\\Service\\ServiceNetworking\\CloudSQLConfig' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CloudSQLConfig.php',
    'Google\\Service\\ServiceNetworking\\CommonLanguageSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CommonLanguageSettings.php',
    'Google\\Service\\ServiceNetworking\\Connection' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Connection.php',
    'Google\\Service\\ServiceNetworking\\ConsumerConfig' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ConsumerConfig.php',
    'Google\\Service\\ServiceNetworking\\ConsumerConfigMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ConsumerConfigMetadata.php',
    'Google\\Service\\ServiceNetworking\\ConsumerProject' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ConsumerProject.php',
    'Google\\Service\\ServiceNetworking\\Context' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Context.php',
    'Google\\Service\\ServiceNetworking\\ContextRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ContextRule.php',
    'Google\\Service\\ServiceNetworking\\Control' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Control.php',
    'Google\\Service\\ServiceNetworking\\CppSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CppSettings.php',
    'Google\\Service\\ServiceNetworking\\CustomError' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CustomError.php',
    'Google\\Service\\ServiceNetworking\\CustomErrorRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CustomErrorRule.php',
    'Google\\Service\\ServiceNetworking\\CustomHttpPattern' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/CustomHttpPattern.php',
    'Google\\Service\\ServiceNetworking\\DeleteConnectionMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DeleteConnectionMetadata.php',
    'Google\\Service\\ServiceNetworking\\DeleteConnectionRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DeleteConnectionRequest.php',
    'Google\\Service\\ServiceNetworking\\DeletePeeredDnsDomainMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DeletePeeredDnsDomainMetadata.php',
    'Google\\Service\\ServiceNetworking\\DisableVpcServiceControlsRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DisableVpcServiceControlsRequest.php',
    'Google\\Service\\ServiceNetworking\\DnsRecordSet' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DnsRecordSet.php',
    'Google\\Service\\ServiceNetworking\\DnsZone' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DnsZone.php',
    'Google\\Service\\ServiceNetworking\\DnsZonePair' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DnsZonePair.php',
    'Google\\Service\\ServiceNetworking\\Documentation' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Documentation.php',
    'Google\\Service\\ServiceNetworking\\DocumentationRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DocumentationRule.php',
    'Google\\Service\\ServiceNetworking\\DotnetSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/DotnetSettings.php',
    'Google\\Service\\ServiceNetworking\\EnableVpcServiceControlsRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/EnableVpcServiceControlsRequest.php',
    'Google\\Service\\ServiceNetworking\\Endpoint' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Endpoint.php',
    'Google\\Service\\ServiceNetworking\\Enum' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Enum.php',
    'Google\\Service\\ServiceNetworking\\EnumValue' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/EnumValue.php',
    'Google\\Service\\ServiceNetworking\\ExperimentalFeatures' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ExperimentalFeatures.php',
    'Google\\Service\\ServiceNetworking\\Field' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Field.php',
    'Google\\Service\\ServiceNetworking\\FieldPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/FieldPolicy.php',
    'Google\\Service\\ServiceNetworking\\GetDnsZoneResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/GetDnsZoneResponse.php',
    'Google\\Service\\ServiceNetworking\\GoSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/GoSettings.php',
    'Google\\Service\\ServiceNetworking\\GoogleCloudServicenetworkingV1ConsumerConfigReservedRange' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/GoogleCloudServicenetworkingV1ConsumerConfigReservedRange.php',
    'Google\\Service\\ServiceNetworking\\GoogleCloudServicenetworkingV1betaConnection' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/GoogleCloudServicenetworkingV1betaConnection.php',
    'Google\\Service\\ServiceNetworking\\GoogleCloudServicenetworkingV1betaSubnetwork' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/GoogleCloudServicenetworkingV1betaSubnetwork.php',
    'Google\\Service\\ServiceNetworking\\Http' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Http.php',
    'Google\\Service\\ServiceNetworking\\HttpRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/HttpRule.php',
    'Google\\Service\\ServiceNetworking\\JavaSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/JavaSettings.php',
    'Google\\Service\\ServiceNetworking\\JwtLocation' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/JwtLocation.php',
    'Google\\Service\\ServiceNetworking\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/LabelDescriptor.php',
    'Google\\Service\\ServiceNetworking\\ListConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ListConnectionsResponse.php',
    'Google\\Service\\ServiceNetworking\\ListDnsRecordSetsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ListDnsRecordSetsResponse.php',
    'Google\\Service\\ServiceNetworking\\ListDnsZonesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ListDnsZonesResponse.php',
    'Google\\Service\\ServiceNetworking\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ListOperationsResponse.php',
    'Google\\Service\\ServiceNetworking\\ListPeeredDnsDomainsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ListPeeredDnsDomainsResponse.php',
    'Google\\Service\\ServiceNetworking\\LogDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/LogDescriptor.php',
    'Google\\Service\\ServiceNetworking\\Logging' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Logging.php',
    'Google\\Service\\ServiceNetworking\\LoggingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/LoggingDestination.php',
    'Google\\Service\\ServiceNetworking\\LongRunning' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/LongRunning.php',
    'Google\\Service\\ServiceNetworking\\Method' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Method.php',
    'Google\\Service\\ServiceNetworking\\MethodPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MethodPolicy.php',
    'Google\\Service\\ServiceNetworking\\MethodSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MethodSettings.php',
    'Google\\Service\\ServiceNetworking\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MetricDescriptor.php',
    'Google\\Service\\ServiceNetworking\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MetricDescriptorMetadata.php',
    'Google\\Service\\ServiceNetworking\\MetricRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MetricRule.php',
    'Google\\Service\\ServiceNetworking\\Mixin' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Mixin.php',
    'Google\\Service\\ServiceNetworking\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MonitoredResourceDescriptor.php',
    'Google\\Service\\ServiceNetworking\\Monitoring' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Monitoring.php',
    'Google\\Service\\ServiceNetworking\\MonitoringDestination' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/MonitoringDestination.php',
    'Google\\Service\\ServiceNetworking\\NodeSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/NodeSettings.php',
    'Google\\Service\\ServiceNetworking\\OAuthRequirements' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/OAuthRequirements.php',
    'Google\\Service\\ServiceNetworking\\Operation' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Operation.php',
    'Google\\Service\\ServiceNetworking\\Option' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Option.php',
    'Google\\Service\\ServiceNetworking\\Page' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Page.php',
    'Google\\Service\\ServiceNetworking\\PartialDeleteConnectionMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PartialDeleteConnectionMetadata.php',
    'Google\\Service\\ServiceNetworking\\PeeredDnsDomain' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PeeredDnsDomain.php',
    'Google\\Service\\ServiceNetworking\\PeeredDnsDomainMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PeeredDnsDomainMetadata.php',
    'Google\\Service\\ServiceNetworking\\PhpSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PhpSettings.php',
    'Google\\Service\\ServiceNetworking\\PolicyBinding' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PolicyBinding.php',
    'Google\\Service\\ServiceNetworking\\Publishing' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Publishing.php',
    'Google\\Service\\ServiceNetworking\\PythonSettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/PythonSettings.php',
    'Google\\Service\\ServiceNetworking\\Quota' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Quota.php',
    'Google\\Service\\ServiceNetworking\\QuotaLimit' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/QuotaLimit.php',
    'Google\\Service\\ServiceNetworking\\Range' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Range.php',
    'Google\\Service\\ServiceNetworking\\RangeReservation' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RangeReservation.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsRecordSetMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsRecordSetMetadata.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsRecordSetRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsRecordSetRequest.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsRecordSetResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsRecordSetResponse.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsZoneMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsZoneMetadata.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsZoneRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsZoneRequest.php',
    'Google\\Service\\ServiceNetworking\\RemoveDnsZoneResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RemoveDnsZoneResponse.php',
    'Google\\Service\\ServiceNetworking\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/Operations.php',
    'Google\\Service\\ServiceNetworking\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/Services.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesConnections' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesConnections.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesDnsRecordSet' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesDnsRecordSet.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesDnsRecordSets' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesDnsRecordSets.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesDnsZone' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesDnsZone.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesDnsZones' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesDnsZones.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesDnsZonesDnsZone' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesDnsZonesDnsZone.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjects' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjects.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobal' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobal.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobalNetworks' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobalNetworks.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobalNetworksDnsZones' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobalNetworksDnsZones.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobalNetworksPeeredDnsDomains' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobalNetworksPeeredDnsDomains.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobalNetworksZones' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobalNetworksZones.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesProjectsServicenetworkingGlobalNetworksZonesDnsRecordSet' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesProjectsServicenetworkingGlobalNetworksZonesDnsRecordSet.php',
    'Google\\Service\\ServiceNetworking\\Resource\\ServicesRoles' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Resource/ServicesRoles.php',
    'Google\\Service\\ServiceNetworking\\Route' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Route.php',
    'Google\\Service\\ServiceNetworking\\RubySettings' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/RubySettings.php',
    'Google\\Service\\ServiceNetworking\\SearchRangeRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SearchRangeRequest.php',
    'Google\\Service\\ServiceNetworking\\SecondaryIpRange' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SecondaryIpRange.php',
    'Google\\Service\\ServiceNetworking\\SecondaryIpRangeSpec' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SecondaryIpRangeSpec.php',
    'Google\\Service\\ServiceNetworking\\Service' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Service.php',
    'Google\\Service\\ServiceNetworking\\ServicenetworkingEmpty' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ServicenetworkingEmpty.php',
    'Google\\Service\\ServiceNetworking\\SourceContext' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SourceContext.php',
    'Google\\Service\\ServiceNetworking\\SourceInfo' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SourceInfo.php',
    'Google\\Service\\ServiceNetworking\\Status' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Status.php',
    'Google\\Service\\ServiceNetworking\\Subnetwork' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Subnetwork.php',
    'Google\\Service\\ServiceNetworking\\SystemParameter' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SystemParameter.php',
    'Google\\Service\\ServiceNetworking\\SystemParameterRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SystemParameterRule.php',
    'Google\\Service\\ServiceNetworking\\SystemParameters' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/SystemParameters.php',
    'Google\\Service\\ServiceNetworking\\Type' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Type.php',
    'Google\\Service\\ServiceNetworking\\UpdateConsumerConfigRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/UpdateConsumerConfigRequest.php',
    'Google\\Service\\ServiceNetworking\\UpdateDnsRecordSetMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/UpdateDnsRecordSetMetadata.php',
    'Google\\Service\\ServiceNetworking\\UpdateDnsRecordSetRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/UpdateDnsRecordSetRequest.php',
    'Google\\Service\\ServiceNetworking\\Usage' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/Usage.php',
    'Google\\Service\\ServiceNetworking\\UsageRule' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/UsageRule.php',
    'Google\\Service\\ServiceNetworking\\ValidateConsumerConfigRequest' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ValidateConsumerConfigRequest.php',
    'Google\\Service\\ServiceNetworking\\ValidateConsumerConfigResponse' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/ValidateConsumerConfigResponse.php',
    'Google\\Service\\ServiceNetworking\\VpcServiceControls' => $vendorDir . '/google/apiclient-services/src/ServiceNetworking/VpcServiceControls.php',
    'Google\\Service\\ServiceUsage' => $vendorDir . '/google/apiclient-services/src/ServiceUsage.php',
    'Google\\Service\\ServiceUsage\\AddEnableRulesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AddEnableRulesMetadata.php',
    'Google\\Service\\ServiceUsage\\AddEnableRulesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AddEnableRulesResponse.php',
    'Google\\Service\\ServiceUsage\\AdminQuotaPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AdminQuotaPolicy.php',
    'Google\\Service\\ServiceUsage\\Analysis' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Analysis.php',
    'Google\\Service\\ServiceUsage\\AnalysisResult' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AnalysisResult.php',
    'Google\\Service\\ServiceUsage\\AnalyzeConsumerPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AnalyzeConsumerPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\AnalyzeConsumerPolicyResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AnalyzeConsumerPolicyResponse.php',
    'Google\\Service\\ServiceUsage\\Api' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Api.php',
    'Google\\Service\\ServiceUsage\\AuthProvider' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AuthProvider.php',
    'Google\\Service\\ServiceUsage\\AuthRequirement' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AuthRequirement.php',
    'Google\\Service\\ServiceUsage\\Authentication' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Authentication.php',
    'Google\\Service\\ServiceUsage\\AuthenticationRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/AuthenticationRule.php',
    'Google\\Service\\ServiceUsage\\Backend' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Backend.php',
    'Google\\Service\\ServiceUsage\\BackendRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BackendRule.php',
    'Google\\Service\\ServiceUsage\\BatchCreateAdminOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BatchCreateAdminOverridesResponse.php',
    'Google\\Service\\ServiceUsage\\BatchCreateConsumerOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BatchCreateConsumerOverridesResponse.php',
    'Google\\Service\\ServiceUsage\\BatchEnableServicesRequest' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BatchEnableServicesRequest.php',
    'Google\\Service\\ServiceUsage\\BatchEnableServicesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BatchEnableServicesResponse.php',
    'Google\\Service\\ServiceUsage\\BatchGetServicesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BatchGetServicesResponse.php',
    'Google\\Service\\ServiceUsage\\Billing' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Billing.php',
    'Google\\Service\\ServiceUsage\\BillingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/BillingDestination.php',
    'Google\\Service\\ServiceUsage\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CancelOperationRequest.php',
    'Google\\Service\\ServiceUsage\\ClientLibrarySettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ClientLibrarySettings.php',
    'Google\\Service\\ServiceUsage\\CommonLanguageSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CommonLanguageSettings.php',
    'Google\\Service\\ServiceUsage\\ConsumerPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ConsumerPolicy.php',
    'Google\\Service\\ServiceUsage\\Context' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Context.php',
    'Google\\Service\\ServiceUsage\\ContextRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ContextRule.php',
    'Google\\Service\\ServiceUsage\\Control' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Control.php',
    'Google\\Service\\ServiceUsage\\CppSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CppSettings.php',
    'Google\\Service\\ServiceUsage\\CreateAdminQuotaPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CreateAdminQuotaPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\CustomError' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CustomError.php',
    'Google\\Service\\ServiceUsage\\CustomErrorRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CustomErrorRule.php',
    'Google\\Service\\ServiceUsage\\CustomHttpPattern' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/CustomHttpPattern.php',
    'Google\\Service\\ServiceUsage\\DeleteAdminQuotaPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/DeleteAdminQuotaPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\DisableServiceRequest' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/DisableServiceRequest.php',
    'Google\\Service\\ServiceUsage\\DisableServiceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/DisableServiceResponse.php',
    'Google\\Service\\ServiceUsage\\Documentation' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Documentation.php',
    'Google\\Service\\ServiceUsage\\DocumentationRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/DocumentationRule.php',
    'Google\\Service\\ServiceUsage\\DotnetSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/DotnetSettings.php',
    'Google\\Service\\ServiceUsage\\EnableFailure' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/EnableFailure.php',
    'Google\\Service\\ServiceUsage\\EnableRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/EnableRule.php',
    'Google\\Service\\ServiceUsage\\EnableServiceRequest' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/EnableServiceRequest.php',
    'Google\\Service\\ServiceUsage\\EnableServiceResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/EnableServiceResponse.php',
    'Google\\Service\\ServiceUsage\\Endpoint' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Endpoint.php',
    'Google\\Service\\ServiceUsage\\Enum' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Enum.php',
    'Google\\Service\\ServiceUsage\\EnumValue' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/EnumValue.php',
    'Google\\Service\\ServiceUsage\\Field' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Field.php',
    'Google\\Service\\ServiceUsage\\FieldPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/FieldPolicy.php',
    'Google\\Service\\ServiceUsage\\GetServiceIdentityMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GetServiceIdentityMetadata.php',
    'Google\\Service\\ServiceUsage\\GetServiceIdentityResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GetServiceIdentityResponse.php',
    'Google\\Service\\ServiceUsage\\GoSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoSettings.php',
    'Google\\Service\\ServiceUsage\\GoogleApiService' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiService.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV1OperationMetadata.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV1Service' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV1Service.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV1ServiceConfig' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV1ServiceConfig.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV1beta1GetServiceIdentityResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV1beta1GetServiceIdentityResponse.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV1beta1ServiceIdentity' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV1beta1ServiceIdentity.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV2alphaConsumerPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV2alphaConsumerPolicy.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV2alphaEnableRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV2alphaEnableRule.php',
    'Google\\Service\\ServiceUsage\\GoogleApiServiceusageV2alphaUpdateConsumerPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GoogleApiServiceusageV2alphaUpdateConsumerPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\GroupValue' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/GroupValue.php',
    'Google\\Service\\ServiceUsage\\Http' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Http.php',
    'Google\\Service\\ServiceUsage\\HttpRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/HttpRule.php',
    'Google\\Service\\ServiceUsage\\Impact' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Impact.php',
    'Google\\Service\\ServiceUsage\\ImportAdminOverridesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportAdminOverridesMetadata.php',
    'Google\\Service\\ServiceUsage\\ImportAdminOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportAdminOverridesResponse.php',
    'Google\\Service\\ServiceUsage\\ImportAdminQuotaPoliciesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportAdminQuotaPoliciesMetadata.php',
    'Google\\Service\\ServiceUsage\\ImportAdminQuotaPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportAdminQuotaPoliciesResponse.php',
    'Google\\Service\\ServiceUsage\\ImportConsumerOverridesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportConsumerOverridesMetadata.php',
    'Google\\Service\\ServiceUsage\\ImportConsumerOverridesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ImportConsumerOverridesResponse.php',
    'Google\\Service\\ServiceUsage\\JavaSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/JavaSettings.php',
    'Google\\Service\\ServiceUsage\\JwtLocation' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/JwtLocation.php',
    'Google\\Service\\ServiceUsage\\LabelDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/LabelDescriptor.php',
    'Google\\Service\\ServiceUsage\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ListOperationsResponse.php',
    'Google\\Service\\ServiceUsage\\ListServicesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ListServicesResponse.php',
    'Google\\Service\\ServiceUsage\\LogDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/LogDescriptor.php',
    'Google\\Service\\ServiceUsage\\Logging' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Logging.php',
    'Google\\Service\\ServiceUsage\\LoggingDestination' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/LoggingDestination.php',
    'Google\\Service\\ServiceUsage\\LongRunning' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/LongRunning.php',
    'Google\\Service\\ServiceUsage\\Method' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Method.php',
    'Google\\Service\\ServiceUsage\\MethodPolicy' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MethodPolicy.php',
    'Google\\Service\\ServiceUsage\\MethodSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MethodSettings.php',
    'Google\\Service\\ServiceUsage\\MetricDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MetricDescriptor.php',
    'Google\\Service\\ServiceUsage\\MetricDescriptorMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MetricDescriptorMetadata.php',
    'Google\\Service\\ServiceUsage\\MetricRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MetricRule.php',
    'Google\\Service\\ServiceUsage\\Mixin' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Mixin.php',
    'Google\\Service\\ServiceUsage\\MonitoredResourceDescriptor' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MonitoredResourceDescriptor.php',
    'Google\\Service\\ServiceUsage\\Monitoring' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Monitoring.php',
    'Google\\Service\\ServiceUsage\\MonitoringDestination' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/MonitoringDestination.php',
    'Google\\Service\\ServiceUsage\\NodeSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/NodeSettings.php',
    'Google\\Service\\ServiceUsage\\OAuthRequirements' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/OAuthRequirements.php',
    'Google\\Service\\ServiceUsage\\Operation' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Operation.php',
    'Google\\Service\\ServiceUsage\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/OperationMetadata.php',
    'Google\\Service\\ServiceUsage\\Option' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Option.php',
    'Google\\Service\\ServiceUsage\\Page' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Page.php',
    'Google\\Service\\ServiceUsage\\PhpSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/PhpSettings.php',
    'Google\\Service\\ServiceUsage\\Publishing' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Publishing.php',
    'Google\\Service\\ServiceUsage\\PythonSettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/PythonSettings.php',
    'Google\\Service\\ServiceUsage\\Quota' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Quota.php',
    'Google\\Service\\ServiceUsage\\QuotaLimit' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/QuotaLimit.php',
    'Google\\Service\\ServiceUsage\\QuotaOverride' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/QuotaOverride.php',
    'Google\\Service\\ServiceUsage\\RemoveEnableRulesMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/RemoveEnableRulesMetadata.php',
    'Google\\Service\\ServiceUsage\\RemoveEnableRulesResponse' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/RemoveEnableRulesResponse.php',
    'Google\\Service\\ServiceUsage\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Resource/Operations.php',
    'Google\\Service\\ServiceUsage\\Resource\\Services' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Resource/Services.php',
    'Google\\Service\\ServiceUsage\\RubySettings' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/RubySettings.php',
    'Google\\Service\\ServiceUsage\\ServiceIdentity' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ServiceIdentity.php',
    'Google\\Service\\ServiceUsage\\ServiceValue' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ServiceValue.php',
    'Google\\Service\\ServiceUsage\\ServiceusageEmpty' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ServiceusageEmpty.php',
    'Google\\Service\\ServiceUsage\\SourceContext' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/SourceContext.php',
    'Google\\Service\\ServiceUsage\\SourceInfo' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/SourceInfo.php',
    'Google\\Service\\ServiceUsage\\Status' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Status.php',
    'Google\\Service\\ServiceUsage\\SystemParameter' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/SystemParameter.php',
    'Google\\Service\\ServiceUsage\\SystemParameterRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/SystemParameterRule.php',
    'Google\\Service\\ServiceUsage\\SystemParameters' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/SystemParameters.php',
    'Google\\Service\\ServiceUsage\\TermsOfService' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/TermsOfService.php',
    'Google\\Service\\ServiceUsage\\Type' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Type.php',
    'Google\\Service\\ServiceUsage\\UpdateAdminQuotaPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/UpdateAdminQuotaPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\UpdateConsumerPolicyLROMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/UpdateConsumerPolicyLROMetadata.php',
    'Google\\Service\\ServiceUsage\\UpdateConsumerPolicyMetadata' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/UpdateConsumerPolicyMetadata.php',
    'Google\\Service\\ServiceUsage\\Usage' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/Usage.php',
    'Google\\Service\\ServiceUsage\\UsageRule' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/UsageRule.php',
    'Google\\Service\\ServiceUsage\\ValueInfo' => $vendorDir . '/google/apiclient-services/src/ServiceUsage/ValueInfo.php',
    'Google\\Service\\Sheets' => $vendorDir . '/google/apiclient-services/src/Sheets.php',
    'Google\\Service\\Sheets\\AddBandingRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddBandingRequest.php',
    'Google\\Service\\Sheets\\AddBandingResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddBandingResponse.php',
    'Google\\Service\\Sheets\\AddChartRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddChartRequest.php',
    'Google\\Service\\Sheets\\AddChartResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddChartResponse.php',
    'Google\\Service\\Sheets\\AddConditionalFormatRuleRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddConditionalFormatRuleRequest.php',
    'Google\\Service\\Sheets\\AddDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddDataSourceRequest.php',
    'Google\\Service\\Sheets\\AddDataSourceResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddDataSourceResponse.php',
    'Google\\Service\\Sheets\\AddDimensionGroupRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddDimensionGroupRequest.php',
    'Google\\Service\\Sheets\\AddDimensionGroupResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddDimensionGroupResponse.php',
    'Google\\Service\\Sheets\\AddFilterViewRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddFilterViewRequest.php',
    'Google\\Service\\Sheets\\AddFilterViewResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddFilterViewResponse.php',
    'Google\\Service\\Sheets\\AddNamedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddNamedRangeRequest.php',
    'Google\\Service\\Sheets\\AddNamedRangeResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddNamedRangeResponse.php',
    'Google\\Service\\Sheets\\AddProtectedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddProtectedRangeRequest.php',
    'Google\\Service\\Sheets\\AddProtectedRangeResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddProtectedRangeResponse.php',
    'Google\\Service\\Sheets\\AddSheetRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddSheetRequest.php',
    'Google\\Service\\Sheets\\AddSheetResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddSheetResponse.php',
    'Google\\Service\\Sheets\\AddSlicerRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AddSlicerRequest.php',
    'Google\\Service\\Sheets\\AddSlicerResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AddSlicerResponse.php',
    'Google\\Service\\Sheets\\AppendCellsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AppendCellsRequest.php',
    'Google\\Service\\Sheets\\AppendDimensionRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AppendDimensionRequest.php',
    'Google\\Service\\Sheets\\AppendValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/AppendValuesResponse.php',
    'Google\\Service\\Sheets\\AutoFillRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AutoFillRequest.php',
    'Google\\Service\\Sheets\\AutoResizeDimensionsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/AutoResizeDimensionsRequest.php',
    'Google\\Service\\Sheets\\BandedRange' => $vendorDir . '/google/apiclient-services/src/Sheets/BandedRange.php',
    'Google\\Service\\Sheets\\BandingProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/BandingProperties.php',
    'Google\\Service\\Sheets\\BaselineValueFormat' => $vendorDir . '/google/apiclient-services/src/Sheets/BaselineValueFormat.php',
    'Google\\Service\\Sheets\\BasicChartAxis' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicChartAxis.php',
    'Google\\Service\\Sheets\\BasicChartDomain' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicChartDomain.php',
    'Google\\Service\\Sheets\\BasicChartSeries' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicChartSeries.php',
    'Google\\Service\\Sheets\\BasicChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicChartSpec.php',
    'Google\\Service\\Sheets\\BasicFilter' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicFilter.php',
    'Google\\Service\\Sheets\\BasicSeriesDataPointStyleOverride' => $vendorDir . '/google/apiclient-services/src/Sheets/BasicSeriesDataPointStyleOverride.php',
    'Google\\Service\\Sheets\\BatchClearValuesByDataFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchClearValuesByDataFilterRequest.php',
    'Google\\Service\\Sheets\\BatchClearValuesByDataFilterResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchClearValuesByDataFilterResponse.php',
    'Google\\Service\\Sheets\\BatchClearValuesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchClearValuesRequest.php',
    'Google\\Service\\Sheets\\BatchClearValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchClearValuesResponse.php',
    'Google\\Service\\Sheets\\BatchGetValuesByDataFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchGetValuesByDataFilterRequest.php',
    'Google\\Service\\Sheets\\BatchGetValuesByDataFilterResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchGetValuesByDataFilterResponse.php',
    'Google\\Service\\Sheets\\BatchGetValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchGetValuesResponse.php',
    'Google\\Service\\Sheets\\BatchUpdateSpreadsheetRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateSpreadsheetRequest.php',
    'Google\\Service\\Sheets\\BatchUpdateSpreadsheetResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateSpreadsheetResponse.php',
    'Google\\Service\\Sheets\\BatchUpdateValuesByDataFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateValuesByDataFilterRequest.php',
    'Google\\Service\\Sheets\\BatchUpdateValuesByDataFilterResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateValuesByDataFilterResponse.php',
    'Google\\Service\\Sheets\\BatchUpdateValuesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateValuesRequest.php',
    'Google\\Service\\Sheets\\BatchUpdateValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/BatchUpdateValuesResponse.php',
    'Google\\Service\\Sheets\\BigQueryDataSourceSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/BigQueryDataSourceSpec.php',
    'Google\\Service\\Sheets\\BigQueryQuerySpec' => $vendorDir . '/google/apiclient-services/src/Sheets/BigQueryQuerySpec.php',
    'Google\\Service\\Sheets\\BigQueryTableSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/BigQueryTableSpec.php',
    'Google\\Service\\Sheets\\BooleanCondition' => $vendorDir . '/google/apiclient-services/src/Sheets/BooleanCondition.php',
    'Google\\Service\\Sheets\\BooleanRule' => $vendorDir . '/google/apiclient-services/src/Sheets/BooleanRule.php',
    'Google\\Service\\Sheets\\Border' => $vendorDir . '/google/apiclient-services/src/Sheets/Border.php',
    'Google\\Service\\Sheets\\Borders' => $vendorDir . '/google/apiclient-services/src/Sheets/Borders.php',
    'Google\\Service\\Sheets\\BubbleChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/BubbleChartSpec.php',
    'Google\\Service\\Sheets\\CancelDataSourceRefreshRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/CancelDataSourceRefreshRequest.php',
    'Google\\Service\\Sheets\\CancelDataSourceRefreshResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/CancelDataSourceRefreshResponse.php',
    'Google\\Service\\Sheets\\CancelDataSourceRefreshStatus' => $vendorDir . '/google/apiclient-services/src/Sheets/CancelDataSourceRefreshStatus.php',
    'Google\\Service\\Sheets\\CandlestickChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/CandlestickChartSpec.php',
    'Google\\Service\\Sheets\\CandlestickData' => $vendorDir . '/google/apiclient-services/src/Sheets/CandlestickData.php',
    'Google\\Service\\Sheets\\CandlestickDomain' => $vendorDir . '/google/apiclient-services/src/Sheets/CandlestickDomain.php',
    'Google\\Service\\Sheets\\CandlestickSeries' => $vendorDir . '/google/apiclient-services/src/Sheets/CandlestickSeries.php',
    'Google\\Service\\Sheets\\CellData' => $vendorDir . '/google/apiclient-services/src/Sheets/CellData.php',
    'Google\\Service\\Sheets\\CellFormat' => $vendorDir . '/google/apiclient-services/src/Sheets/CellFormat.php',
    'Google\\Service\\Sheets\\ChartAxisViewWindowOptions' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartAxisViewWindowOptions.php',
    'Google\\Service\\Sheets\\ChartCustomNumberFormatOptions' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartCustomNumberFormatOptions.php',
    'Google\\Service\\Sheets\\ChartData' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartData.php',
    'Google\\Service\\Sheets\\ChartDateTimeRule' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartDateTimeRule.php',
    'Google\\Service\\Sheets\\ChartGroupRule' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartGroupRule.php',
    'Google\\Service\\Sheets\\ChartHistogramRule' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartHistogramRule.php',
    'Google\\Service\\Sheets\\ChartSourceRange' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartSourceRange.php',
    'Google\\Service\\Sheets\\ChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/ChartSpec.php',
    'Google\\Service\\Sheets\\ClearBasicFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/ClearBasicFilterRequest.php',
    'Google\\Service\\Sheets\\ClearValuesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/ClearValuesRequest.php',
    'Google\\Service\\Sheets\\ClearValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/ClearValuesResponse.php',
    'Google\\Service\\Sheets\\Color' => $vendorDir . '/google/apiclient-services/src/Sheets/Color.php',
    'Google\\Service\\Sheets\\ColorStyle' => $vendorDir . '/google/apiclient-services/src/Sheets/ColorStyle.php',
    'Google\\Service\\Sheets\\ConditionValue' => $vendorDir . '/google/apiclient-services/src/Sheets/ConditionValue.php',
    'Google\\Service\\Sheets\\ConditionalFormatRule' => $vendorDir . '/google/apiclient-services/src/Sheets/ConditionalFormatRule.php',
    'Google\\Service\\Sheets\\CopyPasteRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/CopyPasteRequest.php',
    'Google\\Service\\Sheets\\CopySheetToAnotherSpreadsheetRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/CopySheetToAnotherSpreadsheetRequest.php',
    'Google\\Service\\Sheets\\CreateDeveloperMetadataRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/CreateDeveloperMetadataRequest.php',
    'Google\\Service\\Sheets\\CreateDeveloperMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/CreateDeveloperMetadataResponse.php',
    'Google\\Service\\Sheets\\CutPasteRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/CutPasteRequest.php',
    'Google\\Service\\Sheets\\DataExecutionStatus' => $vendorDir . '/google/apiclient-services/src/Sheets/DataExecutionStatus.php',
    'Google\\Service\\Sheets\\DataFilter' => $vendorDir . '/google/apiclient-services/src/Sheets/DataFilter.php',
    'Google\\Service\\Sheets\\DataFilterValueRange' => $vendorDir . '/google/apiclient-services/src/Sheets/DataFilterValueRange.php',
    'Google\\Service\\Sheets\\DataLabel' => $vendorDir . '/google/apiclient-services/src/Sheets/DataLabel.php',
    'Google\\Service\\Sheets\\DataSource' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSource.php',
    'Google\\Service\\Sheets\\DataSourceChartProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceChartProperties.php',
    'Google\\Service\\Sheets\\DataSourceColumn' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceColumn.php',
    'Google\\Service\\Sheets\\DataSourceColumnReference' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceColumnReference.php',
    'Google\\Service\\Sheets\\DataSourceFormula' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceFormula.php',
    'Google\\Service\\Sheets\\DataSourceObjectReference' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceObjectReference.php',
    'Google\\Service\\Sheets\\DataSourceObjectReferences' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceObjectReferences.php',
    'Google\\Service\\Sheets\\DataSourceParameter' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceParameter.php',
    'Google\\Service\\Sheets\\DataSourceRefreshDailySchedule' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceRefreshDailySchedule.php',
    'Google\\Service\\Sheets\\DataSourceRefreshMonthlySchedule' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceRefreshMonthlySchedule.php',
    'Google\\Service\\Sheets\\DataSourceRefreshSchedule' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceRefreshSchedule.php',
    'Google\\Service\\Sheets\\DataSourceRefreshWeeklySchedule' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceRefreshWeeklySchedule.php',
    'Google\\Service\\Sheets\\DataSourceSheetDimensionRange' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceSheetDimensionRange.php',
    'Google\\Service\\Sheets\\DataSourceSheetProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceSheetProperties.php',
    'Google\\Service\\Sheets\\DataSourceSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceSpec.php',
    'Google\\Service\\Sheets\\DataSourceTable' => $vendorDir . '/google/apiclient-services/src/Sheets/DataSourceTable.php',
    'Google\\Service\\Sheets\\DataValidationRule' => $vendorDir . '/google/apiclient-services/src/Sheets/DataValidationRule.php',
    'Google\\Service\\Sheets\\DateTimeRule' => $vendorDir . '/google/apiclient-services/src/Sheets/DateTimeRule.php',
    'Google\\Service\\Sheets\\DeleteBandingRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteBandingRequest.php',
    'Google\\Service\\Sheets\\DeleteConditionalFormatRuleRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteConditionalFormatRuleRequest.php',
    'Google\\Service\\Sheets\\DeleteConditionalFormatRuleResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteConditionalFormatRuleResponse.php',
    'Google\\Service\\Sheets\\DeleteDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDataSourceRequest.php',
    'Google\\Service\\Sheets\\DeleteDeveloperMetadataRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDeveloperMetadataRequest.php',
    'Google\\Service\\Sheets\\DeleteDeveloperMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDeveloperMetadataResponse.php',
    'Google\\Service\\Sheets\\DeleteDimensionGroupRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDimensionGroupRequest.php',
    'Google\\Service\\Sheets\\DeleteDimensionGroupResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDimensionGroupResponse.php',
    'Google\\Service\\Sheets\\DeleteDimensionRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDimensionRequest.php',
    'Google\\Service\\Sheets\\DeleteDuplicatesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDuplicatesRequest.php',
    'Google\\Service\\Sheets\\DeleteDuplicatesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteDuplicatesResponse.php',
    'Google\\Service\\Sheets\\DeleteEmbeddedObjectRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteEmbeddedObjectRequest.php',
    'Google\\Service\\Sheets\\DeleteFilterViewRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteFilterViewRequest.php',
    'Google\\Service\\Sheets\\DeleteNamedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteNamedRangeRequest.php',
    'Google\\Service\\Sheets\\DeleteProtectedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteProtectedRangeRequest.php',
    'Google\\Service\\Sheets\\DeleteRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteRangeRequest.php',
    'Google\\Service\\Sheets\\DeleteSheetRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DeleteSheetRequest.php',
    'Google\\Service\\Sheets\\DeveloperMetadata' => $vendorDir . '/google/apiclient-services/src/Sheets/DeveloperMetadata.php',
    'Google\\Service\\Sheets\\DeveloperMetadataLocation' => $vendorDir . '/google/apiclient-services/src/Sheets/DeveloperMetadataLocation.php',
    'Google\\Service\\Sheets\\DeveloperMetadataLookup' => $vendorDir . '/google/apiclient-services/src/Sheets/DeveloperMetadataLookup.php',
    'Google\\Service\\Sheets\\DimensionGroup' => $vendorDir . '/google/apiclient-services/src/Sheets/DimensionGroup.php',
    'Google\\Service\\Sheets\\DimensionProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/DimensionProperties.php',
    'Google\\Service\\Sheets\\DimensionRange' => $vendorDir . '/google/apiclient-services/src/Sheets/DimensionRange.php',
    'Google\\Service\\Sheets\\DuplicateFilterViewRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DuplicateFilterViewRequest.php',
    'Google\\Service\\Sheets\\DuplicateFilterViewResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DuplicateFilterViewResponse.php',
    'Google\\Service\\Sheets\\DuplicateSheetRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/DuplicateSheetRequest.php',
    'Google\\Service\\Sheets\\DuplicateSheetResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/DuplicateSheetResponse.php',
    'Google\\Service\\Sheets\\Editors' => $vendorDir . '/google/apiclient-services/src/Sheets/Editors.php',
    'Google\\Service\\Sheets\\EmbeddedChart' => $vendorDir . '/google/apiclient-services/src/Sheets/EmbeddedChart.php',
    'Google\\Service\\Sheets\\EmbeddedObjectBorder' => $vendorDir . '/google/apiclient-services/src/Sheets/EmbeddedObjectBorder.php',
    'Google\\Service\\Sheets\\EmbeddedObjectPosition' => $vendorDir . '/google/apiclient-services/src/Sheets/EmbeddedObjectPosition.php',
    'Google\\Service\\Sheets\\ErrorValue' => $vendorDir . '/google/apiclient-services/src/Sheets/ErrorValue.php',
    'Google\\Service\\Sheets\\ExtendedValue' => $vendorDir . '/google/apiclient-services/src/Sheets/ExtendedValue.php',
    'Google\\Service\\Sheets\\FilterCriteria' => $vendorDir . '/google/apiclient-services/src/Sheets/FilterCriteria.php',
    'Google\\Service\\Sheets\\FilterSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/FilterSpec.php',
    'Google\\Service\\Sheets\\FilterView' => $vendorDir . '/google/apiclient-services/src/Sheets/FilterView.php',
    'Google\\Service\\Sheets\\FindReplaceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/FindReplaceRequest.php',
    'Google\\Service\\Sheets\\FindReplaceResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/FindReplaceResponse.php',
    'Google\\Service\\Sheets\\GetSpreadsheetByDataFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/GetSpreadsheetByDataFilterRequest.php',
    'Google\\Service\\Sheets\\GradientRule' => $vendorDir . '/google/apiclient-services/src/Sheets/GradientRule.php',
    'Google\\Service\\Sheets\\GridCoordinate' => $vendorDir . '/google/apiclient-services/src/Sheets/GridCoordinate.php',
    'Google\\Service\\Sheets\\GridData' => $vendorDir . '/google/apiclient-services/src/Sheets/GridData.php',
    'Google\\Service\\Sheets\\GridProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/GridProperties.php',
    'Google\\Service\\Sheets\\GridRange' => $vendorDir . '/google/apiclient-services/src/Sheets/GridRange.php',
    'Google\\Service\\Sheets\\HistogramChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/HistogramChartSpec.php',
    'Google\\Service\\Sheets\\HistogramRule' => $vendorDir . '/google/apiclient-services/src/Sheets/HistogramRule.php',
    'Google\\Service\\Sheets\\HistogramSeries' => $vendorDir . '/google/apiclient-services/src/Sheets/HistogramSeries.php',
    'Google\\Service\\Sheets\\InsertDimensionRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/InsertDimensionRequest.php',
    'Google\\Service\\Sheets\\InsertRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/InsertRangeRequest.php',
    'Google\\Service\\Sheets\\InterpolationPoint' => $vendorDir . '/google/apiclient-services/src/Sheets/InterpolationPoint.php',
    'Google\\Service\\Sheets\\Interval' => $vendorDir . '/google/apiclient-services/src/Sheets/Interval.php',
    'Google\\Service\\Sheets\\IterativeCalculationSettings' => $vendorDir . '/google/apiclient-services/src/Sheets/IterativeCalculationSettings.php',
    'Google\\Service\\Sheets\\KeyValueFormat' => $vendorDir . '/google/apiclient-services/src/Sheets/KeyValueFormat.php',
    'Google\\Service\\Sheets\\LineStyle' => $vendorDir . '/google/apiclient-services/src/Sheets/LineStyle.php',
    'Google\\Service\\Sheets\\Link' => $vendorDir . '/google/apiclient-services/src/Sheets/Link.php',
    'Google\\Service\\Sheets\\LookerDataSourceSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/LookerDataSourceSpec.php',
    'Google\\Service\\Sheets\\ManualRule' => $vendorDir . '/google/apiclient-services/src/Sheets/ManualRule.php',
    'Google\\Service\\Sheets\\ManualRuleGroup' => $vendorDir . '/google/apiclient-services/src/Sheets/ManualRuleGroup.php',
    'Google\\Service\\Sheets\\MatchedDeveloperMetadata' => $vendorDir . '/google/apiclient-services/src/Sheets/MatchedDeveloperMetadata.php',
    'Google\\Service\\Sheets\\MatchedValueRange' => $vendorDir . '/google/apiclient-services/src/Sheets/MatchedValueRange.php',
    'Google\\Service\\Sheets\\MergeCellsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/MergeCellsRequest.php',
    'Google\\Service\\Sheets\\MoveDimensionRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/MoveDimensionRequest.php',
    'Google\\Service\\Sheets\\NamedRange' => $vendorDir . '/google/apiclient-services/src/Sheets/NamedRange.php',
    'Google\\Service\\Sheets\\NumberFormat' => $vendorDir . '/google/apiclient-services/src/Sheets/NumberFormat.php',
    'Google\\Service\\Sheets\\OrgChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/OrgChartSpec.php',
    'Google\\Service\\Sheets\\OverlayPosition' => $vendorDir . '/google/apiclient-services/src/Sheets/OverlayPosition.php',
    'Google\\Service\\Sheets\\Padding' => $vendorDir . '/google/apiclient-services/src/Sheets/Padding.php',
    'Google\\Service\\Sheets\\PasteDataRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/PasteDataRequest.php',
    'Google\\Service\\Sheets\\PieChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/PieChartSpec.php',
    'Google\\Service\\Sheets\\PivotFilterCriteria' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotFilterCriteria.php',
    'Google\\Service\\Sheets\\PivotFilterSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotFilterSpec.php',
    'Google\\Service\\Sheets\\PivotGroup' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotGroup.php',
    'Google\\Service\\Sheets\\PivotGroupLimit' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotGroupLimit.php',
    'Google\\Service\\Sheets\\PivotGroupRule' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotGroupRule.php',
    'Google\\Service\\Sheets\\PivotGroupSortValueBucket' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotGroupSortValueBucket.php',
    'Google\\Service\\Sheets\\PivotGroupValueMetadata' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotGroupValueMetadata.php',
    'Google\\Service\\Sheets\\PivotTable' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotTable.php',
    'Google\\Service\\Sheets\\PivotValue' => $vendorDir . '/google/apiclient-services/src/Sheets/PivotValue.php',
    'Google\\Service\\Sheets\\PointStyle' => $vendorDir . '/google/apiclient-services/src/Sheets/PointStyle.php',
    'Google\\Service\\Sheets\\ProtectedRange' => $vendorDir . '/google/apiclient-services/src/Sheets/ProtectedRange.php',
    'Google\\Service\\Sheets\\RandomizeRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/RandomizeRangeRequest.php',
    'Google\\Service\\Sheets\\RefreshCancellationStatus' => $vendorDir . '/google/apiclient-services/src/Sheets/RefreshCancellationStatus.php',
    'Google\\Service\\Sheets\\RefreshDataSourceObjectExecutionStatus' => $vendorDir . '/google/apiclient-services/src/Sheets/RefreshDataSourceObjectExecutionStatus.php',
    'Google\\Service\\Sheets\\RefreshDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/RefreshDataSourceRequest.php',
    'Google\\Service\\Sheets\\RefreshDataSourceResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/RefreshDataSourceResponse.php',
    'Google\\Service\\Sheets\\RepeatCellRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/RepeatCellRequest.php',
    'Google\\Service\\Sheets\\Request' => $vendorDir . '/google/apiclient-services/src/Sheets/Request.php',
    'Google\\Service\\Sheets\\Resource\\Spreadsheets' => $vendorDir . '/google/apiclient-services/src/Sheets/Resource/Spreadsheets.php',
    'Google\\Service\\Sheets\\Resource\\SpreadsheetsDeveloperMetadata' => $vendorDir . '/google/apiclient-services/src/Sheets/Resource/SpreadsheetsDeveloperMetadata.php',
    'Google\\Service\\Sheets\\Resource\\SpreadsheetsSheets' => $vendorDir . '/google/apiclient-services/src/Sheets/Resource/SpreadsheetsSheets.php',
    'Google\\Service\\Sheets\\Resource\\SpreadsheetsValues' => $vendorDir . '/google/apiclient-services/src/Sheets/Resource/SpreadsheetsValues.php',
    'Google\\Service\\Sheets\\Response' => $vendorDir . '/google/apiclient-services/src/Sheets/Response.php',
    'Google\\Service\\Sheets\\RowData' => $vendorDir . '/google/apiclient-services/src/Sheets/RowData.php',
    'Google\\Service\\Sheets\\ScorecardChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/ScorecardChartSpec.php',
    'Google\\Service\\Sheets\\SearchDeveloperMetadataRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/SearchDeveloperMetadataRequest.php',
    'Google\\Service\\Sheets\\SearchDeveloperMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/SearchDeveloperMetadataResponse.php',
    'Google\\Service\\Sheets\\SetBasicFilterRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/SetBasicFilterRequest.php',
    'Google\\Service\\Sheets\\SetDataValidationRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/SetDataValidationRequest.php',
    'Google\\Service\\Sheets\\Sheet' => $vendorDir . '/google/apiclient-services/src/Sheets/Sheet.php',
    'Google\\Service\\Sheets\\SheetProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/SheetProperties.php',
    'Google\\Service\\Sheets\\Slicer' => $vendorDir . '/google/apiclient-services/src/Sheets/Slicer.php',
    'Google\\Service\\Sheets\\SlicerSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/SlicerSpec.php',
    'Google\\Service\\Sheets\\SortRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/SortRangeRequest.php',
    'Google\\Service\\Sheets\\SortSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/SortSpec.php',
    'Google\\Service\\Sheets\\SourceAndDestination' => $vendorDir . '/google/apiclient-services/src/Sheets/SourceAndDestination.php',
    'Google\\Service\\Sheets\\Spreadsheet' => $vendorDir . '/google/apiclient-services/src/Sheets/Spreadsheet.php',
    'Google\\Service\\Sheets\\SpreadsheetProperties' => $vendorDir . '/google/apiclient-services/src/Sheets/SpreadsheetProperties.php',
    'Google\\Service\\Sheets\\SpreadsheetTheme' => $vendorDir . '/google/apiclient-services/src/Sheets/SpreadsheetTheme.php',
    'Google\\Service\\Sheets\\TextFormat' => $vendorDir . '/google/apiclient-services/src/Sheets/TextFormat.php',
    'Google\\Service\\Sheets\\TextFormatRun' => $vendorDir . '/google/apiclient-services/src/Sheets/TextFormatRun.php',
    'Google\\Service\\Sheets\\TextPosition' => $vendorDir . '/google/apiclient-services/src/Sheets/TextPosition.php',
    'Google\\Service\\Sheets\\TextRotation' => $vendorDir . '/google/apiclient-services/src/Sheets/TextRotation.php',
    'Google\\Service\\Sheets\\TextToColumnsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/TextToColumnsRequest.php',
    'Google\\Service\\Sheets\\ThemeColorPair' => $vendorDir . '/google/apiclient-services/src/Sheets/ThemeColorPair.php',
    'Google\\Service\\Sheets\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Sheets/TimeOfDay.php',
    'Google\\Service\\Sheets\\TreemapChartColorScale' => $vendorDir . '/google/apiclient-services/src/Sheets/TreemapChartColorScale.php',
    'Google\\Service\\Sheets\\TreemapChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/TreemapChartSpec.php',
    'Google\\Service\\Sheets\\TrimWhitespaceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/TrimWhitespaceRequest.php',
    'Google\\Service\\Sheets\\TrimWhitespaceResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/TrimWhitespaceResponse.php',
    'Google\\Service\\Sheets\\UnmergeCellsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UnmergeCellsRequest.php',
    'Google\\Service\\Sheets\\UpdateBandingRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateBandingRequest.php',
    'Google\\Service\\Sheets\\UpdateBordersRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateBordersRequest.php',
    'Google\\Service\\Sheets\\UpdateCellsRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateCellsRequest.php',
    'Google\\Service\\Sheets\\UpdateChartSpecRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateChartSpecRequest.php',
    'Google\\Service\\Sheets\\UpdateConditionalFormatRuleRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateConditionalFormatRuleRequest.php',
    'Google\\Service\\Sheets\\UpdateConditionalFormatRuleResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateConditionalFormatRuleResponse.php',
    'Google\\Service\\Sheets\\UpdateDataSourceRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDataSourceRequest.php',
    'Google\\Service\\Sheets\\UpdateDataSourceResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDataSourceResponse.php',
    'Google\\Service\\Sheets\\UpdateDeveloperMetadataRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDeveloperMetadataRequest.php',
    'Google\\Service\\Sheets\\UpdateDeveloperMetadataResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDeveloperMetadataResponse.php',
    'Google\\Service\\Sheets\\UpdateDimensionGroupRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDimensionGroupRequest.php',
    'Google\\Service\\Sheets\\UpdateDimensionPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateDimensionPropertiesRequest.php',
    'Google\\Service\\Sheets\\UpdateEmbeddedObjectBorderRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateEmbeddedObjectBorderRequest.php',
    'Google\\Service\\Sheets\\UpdateEmbeddedObjectPositionRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateEmbeddedObjectPositionRequest.php',
    'Google\\Service\\Sheets\\UpdateEmbeddedObjectPositionResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateEmbeddedObjectPositionResponse.php',
    'Google\\Service\\Sheets\\UpdateFilterViewRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateFilterViewRequest.php',
    'Google\\Service\\Sheets\\UpdateNamedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateNamedRangeRequest.php',
    'Google\\Service\\Sheets\\UpdateProtectedRangeRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateProtectedRangeRequest.php',
    'Google\\Service\\Sheets\\UpdateSheetPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateSheetPropertiesRequest.php',
    'Google\\Service\\Sheets\\UpdateSlicerSpecRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateSlicerSpecRequest.php',
    'Google\\Service\\Sheets\\UpdateSpreadsheetPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateSpreadsheetPropertiesRequest.php',
    'Google\\Service\\Sheets\\UpdateValuesByDataFilterResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateValuesByDataFilterResponse.php',
    'Google\\Service\\Sheets\\UpdateValuesResponse' => $vendorDir . '/google/apiclient-services/src/Sheets/UpdateValuesResponse.php',
    'Google\\Service\\Sheets\\ValueRange' => $vendorDir . '/google/apiclient-services/src/Sheets/ValueRange.php',
    'Google\\Service\\Sheets\\WaterfallChartColumnStyle' => $vendorDir . '/google/apiclient-services/src/Sheets/WaterfallChartColumnStyle.php',
    'Google\\Service\\Sheets\\WaterfallChartCustomSubtotal' => $vendorDir . '/google/apiclient-services/src/Sheets/WaterfallChartCustomSubtotal.php',
    'Google\\Service\\Sheets\\WaterfallChartDomain' => $vendorDir . '/google/apiclient-services/src/Sheets/WaterfallChartDomain.php',
    'Google\\Service\\Sheets\\WaterfallChartSeries' => $vendorDir . '/google/apiclient-services/src/Sheets/WaterfallChartSeries.php',
    'Google\\Service\\Sheets\\WaterfallChartSpec' => $vendorDir . '/google/apiclient-services/src/Sheets/WaterfallChartSpec.php',
    'Google\\Service\\ShoppingContent' => $vendorDir . '/google/apiclient-services/src/ShoppingContent.php',
    'Google\\Service\\ShoppingContent\\Account' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Account.php',
    'Google\\Service\\ShoppingContent\\AccountAddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountAddress.php',
    'Google\\Service\\ShoppingContent\\AccountAdsLink' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountAdsLink.php',
    'Google\\Service\\ShoppingContent\\AccountAutomaticImprovements' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountAutomaticImprovements.php',
    'Google\\Service\\ShoppingContent\\AccountBusinessIdentity' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountBusinessIdentity.php',
    'Google\\Service\\ShoppingContent\\AccountBusinessInformation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountBusinessInformation.php',
    'Google\\Service\\ShoppingContent\\AccountConversionSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountConversionSettings.php',
    'Google\\Service\\ShoppingContent\\AccountCredentials' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountCredentials.php',
    'Google\\Service\\ShoppingContent\\AccountCustomerService' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountCustomerService.php',
    'Google\\Service\\ShoppingContent\\AccountGoogleMyBusinessLink' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountGoogleMyBusinessLink.php',
    'Google\\Service\\ShoppingContent\\AccountIdentifier' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountIdentifier.php',
    'Google\\Service\\ShoppingContent\\AccountIdentityType' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountIdentityType.php',
    'Google\\Service\\ShoppingContent\\AccountImageImprovements' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountImageImprovements.php',
    'Google\\Service\\ShoppingContent\\AccountImageImprovementsSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountImageImprovementsSettings.php',
    'Google\\Service\\ShoppingContent\\AccountIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountIssue.php',
    'Google\\Service\\ShoppingContent\\AccountIssueImpact' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountIssueImpact.php',
    'Google\\Service\\ShoppingContent\\AccountItemUpdates' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountItemUpdates.php',
    'Google\\Service\\ShoppingContent\\AccountItemUpdatesSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountItemUpdatesSettings.php',
    'Google\\Service\\ShoppingContent\\AccountLabel' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountLabel.php',
    'Google\\Service\\ShoppingContent\\AccountReturnCarrier' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountReturnCarrier.php',
    'Google\\Service\\ShoppingContent\\AccountShippingImprovements' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountShippingImprovements.php',
    'Google\\Service\\ShoppingContent\\AccountStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountStatus.php',
    'Google\\Service\\ShoppingContent\\AccountStatusAccountLevelIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountStatusAccountLevelIssue.php',
    'Google\\Service\\ShoppingContent\\AccountStatusItemLevelIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountStatusItemLevelIssue.php',
    'Google\\Service\\ShoppingContent\\AccountStatusProducts' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountStatusProducts.php',
    'Google\\Service\\ShoppingContent\\AccountStatusStatistics' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountStatusStatistics.php',
    'Google\\Service\\ShoppingContent\\AccountTax' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountTax.php',
    'Google\\Service\\ShoppingContent\\AccountTaxTaxRule' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountTaxTaxRule.php',
    'Google\\Service\\ShoppingContent\\AccountUser' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountUser.php',
    'Google\\Service\\ShoppingContent\\AccountYouTubeChannelLink' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountYouTubeChannelLink.php',
    'Google\\Service\\ShoppingContent\\AccountsAuthInfoResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsAuthInfoResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsClaimWebsiteResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsClaimWebsiteResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\AccountsCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\AccountsCustomBatchRequestEntryLinkRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsCustomBatchRequestEntryLinkRequest.php',
    'Google\\Service\\ShoppingContent\\AccountsCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\AccountsLinkRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsLinkRequest.php',
    'Google\\Service\\ShoppingContent\\AccountsLinkResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsLinkResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsListLinksResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsListLinksResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsListResponse.php',
    'Google\\Service\\ShoppingContent\\AccountsUpdateLabelsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsUpdateLabelsRequest.php',
    'Google\\Service\\ShoppingContent\\AccountsUpdateLabelsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountsUpdateLabelsResponse.php',
    'Google\\Service\\ShoppingContent\\AccountstatusesCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountstatusesCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\AccountstatusesCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountstatusesCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\AccountstatusesCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountstatusesCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\AccountstatusesCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountstatusesCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\AccountstatusesListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccountstatusesListResponse.php',
    'Google\\Service\\ShoppingContent\\AccounttaxCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccounttaxCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\AccounttaxCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccounttaxCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\AccounttaxCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccounttaxCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\AccounttaxCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccounttaxCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\AccounttaxListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AccounttaxListResponse.php',
    'Google\\Service\\ShoppingContent\\Action' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Action.php',
    'Google\\Service\\ShoppingContent\\ActionFlow' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ActionFlow.php',
    'Google\\Service\\ShoppingContent\\ActionInput' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ActionInput.php',
    'Google\\Service\\ShoppingContent\\ActionReason' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ActionReason.php',
    'Google\\Service\\ShoppingContent\\ActivateBuyOnGoogleProgramRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ActivateBuyOnGoogleProgramRequest.php',
    'Google\\Service\\ShoppingContent\\Address' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Address.php',
    'Google\\Service\\ShoppingContent\\AlternateDisputeResolution' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AlternateDisputeResolution.php',
    'Google\\Service\\ShoppingContent\\Amount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Amount.php',
    'Google\\Service\\ShoppingContent\\AttributionSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AttributionSettings.php',
    'Google\\Service\\ShoppingContent\\AttributionSettingsConversionType' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/AttributionSettingsConversionType.php',
    'Google\\Service\\ShoppingContent\\BestSellers' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BestSellers.php',
    'Google\\Service\\ShoppingContent\\Brand' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Brand.php',
    'Google\\Service\\ShoppingContent\\Breakdown' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Breakdown.php',
    'Google\\Service\\ShoppingContent\\BreakdownRegion' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BreakdownRegion.php',
    'Google\\Service\\ShoppingContent\\BuiltInSimpleAction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BuiltInSimpleAction.php',
    'Google\\Service\\ShoppingContent\\BuiltInSimpleActionAdditionalContent' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BuiltInSimpleActionAdditionalContent.php',
    'Google\\Service\\ShoppingContent\\BuiltInUserInputAction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BuiltInUserInputAction.php',
    'Google\\Service\\ShoppingContent\\BusinessDayConfig' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BusinessDayConfig.php',
    'Google\\Service\\ShoppingContent\\BusinessMessagesLink' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BusinessMessagesLink.php',
    'Google\\Service\\ShoppingContent\\BuyOnGoogleProgramStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/BuyOnGoogleProgramStatus.php',
    'Google\\Service\\ShoppingContent\\Callout' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Callout.php',
    'Google\\Service\\ShoppingContent\\CaptureOrderRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CaptureOrderRequest.php',
    'Google\\Service\\ShoppingContent\\CaptureOrderResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CaptureOrderResponse.php',
    'Google\\Service\\ShoppingContent\\CarrierRate' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CarrierRate.php',
    'Google\\Service\\ShoppingContent\\CarriersCarrier' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CarriersCarrier.php',
    'Google\\Service\\ShoppingContent\\CheckoutSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CheckoutSettings.php',
    'Google\\Service\\ShoppingContent\\CloudExportAdditionalProperties' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CloudExportAdditionalProperties.php',
    'Google\\Service\\ShoppingContent\\Collection' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Collection.php',
    'Google\\Service\\ShoppingContent\\CollectionFeaturedProduct' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CollectionFeaturedProduct.php',
    'Google\\Service\\ShoppingContent\\CollectionStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CollectionStatus.php',
    'Google\\Service\\ShoppingContent\\CollectionStatusDestinationStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CollectionStatusDestinationStatus.php',
    'Google\\Service\\ShoppingContent\\CollectionStatusItemLevelIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CollectionStatusItemLevelIssue.php',
    'Google\\Service\\ShoppingContent\\CompetitiveVisibility' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CompetitiveVisibility.php',
    'Google\\Service\\ShoppingContent\\ConversionSource' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ConversionSource.php',
    'Google\\Service\\ShoppingContent\\Css' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Css.php',
    'Google\\Service\\ShoppingContent\\CustomAttribute' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CustomAttribute.php',
    'Google\\Service\\ShoppingContent\\Customer' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Customer.php',
    'Google\\Service\\ShoppingContent\\CustomerLoyaltyData' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CustomerLoyaltyData.php',
    'Google\\Service\\ShoppingContent\\CustomerReturnReason' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CustomerReturnReason.php',
    'Google\\Service\\ShoppingContent\\CutoffTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/CutoffTime.php',
    'Google\\Service\\ShoppingContent\\Datafeed' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Datafeed.php',
    'Google\\Service\\ShoppingContent\\DatafeedFetchSchedule' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedFetchSchedule.php',
    'Google\\Service\\ShoppingContent\\DatafeedFormat' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedFormat.php',
    'Google\\Service\\ShoppingContent\\DatafeedStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedStatus.php',
    'Google\\Service\\ShoppingContent\\DatafeedStatusError' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedStatusError.php',
    'Google\\Service\\ShoppingContent\\DatafeedStatusExample' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedStatusExample.php',
    'Google\\Service\\ShoppingContent\\DatafeedTarget' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedTarget.php',
    'Google\\Service\\ShoppingContent\\DatafeedsCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\DatafeedsCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\DatafeedsCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\DatafeedsCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\DatafeedsFetchNowResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsFetchNowResponse.php',
    'Google\\Service\\ShoppingContent\\DatafeedsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedsListResponse.php',
    'Google\\Service\\ShoppingContent\\DatafeedstatusesCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedstatusesCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\DatafeedstatusesCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedstatusesCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\DatafeedstatusesCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedstatusesCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\DatafeedstatusesCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedstatusesCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\DatafeedstatusesListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DatafeedstatusesListResponse.php',
    'Google\\Service\\ShoppingContent\\Date' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Date.php',
    'Google\\Service\\ShoppingContent\\DateTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DateTime.php',
    'Google\\Service\\ShoppingContent\\DeliveryArea' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DeliveryArea.php',
    'Google\\Service\\ShoppingContent\\DeliveryAreaPostalCodeRange' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DeliveryAreaPostalCodeRange.php',
    'Google\\Service\\ShoppingContent\\DeliveryTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/DeliveryTime.php',
    'Google\\Service\\ShoppingContent\\Distance' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Distance.php',
    'Google\\Service\\ShoppingContent\\ECommercePlatformLinkInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ECommercePlatformLinkInfo.php',
    'Google\\Service\\ShoppingContent\\Error' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Error.php',
    'Google\\Service\\ShoppingContent\\Errors' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Errors.php',
    'Google\\Service\\ShoppingContent\\ExternalAction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ExternalAction.php',
    'Google\\Service\\ShoppingContent\\FreeListingsProgramStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/FreeListingsProgramStatus.php',
    'Google\\Service\\ShoppingContent\\FreeListingsProgramStatusRegionStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/FreeListingsProgramStatusRegionStatus.php',
    'Google\\Service\\ShoppingContent\\FreeListingsProgramStatusReviewIneligibilityReasonDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/FreeListingsProgramStatusReviewIneligibilityReasonDetails.php',
    'Google\\Service\\ShoppingContent\\FreeShippingThreshold' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/FreeShippingThreshold.php',
    'Google\\Service\\ShoppingContent\\GenerateRecommendationsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/GenerateRecommendationsResponse.php',
    'Google\\Service\\ShoppingContent\\GmbAccounts' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/GmbAccounts.php',
    'Google\\Service\\ShoppingContent\\GmbAccountsGmbAccount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/GmbAccountsGmbAccount.php',
    'Google\\Service\\ShoppingContent\\GoogleAnalyticsLink' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/GoogleAnalyticsLink.php',
    'Google\\Service\\ShoppingContent\\Headers' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Headers.php',
    'Google\\Service\\ShoppingContent\\HolidayCutoff' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/HolidayCutoff.php',
    'Google\\Service\\ShoppingContent\\HolidaysHoliday' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/HolidaysHoliday.php',
    'Google\\Service\\ShoppingContent\\InapplicabilityDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InapplicabilityDetails.php',
    'Google\\Service\\ShoppingContent\\InputField' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputField.php',
    'Google\\Service\\ShoppingContent\\InputFieldCheckboxInput' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputFieldCheckboxInput.php',
    'Google\\Service\\ShoppingContent\\InputFieldChoiceInput' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputFieldChoiceInput.php',
    'Google\\Service\\ShoppingContent\\InputFieldChoiceInputChoiceInputOption' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputFieldChoiceInputChoiceInputOption.php',
    'Google\\Service\\ShoppingContent\\InputFieldTextInput' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputFieldTextInput.php',
    'Google\\Service\\ShoppingContent\\InputValue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputValue.php',
    'Google\\Service\\ShoppingContent\\InputValueCheckboxInputValue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputValueCheckboxInputValue.php',
    'Google\\Service\\ShoppingContent\\InputValueChoiceInputValue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputValueChoiceInputValue.php',
    'Google\\Service\\ShoppingContent\\InputValueTextInputValue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InputValueTextInputValue.php',
    'Google\\Service\\ShoppingContent\\InsertCheckoutSettingsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InsertCheckoutSettingsRequest.php',
    'Google\\Service\\ShoppingContent\\Installment' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Installment.php',
    'Google\\Service\\ShoppingContent\\InvoiceSummary' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InvoiceSummary.php',
    'Google\\Service\\ShoppingContent\\InvoiceSummaryAdditionalChargeSummary' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/InvoiceSummaryAdditionalChargeSummary.php',
    'Google\\Service\\ShoppingContent\\LabelIds' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LabelIds.php',
    'Google\\Service\\ShoppingContent\\LiaAboutPageSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaAboutPageSettings.php',
    'Google\\Service\\ShoppingContent\\LiaCountrySettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaCountrySettings.php',
    'Google\\Service\\ShoppingContent\\LiaInventorySettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaInventorySettings.php',
    'Google\\Service\\ShoppingContent\\LiaOmnichannelExperience' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaOmnichannelExperience.php',
    'Google\\Service\\ShoppingContent\\LiaOnDisplayToOrderSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaOnDisplayToOrderSettings.php',
    'Google\\Service\\ShoppingContent\\LiaPosDataProvider' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaPosDataProvider.php',
    'Google\\Service\\ShoppingContent\\LiaSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiaSettings.php',
    'Google\\Service\\ShoppingContent\\LiasettingsCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\LiasettingsCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\LiasettingsCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\LiasettingsGetAccessibleGmbAccountsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsGetAccessibleGmbAccountsResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsListPosDataProvidersResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsListPosDataProvidersResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsListResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsRequestGmbAccessResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsRequestGmbAccessResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsRequestInventoryVerificationResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsRequestInventoryVerificationResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsSetInventoryVerificationContactResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsSetInventoryVerificationContactResponse.php',
    'Google\\Service\\ShoppingContent\\LiasettingsSetPosDataProviderResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LiasettingsSetPosDataProviderResponse.php',
    'Google\\Service\\ShoppingContent\\LinkService' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LinkService.php',
    'Google\\Service\\ShoppingContent\\LinkedAccount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LinkedAccount.php',
    'Google\\Service\\ShoppingContent\\ListAccountLabelsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListAccountLabelsResponse.php',
    'Google\\Service\\ShoppingContent\\ListAccountReturnCarrierResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListAccountReturnCarrierResponse.php',
    'Google\\Service\\ShoppingContent\\ListBusinessMessagesLinksResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListBusinessMessagesLinksResponse.php',
    'Google\\Service\\ShoppingContent\\ListCollectionStatusesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListCollectionStatusesResponse.php',
    'Google\\Service\\ShoppingContent\\ListCollectionsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListCollectionsResponse.php',
    'Google\\Service\\ShoppingContent\\ListConversionSourcesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListConversionSourcesResponse.php',
    'Google\\Service\\ShoppingContent\\ListCssesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListCssesResponse.php',
    'Google\\Service\\ShoppingContent\\ListMethodQuotasResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListMethodQuotasResponse.php',
    'Google\\Service\\ShoppingContent\\ListPromotionResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListPromotionResponse.php',
    'Google\\Service\\ShoppingContent\\ListRegionsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListRegionsResponse.php',
    'Google\\Service\\ShoppingContent\\ListRepricingProductReportsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListRepricingProductReportsResponse.php',
    'Google\\Service\\ShoppingContent\\ListRepricingRuleReportsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListRepricingRuleReportsResponse.php',
    'Google\\Service\\ShoppingContent\\ListRepricingRulesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListRepricingRulesResponse.php',
    'Google\\Service\\ShoppingContent\\ListReturnPolicyOnlineResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ListReturnPolicyOnlineResponse.php',
    'Google\\Service\\ShoppingContent\\LocalInventory' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocalInventory.php',
    'Google\\Service\\ShoppingContent\\LocalinventoryCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocalinventoryCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\LocalinventoryCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocalinventoryCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\LocalinventoryCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocalinventoryCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\LocalinventoryCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocalinventoryCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\LocationIdSet' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LocationIdSet.php',
    'Google\\Service\\ShoppingContent\\LoyaltyPoints' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LoyaltyPoints.php',
    'Google\\Service\\ShoppingContent\\LoyaltyProgram' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/LoyaltyProgram.php',
    'Google\\Service\\ShoppingContent\\MerchantCenterDestination' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MerchantCenterDestination.php',
    'Google\\Service\\ShoppingContent\\MerchantOrderReturn' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MerchantOrderReturn.php',
    'Google\\Service\\ShoppingContent\\MerchantOrderReturnItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MerchantOrderReturnItem.php',
    'Google\\Service\\ShoppingContent\\MerchantRejectionReason' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MerchantRejectionReason.php',
    'Google\\Service\\ShoppingContent\\MethodQuota' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MethodQuota.php',
    'Google\\Service\\ShoppingContent\\Metrics' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Metrics.php',
    'Google\\Service\\ShoppingContent\\MinimumOrderValueTable' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MinimumOrderValueTable.php',
    'Google\\Service\\ShoppingContent\\MinimumOrderValueTableStoreCodeSetWithMov' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MinimumOrderValueTableStoreCodeSetWithMov.php',
    'Google\\Service\\ShoppingContent\\MonetaryAmount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/MonetaryAmount.php',
    'Google\\Service\\ShoppingContent\\OnboardBuyOnGoogleProgramRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OnboardBuyOnGoogleProgramRequest.php',
    'Google\\Service\\ShoppingContent\\Order' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Order.php',
    'Google\\Service\\ShoppingContent\\OrderAddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderAddress.php',
    'Google\\Service\\ShoppingContent\\OrderCancellation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderCancellation.php',
    'Google\\Service\\ShoppingContent\\OrderCustomer' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderCustomer.php',
    'Google\\Service\\ShoppingContent\\OrderCustomerLoyaltyInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderCustomerLoyaltyInfo.php',
    'Google\\Service\\ShoppingContent\\OrderCustomerMarketingRightsInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderCustomerMarketingRightsInfo.php',
    'Google\\Service\\ShoppingContent\\OrderDeliveryDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderDeliveryDetails.php',
    'Google\\Service\\ShoppingContent\\OrderLineItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItem.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemAdjustment' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemAdjustment.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemProduct' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemProduct.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemProductFee' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemProductFee.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemProductVariantAttribute' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemProductVariantAttribute.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemReturnInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemReturnInfo.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemShippingDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemShippingDetails.php',
    'Google\\Service\\ShoppingContent\\OrderLineItemShippingDetailsMethod' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderLineItemShippingDetailsMethod.php',
    'Google\\Service\\ShoppingContent\\OrderMerchantProvidedAnnotation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderMerchantProvidedAnnotation.php',
    'Google\\Service\\ShoppingContent\\OrderOrderAnnotation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderOrderAnnotation.php',
    'Google\\Service\\ShoppingContent\\OrderPickupDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderPickupDetails.php',
    'Google\\Service\\ShoppingContent\\OrderPickupDetailsCollector' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderPickupDetailsCollector.php',
    'Google\\Service\\ShoppingContent\\OrderPromotion' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderPromotion.php',
    'Google\\Service\\ShoppingContent\\OrderPromotionItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderPromotionItem.php',
    'Google\\Service\\ShoppingContent\\OrderRefund' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderRefund.php',
    'Google\\Service\\ShoppingContent\\OrderReportDisbursement' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderReportDisbursement.php',
    'Google\\Service\\ShoppingContent\\OrderReportTransaction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderReportTransaction.php',
    'Google\\Service\\ShoppingContent\\OrderReturn' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderReturn.php',
    'Google\\Service\\ShoppingContent\\OrderShipment' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderShipment.php',
    'Google\\Service\\ShoppingContent\\OrderShipmentLineItemShipment' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderShipmentLineItemShipment.php',
    'Google\\Service\\ShoppingContent\\OrderShipmentScheduledDeliveryDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderShipmentScheduledDeliveryDetails.php',
    'Google\\Service\\ShoppingContent\\OrderTrackingSignal' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderTrackingSignal.php',
    'Google\\Service\\ShoppingContent\\OrderTrackingSignalLineItemDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderTrackingSignalLineItemDetails.php',
    'Google\\Service\\ShoppingContent\\OrderTrackingSignalShipmentLineItemMapping' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderTrackingSignalShipmentLineItemMapping.php',
    'Google\\Service\\ShoppingContent\\OrderTrackingSignalShippingInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderTrackingSignalShippingInfo.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCreateChargeInvoiceRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCreateChargeInvoiceRequest.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCreateChargeInvoiceResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCreateChargeInvoiceResponse.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCreateRefundInvoiceRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCreateRefundInvoiceRequest.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCreateRefundInvoiceResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCreateRefundInvoiceResponse.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCustomBatchRequestEntryCreateRefundInvoiceRefundOption' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCustomBatchRequestEntryCreateRefundInvoiceRefundOption.php',
    'Google\\Service\\ShoppingContent\\OrderinvoicesCustomBatchRequestEntryCreateRefundInvoiceReturnOption' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderinvoicesCustomBatchRequestEntryCreateRefundInvoiceReturnOption.php',
    'Google\\Service\\ShoppingContent\\OrderreportsListDisbursementsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreportsListDisbursementsResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreportsListTransactionsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreportsListTransactionsResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsAcknowledgeRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsAcknowledgeRequest.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsAcknowledgeResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsAcknowledgeResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsCreateOrderReturnRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsCreateOrderReturnRequest.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsCreateOrderReturnResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsCreateOrderReturnResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsLineItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsLineItem.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsListResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsPartialRefund' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsPartialRefund.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsProcessRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsProcessRequest.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsProcessResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsProcessResponse.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsRefundOperation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsRefundOperation.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsRejectOperation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsRejectOperation.php',
    'Google\\Service\\ShoppingContent\\OrderreturnsReturnItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrderreturnsReturnItem.php',
    'Google\\Service\\ShoppingContent\\OrdersAcknowledgeRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersAcknowledgeRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersAcknowledgeResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersAcknowledgeResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersAdvanceTestOrderResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersAdvanceTestOrderResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelLineItemRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelLineItemRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelLineItemResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelLineItemResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelTestOrderByCustomerRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelTestOrderByCustomerRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersCancelTestOrderByCustomerResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCancelTestOrderByCustomerResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCreateTestOrderRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCreateTestOrderRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersCreateTestOrderResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCreateTestOrderResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCreateTestReturnRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCreateTestReturnRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersCreateTestReturnResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCreateTestReturnResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersCustomBatchRequestEntryCreateTestReturnReturnItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCustomBatchRequestEntryCreateTestReturnReturnItem.php',
    'Google\\Service\\ShoppingContent\\OrdersCustomBatchRequestEntryRefundItemItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCustomBatchRequestEntryRefundItemItem.php',
    'Google\\Service\\ShoppingContent\\OrdersCustomBatchRequestEntryRefundItemShipping' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCustomBatchRequestEntryRefundItemShipping.php',
    'Google\\Service\\ShoppingContent\\OrdersCustomBatchRequestEntryShipLineItemsShipmentInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCustomBatchRequestEntryShipLineItemsShipmentInfo.php',
    'Google\\Service\\ShoppingContent\\OrdersCustomBatchRequestEntryUpdateShipmentScheduledDeliveryDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersCustomBatchRequestEntryUpdateShipmentScheduledDeliveryDetails.php',
    'Google\\Service\\ShoppingContent\\OrdersGetByMerchantOrderIdResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersGetByMerchantOrderIdResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersGetTestOrderTemplateResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersGetTestOrderTemplateResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersInStoreRefundLineItemRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersInStoreRefundLineItemRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersInStoreRefundLineItemResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersInStoreRefundLineItemResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersListResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersRefundItemRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRefundItemRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersRefundItemResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRefundItemResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersRefundOrderRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRefundOrderRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersRefundOrderResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRefundOrderResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersRejectReturnLineItemRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRejectReturnLineItemRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersRejectReturnLineItemResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersRejectReturnLineItemResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersReturnRefundLineItemRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersReturnRefundLineItemRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersReturnRefundLineItemResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersReturnRefundLineItemResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersSetLineItemMetadataRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersSetLineItemMetadataRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersSetLineItemMetadataResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersSetLineItemMetadataResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersShipLineItemsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersShipLineItemsRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersShipLineItemsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersShipLineItemsResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateLineItemShippingDetailsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateLineItemShippingDetailsRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateLineItemShippingDetailsResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateLineItemShippingDetailsResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateMerchantOrderIdRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateMerchantOrderIdRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateMerchantOrderIdResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateMerchantOrderIdResponse.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateShipmentRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateShipmentRequest.php',
    'Google\\Service\\ShoppingContent\\OrdersUpdateShipmentResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/OrdersUpdateShipmentResponse.php',
    'Google\\Service\\ShoppingContent\\PauseBuyOnGoogleProgramRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PauseBuyOnGoogleProgramRequest.php',
    'Google\\Service\\ShoppingContent\\PaymentServiceProviderLinkInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PaymentServiceProviderLinkInfo.php',
    'Google\\Service\\ShoppingContent\\PickupCarrierService' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PickupCarrierService.php',
    'Google\\Service\\ShoppingContent\\PickupServicesPickupService' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PickupServicesPickupService.php',
    'Google\\Service\\ShoppingContent\\PosCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\PosCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\PosCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\PosCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\PosDataProviders' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosDataProviders.php',
    'Google\\Service\\ShoppingContent\\PosDataProvidersPosDataProvider' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosDataProvidersPosDataProvider.php',
    'Google\\Service\\ShoppingContent\\PosInventory' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosInventory.php',
    'Google\\Service\\ShoppingContent\\PosInventoryRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosInventoryRequest.php',
    'Google\\Service\\ShoppingContent\\PosInventoryResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosInventoryResponse.php',
    'Google\\Service\\ShoppingContent\\PosListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosListResponse.php',
    'Google\\Service\\ShoppingContent\\PosSale' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosSale.php',
    'Google\\Service\\ShoppingContent\\PosSaleRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosSaleRequest.php',
    'Google\\Service\\ShoppingContent\\PosSaleResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosSaleResponse.php',
    'Google\\Service\\ShoppingContent\\PosStore' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PosStore.php',
    'Google\\Service\\ShoppingContent\\PostalCodeGroup' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PostalCodeGroup.php',
    'Google\\Service\\ShoppingContent\\PostalCodeRange' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PostalCodeRange.php',
    'Google\\Service\\ShoppingContent\\Price' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Price.php',
    'Google\\Service\\ShoppingContent\\PriceAmount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PriceAmount.php',
    'Google\\Service\\ShoppingContent\\PriceCompetitiveness' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PriceCompetitiveness.php',
    'Google\\Service\\ShoppingContent\\PriceInsights' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PriceInsights.php',
    'Google\\Service\\ShoppingContent\\Product' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Product.php',
    'Google\\Service\\ShoppingContent\\ProductAmount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductAmount.php',
    'Google\\Service\\ShoppingContent\\ProductCertification' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductCertification.php',
    'Google\\Service\\ShoppingContent\\ProductCluster' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductCluster.php',
    'Google\\Service\\ShoppingContent\\ProductDeliveryTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductDeliveryTime.php',
    'Google\\Service\\ShoppingContent\\ProductDeliveryTimeAreaDeliveryTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductDeliveryTimeAreaDeliveryTime.php',
    'Google\\Service\\ShoppingContent\\ProductDeliveryTimeAreaDeliveryTimeDeliveryTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductDeliveryTimeAreaDeliveryTimeDeliveryTime.php',
    'Google\\Service\\ShoppingContent\\ProductDimension' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductDimension.php',
    'Google\\Service\\ShoppingContent\\ProductId' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductId.php',
    'Google\\Service\\ShoppingContent\\ProductIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductIssue.php',
    'Google\\Service\\ShoppingContent\\ProductIssueImpact' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductIssueImpact.php',
    'Google\\Service\\ShoppingContent\\ProductProductDetail' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductProductDetail.php',
    'Google\\Service\\ShoppingContent\\ProductShipping' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductShipping.php',
    'Google\\Service\\ShoppingContent\\ProductShippingDimension' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductShippingDimension.php',
    'Google\\Service\\ShoppingContent\\ProductShippingWeight' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductShippingWeight.php',
    'Google\\Service\\ShoppingContent\\ProductStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductStatus.php',
    'Google\\Service\\ShoppingContent\\ProductStatusDestinationStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductStatusDestinationStatus.php',
    'Google\\Service\\ShoppingContent\\ProductStatusItemLevelIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductStatusItemLevelIssue.php',
    'Google\\Service\\ShoppingContent\\ProductStructuredDescription' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductStructuredDescription.php',
    'Google\\Service\\ShoppingContent\\ProductStructuredTitle' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductStructuredTitle.php',
    'Google\\Service\\ShoppingContent\\ProductSubscriptionCost' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductSubscriptionCost.php',
    'Google\\Service\\ShoppingContent\\ProductTax' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductTax.php',
    'Google\\Service\\ShoppingContent\\ProductUnitPricingBaseMeasure' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductUnitPricingBaseMeasure.php',
    'Google\\Service\\ShoppingContent\\ProductUnitPricingMeasure' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductUnitPricingMeasure.php',
    'Google\\Service\\ShoppingContent\\ProductView' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductView.php',
    'Google\\Service\\ShoppingContent\\ProductViewItemIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductViewItemIssue.php',
    'Google\\Service\\ShoppingContent\\ProductViewItemIssueIssueSeverityPerDestination' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductViewItemIssueIssueSeverityPerDestination.php',
    'Google\\Service\\ShoppingContent\\ProductViewItemIssueItemIssueSeverity' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductViewItemIssueItemIssueSeverity.php',
    'Google\\Service\\ShoppingContent\\ProductViewItemIssueItemIssueType' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductViewItemIssueItemIssueType.php',
    'Google\\Service\\ShoppingContent\\ProductWeight' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductWeight.php',
    'Google\\Service\\ShoppingContent\\ProductsCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductsCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\ProductsCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductsCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\ProductsCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductsCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\ProductsCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductsCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\ProductsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductsListResponse.php',
    'Google\\Service\\ShoppingContent\\ProductstatusesCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductstatusesCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\ProductstatusesCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductstatusesCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\ProductstatusesCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductstatusesCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\ProductstatusesCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductstatusesCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\ProductstatusesListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ProductstatusesListResponse.php',
    'Google\\Service\\ShoppingContent\\Promotion' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Promotion.php',
    'Google\\Service\\ShoppingContent\\PromotionPromotionStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PromotionPromotionStatus.php',
    'Google\\Service\\ShoppingContent\\PromotionPromotionStatusDestinationStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PromotionPromotionStatusDestinationStatus.php',
    'Google\\Service\\ShoppingContent\\PromotionPromotionStatusPromotionIssue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PromotionPromotionStatusPromotionIssue.php',
    'Google\\Service\\ShoppingContent\\PubsubNotificationSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/PubsubNotificationSettings.php',
    'Google\\Service\\ShoppingContent\\RateGroup' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RateGroup.php',
    'Google\\Service\\ShoppingContent\\Recommendation' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Recommendation.php',
    'Google\\Service\\ShoppingContent\\RecommendationCallToAction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RecommendationCallToAction.php',
    'Google\\Service\\ShoppingContent\\RecommendationCreative' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RecommendationCreative.php',
    'Google\\Service\\ShoppingContent\\RecommendationDescription' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RecommendationDescription.php',
    'Google\\Service\\ShoppingContent\\RefundReason' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RefundReason.php',
    'Google\\Service\\ShoppingContent\\Region' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Region.php',
    'Google\\Service\\ShoppingContent\\RegionGeoTargetArea' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionGeoTargetArea.php',
    'Google\\Service\\ShoppingContent\\RegionPostalCodeArea' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionPostalCodeArea.php',
    'Google\\Service\\ShoppingContent\\RegionPostalCodeAreaPostalCodeRange' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionPostalCodeAreaPostalCodeRange.php',
    'Google\\Service\\ShoppingContent\\RegionalInventory' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionalInventory.php',
    'Google\\Service\\ShoppingContent\\RegionalinventoryCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionalinventoryCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\RegionalinventoryCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionalinventoryCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\RegionalinventoryCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionalinventoryCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\RegionalinventoryCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RegionalinventoryCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\RenderAccountIssuesRequestPayload' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RenderAccountIssuesRequestPayload.php',
    'Google\\Service\\ShoppingContent\\RenderAccountIssuesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RenderAccountIssuesResponse.php',
    'Google\\Service\\ShoppingContent\\RenderProductIssuesRequestPayload' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RenderProductIssuesRequestPayload.php',
    'Google\\Service\\ShoppingContent\\RenderProductIssuesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RenderProductIssuesResponse.php',
    'Google\\Service\\ShoppingContent\\ReportInteractionRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReportInteractionRequest.php',
    'Google\\Service\\ShoppingContent\\ReportRow' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReportRow.php',
    'Google\\Service\\ShoppingContent\\RepricingProductReport' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingProductReport.php',
    'Google\\Service\\ShoppingContent\\RepricingProductReportBuyboxWinningProductStats' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingProductReportBuyboxWinningProductStats.php',
    'Google\\Service\\ShoppingContent\\RepricingRule' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRule.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleCostOfGoodsSaleRule' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleCostOfGoodsSaleRule.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleEffectiveTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleEffectiveTime.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleEffectiveTimeFixedTimePeriod' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleEffectiveTimeFixedTimePeriod.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleEligibleOfferMatcher' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleEligibleOfferMatcher.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleEligibleOfferMatcherStringMatcher' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleEligibleOfferMatcherStringMatcher.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleReport' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleReport.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleReportBuyboxWinningRuleStats' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleReportBuyboxWinningRuleStats.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleRestriction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleRestriction.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleRestrictionBoundary' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleRestrictionBoundary.php',
    'Google\\Service\\ShoppingContent\\RepricingRuleStatsBasedRule' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RepricingRuleStatsBasedRule.php',
    'Google\\Service\\ShoppingContent\\RequestPhoneVerificationRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RequestPhoneVerificationRequest.php',
    'Google\\Service\\ShoppingContent\\RequestPhoneVerificationResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RequestPhoneVerificationResponse.php',
    'Google\\Service\\ShoppingContent\\RequestReviewBuyOnGoogleProgramRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RequestReviewBuyOnGoogleProgramRequest.php',
    'Google\\Service\\ShoppingContent\\RequestReviewFreeListingsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RequestReviewFreeListingsRequest.php',
    'Google\\Service\\ShoppingContent\\RequestReviewShoppingAdsRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/RequestReviewShoppingAdsRequest.php',
    'Google\\Service\\ShoppingContent\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Accounts.php',
    'Google\\Service\\ShoppingContent\\Resource\\AccountsBusinessmessageslinks' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/AccountsBusinessmessageslinks.php',
    'Google\\Service\\ShoppingContent\\Resource\\AccountsCredentials' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/AccountsCredentials.php',
    'Google\\Service\\ShoppingContent\\Resource\\AccountsLabels' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/AccountsLabels.php',
    'Google\\Service\\ShoppingContent\\Resource\\AccountsReturncarrier' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/AccountsReturncarrier.php',
    'Google\\Service\\ShoppingContent\\Resource\\Accountsbyexternalsellerid' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Accountsbyexternalsellerid.php',
    'Google\\Service\\ShoppingContent\\Resource\\Accountstatuses' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Accountstatuses.php',
    'Google\\Service\\ShoppingContent\\Resource\\Accountstatusesbyexternalsellerid' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Accountstatusesbyexternalsellerid.php',
    'Google\\Service\\ShoppingContent\\Resource\\Accounttax' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Accounttax.php',
    'Google\\Service\\ShoppingContent\\Resource\\Buyongoogleprograms' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Buyongoogleprograms.php',
    'Google\\Service\\ShoppingContent\\Resource\\Collections' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Collections.php',
    'Google\\Service\\ShoppingContent\\Resource\\Collectionstatuses' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Collectionstatuses.php',
    'Google\\Service\\ShoppingContent\\Resource\\Conversionsources' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Conversionsources.php',
    'Google\\Service\\ShoppingContent\\Resource\\Csses' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Csses.php',
    'Google\\Service\\ShoppingContent\\Resource\\Customers' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Customers.php',
    'Google\\Service\\ShoppingContent\\Resource\\Datafeeds' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Datafeeds.php',
    'Google\\Service\\ShoppingContent\\Resource\\Datafeedstatuses' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Datafeedstatuses.php',
    'Google\\Service\\ShoppingContent\\Resource\\Freelistingsprogram' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Freelistingsprogram.php',
    'Google\\Service\\ShoppingContent\\Resource\\FreelistingsprogramCheckoutsettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/FreelistingsprogramCheckoutsettings.php',
    'Google\\Service\\ShoppingContent\\Resource\\Liasettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Liasettings.php',
    'Google\\Service\\ShoppingContent\\Resource\\Localinventory' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Localinventory.php',
    'Google\\Service\\ShoppingContent\\Resource\\Merchantsupport' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Merchantsupport.php',
    'Google\\Service\\ShoppingContent\\Resource\\Orderinvoices' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Orderinvoices.php',
    'Google\\Service\\ShoppingContent\\Resource\\Orderreports' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Orderreports.php',
    'Google\\Service\\ShoppingContent\\Resource\\Orderreturns' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Orderreturns.php',
    'Google\\Service\\ShoppingContent\\Resource\\OrderreturnsLabels' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/OrderreturnsLabels.php',
    'Google\\Service\\ShoppingContent\\Resource\\Orders' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Orders.php',
    'Google\\Service\\ShoppingContent\\Resource\\Ordertrackingsignals' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Ordertrackingsignals.php',
    'Google\\Service\\ShoppingContent\\Resource\\Pos' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Pos.php',
    'Google\\Service\\ShoppingContent\\Resource\\Productdeliverytime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Productdeliverytime.php',
    'Google\\Service\\ShoppingContent\\Resource\\Products' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Products.php',
    'Google\\Service\\ShoppingContent\\Resource\\Productstatuses' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Productstatuses.php',
    'Google\\Service\\ShoppingContent\\Resource\\ProductstatusesRepricingreports' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/ProductstatusesRepricingreports.php',
    'Google\\Service\\ShoppingContent\\Resource\\Promotions' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Promotions.php',
    'Google\\Service\\ShoppingContent\\Resource\\Pubsubnotificationsettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Pubsubnotificationsettings.php',
    'Google\\Service\\ShoppingContent\\Resource\\Quotas' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Quotas.php',
    'Google\\Service\\ShoppingContent\\Resource\\Recommendations' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Recommendations.php',
    'Google\\Service\\ShoppingContent\\Resource\\Regionalinventory' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Regionalinventory.php',
    'Google\\Service\\ShoppingContent\\Resource\\Regions' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Regions.php',
    'Google\\Service\\ShoppingContent\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Reports.php',
    'Google\\Service\\ShoppingContent\\Resource\\Repricingrules' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Repricingrules.php',
    'Google\\Service\\ShoppingContent\\Resource\\RepricingrulesRepricingreports' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/RepricingrulesRepricingreports.php',
    'Google\\Service\\ShoppingContent\\Resource\\Returnaddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Returnaddress.php',
    'Google\\Service\\ShoppingContent\\Resource\\Returnpolicy' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Returnpolicy.php',
    'Google\\Service\\ShoppingContent\\Resource\\Returnpolicyonline' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Returnpolicyonline.php',
    'Google\\Service\\ShoppingContent\\Resource\\Settlementreports' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Settlementreports.php',
    'Google\\Service\\ShoppingContent\\Resource\\Settlementtransactions' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Settlementtransactions.php',
    'Google\\Service\\ShoppingContent\\Resource\\Shippingsettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Shippingsettings.php',
    'Google\\Service\\ShoppingContent\\Resource\\Shoppingadsprogram' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Resource/Shoppingadsprogram.php',
    'Google\\Service\\ShoppingContent\\ReturnAddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnAddress.php',
    'Google\\Service\\ShoppingContent\\ReturnAddressAddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnAddressAddress.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicy' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicy.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyOnline' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyOnline.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyOnlinePolicy' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyOnlinePolicy.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyOnlineRestockingFee' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyOnlineRestockingFee.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyOnlineReturnReasonCategoryInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyOnlineReturnReasonCategoryInfo.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyOnlineReturnShippingFee' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyOnlineReturnShippingFee.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicyPolicy' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicyPolicy.php',
    'Google\\Service\\ShoppingContent\\ReturnPolicySeasonalOverride' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPolicySeasonalOverride.php',
    'Google\\Service\\ShoppingContent\\ReturnPricingInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnPricingInfo.php',
    'Google\\Service\\ShoppingContent\\ReturnShipment' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnShipment.php',
    'Google\\Service\\ShoppingContent\\ReturnShippingLabel' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnShippingLabel.php',
    'Google\\Service\\ShoppingContent\\ReturnaddressCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnaddressCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\ReturnaddressCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnaddressCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\ReturnaddressCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnaddressCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\ReturnaddressCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnaddressCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\ReturnaddressListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnaddressListResponse.php',
    'Google\\Service\\ShoppingContent\\ReturnpolicyCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnpolicyCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\ReturnpolicyCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnpolicyCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\ReturnpolicyCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnpolicyCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\ReturnpolicyCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnpolicyCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\ReturnpolicyListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ReturnpolicyListResponse.php',
    'Google\\Service\\ShoppingContent\\Row' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Row.php',
    'Google\\Service\\ShoppingContent\\SearchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SearchRequest.php',
    'Google\\Service\\ShoppingContent\\SearchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SearchResponse.php',
    'Google\\Service\\ShoppingContent\\Segments' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Segments.php',
    'Google\\Service\\ShoppingContent\\Service' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Service.php',
    'Google\\Service\\ShoppingContent\\ServiceStoreConfig' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ServiceStoreConfig.php',
    'Google\\Service\\ShoppingContent\\ServiceStoreConfigCutoffConfig' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ServiceStoreConfigCutoffConfig.php',
    'Google\\Service\\ShoppingContent\\ServiceStoreConfigCutoffConfigLocalCutoffTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ServiceStoreConfigCutoffConfigLocalCutoffTime.php',
    'Google\\Service\\ShoppingContent\\SettlementReport' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementReport.php',
    'Google\\Service\\ShoppingContent\\SettlementTransaction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementTransaction.php',
    'Google\\Service\\ShoppingContent\\SettlementTransactionAmount' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementTransactionAmount.php',
    'Google\\Service\\ShoppingContent\\SettlementTransactionAmountCommission' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementTransactionAmountCommission.php',
    'Google\\Service\\ShoppingContent\\SettlementTransactionIdentifiers' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementTransactionIdentifiers.php',
    'Google\\Service\\ShoppingContent\\SettlementTransactionTransaction' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementTransactionTransaction.php',
    'Google\\Service\\ShoppingContent\\SettlementreportsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementreportsListResponse.php',
    'Google\\Service\\ShoppingContent\\SettlementtransactionsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/SettlementtransactionsListResponse.php',
    'Google\\Service\\ShoppingContent\\ShipmentInvoice' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShipmentInvoice.php',
    'Google\\Service\\ShoppingContent\\ShipmentInvoiceLineItemInvoice' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShipmentInvoiceLineItemInvoice.php',
    'Google\\Service\\ShoppingContent\\ShipmentTrackingInfo' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShipmentTrackingInfo.php',
    'Google\\Service\\ShoppingContent\\ShippingSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingSettings.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsCustomBatchRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsCustomBatchRequest.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsCustomBatchRequestEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsCustomBatchRequestEntry.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsCustomBatchResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsCustomBatchResponse.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsCustomBatchResponseEntry' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsCustomBatchResponseEntry.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsGetSupportedCarriersResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsGetSupportedCarriersResponse.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsGetSupportedHolidaysResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsGetSupportedHolidaysResponse.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsGetSupportedPickupServicesResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsGetSupportedPickupServicesResponse.php',
    'Google\\Service\\ShoppingContent\\ShippingsettingsListResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShippingsettingsListResponse.php',
    'Google\\Service\\ShoppingContent\\ShoppingAdsProgramStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShoppingAdsProgramStatus.php',
    'Google\\Service\\ShoppingContent\\ShoppingAdsProgramStatusRegionStatus' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShoppingAdsProgramStatusRegionStatus.php',
    'Google\\Service\\ShoppingContent\\ShoppingAdsProgramStatusReviewIneligibilityReasonDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/ShoppingAdsProgramStatusReviewIneligibilityReasonDetails.php',
    'Google\\Service\\ShoppingContent\\Table' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Table.php',
    'Google\\Service\\ShoppingContent\\TestOrder' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrder.php',
    'Google\\Service\\ShoppingContent\\TestOrderAddress' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderAddress.php',
    'Google\\Service\\ShoppingContent\\TestOrderDeliveryDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderDeliveryDetails.php',
    'Google\\Service\\ShoppingContent\\TestOrderLineItem' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderLineItem.php',
    'Google\\Service\\ShoppingContent\\TestOrderLineItemProduct' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderLineItemProduct.php',
    'Google\\Service\\ShoppingContent\\TestOrderPickupDetails' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderPickupDetails.php',
    'Google\\Service\\ShoppingContent\\TestOrderPickupDetailsPickupPerson' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TestOrderPickupDetailsPickupPerson.php',
    'Google\\Service\\ShoppingContent\\TextWithTooltip' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TextWithTooltip.php',
    'Google\\Service\\ShoppingContent\\TimePeriod' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TimePeriod.php',
    'Google\\Service\\ShoppingContent\\TimeZone' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TimeZone.php',
    'Google\\Service\\ShoppingContent\\TopicTrends' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TopicTrends.php',
    'Google\\Service\\ShoppingContent\\TransitTable' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TransitTable.php',
    'Google\\Service\\ShoppingContent\\TransitTableTransitTimeRow' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TransitTableTransitTimeRow.php',
    'Google\\Service\\ShoppingContent\\TransitTableTransitTimeRowTransitTimeValue' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TransitTableTransitTimeRowTransitTimeValue.php',
    'Google\\Service\\ShoppingContent\\TriggerActionPayload' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TriggerActionPayload.php',
    'Google\\Service\\ShoppingContent\\TriggerActionResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/TriggerActionResponse.php',
    'Google\\Service\\ShoppingContent\\UndeleteConversionSourceRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/UndeleteConversionSourceRequest.php',
    'Google\\Service\\ShoppingContent\\UnitInvoice' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/UnitInvoice.php',
    'Google\\Service\\ShoppingContent\\UnitInvoiceAdditionalCharge' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/UnitInvoiceAdditionalCharge.php',
    'Google\\Service\\ShoppingContent\\UnitInvoiceTaxLine' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/UnitInvoiceTaxLine.php',
    'Google\\Service\\ShoppingContent\\UrlSettings' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/UrlSettings.php',
    'Google\\Service\\ShoppingContent\\Value' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Value.php',
    'Google\\Service\\ShoppingContent\\VerifyPhoneNumberRequest' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/VerifyPhoneNumberRequest.php',
    'Google\\Service\\ShoppingContent\\VerifyPhoneNumberResponse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/VerifyPhoneNumberResponse.php',
    'Google\\Service\\ShoppingContent\\Warehouse' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Warehouse.php',
    'Google\\Service\\ShoppingContent\\WarehouseBasedDeliveryTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/WarehouseBasedDeliveryTime.php',
    'Google\\Service\\ShoppingContent\\WarehouseCutoffTime' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/WarehouseCutoffTime.php',
    'Google\\Service\\ShoppingContent\\Weight' => $vendorDir . '/google/apiclient-services/src/ShoppingContent/Weight.php',
    'Google\\Service\\SiteVerification' => $vendorDir . '/google/apiclient-services/src/SiteVerification.php',
    'Google\\Service\\SiteVerification\\Resource\\WebResource' => $vendorDir . '/google/apiclient-services/src/SiteVerification/Resource/WebResource.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenRequest' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceGettokenRequest.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenRequestSite' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceGettokenRequestSite.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenResponse' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceGettokenResponse.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceListResponse' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceListResponse.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceResource' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceResource.php',
    'Google\\Service\\SiteVerification\\SiteVerificationWebResourceResourceSite' => $vendorDir . '/google/apiclient-services/src/SiteVerification/SiteVerificationWebResourceResourceSite.php',
    'Google\\Service\\Slides' => $vendorDir . '/google/apiclient-services/src/Slides.php',
    'Google\\Service\\Slides\\AffineTransform' => $vendorDir . '/google/apiclient-services/src/Slides/AffineTransform.php',
    'Google\\Service\\Slides\\AutoText' => $vendorDir . '/google/apiclient-services/src/Slides/AutoText.php',
    'Google\\Service\\Slides\\Autofit' => $vendorDir . '/google/apiclient-services/src/Slides/Autofit.php',
    'Google\\Service\\Slides\\BatchUpdatePresentationRequest' => $vendorDir . '/google/apiclient-services/src/Slides/BatchUpdatePresentationRequest.php',
    'Google\\Service\\Slides\\BatchUpdatePresentationResponse' => $vendorDir . '/google/apiclient-services/src/Slides/BatchUpdatePresentationResponse.php',
    'Google\\Service\\Slides\\Bullet' => $vendorDir . '/google/apiclient-services/src/Slides/Bullet.php',
    'Google\\Service\\Slides\\ColorScheme' => $vendorDir . '/google/apiclient-services/src/Slides/ColorScheme.php',
    'Google\\Service\\Slides\\ColorStop' => $vendorDir . '/google/apiclient-services/src/Slides/ColorStop.php',
    'Google\\Service\\Slides\\CreateImageRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateImageRequest.php',
    'Google\\Service\\Slides\\CreateImageResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateImageResponse.php',
    'Google\\Service\\Slides\\CreateLineRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateLineRequest.php',
    'Google\\Service\\Slides\\CreateLineResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateLineResponse.php',
    'Google\\Service\\Slides\\CreateParagraphBulletsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateParagraphBulletsRequest.php',
    'Google\\Service\\Slides\\CreateShapeRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateShapeRequest.php',
    'Google\\Service\\Slides\\CreateShapeResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateShapeResponse.php',
    'Google\\Service\\Slides\\CreateSheetsChartRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateSheetsChartRequest.php',
    'Google\\Service\\Slides\\CreateSheetsChartResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateSheetsChartResponse.php',
    'Google\\Service\\Slides\\CreateSlideRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateSlideRequest.php',
    'Google\\Service\\Slides\\CreateSlideResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateSlideResponse.php',
    'Google\\Service\\Slides\\CreateTableRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateTableRequest.php',
    'Google\\Service\\Slides\\CreateTableResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateTableResponse.php',
    'Google\\Service\\Slides\\CreateVideoRequest' => $vendorDir . '/google/apiclient-services/src/Slides/CreateVideoRequest.php',
    'Google\\Service\\Slides\\CreateVideoResponse' => $vendorDir . '/google/apiclient-services/src/Slides/CreateVideoResponse.php',
    'Google\\Service\\Slides\\CropProperties' => $vendorDir . '/google/apiclient-services/src/Slides/CropProperties.php',
    'Google\\Service\\Slides\\DeleteObjectRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DeleteObjectRequest.php',
    'Google\\Service\\Slides\\DeleteParagraphBulletsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DeleteParagraphBulletsRequest.php',
    'Google\\Service\\Slides\\DeleteTableColumnRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DeleteTableColumnRequest.php',
    'Google\\Service\\Slides\\DeleteTableRowRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DeleteTableRowRequest.php',
    'Google\\Service\\Slides\\DeleteTextRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DeleteTextRequest.php',
    'Google\\Service\\Slides\\Dimension' => $vendorDir . '/google/apiclient-services/src/Slides/Dimension.php',
    'Google\\Service\\Slides\\DuplicateObjectRequest' => $vendorDir . '/google/apiclient-services/src/Slides/DuplicateObjectRequest.php',
    'Google\\Service\\Slides\\DuplicateObjectResponse' => $vendorDir . '/google/apiclient-services/src/Slides/DuplicateObjectResponse.php',
    'Google\\Service\\Slides\\Group' => $vendorDir . '/google/apiclient-services/src/Slides/Group.php',
    'Google\\Service\\Slides\\GroupObjectsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/GroupObjectsRequest.php',
    'Google\\Service\\Slides\\GroupObjectsResponse' => $vendorDir . '/google/apiclient-services/src/Slides/GroupObjectsResponse.php',
    'Google\\Service\\Slides\\Image' => $vendorDir . '/google/apiclient-services/src/Slides/Image.php',
    'Google\\Service\\Slides\\ImageProperties' => $vendorDir . '/google/apiclient-services/src/Slides/ImageProperties.php',
    'Google\\Service\\Slides\\InsertTableColumnsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/InsertTableColumnsRequest.php',
    'Google\\Service\\Slides\\InsertTableRowsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/InsertTableRowsRequest.php',
    'Google\\Service\\Slides\\InsertTextRequest' => $vendorDir . '/google/apiclient-services/src/Slides/InsertTextRequest.php',
    'Google\\Service\\Slides\\LayoutPlaceholderIdMapping' => $vendorDir . '/google/apiclient-services/src/Slides/LayoutPlaceholderIdMapping.php',
    'Google\\Service\\Slides\\LayoutProperties' => $vendorDir . '/google/apiclient-services/src/Slides/LayoutProperties.php',
    'Google\\Service\\Slides\\LayoutReference' => $vendorDir . '/google/apiclient-services/src/Slides/LayoutReference.php',
    'Google\\Service\\Slides\\Line' => $vendorDir . '/google/apiclient-services/src/Slides/Line.php',
    'Google\\Service\\Slides\\LineConnection' => $vendorDir . '/google/apiclient-services/src/Slides/LineConnection.php',
    'Google\\Service\\Slides\\LineFill' => $vendorDir . '/google/apiclient-services/src/Slides/LineFill.php',
    'Google\\Service\\Slides\\LineProperties' => $vendorDir . '/google/apiclient-services/src/Slides/LineProperties.php',
    'Google\\Service\\Slides\\Link' => $vendorDir . '/google/apiclient-services/src/Slides/Link.php',
    'Google\\Service\\Slides\\MasterProperties' => $vendorDir . '/google/apiclient-services/src/Slides/MasterProperties.php',
    'Google\\Service\\Slides\\MergeTableCellsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/MergeTableCellsRequest.php',
    'Google\\Service\\Slides\\NestingLevel' => $vendorDir . '/google/apiclient-services/src/Slides/NestingLevel.php',
    'Google\\Service\\Slides\\NotesProperties' => $vendorDir . '/google/apiclient-services/src/Slides/NotesProperties.php',
    'Google\\Service\\Slides\\OpaqueColor' => $vendorDir . '/google/apiclient-services/src/Slides/OpaqueColor.php',
    'Google\\Service\\Slides\\OptionalColor' => $vendorDir . '/google/apiclient-services/src/Slides/OptionalColor.php',
    'Google\\Service\\Slides\\Outline' => $vendorDir . '/google/apiclient-services/src/Slides/Outline.php',
    'Google\\Service\\Slides\\OutlineFill' => $vendorDir . '/google/apiclient-services/src/Slides/OutlineFill.php',
    'Google\\Service\\Slides\\Page' => $vendorDir . '/google/apiclient-services/src/Slides/Page.php',
    'Google\\Service\\Slides\\PageBackgroundFill' => $vendorDir . '/google/apiclient-services/src/Slides/PageBackgroundFill.php',
    'Google\\Service\\Slides\\PageElement' => $vendorDir . '/google/apiclient-services/src/Slides/PageElement.php',
    'Google\\Service\\Slides\\PageElementProperties' => $vendorDir . '/google/apiclient-services/src/Slides/PageElementProperties.php',
    'Google\\Service\\Slides\\PageProperties' => $vendorDir . '/google/apiclient-services/src/Slides/PageProperties.php',
    'Google\\Service\\Slides\\ParagraphMarker' => $vendorDir . '/google/apiclient-services/src/Slides/ParagraphMarker.php',
    'Google\\Service\\Slides\\ParagraphStyle' => $vendorDir . '/google/apiclient-services/src/Slides/ParagraphStyle.php',
    'Google\\Service\\Slides\\Placeholder' => $vendorDir . '/google/apiclient-services/src/Slides/Placeholder.php',
    'Google\\Service\\Slides\\Presentation' => $vendorDir . '/google/apiclient-services/src/Slides/Presentation.php',
    'Google\\Service\\Slides\\Range' => $vendorDir . '/google/apiclient-services/src/Slides/Range.php',
    'Google\\Service\\Slides\\Recolor' => $vendorDir . '/google/apiclient-services/src/Slides/Recolor.php',
    'Google\\Service\\Slides\\RefreshSheetsChartRequest' => $vendorDir . '/google/apiclient-services/src/Slides/RefreshSheetsChartRequest.php',
    'Google\\Service\\Slides\\ReplaceAllShapesWithImageRequest' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllShapesWithImageRequest.php',
    'Google\\Service\\Slides\\ReplaceAllShapesWithImageResponse' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllShapesWithImageResponse.php',
    'Google\\Service\\Slides\\ReplaceAllShapesWithSheetsChartRequest' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllShapesWithSheetsChartRequest.php',
    'Google\\Service\\Slides\\ReplaceAllShapesWithSheetsChartResponse' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllShapesWithSheetsChartResponse.php',
    'Google\\Service\\Slides\\ReplaceAllTextRequest' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllTextRequest.php',
    'Google\\Service\\Slides\\ReplaceAllTextResponse' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceAllTextResponse.php',
    'Google\\Service\\Slides\\ReplaceImageRequest' => $vendorDir . '/google/apiclient-services/src/Slides/ReplaceImageRequest.php',
    'Google\\Service\\Slides\\Request' => $vendorDir . '/google/apiclient-services/src/Slides/Request.php',
    'Google\\Service\\Slides\\RerouteLineRequest' => $vendorDir . '/google/apiclient-services/src/Slides/RerouteLineRequest.php',
    'Google\\Service\\Slides\\Resource\\Presentations' => $vendorDir . '/google/apiclient-services/src/Slides/Resource/Presentations.php',
    'Google\\Service\\Slides\\Resource\\PresentationsPages' => $vendorDir . '/google/apiclient-services/src/Slides/Resource/PresentationsPages.php',
    'Google\\Service\\Slides\\Response' => $vendorDir . '/google/apiclient-services/src/Slides/Response.php',
    'Google\\Service\\Slides\\RgbColor' => $vendorDir . '/google/apiclient-services/src/Slides/RgbColor.php',
    'Google\\Service\\Slides\\Shadow' => $vendorDir . '/google/apiclient-services/src/Slides/Shadow.php',
    'Google\\Service\\Slides\\Shape' => $vendorDir . '/google/apiclient-services/src/Slides/Shape.php',
    'Google\\Service\\Slides\\ShapeBackgroundFill' => $vendorDir . '/google/apiclient-services/src/Slides/ShapeBackgroundFill.php',
    'Google\\Service\\Slides\\ShapeProperties' => $vendorDir . '/google/apiclient-services/src/Slides/ShapeProperties.php',
    'Google\\Service\\Slides\\SheetsChart' => $vendorDir . '/google/apiclient-services/src/Slides/SheetsChart.php',
    'Google\\Service\\Slides\\SheetsChartProperties' => $vendorDir . '/google/apiclient-services/src/Slides/SheetsChartProperties.php',
    'Google\\Service\\Slides\\Size' => $vendorDir . '/google/apiclient-services/src/Slides/Size.php',
    'Google\\Service\\Slides\\SlideProperties' => $vendorDir . '/google/apiclient-services/src/Slides/SlideProperties.php',
    'Google\\Service\\Slides\\SlidesList' => $vendorDir . '/google/apiclient-services/src/Slides/SlidesList.php',
    'Google\\Service\\Slides\\SolidFill' => $vendorDir . '/google/apiclient-services/src/Slides/SolidFill.php',
    'Google\\Service\\Slides\\SpeakerSpotlight' => $vendorDir . '/google/apiclient-services/src/Slides/SpeakerSpotlight.php',
    'Google\\Service\\Slides\\SpeakerSpotlightProperties' => $vendorDir . '/google/apiclient-services/src/Slides/SpeakerSpotlightProperties.php',
    'Google\\Service\\Slides\\StretchedPictureFill' => $vendorDir . '/google/apiclient-services/src/Slides/StretchedPictureFill.php',
    'Google\\Service\\Slides\\SubstringMatchCriteria' => $vendorDir . '/google/apiclient-services/src/Slides/SubstringMatchCriteria.php',
    'Google\\Service\\Slides\\Table' => $vendorDir . '/google/apiclient-services/src/Slides/Table.php',
    'Google\\Service\\Slides\\TableBorderCell' => $vendorDir . '/google/apiclient-services/src/Slides/TableBorderCell.php',
    'Google\\Service\\Slides\\TableBorderFill' => $vendorDir . '/google/apiclient-services/src/Slides/TableBorderFill.php',
    'Google\\Service\\Slides\\TableBorderProperties' => $vendorDir . '/google/apiclient-services/src/Slides/TableBorderProperties.php',
    'Google\\Service\\Slides\\TableBorderRow' => $vendorDir . '/google/apiclient-services/src/Slides/TableBorderRow.php',
    'Google\\Service\\Slides\\TableCell' => $vendorDir . '/google/apiclient-services/src/Slides/TableCell.php',
    'Google\\Service\\Slides\\TableCellBackgroundFill' => $vendorDir . '/google/apiclient-services/src/Slides/TableCellBackgroundFill.php',
    'Google\\Service\\Slides\\TableCellLocation' => $vendorDir . '/google/apiclient-services/src/Slides/TableCellLocation.php',
    'Google\\Service\\Slides\\TableCellProperties' => $vendorDir . '/google/apiclient-services/src/Slides/TableCellProperties.php',
    'Google\\Service\\Slides\\TableColumnProperties' => $vendorDir . '/google/apiclient-services/src/Slides/TableColumnProperties.php',
    'Google\\Service\\Slides\\TableRange' => $vendorDir . '/google/apiclient-services/src/Slides/TableRange.php',
    'Google\\Service\\Slides\\TableRow' => $vendorDir . '/google/apiclient-services/src/Slides/TableRow.php',
    'Google\\Service\\Slides\\TableRowProperties' => $vendorDir . '/google/apiclient-services/src/Slides/TableRowProperties.php',
    'Google\\Service\\Slides\\TextContent' => $vendorDir . '/google/apiclient-services/src/Slides/TextContent.php',
    'Google\\Service\\Slides\\TextElement' => $vendorDir . '/google/apiclient-services/src/Slides/TextElement.php',
    'Google\\Service\\Slides\\TextRun' => $vendorDir . '/google/apiclient-services/src/Slides/TextRun.php',
    'Google\\Service\\Slides\\TextStyle' => $vendorDir . '/google/apiclient-services/src/Slides/TextStyle.php',
    'Google\\Service\\Slides\\ThemeColorPair' => $vendorDir . '/google/apiclient-services/src/Slides/ThemeColorPair.php',
    'Google\\Service\\Slides\\Thumbnail' => $vendorDir . '/google/apiclient-services/src/Slides/Thumbnail.php',
    'Google\\Service\\Slides\\UngroupObjectsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UngroupObjectsRequest.php',
    'Google\\Service\\Slides\\UnmergeTableCellsRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UnmergeTableCellsRequest.php',
    'Google\\Service\\Slides\\UpdateImagePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateImagePropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateLineCategoryRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateLineCategoryRequest.php',
    'Google\\Service\\Slides\\UpdateLinePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateLinePropertiesRequest.php',
    'Google\\Service\\Slides\\UpdatePageElementAltTextRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdatePageElementAltTextRequest.php',
    'Google\\Service\\Slides\\UpdatePageElementTransformRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdatePageElementTransformRequest.php',
    'Google\\Service\\Slides\\UpdatePageElementsZOrderRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdatePageElementsZOrderRequest.php',
    'Google\\Service\\Slides\\UpdatePagePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdatePagePropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateParagraphStyleRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateParagraphStyleRequest.php',
    'Google\\Service\\Slides\\UpdateShapePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateShapePropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateSlidePropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateSlidePropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateSlidesPositionRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateSlidesPositionRequest.php',
    'Google\\Service\\Slides\\UpdateTableBorderPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateTableBorderPropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateTableCellPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateTableCellPropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateTableColumnPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateTableColumnPropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateTableRowPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateTableRowPropertiesRequest.php',
    'Google\\Service\\Slides\\UpdateTextStyleRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateTextStyleRequest.php',
    'Google\\Service\\Slides\\UpdateVideoPropertiesRequest' => $vendorDir . '/google/apiclient-services/src/Slides/UpdateVideoPropertiesRequest.php',
    'Google\\Service\\Slides\\Video' => $vendorDir . '/google/apiclient-services/src/Slides/Video.php',
    'Google\\Service\\Slides\\VideoProperties' => $vendorDir . '/google/apiclient-services/src/Slides/VideoProperties.php',
    'Google\\Service\\Slides\\WeightedFontFamily' => $vendorDir . '/google/apiclient-services/src/Slides/WeightedFontFamily.php',
    'Google\\Service\\Slides\\WordArt' => $vendorDir . '/google/apiclient-services/src/Slides/WordArt.php',
    'Google\\Service\\Slides\\WriteControl' => $vendorDir . '/google/apiclient-services/src/Slides/WriteControl.php',
    'Google\\Service\\SmartDeviceManagement' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1Device' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1Device.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ExecuteDeviceCommandRequest' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ExecuteDeviceCommandRequest.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ExecuteDeviceCommandResponse' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ExecuteDeviceCommandResponse.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ListDevicesResponse' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ListDevicesResponse.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ListRoomsResponse' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ListRoomsResponse.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ListStructuresResponse' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ListStructuresResponse.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1ParentRelation' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1ParentRelation.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1Room' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1Room.php',
    'Google\\Service\\SmartDeviceManagement\\GoogleHomeEnterpriseSdmV1Structure' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/GoogleHomeEnterpriseSdmV1Structure.php',
    'Google\\Service\\SmartDeviceManagement\\Resource\\Enterprises' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/Resource/Enterprises.php',
    'Google\\Service\\SmartDeviceManagement\\Resource\\EnterprisesDevices' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/Resource/EnterprisesDevices.php',
    'Google\\Service\\SmartDeviceManagement\\Resource\\EnterprisesStructures' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/Resource/EnterprisesStructures.php',
    'Google\\Service\\SmartDeviceManagement\\Resource\\EnterprisesStructuresRooms' => $vendorDir . '/google/apiclient-services/src/SmartDeviceManagement/Resource/EnterprisesStructuresRooms.php',
    'Google\\Service\\Solar' => $vendorDir . '/google/apiclient-services/src/Solar.php',
    'Google\\Service\\Solar\\BuildingInsights' => $vendorDir . '/google/apiclient-services/src/Solar/BuildingInsights.php',
    'Google\\Service\\Solar\\CashPurchaseSavings' => $vendorDir . '/google/apiclient-services/src/Solar/CashPurchaseSavings.php',
    'Google\\Service\\Solar\\DataLayers' => $vendorDir . '/google/apiclient-services/src/Solar/DataLayers.php',
    'Google\\Service\\Solar\\Date' => $vendorDir . '/google/apiclient-services/src/Solar/Date.php',
    'Google\\Service\\Solar\\FinancedPurchaseSavings' => $vendorDir . '/google/apiclient-services/src/Solar/FinancedPurchaseSavings.php',
    'Google\\Service\\Solar\\FinancialAnalysis' => $vendorDir . '/google/apiclient-services/src/Solar/FinancialAnalysis.php',
    'Google\\Service\\Solar\\FinancialDetails' => $vendorDir . '/google/apiclient-services/src/Solar/FinancialDetails.php',
    'Google\\Service\\Solar\\HttpBody' => $vendorDir . '/google/apiclient-services/src/Solar/HttpBody.php',
    'Google\\Service\\Solar\\LatLng' => $vendorDir . '/google/apiclient-services/src/Solar/LatLng.php',
    'Google\\Service\\Solar\\LatLngBox' => $vendorDir . '/google/apiclient-services/src/Solar/LatLngBox.php',
    'Google\\Service\\Solar\\LeasingSavings' => $vendorDir . '/google/apiclient-services/src/Solar/LeasingSavings.php',
    'Google\\Service\\Solar\\Money' => $vendorDir . '/google/apiclient-services/src/Solar/Money.php',
    'Google\\Service\\Solar\\Resource\\BuildingInsights' => $vendorDir . '/google/apiclient-services/src/Solar/Resource/BuildingInsights.php',
    'Google\\Service\\Solar\\Resource\\DataLayers' => $vendorDir . '/google/apiclient-services/src/Solar/Resource/DataLayers.php',
    'Google\\Service\\Solar\\Resource\\GeoTiff' => $vendorDir . '/google/apiclient-services/src/Solar/Resource/GeoTiff.php',
    'Google\\Service\\Solar\\RoofSegmentSizeAndSunshineStats' => $vendorDir . '/google/apiclient-services/src/Solar/RoofSegmentSizeAndSunshineStats.php',
    'Google\\Service\\Solar\\RoofSegmentSummary' => $vendorDir . '/google/apiclient-services/src/Solar/RoofSegmentSummary.php',
    'Google\\Service\\Solar\\SavingsOverTime' => $vendorDir . '/google/apiclient-services/src/Solar/SavingsOverTime.php',
    'Google\\Service\\Solar\\SizeAndSunshineStats' => $vendorDir . '/google/apiclient-services/src/Solar/SizeAndSunshineStats.php',
    'Google\\Service\\Solar\\SolarPanel' => $vendorDir . '/google/apiclient-services/src/Solar/SolarPanel.php',
    'Google\\Service\\Solar\\SolarPanelConfig' => $vendorDir . '/google/apiclient-services/src/Solar/SolarPanelConfig.php',
    'Google\\Service\\Solar\\SolarPotential' => $vendorDir . '/google/apiclient-services/src/Solar/SolarPotential.php',
    'Google\\Service\\Spanner' => $vendorDir . '/google/apiclient-services/src/Spanner.php',
    'Google\\Service\\Spanner\\AutoscalingConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/AutoscalingConfig.php',
    'Google\\Service\\Spanner\\AutoscalingLimits' => $vendorDir . '/google/apiclient-services/src/Spanner/AutoscalingLimits.php',
    'Google\\Service\\Spanner\\AutoscalingTargets' => $vendorDir . '/google/apiclient-services/src/Spanner/AutoscalingTargets.php',
    'Google\\Service\\Spanner\\Backup' => $vendorDir . '/google/apiclient-services/src/Spanner/Backup.php',
    'Google\\Service\\Spanner\\BackupInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/BackupInfo.php',
    'Google\\Service\\Spanner\\BackupSchedule' => $vendorDir . '/google/apiclient-services/src/Spanner/BackupSchedule.php',
    'Google\\Service\\Spanner\\BackupScheduleSpec' => $vendorDir . '/google/apiclient-services/src/Spanner/BackupScheduleSpec.php',
    'Google\\Service\\Spanner\\BatchCreateSessionsRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/BatchCreateSessionsRequest.php',
    'Google\\Service\\Spanner\\BatchCreateSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/BatchCreateSessionsResponse.php',
    'Google\\Service\\Spanner\\BatchWriteRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/BatchWriteRequest.php',
    'Google\\Service\\Spanner\\BatchWriteResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/BatchWriteResponse.php',
    'Google\\Service\\Spanner\\BeginTransactionRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/BeginTransactionRequest.php',
    'Google\\Service\\Spanner\\Binding' => $vendorDir . '/google/apiclient-services/src/Spanner/Binding.php',
    'Google\\Service\\Spanner\\ChangeQuorumMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/ChangeQuorumMetadata.php',
    'Google\\Service\\Spanner\\ChangeQuorumRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/ChangeQuorumRequest.php',
    'Google\\Service\\Spanner\\ChildLink' => $vendorDir . '/google/apiclient-services/src/Spanner/ChildLink.php',
    'Google\\Service\\Spanner\\CommitRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CommitRequest.php',
    'Google\\Service\\Spanner\\CommitResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/CommitResponse.php',
    'Google\\Service\\Spanner\\CommitStats' => $vendorDir . '/google/apiclient-services/src/Spanner/CommitStats.php',
    'Google\\Service\\Spanner\\ContextValue' => $vendorDir . '/google/apiclient-services/src/Spanner/ContextValue.php',
    'Google\\Service\\Spanner\\CopyBackupEncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/CopyBackupEncryptionConfig.php',
    'Google\\Service\\Spanner\\CopyBackupMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CopyBackupMetadata.php',
    'Google\\Service\\Spanner\\CopyBackupRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CopyBackupRequest.php',
    'Google\\Service\\Spanner\\CreateBackupEncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateBackupEncryptionConfig.php',
    'Google\\Service\\Spanner\\CreateBackupMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateBackupMetadata.php',
    'Google\\Service\\Spanner\\CreateDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateDatabaseMetadata.php',
    'Google\\Service\\Spanner\\CreateDatabaseRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateDatabaseRequest.php',
    'Google\\Service\\Spanner\\CreateInstanceConfigMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstanceConfigMetadata.php',
    'Google\\Service\\Spanner\\CreateInstanceConfigRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstanceConfigRequest.php',
    'Google\\Service\\Spanner\\CreateInstanceMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstanceMetadata.php',
    'Google\\Service\\Spanner\\CreateInstancePartitionMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstancePartitionMetadata.php',
    'Google\\Service\\Spanner\\CreateInstancePartitionRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstancePartitionRequest.php',
    'Google\\Service\\Spanner\\CreateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateInstanceRequest.php',
    'Google\\Service\\Spanner\\CreateSessionRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/CreateSessionRequest.php',
    'Google\\Service\\Spanner\\CrontabSpec' => $vendorDir . '/google/apiclient-services/src/Spanner/CrontabSpec.php',
    'Google\\Service\\Spanner\\Database' => $vendorDir . '/google/apiclient-services/src/Spanner/Database.php',
    'Google\\Service\\Spanner\\DatabaseRole' => $vendorDir . '/google/apiclient-services/src/Spanner/DatabaseRole.php',
    'Google\\Service\\Spanner\\DdlStatementActionInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/DdlStatementActionInfo.php',
    'Google\\Service\\Spanner\\Delete' => $vendorDir . '/google/apiclient-services/src/Spanner/Delete.php',
    'Google\\Service\\Spanner\\DerivedMetric' => $vendorDir . '/google/apiclient-services/src/Spanner/DerivedMetric.php',
    'Google\\Service\\Spanner\\DiagnosticMessage' => $vendorDir . '/google/apiclient-services/src/Spanner/DiagnosticMessage.php',
    'Google\\Service\\Spanner\\DirectedReadOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/DirectedReadOptions.php',
    'Google\\Service\\Spanner\\DualRegionQuorum' => $vendorDir . '/google/apiclient-services/src/Spanner/DualRegionQuorum.php',
    'Google\\Service\\Spanner\\EncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/EncryptionConfig.php',
    'Google\\Service\\Spanner\\EncryptionInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/EncryptionInfo.php',
    'Google\\Service\\Spanner\\ExcludeReplicas' => $vendorDir . '/google/apiclient-services/src/Spanner/ExcludeReplicas.php',
    'Google\\Service\\Spanner\\ExecuteBatchDmlRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/ExecuteBatchDmlRequest.php',
    'Google\\Service\\Spanner\\ExecuteBatchDmlResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ExecuteBatchDmlResponse.php',
    'Google\\Service\\Spanner\\ExecuteSqlRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/ExecuteSqlRequest.php',
    'Google\\Service\\Spanner\\Expr' => $vendorDir . '/google/apiclient-services/src/Spanner/Expr.php',
    'Google\\Service\\Spanner\\Field' => $vendorDir . '/google/apiclient-services/src/Spanner/Field.php',
    'Google\\Service\\Spanner\\FreeInstanceMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/FreeInstanceMetadata.php',
    'Google\\Service\\Spanner\\FullBackupSpec' => $vendorDir . '/google/apiclient-services/src/Spanner/FullBackupSpec.php',
    'Google\\Service\\Spanner\\GetDatabaseDdlResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/GetDatabaseDdlResponse.php',
    'Google\\Service\\Spanner\\GetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/GetIamPolicyRequest.php',
    'Google\\Service\\Spanner\\GetPolicyOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/GetPolicyOptions.php',
    'Google\\Service\\Spanner\\IncludeReplicas' => $vendorDir . '/google/apiclient-services/src/Spanner/IncludeReplicas.php',
    'Google\\Service\\Spanner\\IncrementalBackupSpec' => $vendorDir . '/google/apiclient-services/src/Spanner/IncrementalBackupSpec.php',
    'Google\\Service\\Spanner\\IndexAdvice' => $vendorDir . '/google/apiclient-services/src/Spanner/IndexAdvice.php',
    'Google\\Service\\Spanner\\IndexedHotKey' => $vendorDir . '/google/apiclient-services/src/Spanner/IndexedHotKey.php',
    'Google\\Service\\Spanner\\IndexedKeyRangeInfos' => $vendorDir . '/google/apiclient-services/src/Spanner/IndexedKeyRangeInfos.php',
    'Google\\Service\\Spanner\\Instance' => $vendorDir . '/google/apiclient-services/src/Spanner/Instance.php',
    'Google\\Service\\Spanner\\InstanceConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/InstanceConfig.php',
    'Google\\Service\\Spanner\\InstanceOperationProgress' => $vendorDir . '/google/apiclient-services/src/Spanner/InstanceOperationProgress.php',
    'Google\\Service\\Spanner\\InstancePartition' => $vendorDir . '/google/apiclient-services/src/Spanner/InstancePartition.php',
    'Google\\Service\\Spanner\\KeyRange' => $vendorDir . '/google/apiclient-services/src/Spanner/KeyRange.php',
    'Google\\Service\\Spanner\\KeyRangeInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/KeyRangeInfo.php',
    'Google\\Service\\Spanner\\KeyRangeInfos' => $vendorDir . '/google/apiclient-services/src/Spanner/KeyRangeInfos.php',
    'Google\\Service\\Spanner\\KeySet' => $vendorDir . '/google/apiclient-services/src/Spanner/KeySet.php',
    'Google\\Service\\Spanner\\ListBackupOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListBackupOperationsResponse.php',
    'Google\\Service\\Spanner\\ListBackupSchedulesResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListBackupSchedulesResponse.php',
    'Google\\Service\\Spanner\\ListBackupsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListBackupsResponse.php',
    'Google\\Service\\Spanner\\ListDatabaseOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListDatabaseOperationsResponse.php',
    'Google\\Service\\Spanner\\ListDatabaseRolesResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListDatabaseRolesResponse.php',
    'Google\\Service\\Spanner\\ListDatabasesResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListDatabasesResponse.php',
    'Google\\Service\\Spanner\\ListInstanceConfigOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListInstanceConfigOperationsResponse.php',
    'Google\\Service\\Spanner\\ListInstanceConfigsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListInstanceConfigsResponse.php',
    'Google\\Service\\Spanner\\ListInstancePartitionOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListInstancePartitionOperationsResponse.php',
    'Google\\Service\\Spanner\\ListInstancePartitionsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListInstancePartitionsResponse.php',
    'Google\\Service\\Spanner\\ListInstancesResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListInstancesResponse.php',
    'Google\\Service\\Spanner\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListOperationsResponse.php',
    'Google\\Service\\Spanner\\ListScansResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListScansResponse.php',
    'Google\\Service\\Spanner\\ListSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/ListSessionsResponse.php',
    'Google\\Service\\Spanner\\LocalizedString' => $vendorDir . '/google/apiclient-services/src/Spanner/LocalizedString.php',
    'Google\\Service\\Spanner\\Metric' => $vendorDir . '/google/apiclient-services/src/Spanner/Metric.php',
    'Google\\Service\\Spanner\\MetricMatrix' => $vendorDir . '/google/apiclient-services/src/Spanner/MetricMatrix.php',
    'Google\\Service\\Spanner\\MetricMatrixRow' => $vendorDir . '/google/apiclient-services/src/Spanner/MetricMatrixRow.php',
    'Google\\Service\\Spanner\\MoveInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/MoveInstanceRequest.php',
    'Google\\Service\\Spanner\\Mutation' => $vendorDir . '/google/apiclient-services/src/Spanner/Mutation.php',
    'Google\\Service\\Spanner\\MutationGroup' => $vendorDir . '/google/apiclient-services/src/Spanner/MutationGroup.php',
    'Google\\Service\\Spanner\\Operation' => $vendorDir . '/google/apiclient-services/src/Spanner/Operation.php',
    'Google\\Service\\Spanner\\OperationProgress' => $vendorDir . '/google/apiclient-services/src/Spanner/OperationProgress.php',
    'Google\\Service\\Spanner\\OptimizeRestoredDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/OptimizeRestoredDatabaseMetadata.php',
    'Google\\Service\\Spanner\\PartialResultSet' => $vendorDir . '/google/apiclient-services/src/Spanner/PartialResultSet.php',
    'Google\\Service\\Spanner\\Partition' => $vendorDir . '/google/apiclient-services/src/Spanner/Partition.php',
    'Google\\Service\\Spanner\\PartitionOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/PartitionOptions.php',
    'Google\\Service\\Spanner\\PartitionQueryRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/PartitionQueryRequest.php',
    'Google\\Service\\Spanner\\PartitionReadRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/PartitionReadRequest.php',
    'Google\\Service\\Spanner\\PartitionResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/PartitionResponse.php',
    'Google\\Service\\Spanner\\PartitionedDml' => $vendorDir . '/google/apiclient-services/src/Spanner/PartitionedDml.php',
    'Google\\Service\\Spanner\\PlanNode' => $vendorDir . '/google/apiclient-services/src/Spanner/PlanNode.php',
    'Google\\Service\\Spanner\\Policy' => $vendorDir . '/google/apiclient-services/src/Spanner/Policy.php',
    'Google\\Service\\Spanner\\PrefixNode' => $vendorDir . '/google/apiclient-services/src/Spanner/PrefixNode.php',
    'Google\\Service\\Spanner\\QueryAdvisorResult' => $vendorDir . '/google/apiclient-services/src/Spanner/QueryAdvisorResult.php',
    'Google\\Service\\Spanner\\QueryOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/QueryOptions.php',
    'Google\\Service\\Spanner\\QueryPlan' => $vendorDir . '/google/apiclient-services/src/Spanner/QueryPlan.php',
    'Google\\Service\\Spanner\\QuorumInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/QuorumInfo.php',
    'Google\\Service\\Spanner\\QuorumType' => $vendorDir . '/google/apiclient-services/src/Spanner/QuorumType.php',
    'Google\\Service\\Spanner\\ReadRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/ReadRequest.php',
    'Google\\Service\\Spanner\\ReadWrite' => $vendorDir . '/google/apiclient-services/src/Spanner/ReadWrite.php',
    'Google\\Service\\Spanner\\ReplicaInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/ReplicaInfo.php',
    'Google\\Service\\Spanner\\ReplicaSelection' => $vendorDir . '/google/apiclient-services/src/Spanner/ReplicaSelection.php',
    'Google\\Service\\Spanner\\RequestOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/RequestOptions.php',
    'Google\\Service\\Spanner\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/Projects.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstanceConfigOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstanceConfigOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstanceConfigs' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstanceConfigs.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstanceConfigsOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstanceConfigsOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstanceConfigsSsdCaches' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstanceConfigsSsdCaches.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstanceConfigsSsdCachesOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstanceConfigsSsdCachesOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstances' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstances.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesBackupOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesBackupOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesBackups' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesBackups.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesBackupsOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesBackupsOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabaseOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabaseOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabases' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabases.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabasesBackupSchedules' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabasesBackupSchedules.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabasesDatabaseRoles' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabasesDatabaseRoles.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabasesOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabasesOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesDatabasesSessions' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesDatabasesSessions.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesInstancePartitionOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesInstancePartitionOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesInstancePartitions' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesInstancePartitions.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesInstancePartitionsOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesInstancePartitionsOperations.php',
    'Google\\Service\\Spanner\\Resource\\ProjectsInstancesOperations' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/ProjectsInstancesOperations.php',
    'Google\\Service\\Spanner\\Resource\\Scans' => $vendorDir . '/google/apiclient-services/src/Spanner/Resource/Scans.php',
    'Google\\Service\\Spanner\\RestoreDatabaseEncryptionConfig' => $vendorDir . '/google/apiclient-services/src/Spanner/RestoreDatabaseEncryptionConfig.php',
    'Google\\Service\\Spanner\\RestoreDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/RestoreDatabaseMetadata.php',
    'Google\\Service\\Spanner\\RestoreDatabaseRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/RestoreDatabaseRequest.php',
    'Google\\Service\\Spanner\\RestoreInfo' => $vendorDir . '/google/apiclient-services/src/Spanner/RestoreInfo.php',
    'Google\\Service\\Spanner\\ResultSet' => $vendorDir . '/google/apiclient-services/src/Spanner/ResultSet.php',
    'Google\\Service\\Spanner\\ResultSetMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/ResultSetMetadata.php',
    'Google\\Service\\Spanner\\ResultSetStats' => $vendorDir . '/google/apiclient-services/src/Spanner/ResultSetStats.php',
    'Google\\Service\\Spanner\\RollbackRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/RollbackRequest.php',
    'Google\\Service\\Spanner\\Scan' => $vendorDir . '/google/apiclient-services/src/Spanner/Scan.php',
    'Google\\Service\\Spanner\\ScanData' => $vendorDir . '/google/apiclient-services/src/Spanner/ScanData.php',
    'Google\\Service\\Spanner\\Session' => $vendorDir . '/google/apiclient-services/src/Spanner/Session.php',
    'Google\\Service\\Spanner\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/SetIamPolicyRequest.php',
    'Google\\Service\\Spanner\\ShortRepresentation' => $vendorDir . '/google/apiclient-services/src/Spanner/ShortRepresentation.php',
    'Google\\Service\\Spanner\\SingleRegionQuorum' => $vendorDir . '/google/apiclient-services/src/Spanner/SingleRegionQuorum.php',
    'Google\\Service\\Spanner\\SpannerEmpty' => $vendorDir . '/google/apiclient-services/src/Spanner/SpannerEmpty.php',
    'Google\\Service\\Spanner\\SpannerReadOnly' => $vendorDir . '/google/apiclient-services/src/Spanner/SpannerReadOnly.php',
    'Google\\Service\\Spanner\\Statement' => $vendorDir . '/google/apiclient-services/src/Spanner/Statement.php',
    'Google\\Service\\Spanner\\Status' => $vendorDir . '/google/apiclient-services/src/Spanner/Status.php',
    'Google\\Service\\Spanner\\StructType' => $vendorDir . '/google/apiclient-services/src/Spanner/StructType.php',
    'Google\\Service\\Spanner\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/TestIamPermissionsRequest.php',
    'Google\\Service\\Spanner\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Spanner/TestIamPermissionsResponse.php',
    'Google\\Service\\Spanner\\Transaction' => $vendorDir . '/google/apiclient-services/src/Spanner/Transaction.php',
    'Google\\Service\\Spanner\\TransactionOptions' => $vendorDir . '/google/apiclient-services/src/Spanner/TransactionOptions.php',
    'Google\\Service\\Spanner\\TransactionSelector' => $vendorDir . '/google/apiclient-services/src/Spanner/TransactionSelector.php',
    'Google\\Service\\Spanner\\Type' => $vendorDir . '/google/apiclient-services/src/Spanner/Type.php',
    'Google\\Service\\Spanner\\UpdateDatabaseDdlMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateDatabaseDdlMetadata.php',
    'Google\\Service\\Spanner\\UpdateDatabaseDdlRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateDatabaseDdlRequest.php',
    'Google\\Service\\Spanner\\UpdateDatabaseMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateDatabaseMetadata.php',
    'Google\\Service\\Spanner\\UpdateDatabaseRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateDatabaseRequest.php',
    'Google\\Service\\Spanner\\UpdateInstanceConfigMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstanceConfigMetadata.php',
    'Google\\Service\\Spanner\\UpdateInstanceConfigRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstanceConfigRequest.php',
    'Google\\Service\\Spanner\\UpdateInstanceMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstanceMetadata.php',
    'Google\\Service\\Spanner\\UpdateInstancePartitionMetadata' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstancePartitionMetadata.php',
    'Google\\Service\\Spanner\\UpdateInstancePartitionRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstancePartitionRequest.php',
    'Google\\Service\\Spanner\\UpdateInstanceRequest' => $vendorDir . '/google/apiclient-services/src/Spanner/UpdateInstanceRequest.php',
    'Google\\Service\\Spanner\\VisualizationData' => $vendorDir . '/google/apiclient-services/src/Spanner/VisualizationData.php',
    'Google\\Service\\Spanner\\Write' => $vendorDir . '/google/apiclient-services/src/Spanner/Write.php',
    'Google\\Service\\Speech' => $vendorDir . '/google/apiclient-services/src/Speech.php',
    'Google\\Service\\Speech\\ABNFGrammar' => $vendorDir . '/google/apiclient-services/src/Speech/ABNFGrammar.php',
    'Google\\Service\\Speech\\ClassItem' => $vendorDir . '/google/apiclient-services/src/Speech/ClassItem.php',
    'Google\\Service\\Speech\\CreateCustomClassRequest' => $vendorDir . '/google/apiclient-services/src/Speech/CreateCustomClassRequest.php',
    'Google\\Service\\Speech\\CreatePhraseSetRequest' => $vendorDir . '/google/apiclient-services/src/Speech/CreatePhraseSetRequest.php',
    'Google\\Service\\Speech\\CustomClass' => $vendorDir . '/google/apiclient-services/src/Speech/CustomClass.php',
    'Google\\Service\\Speech\\Entry' => $vendorDir . '/google/apiclient-services/src/Speech/Entry.php',
    'Google\\Service\\Speech\\ListCustomClassesResponse' => $vendorDir . '/google/apiclient-services/src/Speech/ListCustomClassesResponse.php',
    'Google\\Service\\Speech\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Speech/ListOperationsResponse.php',
    'Google\\Service\\Speech\\ListPhraseSetResponse' => $vendorDir . '/google/apiclient-services/src/Speech/ListPhraseSetResponse.php',
    'Google\\Service\\Speech\\LongRunningRecognizeMetadata' => $vendorDir . '/google/apiclient-services/src/Speech/LongRunningRecognizeMetadata.php',
    'Google\\Service\\Speech\\LongRunningRecognizeRequest' => $vendorDir . '/google/apiclient-services/src/Speech/LongRunningRecognizeRequest.php',
    'Google\\Service\\Speech\\LongRunningRecognizeResponse' => $vendorDir . '/google/apiclient-services/src/Speech/LongRunningRecognizeResponse.php',
    'Google\\Service\\Speech\\Operation' => $vendorDir . '/google/apiclient-services/src/Speech/Operation.php',
    'Google\\Service\\Speech\\Phrase' => $vendorDir . '/google/apiclient-services/src/Speech/Phrase.php',
    'Google\\Service\\Speech\\PhraseSet' => $vendorDir . '/google/apiclient-services/src/Speech/PhraseSet.php',
    'Google\\Service\\Speech\\RecognitionAudio' => $vendorDir . '/google/apiclient-services/src/Speech/RecognitionAudio.php',
    'Google\\Service\\Speech\\RecognitionConfig' => $vendorDir . '/google/apiclient-services/src/Speech/RecognitionConfig.php',
    'Google\\Service\\Speech\\RecognitionMetadata' => $vendorDir . '/google/apiclient-services/src/Speech/RecognitionMetadata.php',
    'Google\\Service\\Speech\\RecognizeRequest' => $vendorDir . '/google/apiclient-services/src/Speech/RecognizeRequest.php',
    'Google\\Service\\Speech\\RecognizeResponse' => $vendorDir . '/google/apiclient-services/src/Speech/RecognizeResponse.php',
    'Google\\Service\\Speech\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/Operations.php',
    'Google\\Service\\Speech\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/Projects.php',
    'Google\\Service\\Speech\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/ProjectsLocations.php',
    'Google\\Service\\Speech\\Resource\\ProjectsLocationsCustomClasses' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/ProjectsLocationsCustomClasses.php',
    'Google\\Service\\Speech\\Resource\\ProjectsLocationsPhraseSets' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/ProjectsLocationsPhraseSets.php',
    'Google\\Service\\Speech\\Resource\\Speech' => $vendorDir . '/google/apiclient-services/src/Speech/Resource/Speech.php',
    'Google\\Service\\Speech\\SpeakerDiarizationConfig' => $vendorDir . '/google/apiclient-services/src/Speech/SpeakerDiarizationConfig.php',
    'Google\\Service\\Speech\\SpeechAdaptation' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechAdaptation.php',
    'Google\\Service\\Speech\\SpeechAdaptationInfo' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechAdaptationInfo.php',
    'Google\\Service\\Speech\\SpeechContext' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechContext.php',
    'Google\\Service\\Speech\\SpeechEmpty' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechEmpty.php',
    'Google\\Service\\Speech\\SpeechRecognitionAlternative' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechRecognitionAlternative.php',
    'Google\\Service\\Speech\\SpeechRecognitionResult' => $vendorDir . '/google/apiclient-services/src/Speech/SpeechRecognitionResult.php',
    'Google\\Service\\Speech\\Status' => $vendorDir . '/google/apiclient-services/src/Speech/Status.php',
    'Google\\Service\\Speech\\TranscriptNormalization' => $vendorDir . '/google/apiclient-services/src/Speech/TranscriptNormalization.php',
    'Google\\Service\\Speech\\TranscriptOutputConfig' => $vendorDir . '/google/apiclient-services/src/Speech/TranscriptOutputConfig.php',
    'Google\\Service\\Speech\\WordInfo' => $vendorDir . '/google/apiclient-services/src/Speech/WordInfo.php',
    'Google\\Service\\Storage' => $vendorDir . '/google/apiclient-services/src/Storage.php',
    'Google\\Service\\Storage\\AnywhereCache' => $vendorDir . '/google/apiclient-services/src/Storage/AnywhereCache.php',
    'Google\\Service\\Storage\\AnywhereCaches' => $vendorDir . '/google/apiclient-services/src/Storage/AnywhereCaches.php',
    'Google\\Service\\Storage\\Bucket' => $vendorDir . '/google/apiclient-services/src/Storage/Bucket.php',
    'Google\\Service\\Storage\\BucketAccessControl' => $vendorDir . '/google/apiclient-services/src/Storage/BucketAccessControl.php',
    'Google\\Service\\Storage\\BucketAccessControlProjectTeam' => $vendorDir . '/google/apiclient-services/src/Storage/BucketAccessControlProjectTeam.php',
    'Google\\Service\\Storage\\BucketAccessControls' => $vendorDir . '/google/apiclient-services/src/Storage/BucketAccessControls.php',
    'Google\\Service\\Storage\\BucketAutoclass' => $vendorDir . '/google/apiclient-services/src/Storage/BucketAutoclass.php',
    'Google\\Service\\Storage\\BucketBilling' => $vendorDir . '/google/apiclient-services/src/Storage/BucketBilling.php',
    'Google\\Service\\Storage\\BucketCors' => $vendorDir . '/google/apiclient-services/src/Storage/BucketCors.php',
    'Google\\Service\\Storage\\BucketCustomPlacementConfig' => $vendorDir . '/google/apiclient-services/src/Storage/BucketCustomPlacementConfig.php',
    'Google\\Service\\Storage\\BucketEncryption' => $vendorDir . '/google/apiclient-services/src/Storage/BucketEncryption.php',
    'Google\\Service\\Storage\\BucketHierarchicalNamespace' => $vendorDir . '/google/apiclient-services/src/Storage/BucketHierarchicalNamespace.php',
    'Google\\Service\\Storage\\BucketIamConfiguration' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIamConfiguration.php',
    'Google\\Service\\Storage\\BucketIamConfigurationBucketPolicyOnly' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIamConfigurationBucketPolicyOnly.php',
    'Google\\Service\\Storage\\BucketIamConfigurationUniformBucketLevelAccess' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIamConfigurationUniformBucketLevelAccess.php',
    'Google\\Service\\Storage\\BucketIpFilter' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIpFilter.php',
    'Google\\Service\\Storage\\BucketIpFilterPublicNetworkSource' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIpFilterPublicNetworkSource.php',
    'Google\\Service\\Storage\\BucketIpFilterVpcNetworkSources' => $vendorDir . '/google/apiclient-services/src/Storage/BucketIpFilterVpcNetworkSources.php',
    'Google\\Service\\Storage\\BucketLifecycle' => $vendorDir . '/google/apiclient-services/src/Storage/BucketLifecycle.php',
    'Google\\Service\\Storage\\BucketLifecycleRule' => $vendorDir . '/google/apiclient-services/src/Storage/BucketLifecycleRule.php',
    'Google\\Service\\Storage\\BucketLifecycleRuleAction' => $vendorDir . '/google/apiclient-services/src/Storage/BucketLifecycleRuleAction.php',
    'Google\\Service\\Storage\\BucketLifecycleRuleCondition' => $vendorDir . '/google/apiclient-services/src/Storage/BucketLifecycleRuleCondition.php',
    'Google\\Service\\Storage\\BucketLogging' => $vendorDir . '/google/apiclient-services/src/Storage/BucketLogging.php',
    'Google\\Service\\Storage\\BucketObjectRetention' => $vendorDir . '/google/apiclient-services/src/Storage/BucketObjectRetention.php',
    'Google\\Service\\Storage\\BucketOwner' => $vendorDir . '/google/apiclient-services/src/Storage/BucketOwner.php',
    'Google\\Service\\Storage\\BucketRetentionPolicy' => $vendorDir . '/google/apiclient-services/src/Storage/BucketRetentionPolicy.php',
    'Google\\Service\\Storage\\BucketSoftDeletePolicy' => $vendorDir . '/google/apiclient-services/src/Storage/BucketSoftDeletePolicy.php',
    'Google\\Service\\Storage\\BucketStorageLayout' => $vendorDir . '/google/apiclient-services/src/Storage/BucketStorageLayout.php',
    'Google\\Service\\Storage\\BucketStorageLayoutCustomPlacementConfig' => $vendorDir . '/google/apiclient-services/src/Storage/BucketStorageLayoutCustomPlacementConfig.php',
    'Google\\Service\\Storage\\BucketStorageLayoutHierarchicalNamespace' => $vendorDir . '/google/apiclient-services/src/Storage/BucketStorageLayoutHierarchicalNamespace.php',
    'Google\\Service\\Storage\\BucketVersioning' => $vendorDir . '/google/apiclient-services/src/Storage/BucketVersioning.php',
    'Google\\Service\\Storage\\BucketWebsite' => $vendorDir . '/google/apiclient-services/src/Storage/BucketWebsite.php',
    'Google\\Service\\Storage\\Buckets' => $vendorDir . '/google/apiclient-services/src/Storage/Buckets.php',
    'Google\\Service\\Storage\\BulkRestoreObjectsRequest' => $vendorDir . '/google/apiclient-services/src/Storage/BulkRestoreObjectsRequest.php',
    'Google\\Service\\Storage\\Channel' => $vendorDir . '/google/apiclient-services/src/Storage/Channel.php',
    'Google\\Service\\Storage\\ComposeRequest' => $vendorDir . '/google/apiclient-services/src/Storage/ComposeRequest.php',
    'Google\\Service\\Storage\\ComposeRequestSourceObjects' => $vendorDir . '/google/apiclient-services/src/Storage/ComposeRequestSourceObjects.php',
    'Google\\Service\\Storage\\ComposeRequestSourceObjectsObjectPreconditions' => $vendorDir . '/google/apiclient-services/src/Storage/ComposeRequestSourceObjectsObjectPreconditions.php',
    'Google\\Service\\Storage\\Expr' => $vendorDir . '/google/apiclient-services/src/Storage/Expr.php',
    'Google\\Service\\Storage\\Folder' => $vendorDir . '/google/apiclient-services/src/Storage/Folder.php',
    'Google\\Service\\Storage\\FolderPendingRenameInfo' => $vendorDir . '/google/apiclient-services/src/Storage/FolderPendingRenameInfo.php',
    'Google\\Service\\Storage\\Folders' => $vendorDir . '/google/apiclient-services/src/Storage/Folders.php',
    'Google\\Service\\Storage\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Storage/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\Storage\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/Storage/GoogleLongrunningOperation.php',
    'Google\\Service\\Storage\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/Storage/GoogleRpcStatus.php',
    'Google\\Service\\Storage\\HmacKey' => $vendorDir . '/google/apiclient-services/src/Storage/HmacKey.php',
    'Google\\Service\\Storage\\HmacKeyMetadata' => $vendorDir . '/google/apiclient-services/src/Storage/HmacKeyMetadata.php',
    'Google\\Service\\Storage\\HmacKeysMetadata' => $vendorDir . '/google/apiclient-services/src/Storage/HmacKeysMetadata.php',
    'Google\\Service\\Storage\\ManagedFolder' => $vendorDir . '/google/apiclient-services/src/Storage/ManagedFolder.php',
    'Google\\Service\\Storage\\ManagedFolders' => $vendorDir . '/google/apiclient-services/src/Storage/ManagedFolders.php',
    'Google\\Service\\Storage\\Notification' => $vendorDir . '/google/apiclient-services/src/Storage/Notification.php',
    'Google\\Service\\Storage\\Notifications' => $vendorDir . '/google/apiclient-services/src/Storage/Notifications.php',
    'Google\\Service\\Storage\\ObjectAccessControl' => $vendorDir . '/google/apiclient-services/src/Storage/ObjectAccessControl.php',
    'Google\\Service\\Storage\\ObjectAccessControlProjectTeam' => $vendorDir . '/google/apiclient-services/src/Storage/ObjectAccessControlProjectTeam.php',
    'Google\\Service\\Storage\\ObjectAccessControls' => $vendorDir . '/google/apiclient-services/src/Storage/ObjectAccessControls.php',
    'Google\\Service\\Storage\\Objects' => $vendorDir . '/google/apiclient-services/src/Storage/Objects.php',
    'Google\\Service\\Storage\\Policy' => $vendorDir . '/google/apiclient-services/src/Storage/Policy.php',
    'Google\\Service\\Storage\\PolicyBindings' => $vendorDir . '/google/apiclient-services/src/Storage/PolicyBindings.php',
    'Google\\Service\\Storage\\Resource\\AnywhereCache' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/AnywhereCache.php',
    'Google\\Service\\Storage\\Resource\\AnywhereCaches' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/AnywhereCaches.php',
    'Google\\Service\\Storage\\Resource\\BucketAccessControls' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/BucketAccessControls.php',
    'Google\\Service\\Storage\\Resource\\Buckets' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Buckets.php',
    'Google\\Service\\Storage\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Channels.php',
    'Google\\Service\\Storage\\Resource\\DefaultObjectAccessControls' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/DefaultObjectAccessControls.php',
    'Google\\Service\\Storage\\Resource\\Folders' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Folders.php',
    'Google\\Service\\Storage\\Resource\\ManagedFolders' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/ManagedFolders.php',
    'Google\\Service\\Storage\\Resource\\Notifications' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Notifications.php',
    'Google\\Service\\Storage\\Resource\\ObjectAccessControls' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/ObjectAccessControls.php',
    'Google\\Service\\Storage\\Resource\\Objects' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Objects.php',
    'Google\\Service\\Storage\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Operations.php',
    'Google\\Service\\Storage\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/Projects.php',
    'Google\\Service\\Storage\\Resource\\ProjectsHmacKeys' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/ProjectsHmacKeys.php',
    'Google\\Service\\Storage\\Resource\\ProjectsServiceAccount' => $vendorDir . '/google/apiclient-services/src/Storage/Resource/ProjectsServiceAccount.php',
    'Google\\Service\\Storage\\RewriteResponse' => $vendorDir . '/google/apiclient-services/src/Storage/RewriteResponse.php',
    'Google\\Service\\Storage\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/Storage/ServiceAccount.php',
    'Google\\Service\\Storage\\StorageObject' => $vendorDir . '/google/apiclient-services/src/Storage/StorageObject.php',
    'Google\\Service\\Storage\\StorageObjectCustomerEncryption' => $vendorDir . '/google/apiclient-services/src/Storage/StorageObjectCustomerEncryption.php',
    'Google\\Service\\Storage\\StorageObjectOwner' => $vendorDir . '/google/apiclient-services/src/Storage/StorageObjectOwner.php',
    'Google\\Service\\Storage\\StorageObjectRetention' => $vendorDir . '/google/apiclient-services/src/Storage/StorageObjectRetention.php',
    'Google\\Service\\Storage\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/Storage/TestIamPermissionsResponse.php',
    'Google\\Service\\Storagetransfer' => $vendorDir . '/google/apiclient-services/src/Storagetransfer.php',
    'Google\\Service\\Storagetransfer\\AgentPool' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AgentPool.php',
    'Google\\Service\\Storagetransfer\\AwsAccessKey' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AwsAccessKey.php',
    'Google\\Service\\Storagetransfer\\AwsS3CompatibleData' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AwsS3CompatibleData.php',
    'Google\\Service\\Storagetransfer\\AwsS3Data' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AwsS3Data.php',
    'Google\\Service\\Storagetransfer\\AzureBlobStorageData' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AzureBlobStorageData.php',
    'Google\\Service\\Storagetransfer\\AzureCredentials' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/AzureCredentials.php',
    'Google\\Service\\Storagetransfer\\BandwidthLimit' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/BandwidthLimit.php',
    'Google\\Service\\Storagetransfer\\BatchTaskSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/BatchTaskSpec.php',
    'Google\\Service\\Storagetransfer\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/CancelOperationRequest.php',
    'Google\\Service\\Storagetransfer\\Date' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Date.php',
    'Google\\Service\\Storagetransfer\\DeleteObjectTaskSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/DeleteObjectTaskSpec.php',
    'Google\\Service\\Storagetransfer\\ErrorLogEntry' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ErrorLogEntry.php',
    'Google\\Service\\Storagetransfer\\ErrorSummary' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ErrorSummary.php',
    'Google\\Service\\Storagetransfer\\EventStream' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/EventStream.php',
    'Google\\Service\\Storagetransfer\\GcsData' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/GcsData.php',
    'Google\\Service\\Storagetransfer\\GoogleServiceAccount' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/GoogleServiceAccount.php',
    'Google\\Service\\Storagetransfer\\HdfsData' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/HdfsData.php',
    'Google\\Service\\Storagetransfer\\HttpData' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/HttpData.php',
    'Google\\Service\\Storagetransfer\\ListAgentPoolsResponse' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ListAgentPoolsResponse.php',
    'Google\\Service\\Storagetransfer\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ListOperationsResponse.php',
    'Google\\Service\\Storagetransfer\\ListTaskSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ListTaskSpec.php',
    'Google\\Service\\Storagetransfer\\ListTransferJobsResponse' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ListTransferJobsResponse.php',
    'Google\\Service\\Storagetransfer\\LoggingConfig' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/LoggingConfig.php',
    'Google\\Service\\Storagetransfer\\Manifest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Manifest.php',
    'Google\\Service\\Storagetransfer\\MetadataOptions' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/MetadataOptions.php',
    'Google\\Service\\Storagetransfer\\MetadataTaskSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/MetadataTaskSpec.php',
    'Google\\Service\\Storagetransfer\\NotificationConfig' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/NotificationConfig.php',
    'Google\\Service\\Storagetransfer\\ObjectConditions' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ObjectConditions.php',
    'Google\\Service\\Storagetransfer\\ObjectPrefix' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ObjectPrefix.php',
    'Google\\Service\\Storagetransfer\\ObjectPrefixes' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ObjectPrefixes.php',
    'Google\\Service\\Storagetransfer\\Operation' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Operation.php',
    'Google\\Service\\Storagetransfer\\PauseTransferOperationRequest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/PauseTransferOperationRequest.php',
    'Google\\Service\\Storagetransfer\\PosixFilesystem' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/PosixFilesystem.php',
    'Google\\Service\\Storagetransfer\\ReplicationSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ReplicationSpec.php',
    'Google\\Service\\Storagetransfer\\Resource\\GoogleServiceAccounts' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Resource/GoogleServiceAccounts.php',
    'Google\\Service\\Storagetransfer\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Resource/Projects.php',
    'Google\\Service\\Storagetransfer\\Resource\\ProjectsAgentPools' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Resource/ProjectsAgentPools.php',
    'Google\\Service\\Storagetransfer\\Resource\\TransferJobs' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Resource/TransferJobs.php',
    'Google\\Service\\Storagetransfer\\Resource\\TransferOperations' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Resource/TransferOperations.php',
    'Google\\Service\\Storagetransfer\\ResumeTransferOperationRequest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/ResumeTransferOperationRequest.php',
    'Google\\Service\\Storagetransfer\\RunTransferJobRequest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/RunTransferJobRequest.php',
    'Google\\Service\\Storagetransfer\\S3CompatibleMetadata' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/S3CompatibleMetadata.php',
    'Google\\Service\\Storagetransfer\\Schedule' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Schedule.php',
    'Google\\Service\\Storagetransfer\\Status' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/Status.php',
    'Google\\Service\\Storagetransfer\\StoragetransferEmpty' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/StoragetransferEmpty.php',
    'Google\\Service\\Storagetransfer\\TimeOfDay' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TimeOfDay.php',
    'Google\\Service\\Storagetransfer\\TransferCounters' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferCounters.php',
    'Google\\Service\\Storagetransfer\\TransferJob' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferJob.php',
    'Google\\Service\\Storagetransfer\\TransferManifest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferManifest.php',
    'Google\\Service\\Storagetransfer\\TransferOperation' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferOperation.php',
    'Google\\Service\\Storagetransfer\\TransferOptions' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferOptions.php',
    'Google\\Service\\Storagetransfer\\TransferSpec' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/TransferSpec.php',
    'Google\\Service\\Storagetransfer\\UpdateTransferJobRequest' => $vendorDir . '/google/apiclient-services/src/Storagetransfer/UpdateTransferJobRequest.php',
    'Google\\Service\\StreetViewPublish' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish.php',
    'Google\\Service\\StreetViewPublish\\BatchDeletePhotosRequest' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/BatchDeletePhotosRequest.php',
    'Google\\Service\\StreetViewPublish\\BatchDeletePhotosResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/BatchDeletePhotosResponse.php',
    'Google\\Service\\StreetViewPublish\\BatchGetPhotosResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/BatchGetPhotosResponse.php',
    'Google\\Service\\StreetViewPublish\\BatchUpdatePhotosRequest' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/BatchUpdatePhotosRequest.php',
    'Google\\Service\\StreetViewPublish\\BatchUpdatePhotosResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/BatchUpdatePhotosResponse.php',
    'Google\\Service\\StreetViewPublish\\Connection' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Connection.php',
    'Google\\Service\\StreetViewPublish\\GpsDataGapFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/GpsDataGapFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\Imu' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Imu.php',
    'Google\\Service\\StreetViewPublish\\ImuDataGapFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/ImuDataGapFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\InsufficientGpsFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/InsufficientGpsFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\LatLng' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/LatLng.php',
    'Google\\Service\\StreetViewPublish\\LatLngBounds' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/LatLngBounds.php',
    'Google\\Service\\StreetViewPublish\\Level' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Level.php',
    'Google\\Service\\StreetViewPublish\\ListPhotoSequencesResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/ListPhotoSequencesResponse.php',
    'Google\\Service\\StreetViewPublish\\ListPhotosResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/ListPhotosResponse.php',
    'Google\\Service\\StreetViewPublish\\Measurement3d' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Measurement3d.php',
    'Google\\Service\\StreetViewPublish\\NoOverlapGpsFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/NoOverlapGpsFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\NotOutdoorsFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/NotOutdoorsFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\Operation' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Operation.php',
    'Google\\Service\\StreetViewPublish\\Photo' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Photo.php',
    'Google\\Service\\StreetViewPublish\\PhotoId' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/PhotoId.php',
    'Google\\Service\\StreetViewPublish\\PhotoResponse' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/PhotoResponse.php',
    'Google\\Service\\StreetViewPublish\\PhotoSequence' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/PhotoSequence.php',
    'Google\\Service\\StreetViewPublish\\Place' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Place.php',
    'Google\\Service\\StreetViewPublish\\Pose' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Pose.php',
    'Google\\Service\\StreetViewPublish\\ProcessingFailureDetails' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/ProcessingFailureDetails.php',
    'Google\\Service\\StreetViewPublish\\Resource\\Photo' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Resource/Photo.php',
    'Google\\Service\\StreetViewPublish\\Resource\\PhotoSequence' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Resource/PhotoSequence.php',
    'Google\\Service\\StreetViewPublish\\Resource\\PhotoSequences' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Resource/PhotoSequences.php',
    'Google\\Service\\StreetViewPublish\\Resource\\Photos' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Resource/Photos.php',
    'Google\\Service\\StreetViewPublish\\Status' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/Status.php',
    'Google\\Service\\StreetViewPublish\\StreetviewpublishEmpty' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/StreetviewpublishEmpty.php',
    'Google\\Service\\StreetViewPublish\\UpdatePhotoRequest' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/UpdatePhotoRequest.php',
    'Google\\Service\\StreetViewPublish\\UploadRef' => $vendorDir . '/google/apiclient-services/src/StreetViewPublish/UploadRef.php',
    'Google\\Service\\SubscriptionLinking' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking.php',
    'Google\\Service\\SubscriptionLinking\\DeleteReaderResponse' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/DeleteReaderResponse.php',
    'Google\\Service\\SubscriptionLinking\\Entitlement' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/Entitlement.php',
    'Google\\Service\\SubscriptionLinking\\Reader' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/Reader.php',
    'Google\\Service\\SubscriptionLinking\\ReaderEntitlements' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/ReaderEntitlements.php',
    'Google\\Service\\SubscriptionLinking\\Resource\\Publications' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/Resource/Publications.php',
    'Google\\Service\\SubscriptionLinking\\Resource\\PublicationsReaders' => $vendorDir . '/google/apiclient-services/src/SubscriptionLinking/Resource/PublicationsReaders.php',
    'Google\\Service\\TPU' => $vendorDir . '/google/apiclient-services/src/TPU.php',
    'Google\\Service\\TPU\\AcceleratorConfig' => $vendorDir . '/google/apiclient-services/src/TPU/AcceleratorConfig.php',
    'Google\\Service\\TPU\\AcceleratorType' => $vendorDir . '/google/apiclient-services/src/TPU/AcceleratorType.php',
    'Google\\Service\\TPU\\AcceptedData' => $vendorDir . '/google/apiclient-services/src/TPU/AcceptedData.php',
    'Google\\Service\\TPU\\AccessConfig' => $vendorDir . '/google/apiclient-services/src/TPU/AccessConfig.php',
    'Google\\Service\\TPU\\ActiveData' => $vendorDir . '/google/apiclient-services/src/TPU/ActiveData.php',
    'Google\\Service\\TPU\\AttachedDisk' => $vendorDir . '/google/apiclient-services/src/TPU/AttachedDisk.php',
    'Google\\Service\\TPU\\CreatingData' => $vendorDir . '/google/apiclient-services/src/TPU/CreatingData.php',
    'Google\\Service\\TPU\\DeletingData' => $vendorDir . '/google/apiclient-services/src/TPU/DeletingData.php',
    'Google\\Service\\TPU\\FailedData' => $vendorDir . '/google/apiclient-services/src/TPU/FailedData.php',
    'Google\\Service\\TPU\\GenerateServiceIdentityRequest' => $vendorDir . '/google/apiclient-services/src/TPU/GenerateServiceIdentityRequest.php',
    'Google\\Service\\TPU\\GenerateServiceIdentityResponse' => $vendorDir . '/google/apiclient-services/src/TPU/GenerateServiceIdentityResponse.php',
    'Google\\Service\\TPU\\GetGuestAttributesRequest' => $vendorDir . '/google/apiclient-services/src/TPU/GetGuestAttributesRequest.php',
    'Google\\Service\\TPU\\GetGuestAttributesResponse' => $vendorDir . '/google/apiclient-services/src/TPU/GetGuestAttributesResponse.php',
    'Google\\Service\\TPU\\Guaranteed' => $vendorDir . '/google/apiclient-services/src/TPU/Guaranteed.php',
    'Google\\Service\\TPU\\GuestAttributes' => $vendorDir . '/google/apiclient-services/src/TPU/GuestAttributes.php',
    'Google\\Service\\TPU\\GuestAttributesEntry' => $vendorDir . '/google/apiclient-services/src/TPU/GuestAttributesEntry.php',
    'Google\\Service\\TPU\\GuestAttributesValue' => $vendorDir . '/google/apiclient-services/src/TPU/GuestAttributesValue.php',
    'Google\\Service\\TPU\\Interval' => $vendorDir . '/google/apiclient-services/src/TPU/Interval.php',
    'Google\\Service\\TPU\\ListAcceleratorTypesResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListAcceleratorTypesResponse.php',
    'Google\\Service\\TPU\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListLocationsResponse.php',
    'Google\\Service\\TPU\\ListNodesResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListNodesResponse.php',
    'Google\\Service\\TPU\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListOperationsResponse.php',
    'Google\\Service\\TPU\\ListQueuedResourcesResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListQueuedResourcesResponse.php',
    'Google\\Service\\TPU\\ListRuntimeVersionsResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListRuntimeVersionsResponse.php',
    'Google\\Service\\TPU\\ListTensorFlowVersionsResponse' => $vendorDir . '/google/apiclient-services/src/TPU/ListTensorFlowVersionsResponse.php',
    'Google\\Service\\TPU\\Location' => $vendorDir . '/google/apiclient-services/src/TPU/Location.php',
    'Google\\Service\\TPU\\MultisliceParams' => $vendorDir . '/google/apiclient-services/src/TPU/MultisliceParams.php',
    'Google\\Service\\TPU\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/TPU/NetworkConfig.php',
    'Google\\Service\\TPU\\NetworkEndpoint' => $vendorDir . '/google/apiclient-services/src/TPU/NetworkEndpoint.php',
    'Google\\Service\\TPU\\Node' => $vendorDir . '/google/apiclient-services/src/TPU/Node.php',
    'Google\\Service\\TPU\\NodeSpec' => $vendorDir . '/google/apiclient-services/src/TPU/NodeSpec.php',
    'Google\\Service\\TPU\\Operation' => $vendorDir . '/google/apiclient-services/src/TPU/Operation.php',
    'Google\\Service\\TPU\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/TPU/OperationMetadata.php',
    'Google\\Service\\TPU\\ProvisioningData' => $vendorDir . '/google/apiclient-services/src/TPU/ProvisioningData.php',
    'Google\\Service\\TPU\\QueuedResource' => $vendorDir . '/google/apiclient-services/src/TPU/QueuedResource.php',
    'Google\\Service\\TPU\\QueuedResourceState' => $vendorDir . '/google/apiclient-services/src/TPU/QueuedResourceState.php',
    'Google\\Service\\TPU\\QueueingPolicy' => $vendorDir . '/google/apiclient-services/src/TPU/QueueingPolicy.php',
    'Google\\Service\\TPU\\ReimageNodeRequest' => $vendorDir . '/google/apiclient-services/src/TPU/ReimageNodeRequest.php',
    'Google\\Service\\TPU\\ResetQueuedResourceRequest' => $vendorDir . '/google/apiclient-services/src/TPU/ResetQueuedResourceRequest.php',
    'Google\\Service\\TPU\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/Projects.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocations.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsAcceleratorTypes' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsAcceleratorTypes.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsNodes' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsNodes.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsQueuedResources' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsQueuedResources.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsRuntimeVersions' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsRuntimeVersions.php',
    'Google\\Service\\TPU\\Resource\\ProjectsLocationsTensorflowVersions' => $vendorDir . '/google/apiclient-services/src/TPU/Resource/ProjectsLocationsTensorflowVersions.php',
    'Google\\Service\\TPU\\RuntimeVersion' => $vendorDir . '/google/apiclient-services/src/TPU/RuntimeVersion.php',
    'Google\\Service\\TPU\\SchedulingConfig' => $vendorDir . '/google/apiclient-services/src/TPU/SchedulingConfig.php',
    'Google\\Service\\TPU\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/TPU/ServiceAccount.php',
    'Google\\Service\\TPU\\ServiceIdentity' => $vendorDir . '/google/apiclient-services/src/TPU/ServiceIdentity.php',
    'Google\\Service\\TPU\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/TPU/ShieldedInstanceConfig.php',
    'Google\\Service\\TPU\\Spot' => $vendorDir . '/google/apiclient-services/src/TPU/Spot.php',
    'Google\\Service\\TPU\\StartNodeRequest' => $vendorDir . '/google/apiclient-services/src/TPU/StartNodeRequest.php',
    'Google\\Service\\TPU\\Status' => $vendorDir . '/google/apiclient-services/src/TPU/Status.php',
    'Google\\Service\\TPU\\StopNodeRequest' => $vendorDir . '/google/apiclient-services/src/TPU/StopNodeRequest.php',
    'Google\\Service\\TPU\\SuspendedData' => $vendorDir . '/google/apiclient-services/src/TPU/SuspendedData.php',
    'Google\\Service\\TPU\\SuspendingData' => $vendorDir . '/google/apiclient-services/src/TPU/SuspendingData.php',
    'Google\\Service\\TPU\\Symptom' => $vendorDir . '/google/apiclient-services/src/TPU/Symptom.php',
    'Google\\Service\\TPU\\TensorFlowVersion' => $vendorDir . '/google/apiclient-services/src/TPU/TensorFlowVersion.php',
    'Google\\Service\\TPU\\Tpu' => $vendorDir . '/google/apiclient-services/src/TPU/Tpu.php',
    'Google\\Service\\TPU\\TpuEmpty' => $vendorDir . '/google/apiclient-services/src/TPU/TpuEmpty.php',
    'Google\\Service\\TagManager' => $vendorDir . '/google/apiclient-services/src/TagManager.php',
    'Google\\Service\\TagManager\\Account' => $vendorDir . '/google/apiclient-services/src/TagManager/Account.php',
    'Google\\Service\\TagManager\\AccountAccess' => $vendorDir . '/google/apiclient-services/src/TagManager/AccountAccess.php',
    'Google\\Service\\TagManager\\AccountFeatures' => $vendorDir . '/google/apiclient-services/src/TagManager/AccountFeatures.php',
    'Google\\Service\\TagManager\\BuiltInVariable' => $vendorDir . '/google/apiclient-services/src/TagManager/BuiltInVariable.php',
    'Google\\Service\\TagManager\\Client' => $vendorDir . '/google/apiclient-services/src/TagManager/Client.php',
    'Google\\Service\\TagManager\\Condition' => $vendorDir . '/google/apiclient-services/src/TagManager/Condition.php',
    'Google\\Service\\TagManager\\Container' => $vendorDir . '/google/apiclient-services/src/TagManager/Container.php',
    'Google\\Service\\TagManager\\ContainerAccess' => $vendorDir . '/google/apiclient-services/src/TagManager/ContainerAccess.php',
    'Google\\Service\\TagManager\\ContainerFeatures' => $vendorDir . '/google/apiclient-services/src/TagManager/ContainerFeatures.php',
    'Google\\Service\\TagManager\\ContainerVersion' => $vendorDir . '/google/apiclient-services/src/TagManager/ContainerVersion.php',
    'Google\\Service\\TagManager\\ContainerVersionHeader' => $vendorDir . '/google/apiclient-services/src/TagManager/ContainerVersionHeader.php',
    'Google\\Service\\TagManager\\CreateBuiltInVariableResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/CreateBuiltInVariableResponse.php',
    'Google\\Service\\TagManager\\CreateContainerVersionRequestVersionOptions' => $vendorDir . '/google/apiclient-services/src/TagManager/CreateContainerVersionRequestVersionOptions.php',
    'Google\\Service\\TagManager\\CreateContainerVersionResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/CreateContainerVersionResponse.php',
    'Google\\Service\\TagManager\\CustomTemplate' => $vendorDir . '/google/apiclient-services/src/TagManager/CustomTemplate.php',
    'Google\\Service\\TagManager\\Destination' => $vendorDir . '/google/apiclient-services/src/TagManager/Destination.php',
    'Google\\Service\\TagManager\\Entity' => $vendorDir . '/google/apiclient-services/src/TagManager/Entity.php',
    'Google\\Service\\TagManager\\Environment' => $vendorDir . '/google/apiclient-services/src/TagManager/Environment.php',
    'Google\\Service\\TagManager\\Folder' => $vendorDir . '/google/apiclient-services/src/TagManager/Folder.php',
    'Google\\Service\\TagManager\\FolderEntities' => $vendorDir . '/google/apiclient-services/src/TagManager/FolderEntities.php',
    'Google\\Service\\TagManager\\GalleryReference' => $vendorDir . '/google/apiclient-services/src/TagManager/GalleryReference.php',
    'Google\\Service\\TagManager\\GetContainerSnippetResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/GetContainerSnippetResponse.php',
    'Google\\Service\\TagManager\\GetWorkspaceStatusResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/GetWorkspaceStatusResponse.php',
    'Google\\Service\\TagManager\\GtagConfig' => $vendorDir . '/google/apiclient-services/src/TagManager/GtagConfig.php',
    'Google\\Service\\TagManager\\ListAccountsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListAccountsResponse.php',
    'Google\\Service\\TagManager\\ListClientsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListClientsResponse.php',
    'Google\\Service\\TagManager\\ListContainerVersionsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListContainerVersionsResponse.php',
    'Google\\Service\\TagManager\\ListContainersResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListContainersResponse.php',
    'Google\\Service\\TagManager\\ListDestinationsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListDestinationsResponse.php',
    'Google\\Service\\TagManager\\ListEnabledBuiltInVariablesResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListEnabledBuiltInVariablesResponse.php',
    'Google\\Service\\TagManager\\ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListEnvironmentsResponse.php',
    'Google\\Service\\TagManager\\ListFoldersResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListFoldersResponse.php',
    'Google\\Service\\TagManager\\ListGtagConfigResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListGtagConfigResponse.php',
    'Google\\Service\\TagManager\\ListTagsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListTagsResponse.php',
    'Google\\Service\\TagManager\\ListTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListTemplatesResponse.php',
    'Google\\Service\\TagManager\\ListTransformationsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListTransformationsResponse.php',
    'Google\\Service\\TagManager\\ListTriggersResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListTriggersResponse.php',
    'Google\\Service\\TagManager\\ListUserPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListUserPermissionsResponse.php',
    'Google\\Service\\TagManager\\ListVariablesResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListVariablesResponse.php',
    'Google\\Service\\TagManager\\ListWorkspacesResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListWorkspacesResponse.php',
    'Google\\Service\\TagManager\\ListZonesResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/ListZonesResponse.php',
    'Google\\Service\\TagManager\\MergeConflict' => $vendorDir . '/google/apiclient-services/src/TagManager/MergeConflict.php',
    'Google\\Service\\TagManager\\Parameter' => $vendorDir . '/google/apiclient-services/src/TagManager/Parameter.php',
    'Google\\Service\\TagManager\\PublishContainerVersionResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/PublishContainerVersionResponse.php',
    'Google\\Service\\TagManager\\QuickPreviewResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/QuickPreviewResponse.php',
    'Google\\Service\\TagManager\\Resource\\Accounts' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/Accounts.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainers' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainers.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersDestinations' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersDestinations.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersEnvironments' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersEnvironments.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersVersionHeaders' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersVersionHeaders.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersVersions' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersVersions.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspaces' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspaces.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesBuiltInVariables' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesBuiltInVariables.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesClients' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesClients.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesFolders' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesFolders.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesGtagConfig' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesGtagConfig.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTags' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesTags.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTemplates' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesTemplates.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTransformations' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesTransformations.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTriggers' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesTriggers.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesVariables' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesVariables.php',
    'Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesZones' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsContainersWorkspacesZones.php',
    'Google\\Service\\TagManager\\Resource\\AccountsUserPermissions' => $vendorDir . '/google/apiclient-services/src/TagManager/Resource/AccountsUserPermissions.php',
    'Google\\Service\\TagManager\\RevertBuiltInVariableResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertBuiltInVariableResponse.php',
    'Google\\Service\\TagManager\\RevertClientResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertClientResponse.php',
    'Google\\Service\\TagManager\\RevertFolderResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertFolderResponse.php',
    'Google\\Service\\TagManager\\RevertTagResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertTagResponse.php',
    'Google\\Service\\TagManager\\RevertTemplateResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertTemplateResponse.php',
    'Google\\Service\\TagManager\\RevertTransformationResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertTransformationResponse.php',
    'Google\\Service\\TagManager\\RevertTriggerResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertTriggerResponse.php',
    'Google\\Service\\TagManager\\RevertVariableResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertVariableResponse.php',
    'Google\\Service\\TagManager\\RevertZoneResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/RevertZoneResponse.php',
    'Google\\Service\\TagManager\\SetupTag' => $vendorDir . '/google/apiclient-services/src/TagManager/SetupTag.php',
    'Google\\Service\\TagManager\\SyncStatus' => $vendorDir . '/google/apiclient-services/src/TagManager/SyncStatus.php',
    'Google\\Service\\TagManager\\SyncWorkspaceResponse' => $vendorDir . '/google/apiclient-services/src/TagManager/SyncWorkspaceResponse.php',
    'Google\\Service\\TagManager\\Tag' => $vendorDir . '/google/apiclient-services/src/TagManager/Tag.php',
    'Google\\Service\\TagManager\\TagConsentSetting' => $vendorDir . '/google/apiclient-services/src/TagManager/TagConsentSetting.php',
    'Google\\Service\\TagManager\\TeardownTag' => $vendorDir . '/google/apiclient-services/src/TagManager/TeardownTag.php',
    'Google\\Service\\TagManager\\Transformation' => $vendorDir . '/google/apiclient-services/src/TagManager/Transformation.php',
    'Google\\Service\\TagManager\\Trigger' => $vendorDir . '/google/apiclient-services/src/TagManager/Trigger.php',
    'Google\\Service\\TagManager\\UserPermission' => $vendorDir . '/google/apiclient-services/src/TagManager/UserPermission.php',
    'Google\\Service\\TagManager\\Variable' => $vendorDir . '/google/apiclient-services/src/TagManager/Variable.php',
    'Google\\Service\\TagManager\\VariableFormatValue' => $vendorDir . '/google/apiclient-services/src/TagManager/VariableFormatValue.php',
    'Google\\Service\\TagManager\\Workspace' => $vendorDir . '/google/apiclient-services/src/TagManager/Workspace.php',
    'Google\\Service\\TagManager\\Zone' => $vendorDir . '/google/apiclient-services/src/TagManager/Zone.php',
    'Google\\Service\\TagManager\\ZoneBoundary' => $vendorDir . '/google/apiclient-services/src/TagManager/ZoneBoundary.php',
    'Google\\Service\\TagManager\\ZoneChildContainer' => $vendorDir . '/google/apiclient-services/src/TagManager/ZoneChildContainer.php',
    'Google\\Service\\TagManager\\ZoneTypeRestriction' => $vendorDir . '/google/apiclient-services/src/TagManager/ZoneTypeRestriction.php',
    'Google\\Service\\Tasks' => $vendorDir . '/google/apiclient-services/src/Tasks.php',
    'Google\\Service\\Tasks\\AssignmentInfo' => $vendorDir . '/google/apiclient-services/src/Tasks/AssignmentInfo.php',
    'Google\\Service\\Tasks\\DriveResourceInfo' => $vendorDir . '/google/apiclient-services/src/Tasks/DriveResourceInfo.php',
    'Google\\Service\\Tasks\\Resource\\Tasklists' => $vendorDir . '/google/apiclient-services/src/Tasks/Resource/Tasklists.php',
    'Google\\Service\\Tasks\\Resource\\Tasks' => $vendorDir . '/google/apiclient-services/src/Tasks/Resource/Tasks.php',
    'Google\\Service\\Tasks\\SpaceInfo' => $vendorDir . '/google/apiclient-services/src/Tasks/SpaceInfo.php',
    'Google\\Service\\Tasks\\Task' => $vendorDir . '/google/apiclient-services/src/Tasks/Task.php',
    'Google\\Service\\Tasks\\TaskLinks' => $vendorDir . '/google/apiclient-services/src/Tasks/TaskLinks.php',
    'Google\\Service\\Tasks\\TaskList' => $vendorDir . '/google/apiclient-services/src/Tasks/TaskList.php',
    'Google\\Service\\Tasks\\TaskLists' => $vendorDir . '/google/apiclient-services/src/Tasks/TaskLists.php',
    'Google\\Service\\Tasks\\Tasks' => $vendorDir . '/google/apiclient-services/src/Tasks/Tasks.php',
    'Google\\Service\\Testing' => $vendorDir . '/google/apiclient-services/src/Testing.php',
    'Google\\Service\\Testing\\Account' => $vendorDir . '/google/apiclient-services/src/Testing/Account.php',
    'Google\\Service\\Testing\\AndroidDevice' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidDevice.php',
    'Google\\Service\\Testing\\AndroidDeviceCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidDeviceCatalog.php',
    'Google\\Service\\Testing\\AndroidDeviceList' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidDeviceList.php',
    'Google\\Service\\Testing\\AndroidInstrumentationTest' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidInstrumentationTest.php',
    'Google\\Service\\Testing\\AndroidMatrix' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidMatrix.php',
    'Google\\Service\\Testing\\AndroidModel' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidModel.php',
    'Google\\Service\\Testing\\AndroidRoboTest' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidRoboTest.php',
    'Google\\Service\\Testing\\AndroidRuntimeConfiguration' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidRuntimeConfiguration.php',
    'Google\\Service\\Testing\\AndroidTestLoop' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidTestLoop.php',
    'Google\\Service\\Testing\\AndroidVersion' => $vendorDir . '/google/apiclient-services/src/Testing/AndroidVersion.php',
    'Google\\Service\\Testing\\Apk' => $vendorDir . '/google/apiclient-services/src/Testing/Apk.php',
    'Google\\Service\\Testing\\ApkDetail' => $vendorDir . '/google/apiclient-services/src/Testing/ApkDetail.php',
    'Google\\Service\\Testing\\ApkManifest' => $vendorDir . '/google/apiclient-services/src/Testing/ApkManifest.php',
    'Google\\Service\\Testing\\AppBundle' => $vendorDir . '/google/apiclient-services/src/Testing/AppBundle.php',
    'Google\\Service\\Testing\\CancelDeviceSessionRequest' => $vendorDir . '/google/apiclient-services/src/Testing/CancelDeviceSessionRequest.php',
    'Google\\Service\\Testing\\CancelTestMatrixResponse' => $vendorDir . '/google/apiclient-services/src/Testing/CancelTestMatrixResponse.php',
    'Google\\Service\\Testing\\ClientInfo' => $vendorDir . '/google/apiclient-services/src/Testing/ClientInfo.php',
    'Google\\Service\\Testing\\ClientInfoDetail' => $vendorDir . '/google/apiclient-services/src/Testing/ClientInfoDetail.php',
    'Google\\Service\\Testing\\Date' => $vendorDir . '/google/apiclient-services/src/Testing/Date.php',
    'Google\\Service\\Testing\\DeviceFile' => $vendorDir . '/google/apiclient-services/src/Testing/DeviceFile.php',
    'Google\\Service\\Testing\\DeviceIpBlock' => $vendorDir . '/google/apiclient-services/src/Testing/DeviceIpBlock.php',
    'Google\\Service\\Testing\\DeviceIpBlockCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/DeviceIpBlockCatalog.php',
    'Google\\Service\\Testing\\DeviceSession' => $vendorDir . '/google/apiclient-services/src/Testing/DeviceSession.php',
    'Google\\Service\\Testing\\DirectAccessVersionInfo' => $vendorDir . '/google/apiclient-services/src/Testing/DirectAccessVersionInfo.php',
    'Google\\Service\\Testing\\Distribution' => $vendorDir . '/google/apiclient-services/src/Testing/Distribution.php',
    'Google\\Service\\Testing\\Environment' => $vendorDir . '/google/apiclient-services/src/Testing/Environment.php',
    'Google\\Service\\Testing\\EnvironmentMatrix' => $vendorDir . '/google/apiclient-services/src/Testing/EnvironmentMatrix.php',
    'Google\\Service\\Testing\\EnvironmentVariable' => $vendorDir . '/google/apiclient-services/src/Testing/EnvironmentVariable.php',
    'Google\\Service\\Testing\\FileReference' => $vendorDir . '/google/apiclient-services/src/Testing/FileReference.php',
    'Google\\Service\\Testing\\GetApkDetailsResponse' => $vendorDir . '/google/apiclient-services/src/Testing/GetApkDetailsResponse.php',
    'Google\\Service\\Testing\\GoogleAuto' => $vendorDir . '/google/apiclient-services/src/Testing/GoogleAuto.php',
    'Google\\Service\\Testing\\GoogleCloudStorage' => $vendorDir . '/google/apiclient-services/src/Testing/GoogleCloudStorage.php',
    'Google\\Service\\Testing\\IntentFilter' => $vendorDir . '/google/apiclient-services/src/Testing/IntentFilter.php',
    'Google\\Service\\Testing\\IosDevice' => $vendorDir . '/google/apiclient-services/src/Testing/IosDevice.php',
    'Google\\Service\\Testing\\IosDeviceCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/IosDeviceCatalog.php',
    'Google\\Service\\Testing\\IosDeviceFile' => $vendorDir . '/google/apiclient-services/src/Testing/IosDeviceFile.php',
    'Google\\Service\\Testing\\IosDeviceList' => $vendorDir . '/google/apiclient-services/src/Testing/IosDeviceList.php',
    'Google\\Service\\Testing\\IosModel' => $vendorDir . '/google/apiclient-services/src/Testing/IosModel.php',
    'Google\\Service\\Testing\\IosRoboTest' => $vendorDir . '/google/apiclient-services/src/Testing/IosRoboTest.php',
    'Google\\Service\\Testing\\IosRuntimeConfiguration' => $vendorDir . '/google/apiclient-services/src/Testing/IosRuntimeConfiguration.php',
    'Google\\Service\\Testing\\IosTestLoop' => $vendorDir . '/google/apiclient-services/src/Testing/IosTestLoop.php',
    'Google\\Service\\Testing\\IosTestSetup' => $vendorDir . '/google/apiclient-services/src/Testing/IosTestSetup.php',
    'Google\\Service\\Testing\\IosVersion' => $vendorDir . '/google/apiclient-services/src/Testing/IosVersion.php',
    'Google\\Service\\Testing\\IosXcTest' => $vendorDir . '/google/apiclient-services/src/Testing/IosXcTest.php',
    'Google\\Service\\Testing\\LauncherActivityIntent' => $vendorDir . '/google/apiclient-services/src/Testing/LauncherActivityIntent.php',
    'Google\\Service\\Testing\\ListDeviceSessionsResponse' => $vendorDir . '/google/apiclient-services/src/Testing/ListDeviceSessionsResponse.php',
    'Google\\Service\\Testing\\Locale' => $vendorDir . '/google/apiclient-services/src/Testing/Locale.php',
    'Google\\Service\\Testing\\ManualSharding' => $vendorDir . '/google/apiclient-services/src/Testing/ManualSharding.php',
    'Google\\Service\\Testing\\MatrixErrorDetail' => $vendorDir . '/google/apiclient-services/src/Testing/MatrixErrorDetail.php',
    'Google\\Service\\Testing\\Metadata' => $vendorDir . '/google/apiclient-services/src/Testing/Metadata.php',
    'Google\\Service\\Testing\\NetworkConfiguration' => $vendorDir . '/google/apiclient-services/src/Testing/NetworkConfiguration.php',
    'Google\\Service\\Testing\\NetworkConfigurationCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/NetworkConfigurationCatalog.php',
    'Google\\Service\\Testing\\NoActivityIntent' => $vendorDir . '/google/apiclient-services/src/Testing/NoActivityIntent.php',
    'Google\\Service\\Testing\\ObbFile' => $vendorDir . '/google/apiclient-services/src/Testing/ObbFile.php',
    'Google\\Service\\Testing\\Orientation' => $vendorDir . '/google/apiclient-services/src/Testing/Orientation.php',
    'Google\\Service\\Testing\\PerAndroidVersionInfo' => $vendorDir . '/google/apiclient-services/src/Testing/PerAndroidVersionInfo.php',
    'Google\\Service\\Testing\\PerIosVersionInfo' => $vendorDir . '/google/apiclient-services/src/Testing/PerIosVersionInfo.php',
    'Google\\Service\\Testing\\ProvidedSoftwareCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/ProvidedSoftwareCatalog.php',
    'Google\\Service\\Testing\\RegularFile' => $vendorDir . '/google/apiclient-services/src/Testing/RegularFile.php',
    'Google\\Service\\Testing\\Resource\\ApplicationDetailService' => $vendorDir . '/google/apiclient-services/src/Testing/Resource/ApplicationDetailService.php',
    'Google\\Service\\Testing\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Testing/Resource/Projects.php',
    'Google\\Service\\Testing\\Resource\\ProjectsDeviceSessions' => $vendorDir . '/google/apiclient-services/src/Testing/Resource/ProjectsDeviceSessions.php',
    'Google\\Service\\Testing\\Resource\\ProjectsTestMatrices' => $vendorDir . '/google/apiclient-services/src/Testing/Resource/ProjectsTestMatrices.php',
    'Google\\Service\\Testing\\Resource\\TestEnvironmentCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/Resource/TestEnvironmentCatalog.php',
    'Google\\Service\\Testing\\ResultStorage' => $vendorDir . '/google/apiclient-services/src/Testing/ResultStorage.php',
    'Google\\Service\\Testing\\RoboDirective' => $vendorDir . '/google/apiclient-services/src/Testing/RoboDirective.php',
    'Google\\Service\\Testing\\RoboStartingIntent' => $vendorDir . '/google/apiclient-services/src/Testing/RoboStartingIntent.php',
    'Google\\Service\\Testing\\Service' => $vendorDir . '/google/apiclient-services/src/Testing/Service.php',
    'Google\\Service\\Testing\\SessionStateEvent' => $vendorDir . '/google/apiclient-services/src/Testing/SessionStateEvent.php',
    'Google\\Service\\Testing\\Shard' => $vendorDir . '/google/apiclient-services/src/Testing/Shard.php',
    'Google\\Service\\Testing\\ShardingOption' => $vendorDir . '/google/apiclient-services/src/Testing/ShardingOption.php',
    'Google\\Service\\Testing\\SmartSharding' => $vendorDir . '/google/apiclient-services/src/Testing/SmartSharding.php',
    'Google\\Service\\Testing\\StartActivityIntent' => $vendorDir . '/google/apiclient-services/src/Testing/StartActivityIntent.php',
    'Google\\Service\\Testing\\SystraceSetup' => $vendorDir . '/google/apiclient-services/src/Testing/SystraceSetup.php',
    'Google\\Service\\Testing\\TestDetails' => $vendorDir . '/google/apiclient-services/src/Testing/TestDetails.php',
    'Google\\Service\\Testing\\TestEnvironmentCatalog' => $vendorDir . '/google/apiclient-services/src/Testing/TestEnvironmentCatalog.php',
    'Google\\Service\\Testing\\TestExecution' => $vendorDir . '/google/apiclient-services/src/Testing/TestExecution.php',
    'Google\\Service\\Testing\\TestMatrix' => $vendorDir . '/google/apiclient-services/src/Testing/TestMatrix.php',
    'Google\\Service\\Testing\\TestSetup' => $vendorDir . '/google/apiclient-services/src/Testing/TestSetup.php',
    'Google\\Service\\Testing\\TestSpecification' => $vendorDir . '/google/apiclient-services/src/Testing/TestSpecification.php',
    'Google\\Service\\Testing\\TestTargetsForShard' => $vendorDir . '/google/apiclient-services/src/Testing/TestTargetsForShard.php',
    'Google\\Service\\Testing\\TestingEmpty' => $vendorDir . '/google/apiclient-services/src/Testing/TestingEmpty.php',
    'Google\\Service\\Testing\\ToolResultsExecution' => $vendorDir . '/google/apiclient-services/src/Testing/ToolResultsExecution.php',
    'Google\\Service\\Testing\\ToolResultsHistory' => $vendorDir . '/google/apiclient-services/src/Testing/ToolResultsHistory.php',
    'Google\\Service\\Testing\\ToolResultsStep' => $vendorDir . '/google/apiclient-services/src/Testing/ToolResultsStep.php',
    'Google\\Service\\Testing\\TrafficRule' => $vendorDir . '/google/apiclient-services/src/Testing/TrafficRule.php',
    'Google\\Service\\Testing\\UniformSharding' => $vendorDir . '/google/apiclient-services/src/Testing/UniformSharding.php',
    'Google\\Service\\Testing\\UsesFeature' => $vendorDir . '/google/apiclient-services/src/Testing/UsesFeature.php',
    'Google\\Service\\Testing\\XcodeVersion' => $vendorDir . '/google/apiclient-services/src/Testing/XcodeVersion.php',
    'Google\\Service\\Texttospeech' => $vendorDir . '/google/apiclient-services/src/Texttospeech.php',
    'Google\\Service\\Texttospeech\\AudioConfig' => $vendorDir . '/google/apiclient-services/src/Texttospeech/AudioConfig.php',
    'Google\\Service\\Texttospeech\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Texttospeech/CancelOperationRequest.php',
    'Google\\Service\\Texttospeech\\CustomVoiceParams' => $vendorDir . '/google/apiclient-services/src/Texttospeech/CustomVoiceParams.php',
    'Google\\Service\\Texttospeech\\GoogleCloudTexttospeechV1SynthesizeLongAudioMetadata' => $vendorDir . '/google/apiclient-services/src/Texttospeech/GoogleCloudTexttospeechV1SynthesizeLongAudioMetadata.php',
    'Google\\Service\\Texttospeech\\ImportDataRequest' => $vendorDir . '/google/apiclient-services/src/Texttospeech/ImportDataRequest.php',
    'Google\\Service\\Texttospeech\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Texttospeech/ListOperationsResponse.php',
    'Google\\Service\\Texttospeech\\ListVoicesResponse' => $vendorDir . '/google/apiclient-services/src/Texttospeech/ListVoicesResponse.php',
    'Google\\Service\\Texttospeech\\Operation' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Operation.php',
    'Google\\Service\\Texttospeech\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/Operations.php',
    'Google\\Service\\Texttospeech\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/Projects.php',
    'Google\\Service\\Texttospeech\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/ProjectsLocations.php',
    'Google\\Service\\Texttospeech\\Resource\\ProjectsLocationsDatasets' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/ProjectsLocationsDatasets.php',
    'Google\\Service\\Texttospeech\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Texttospeech\\Resource\\ProjectsLocationsVoices' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/ProjectsLocationsVoices.php',
    'Google\\Service\\Texttospeech\\Resource\\Text' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/Text.php',
    'Google\\Service\\Texttospeech\\Resource\\Voices' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Resource/Voices.php',
    'Google\\Service\\Texttospeech\\Status' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Status.php',
    'Google\\Service\\Texttospeech\\SynthesisInput' => $vendorDir . '/google/apiclient-services/src/Texttospeech/SynthesisInput.php',
    'Google\\Service\\Texttospeech\\SynthesizeLongAudioMetadata' => $vendorDir . '/google/apiclient-services/src/Texttospeech/SynthesizeLongAudioMetadata.php',
    'Google\\Service\\Texttospeech\\SynthesizeLongAudioRequest' => $vendorDir . '/google/apiclient-services/src/Texttospeech/SynthesizeLongAudioRequest.php',
    'Google\\Service\\Texttospeech\\SynthesizeSpeechRequest' => $vendorDir . '/google/apiclient-services/src/Texttospeech/SynthesizeSpeechRequest.php',
    'Google\\Service\\Texttospeech\\SynthesizeSpeechResponse' => $vendorDir . '/google/apiclient-services/src/Texttospeech/SynthesizeSpeechResponse.php',
    'Google\\Service\\Texttospeech\\TexttospeechEmpty' => $vendorDir . '/google/apiclient-services/src/Texttospeech/TexttospeechEmpty.php',
    'Google\\Service\\Texttospeech\\Voice' => $vendorDir . '/google/apiclient-services/src/Texttospeech/Voice.php',
    'Google\\Service\\Texttospeech\\VoiceSelectionParams' => $vendorDir . '/google/apiclient-services/src/Texttospeech/VoiceSelectionParams.php',
    'Google\\Service\\ToolResults' => $vendorDir . '/google/apiclient-services/src/ToolResults.php',
    'Google\\Service\\ToolResults\\ANR' => $vendorDir . '/google/apiclient-services/src/ToolResults/ANR.php',
    'Google\\Service\\ToolResults\\AndroidAppInfo' => $vendorDir . '/google/apiclient-services/src/ToolResults/AndroidAppInfo.php',
    'Google\\Service\\ToolResults\\AndroidInstrumentationTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/AndroidInstrumentationTest.php',
    'Google\\Service\\ToolResults\\AndroidRoboTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/AndroidRoboTest.php',
    'Google\\Service\\ToolResults\\AndroidTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/AndroidTest.php',
    'Google\\Service\\ToolResults\\AndroidTestLoop' => $vendorDir . '/google/apiclient-services/src/ToolResults/AndroidTestLoop.php',
    'Google\\Service\\ToolResults\\Any' => $vendorDir . '/google/apiclient-services/src/ToolResults/Any.php',
    'Google\\Service\\ToolResults\\AppStartTime' => $vendorDir . '/google/apiclient-services/src/ToolResults/AppStartTime.php',
    'Google\\Service\\ToolResults\\AssetIssue' => $vendorDir . '/google/apiclient-services/src/ToolResults/AssetIssue.php',
    'Google\\Service\\ToolResults\\AvailableDeepLinks' => $vendorDir . '/google/apiclient-services/src/ToolResults/AvailableDeepLinks.php',
    'Google\\Service\\ToolResults\\BasicPerfSampleSeries' => $vendorDir . '/google/apiclient-services/src/ToolResults/BasicPerfSampleSeries.php',
    'Google\\Service\\ToolResults\\BatchCreatePerfSamplesRequest' => $vendorDir . '/google/apiclient-services/src/ToolResults/BatchCreatePerfSamplesRequest.php',
    'Google\\Service\\ToolResults\\BatchCreatePerfSamplesResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/BatchCreatePerfSamplesResponse.php',
    'Google\\Service\\ToolResults\\BlankScreen' => $vendorDir . '/google/apiclient-services/src/ToolResults/BlankScreen.php',
    'Google\\Service\\ToolResults\\CPUInfo' => $vendorDir . '/google/apiclient-services/src/ToolResults/CPUInfo.php',
    'Google\\Service\\ToolResults\\CrashDialogError' => $vendorDir . '/google/apiclient-services/src/ToolResults/CrashDialogError.php',
    'Google\\Service\\ToolResults\\DetectedAppSplashScreen' => $vendorDir . '/google/apiclient-services/src/ToolResults/DetectedAppSplashScreen.php',
    'Google\\Service\\ToolResults\\DeviceOutOfMemory' => $vendorDir . '/google/apiclient-services/src/ToolResults/DeviceOutOfMemory.php',
    'Google\\Service\\ToolResults\\Duration' => $vendorDir . '/google/apiclient-services/src/ToolResults/Duration.php',
    'Google\\Service\\ToolResults\\EncounteredLoginScreen' => $vendorDir . '/google/apiclient-services/src/ToolResults/EncounteredLoginScreen.php',
    'Google\\Service\\ToolResults\\EncounteredNonAndroidUiWidgetScreen' => $vendorDir . '/google/apiclient-services/src/ToolResults/EncounteredNonAndroidUiWidgetScreen.php',
    'Google\\Service\\ToolResults\\Environment' => $vendorDir . '/google/apiclient-services/src/ToolResults/Environment.php',
    'Google\\Service\\ToolResults\\EnvironmentDimensionValueEntry' => $vendorDir . '/google/apiclient-services/src/ToolResults/EnvironmentDimensionValueEntry.php',
    'Google\\Service\\ToolResults\\Execution' => $vendorDir . '/google/apiclient-services/src/ToolResults/Execution.php',
    'Google\\Service\\ToolResults\\FailedToInstall' => $vendorDir . '/google/apiclient-services/src/ToolResults/FailedToInstall.php',
    'Google\\Service\\ToolResults\\FailureDetail' => $vendorDir . '/google/apiclient-services/src/ToolResults/FailureDetail.php',
    'Google\\Service\\ToolResults\\FatalException' => $vendorDir . '/google/apiclient-services/src/ToolResults/FatalException.php',
    'Google\\Service\\ToolResults\\FileReference' => $vendorDir . '/google/apiclient-services/src/ToolResults/FileReference.php',
    'Google\\Service\\ToolResults\\GraphicsStats' => $vendorDir . '/google/apiclient-services/src/ToolResults/GraphicsStats.php',
    'Google\\Service\\ToolResults\\GraphicsStatsBucket' => $vendorDir . '/google/apiclient-services/src/ToolResults/GraphicsStatsBucket.php',
    'Google\\Service\\ToolResults\\History' => $vendorDir . '/google/apiclient-services/src/ToolResults/History.php',
    'Google\\Service\\ToolResults\\Image' => $vendorDir . '/google/apiclient-services/src/ToolResults/Image.php',
    'Google\\Service\\ToolResults\\InAppPurchasesFound' => $vendorDir . '/google/apiclient-services/src/ToolResults/InAppPurchasesFound.php',
    'Google\\Service\\ToolResults\\InconclusiveDetail' => $vendorDir . '/google/apiclient-services/src/ToolResults/InconclusiveDetail.php',
    'Google\\Service\\ToolResults\\IndividualOutcome' => $vendorDir . '/google/apiclient-services/src/ToolResults/IndividualOutcome.php',
    'Google\\Service\\ToolResults\\InsufficientCoverage' => $vendorDir . '/google/apiclient-services/src/ToolResults/InsufficientCoverage.php',
    'Google\\Service\\ToolResults\\IosAppCrashed' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosAppCrashed.php',
    'Google\\Service\\ToolResults\\IosAppInfo' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosAppInfo.php',
    'Google\\Service\\ToolResults\\IosRoboTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosRoboTest.php',
    'Google\\Service\\ToolResults\\IosTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosTest.php',
    'Google\\Service\\ToolResults\\IosTestLoop' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosTestLoop.php',
    'Google\\Service\\ToolResults\\IosXcTest' => $vendorDir . '/google/apiclient-services/src/ToolResults/IosXcTest.php',
    'Google\\Service\\ToolResults\\LauncherActivityNotFound' => $vendorDir . '/google/apiclient-services/src/ToolResults/LauncherActivityNotFound.php',
    'Google\\Service\\ToolResults\\ListEnvironmentsResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListEnvironmentsResponse.php',
    'Google\\Service\\ToolResults\\ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListExecutionsResponse.php',
    'Google\\Service\\ToolResults\\ListHistoriesResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListHistoriesResponse.php',
    'Google\\Service\\ToolResults\\ListPerfSampleSeriesResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListPerfSampleSeriesResponse.php',
    'Google\\Service\\ToolResults\\ListPerfSamplesResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListPerfSamplesResponse.php',
    'Google\\Service\\ToolResults\\ListScreenshotClustersResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListScreenshotClustersResponse.php',
    'Google\\Service\\ToolResults\\ListStepAccessibilityClustersResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListStepAccessibilityClustersResponse.php',
    'Google\\Service\\ToolResults\\ListStepThumbnailsResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListStepThumbnailsResponse.php',
    'Google\\Service\\ToolResults\\ListStepsResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListStepsResponse.php',
    'Google\\Service\\ToolResults\\ListTestCasesResponse' => $vendorDir . '/google/apiclient-services/src/ToolResults/ListTestCasesResponse.php',
    'Google\\Service\\ToolResults\\LogcatCollectionError' => $vendorDir . '/google/apiclient-services/src/ToolResults/LogcatCollectionError.php',
    'Google\\Service\\ToolResults\\MatrixDimensionDefinition' => $vendorDir . '/google/apiclient-services/src/ToolResults/MatrixDimensionDefinition.php',
    'Google\\Service\\ToolResults\\MemoryInfo' => $vendorDir . '/google/apiclient-services/src/ToolResults/MemoryInfo.php',
    'Google\\Service\\ToolResults\\MergedResult' => $vendorDir . '/google/apiclient-services/src/ToolResults/MergedResult.php',
    'Google\\Service\\ToolResults\\MultiStep' => $vendorDir . '/google/apiclient-services/src/ToolResults/MultiStep.php',
    'Google\\Service\\ToolResults\\NativeCrash' => $vendorDir . '/google/apiclient-services/src/ToolResults/NativeCrash.php',
    'Google\\Service\\ToolResults\\NonSdkApi' => $vendorDir . '/google/apiclient-services/src/ToolResults/NonSdkApi.php',
    'Google\\Service\\ToolResults\\NonSdkApiInsight' => $vendorDir . '/google/apiclient-services/src/ToolResults/NonSdkApiInsight.php',
    'Google\\Service\\ToolResults\\NonSdkApiUsageViolation' => $vendorDir . '/google/apiclient-services/src/ToolResults/NonSdkApiUsageViolation.php',
    'Google\\Service\\ToolResults\\NonSdkApiUsageViolationReport' => $vendorDir . '/google/apiclient-services/src/ToolResults/NonSdkApiUsageViolationReport.php',
    'Google\\Service\\ToolResults\\Outcome' => $vendorDir . '/google/apiclient-services/src/ToolResults/Outcome.php',
    'Google\\Service\\ToolResults\\OverlappingUIElements' => $vendorDir . '/google/apiclient-services/src/ToolResults/OverlappingUIElements.php',
    'Google\\Service\\ToolResults\\PendingGoogleUpdateInsight' => $vendorDir . '/google/apiclient-services/src/ToolResults/PendingGoogleUpdateInsight.php',
    'Google\\Service\\ToolResults\\PerfEnvironment' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerfEnvironment.php',
    'Google\\Service\\ToolResults\\PerfMetricsSummary' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerfMetricsSummary.php',
    'Google\\Service\\ToolResults\\PerfSample' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerfSample.php',
    'Google\\Service\\ToolResults\\PerfSampleSeries' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerfSampleSeries.php',
    'Google\\Service\\ToolResults\\PerformedGoogleLogin' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerformedGoogleLogin.php',
    'Google\\Service\\ToolResults\\PerformedMonkeyActions' => $vendorDir . '/google/apiclient-services/src/ToolResults/PerformedMonkeyActions.php',
    'Google\\Service\\ToolResults\\PrimaryStep' => $vendorDir . '/google/apiclient-services/src/ToolResults/PrimaryStep.php',
    'Google\\Service\\ToolResults\\ProjectSettings' => $vendorDir . '/google/apiclient-services/src/ToolResults/ProjectSettings.php',
    'Google\\Service\\ToolResults\\PublishXunitXmlFilesRequest' => $vendorDir . '/google/apiclient-services/src/ToolResults/PublishXunitXmlFilesRequest.php',
    'Google\\Service\\ToolResults\\RegionProto' => $vendorDir . '/google/apiclient-services/src/ToolResults/RegionProto.php',
    'Google\\Service\\ToolResults\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/Projects.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistories' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistories.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutions' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutions.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsClusters' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsClusters.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsEnvironments' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsEnvironments.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsSteps' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsSteps.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsStepsPerfMetricsSummary' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsStepsPerfMetricsSummary.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsStepsPerfSampleSeries' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsStepsPerfSampleSeries.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsStepsPerfSampleSeriesSamples' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsStepsPerfSampleSeriesSamples.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsStepsTestCases' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsStepsTestCases.php',
    'Google\\Service\\ToolResults\\Resource\\ProjectsHistoriesExecutionsStepsThumbnails' => $vendorDir . '/google/apiclient-services/src/ToolResults/Resource/ProjectsHistoriesExecutionsStepsThumbnails.php',
    'Google\\Service\\ToolResults\\ResultsStorage' => $vendorDir . '/google/apiclient-services/src/ToolResults/ResultsStorage.php',
    'Google\\Service\\ToolResults\\RoboScriptExecution' => $vendorDir . '/google/apiclient-services/src/ToolResults/RoboScriptExecution.php',
    'Google\\Service\\ToolResults\\SafeHtmlProto' => $vendorDir . '/google/apiclient-services/src/ToolResults/SafeHtmlProto.php',
    'Google\\Service\\ToolResults\\Screen' => $vendorDir . '/google/apiclient-services/src/ToolResults/Screen.php',
    'Google\\Service\\ToolResults\\ScreenshotCluster' => $vendorDir . '/google/apiclient-services/src/ToolResults/ScreenshotCluster.php',
    'Google\\Service\\ToolResults\\ShardSummary' => $vendorDir . '/google/apiclient-services/src/ToolResults/ShardSummary.php',
    'Google\\Service\\ToolResults\\SkippedDetail' => $vendorDir . '/google/apiclient-services/src/ToolResults/SkippedDetail.php',
    'Google\\Service\\ToolResults\\Specification' => $vendorDir . '/google/apiclient-services/src/ToolResults/Specification.php',
    'Google\\Service\\ToolResults\\StackTrace' => $vendorDir . '/google/apiclient-services/src/ToolResults/StackTrace.php',
    'Google\\Service\\ToolResults\\StartActivityNotFound' => $vendorDir . '/google/apiclient-services/src/ToolResults/StartActivityNotFound.php',
    'Google\\Service\\ToolResults\\Status' => $vendorDir . '/google/apiclient-services/src/ToolResults/Status.php',
    'Google\\Service\\ToolResults\\Step' => $vendorDir . '/google/apiclient-services/src/ToolResults/Step.php',
    'Google\\Service\\ToolResults\\StepDimensionValueEntry' => $vendorDir . '/google/apiclient-services/src/ToolResults/StepDimensionValueEntry.php',
    'Google\\Service\\ToolResults\\StepLabelsEntry' => $vendorDir . '/google/apiclient-services/src/ToolResults/StepLabelsEntry.php',
    'Google\\Service\\ToolResults\\StepSummary' => $vendorDir . '/google/apiclient-services/src/ToolResults/StepSummary.php',
    'Google\\Service\\ToolResults\\SuccessDetail' => $vendorDir . '/google/apiclient-services/src/ToolResults/SuccessDetail.php',
    'Google\\Service\\ToolResults\\SuggestionClusterProto' => $vendorDir . '/google/apiclient-services/src/ToolResults/SuggestionClusterProto.php',
    'Google\\Service\\ToolResults\\SuggestionProto' => $vendorDir . '/google/apiclient-services/src/ToolResults/SuggestionProto.php',
    'Google\\Service\\ToolResults\\TestCase' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestCase.php',
    'Google\\Service\\ToolResults\\TestCaseReference' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestCaseReference.php',
    'Google\\Service\\ToolResults\\TestExecutionStep' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestExecutionStep.php',
    'Google\\Service\\ToolResults\\TestIssue' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestIssue.php',
    'Google\\Service\\ToolResults\\TestSuiteOverview' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestSuiteOverview.php',
    'Google\\Service\\ToolResults\\TestTiming' => $vendorDir . '/google/apiclient-services/src/ToolResults/TestTiming.php',
    'Google\\Service\\ToolResults\\Thumbnail' => $vendorDir . '/google/apiclient-services/src/ToolResults/Thumbnail.php',
    'Google\\Service\\ToolResults\\Timestamp' => $vendorDir . '/google/apiclient-services/src/ToolResults/Timestamp.php',
    'Google\\Service\\ToolResults\\ToolExecution' => $vendorDir . '/google/apiclient-services/src/ToolResults/ToolExecution.php',
    'Google\\Service\\ToolResults\\ToolExecutionStep' => $vendorDir . '/google/apiclient-services/src/ToolResults/ToolExecutionStep.php',
    'Google\\Service\\ToolResults\\ToolExitCode' => $vendorDir . '/google/apiclient-services/src/ToolResults/ToolExitCode.php',
    'Google\\Service\\ToolResults\\ToolOutputReference' => $vendorDir . '/google/apiclient-services/src/ToolResults/ToolOutputReference.php',
    'Google\\Service\\ToolResults\\UIElementTooDeep' => $vendorDir . '/google/apiclient-services/src/ToolResults/UIElementTooDeep.php',
    'Google\\Service\\ToolResults\\UnspecifiedWarning' => $vendorDir . '/google/apiclient-services/src/ToolResults/UnspecifiedWarning.php',
    'Google\\Service\\ToolResults\\UnusedRoboDirective' => $vendorDir . '/google/apiclient-services/src/ToolResults/UnusedRoboDirective.php',
    'Google\\Service\\ToolResults\\UpgradeInsight' => $vendorDir . '/google/apiclient-services/src/ToolResults/UpgradeInsight.php',
    'Google\\Service\\ToolResults\\UsedRoboDirective' => $vendorDir . '/google/apiclient-services/src/ToolResults/UsedRoboDirective.php',
    'Google\\Service\\ToolResults\\UsedRoboIgnoreDirective' => $vendorDir . '/google/apiclient-services/src/ToolResults/UsedRoboIgnoreDirective.php',
    'Google\\Service\\TrafficDirectorService' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService.php',
    'Google\\Service\\TrafficDirectorService\\Address' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Address.php',
    'Google\\Service\\TrafficDirectorService\\BuildVersion' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/BuildVersion.php',
    'Google\\Service\\TrafficDirectorService\\ClientConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ClientConfig.php',
    'Google\\Service\\TrafficDirectorService\\ClientStatusRequest' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ClientStatusRequest.php',
    'Google\\Service\\TrafficDirectorService\\ClientStatusResponse' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ClientStatusResponse.php',
    'Google\\Service\\TrafficDirectorService\\ClustersConfigDump' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ClustersConfigDump.php',
    'Google\\Service\\TrafficDirectorService\\ContextParams' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ContextParams.php',
    'Google\\Service\\TrafficDirectorService\\DoubleMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DoubleMatcher.php',
    'Google\\Service\\TrafficDirectorService\\DoubleRange' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DoubleRange.php',
    'Google\\Service\\TrafficDirectorService\\DynamicCluster' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicCluster.php',
    'Google\\Service\\TrafficDirectorService\\DynamicEndpointConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicEndpointConfig.php',
    'Google\\Service\\TrafficDirectorService\\DynamicListener' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicListener.php',
    'Google\\Service\\TrafficDirectorService\\DynamicListenerState' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicListenerState.php',
    'Google\\Service\\TrafficDirectorService\\DynamicRouteConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicRouteConfig.php',
    'Google\\Service\\TrafficDirectorService\\DynamicScopedRouteConfigs' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/DynamicScopedRouteConfigs.php',
    'Google\\Service\\TrafficDirectorService\\EndpointsConfigDump' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/EndpointsConfigDump.php',
    'Google\\Service\\TrafficDirectorService\\EnvoyInternalAddress' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/EnvoyInternalAddress.php',
    'Google\\Service\\TrafficDirectorService\\Extension' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Extension.php',
    'Google\\Service\\TrafficDirectorService\\GenericXdsConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/GenericXdsConfig.php',
    'Google\\Service\\TrafficDirectorService\\GoogleRE2' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/GoogleRE2.php',
    'Google\\Service\\TrafficDirectorService\\InlineScopedRouteConfigs' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/InlineScopedRouteConfigs.php',
    'Google\\Service\\TrafficDirectorService\\ListMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ListMatcher.php',
    'Google\\Service\\TrafficDirectorService\\ListenersConfigDump' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ListenersConfigDump.php',
    'Google\\Service\\TrafficDirectorService\\Locality' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Locality.php',
    'Google\\Service\\TrafficDirectorService\\Node' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Node.php',
    'Google\\Service\\TrafficDirectorService\\NodeMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/NodeMatcher.php',
    'Google\\Service\\TrafficDirectorService\\NullMatch' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/NullMatch.php',
    'Google\\Service\\TrafficDirectorService\\OrMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/OrMatcher.php',
    'Google\\Service\\TrafficDirectorService\\PathSegment' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/PathSegment.php',
    'Google\\Service\\TrafficDirectorService\\PerXdsConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/PerXdsConfig.php',
    'Google\\Service\\TrafficDirectorService\\Pipe' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Pipe.php',
    'Google\\Service\\TrafficDirectorService\\RegexMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/RegexMatcher.php',
    'Google\\Service\\TrafficDirectorService\\Resource\\Discovery' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/Resource/Discovery.php',
    'Google\\Service\\TrafficDirectorService\\RoutesConfigDump' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/RoutesConfigDump.php',
    'Google\\Service\\TrafficDirectorService\\ScopedRoutesConfigDump' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ScopedRoutesConfigDump.php',
    'Google\\Service\\TrafficDirectorService\\SemanticVersion' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/SemanticVersion.php',
    'Google\\Service\\TrafficDirectorService\\SocketAddress' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/SocketAddress.php',
    'Google\\Service\\TrafficDirectorService\\StaticCluster' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StaticCluster.php',
    'Google\\Service\\TrafficDirectorService\\StaticEndpointConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StaticEndpointConfig.php',
    'Google\\Service\\TrafficDirectorService\\StaticListener' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StaticListener.php',
    'Google\\Service\\TrafficDirectorService\\StaticRouteConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StaticRouteConfig.php',
    'Google\\Service\\TrafficDirectorService\\StringMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StringMatcher.php',
    'Google\\Service\\TrafficDirectorService\\StructMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/StructMatcher.php',
    'Google\\Service\\TrafficDirectorService\\TypedExtensionConfig' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/TypedExtensionConfig.php',
    'Google\\Service\\TrafficDirectorService\\UpdateFailureState' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/UpdateFailureState.php',
    'Google\\Service\\TrafficDirectorService\\ValueMatcher' => $vendorDir . '/google/apiclient-services/src/TrafficDirectorService/ValueMatcher.php',
    'Google\\Service\\Transcoder' => $vendorDir . '/google/apiclient-services/src/Transcoder.php',
    'Google\\Service\\Transcoder\\AdBreak' => $vendorDir . '/google/apiclient-services/src/Transcoder/AdBreak.php',
    'Google\\Service\\Transcoder\\Aes128Encryption' => $vendorDir . '/google/apiclient-services/src/Transcoder/Aes128Encryption.php',
    'Google\\Service\\Transcoder\\Animation' => $vendorDir . '/google/apiclient-services/src/Transcoder/Animation.php',
    'Google\\Service\\Transcoder\\AnimationEnd' => $vendorDir . '/google/apiclient-services/src/Transcoder/AnimationEnd.php',
    'Google\\Service\\Transcoder\\AnimationFade' => $vendorDir . '/google/apiclient-services/src/Transcoder/AnimationFade.php',
    'Google\\Service\\Transcoder\\AnimationStatic' => $vendorDir . '/google/apiclient-services/src/Transcoder/AnimationStatic.php',
    'Google\\Service\\Transcoder\\Audio' => $vendorDir . '/google/apiclient-services/src/Transcoder/Audio.php',
    'Google\\Service\\Transcoder\\AudioAtom' => $vendorDir . '/google/apiclient-services/src/Transcoder/AudioAtom.php',
    'Google\\Service\\Transcoder\\AudioChannel' => $vendorDir . '/google/apiclient-services/src/Transcoder/AudioChannel.php',
    'Google\\Service\\Transcoder\\AudioChannelInput' => $vendorDir . '/google/apiclient-services/src/Transcoder/AudioChannelInput.php',
    'Google\\Service\\Transcoder\\AudioMapping' => $vendorDir . '/google/apiclient-services/src/Transcoder/AudioMapping.php',
    'Google\\Service\\Transcoder\\AudioStream' => $vendorDir . '/google/apiclient-services/src/Transcoder/AudioStream.php',
    'Google\\Service\\Transcoder\\BwdifConfig' => $vendorDir . '/google/apiclient-services/src/Transcoder/BwdifConfig.php',
    'Google\\Service\\Transcoder\\Clearkey' => $vendorDir . '/google/apiclient-services/src/Transcoder/Clearkey.php',
    'Google\\Service\\Transcoder\\Color' => $vendorDir . '/google/apiclient-services/src/Transcoder/Color.php',
    'Google\\Service\\Transcoder\\Crop' => $vendorDir . '/google/apiclient-services/src/Transcoder/Crop.php',
    'Google\\Service\\Transcoder\\DashConfig' => $vendorDir . '/google/apiclient-services/src/Transcoder/DashConfig.php',
    'Google\\Service\\Transcoder\\Deblock' => $vendorDir . '/google/apiclient-services/src/Transcoder/Deblock.php',
    'Google\\Service\\Transcoder\\Deinterlace' => $vendorDir . '/google/apiclient-services/src/Transcoder/Deinterlace.php',
    'Google\\Service\\Transcoder\\Denoise' => $vendorDir . '/google/apiclient-services/src/Transcoder/Denoise.php',
    'Google\\Service\\Transcoder\\DrmSystems' => $vendorDir . '/google/apiclient-services/src/Transcoder/DrmSystems.php',
    'Google\\Service\\Transcoder\\EditAtom' => $vendorDir . '/google/apiclient-services/src/Transcoder/EditAtom.php',
    'Google\\Service\\Transcoder\\ElementaryStream' => $vendorDir . '/google/apiclient-services/src/Transcoder/ElementaryStream.php',
    'Google\\Service\\Transcoder\\Encryption' => $vendorDir . '/google/apiclient-services/src/Transcoder/Encryption.php',
    'Google\\Service\\Transcoder\\FailureDetail' => $vendorDir . '/google/apiclient-services/src/Transcoder/FailureDetail.php',
    'Google\\Service\\Transcoder\\Fairplay' => $vendorDir . '/google/apiclient-services/src/Transcoder/Fairplay.php',
    'Google\\Service\\Transcoder\\Fmp4Config' => $vendorDir . '/google/apiclient-services/src/Transcoder/Fmp4Config.php',
    'Google\\Service\\Transcoder\\H264CodecSettings' => $vendorDir . '/google/apiclient-services/src/Transcoder/H264CodecSettings.php',
    'Google\\Service\\Transcoder\\H264ColorFormatHLG' => $vendorDir . '/google/apiclient-services/src/Transcoder/H264ColorFormatHLG.php',
    'Google\\Service\\Transcoder\\H264ColorFormatSDR' => $vendorDir . '/google/apiclient-services/src/Transcoder/H264ColorFormatSDR.php',
    'Google\\Service\\Transcoder\\H265CodecSettings' => $vendorDir . '/google/apiclient-services/src/Transcoder/H265CodecSettings.php',
    'Google\\Service\\Transcoder\\H265ColorFormatHDR10' => $vendorDir . '/google/apiclient-services/src/Transcoder/H265ColorFormatHDR10.php',
    'Google\\Service\\Transcoder\\H265ColorFormatHLG' => $vendorDir . '/google/apiclient-services/src/Transcoder/H265ColorFormatHLG.php',
    'Google\\Service\\Transcoder\\H265ColorFormatSDR' => $vendorDir . '/google/apiclient-services/src/Transcoder/H265ColorFormatSDR.php',
    'Google\\Service\\Transcoder\\Image' => $vendorDir . '/google/apiclient-services/src/Transcoder/Image.php',
    'Google\\Service\\Transcoder\\Input' => $vendorDir . '/google/apiclient-services/src/Transcoder/Input.php',
    'Google\\Service\\Transcoder\\Job' => $vendorDir . '/google/apiclient-services/src/Transcoder/Job.php',
    'Google\\Service\\Transcoder\\JobConfig' => $vendorDir . '/google/apiclient-services/src/Transcoder/JobConfig.php',
    'Google\\Service\\Transcoder\\JobTemplate' => $vendorDir . '/google/apiclient-services/src/Transcoder/JobTemplate.php',
    'Google\\Service\\Transcoder\\ListJobTemplatesResponse' => $vendorDir . '/google/apiclient-services/src/Transcoder/ListJobTemplatesResponse.php',
    'Google\\Service\\Transcoder\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/Transcoder/ListJobsResponse.php',
    'Google\\Service\\Transcoder\\Manifest' => $vendorDir . '/google/apiclient-services/src/Transcoder/Manifest.php',
    'Google\\Service\\Transcoder\\MpegCommonEncryption' => $vendorDir . '/google/apiclient-services/src/Transcoder/MpegCommonEncryption.php',
    'Google\\Service\\Transcoder\\MuxStream' => $vendorDir . '/google/apiclient-services/src/Transcoder/MuxStream.php',
    'Google\\Service\\Transcoder\\NormalizedCoordinate' => $vendorDir . '/google/apiclient-services/src/Transcoder/NormalizedCoordinate.php',
    'Google\\Service\\Transcoder\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Transcoder/OperationMetadata.php',
    'Google\\Service\\Transcoder\\OriginUri' => $vendorDir . '/google/apiclient-services/src/Transcoder/OriginUri.php',
    'Google\\Service\\Transcoder\\Output' => $vendorDir . '/google/apiclient-services/src/Transcoder/Output.php',
    'Google\\Service\\Transcoder\\Overlay' => $vendorDir . '/google/apiclient-services/src/Transcoder/Overlay.php',
    'Google\\Service\\Transcoder\\Pad' => $vendorDir . '/google/apiclient-services/src/Transcoder/Pad.php',
    'Google\\Service\\Transcoder\\Playready' => $vendorDir . '/google/apiclient-services/src/Transcoder/Playready.php',
    'Google\\Service\\Transcoder\\PreprocessingConfig' => $vendorDir . '/google/apiclient-services/src/Transcoder/PreprocessingConfig.php',
    'Google\\Service\\Transcoder\\Progress' => $vendorDir . '/google/apiclient-services/src/Transcoder/Progress.php',
    'Google\\Service\\Transcoder\\PubsubDestination' => $vendorDir . '/google/apiclient-services/src/Transcoder/PubsubDestination.php',
    'Google\\Service\\Transcoder\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Transcoder/Resource/Projects.php',
    'Google\\Service\\Transcoder\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Transcoder/Resource/ProjectsLocations.php',
    'Google\\Service\\Transcoder\\Resource\\ProjectsLocationsJobTemplates' => $vendorDir . '/google/apiclient-services/src/Transcoder/Resource/ProjectsLocationsJobTemplates.php',
    'Google\\Service\\Transcoder\\Resource\\ProjectsLocationsJobs' => $vendorDir . '/google/apiclient-services/src/Transcoder/Resource/ProjectsLocationsJobs.php',
    'Google\\Service\\Transcoder\\SampleAesEncryption' => $vendorDir . '/google/apiclient-services/src/Transcoder/SampleAesEncryption.php',
    'Google\\Service\\Transcoder\\SecretManagerSource' => $vendorDir . '/google/apiclient-services/src/Transcoder/SecretManagerSource.php',
    'Google\\Service\\Transcoder\\SegmentSettings' => $vendorDir . '/google/apiclient-services/src/Transcoder/SegmentSettings.php',
    'Google\\Service\\Transcoder\\SpriteSheet' => $vendorDir . '/google/apiclient-services/src/Transcoder/SpriteSheet.php',
    'Google\\Service\\Transcoder\\Status' => $vendorDir . '/google/apiclient-services/src/Transcoder/Status.php',
    'Google\\Service\\Transcoder\\TextAtom' => $vendorDir . '/google/apiclient-services/src/Transcoder/TextAtom.php',
    'Google\\Service\\Transcoder\\TextInput' => $vendorDir . '/google/apiclient-services/src/Transcoder/TextInput.php',
    'Google\\Service\\Transcoder\\TextMapping' => $vendorDir . '/google/apiclient-services/src/Transcoder/TextMapping.php',
    'Google\\Service\\Transcoder\\TextStream' => $vendorDir . '/google/apiclient-services/src/Transcoder/TextStream.php',
    'Google\\Service\\Transcoder\\TranscoderEmpty' => $vendorDir . '/google/apiclient-services/src/Transcoder/TranscoderEmpty.php',
    'Google\\Service\\Transcoder\\VideoStream' => $vendorDir . '/google/apiclient-services/src/Transcoder/VideoStream.php',
    'Google\\Service\\Transcoder\\Vp9CodecSettings' => $vendorDir . '/google/apiclient-services/src/Transcoder/Vp9CodecSettings.php',
    'Google\\Service\\Transcoder\\Vp9ColorFormatHLG' => $vendorDir . '/google/apiclient-services/src/Transcoder/Vp9ColorFormatHLG.php',
    'Google\\Service\\Transcoder\\Vp9ColorFormatSDR' => $vendorDir . '/google/apiclient-services/src/Transcoder/Vp9ColorFormatSDR.php',
    'Google\\Service\\Transcoder\\Widevine' => $vendorDir . '/google/apiclient-services/src/Transcoder/Widevine.php',
    'Google\\Service\\Transcoder\\YadifConfig' => $vendorDir . '/google/apiclient-services/src/Transcoder/YadifConfig.php',
    'Google\\Service\\Translate' => $vendorDir . '/google/apiclient-services/src/Translate.php',
    'Google\\Service\\Translate\\AdaptiveMtDataset' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtDataset.php',
    'Google\\Service\\Translate\\AdaptiveMtFile' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtFile.php',
    'Google\\Service\\Translate\\AdaptiveMtSentence' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtSentence.php',
    'Google\\Service\\Translate\\AdaptiveMtTranslateRequest' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtTranslateRequest.php',
    'Google\\Service\\Translate\\AdaptiveMtTranslateResponse' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtTranslateResponse.php',
    'Google\\Service\\Translate\\AdaptiveMtTranslation' => $vendorDir . '/google/apiclient-services/src/Translate/AdaptiveMtTranslation.php',
    'Google\\Service\\Translate\\BatchDocumentInputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/BatchDocumentInputConfig.php',
    'Google\\Service\\Translate\\BatchDocumentOutputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/BatchDocumentOutputConfig.php',
    'Google\\Service\\Translate\\BatchTranslateDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Translate/BatchTranslateDocumentRequest.php',
    'Google\\Service\\Translate\\BatchTranslateTextRequest' => $vendorDir . '/google/apiclient-services/src/Translate/BatchTranslateTextRequest.php',
    'Google\\Service\\Translate\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Translate/CancelOperationRequest.php',
    'Google\\Service\\Translate\\Dataset' => $vendorDir . '/google/apiclient-services/src/Translate/Dataset.php',
    'Google\\Service\\Translate\\DatasetInputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/DatasetInputConfig.php',
    'Google\\Service\\Translate\\DatasetOutputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/DatasetOutputConfig.php',
    'Google\\Service\\Translate\\DetectLanguageRequest' => $vendorDir . '/google/apiclient-services/src/Translate/DetectLanguageRequest.php',
    'Google\\Service\\Translate\\DetectLanguageResponse' => $vendorDir . '/google/apiclient-services/src/Translate/DetectLanguageResponse.php',
    'Google\\Service\\Translate\\DetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Translate/DetectedLanguage.php',
    'Google\\Service\\Translate\\DocumentInputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/DocumentInputConfig.php',
    'Google\\Service\\Translate\\DocumentOutputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/DocumentOutputConfig.php',
    'Google\\Service\\Translate\\DocumentTranslation' => $vendorDir . '/google/apiclient-services/src/Translate/DocumentTranslation.php',
    'Google\\Service\\Translate\\Example' => $vendorDir . '/google/apiclient-services/src/Translate/Example.php',
    'Google\\Service\\Translate\\ExportDataRequest' => $vendorDir . '/google/apiclient-services/src/Translate/ExportDataRequest.php',
    'Google\\Service\\Translate\\FileInputSource' => $vendorDir . '/google/apiclient-services/src/Translate/FileInputSource.php',
    'Google\\Service\\Translate\\GcsDestination' => $vendorDir . '/google/apiclient-services/src/Translate/GcsDestination.php',
    'Google\\Service\\Translate\\GcsInputSource' => $vendorDir . '/google/apiclient-services/src/Translate/GcsInputSource.php',
    'Google\\Service\\Translate\\GcsOutputDestination' => $vendorDir . '/google/apiclient-services/src/Translate/GcsOutputDestination.php',
    'Google\\Service\\Translate\\GcsSource' => $vendorDir . '/google/apiclient-services/src/Translate/GcsSource.php',
    'Google\\Service\\Translate\\Glossary' => $vendorDir . '/google/apiclient-services/src/Translate/Glossary.php',
    'Google\\Service\\Translate\\GlossaryConfig' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryConfig.php',
    'Google\\Service\\Translate\\GlossaryEntry' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryEntry.php',
    'Google\\Service\\Translate\\GlossaryInputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryInputConfig.php',
    'Google\\Service\\Translate\\GlossaryTerm' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryTerm.php',
    'Google\\Service\\Translate\\GlossaryTermsPair' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryTermsPair.php',
    'Google\\Service\\Translate\\GlossaryTermsSet' => $vendorDir . '/google/apiclient-services/src/Translate/GlossaryTermsSet.php',
    'Google\\Service\\Translate\\ImportAdaptiveMtFileRequest' => $vendorDir . '/google/apiclient-services/src/Translate/ImportAdaptiveMtFileRequest.php',
    'Google\\Service\\Translate\\ImportAdaptiveMtFileResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ImportAdaptiveMtFileResponse.php',
    'Google\\Service\\Translate\\ImportDataRequest' => $vendorDir . '/google/apiclient-services/src/Translate/ImportDataRequest.php',
    'Google\\Service\\Translate\\InputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/InputConfig.php',
    'Google\\Service\\Translate\\InputFile' => $vendorDir . '/google/apiclient-services/src/Translate/InputFile.php',
    'Google\\Service\\Translate\\LanguageCodePair' => $vendorDir . '/google/apiclient-services/src/Translate/LanguageCodePair.php',
    'Google\\Service\\Translate\\LanguageCodesSet' => $vendorDir . '/google/apiclient-services/src/Translate/LanguageCodesSet.php',
    'Google\\Service\\Translate\\ListAdaptiveMtDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListAdaptiveMtDatasetsResponse.php',
    'Google\\Service\\Translate\\ListAdaptiveMtFilesResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListAdaptiveMtFilesResponse.php',
    'Google\\Service\\Translate\\ListAdaptiveMtSentencesResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListAdaptiveMtSentencesResponse.php',
    'Google\\Service\\Translate\\ListDatasetsResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListDatasetsResponse.php',
    'Google\\Service\\Translate\\ListExamplesResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListExamplesResponse.php',
    'Google\\Service\\Translate\\ListGlossariesResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListGlossariesResponse.php',
    'Google\\Service\\Translate\\ListGlossaryEntriesResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListGlossaryEntriesResponse.php',
    'Google\\Service\\Translate\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListLocationsResponse.php',
    'Google\\Service\\Translate\\ListModelsResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListModelsResponse.php',
    'Google\\Service\\Translate\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Translate/ListOperationsResponse.php',
    'Google\\Service\\Translate\\Location' => $vendorDir . '/google/apiclient-services/src/Translate/Location.php',
    'Google\\Service\\Translate\\Model' => $vendorDir . '/google/apiclient-services/src/Translate/Model.php',
    'Google\\Service\\Translate\\Operation' => $vendorDir . '/google/apiclient-services/src/Translate/Operation.php',
    'Google\\Service\\Translate\\OutputConfig' => $vendorDir . '/google/apiclient-services/src/Translate/OutputConfig.php',
    'Google\\Service\\Translate\\ReferenceSentenceConfig' => $vendorDir . '/google/apiclient-services/src/Translate/ReferenceSentenceConfig.php',
    'Google\\Service\\Translate\\ReferenceSentencePair' => $vendorDir . '/google/apiclient-services/src/Translate/ReferenceSentencePair.php',
    'Google\\Service\\Translate\\ReferenceSentencePairList' => $vendorDir . '/google/apiclient-services/src/Translate/ReferenceSentencePairList.php',
    'Google\\Service\\Translate\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/Projects.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocations.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsAdaptiveMtDatasets' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsAdaptiveMtDatasets.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFiles' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFiles.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFilesAdaptiveMtSentences' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFilesAdaptiveMtSentences.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtSentences' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtSentences.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsDatasets' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsDatasets.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsDatasetsExamples' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsDatasetsExamples.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsGlossaries' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsGlossaries.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsGlossariesGlossaryEntries' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsGlossariesGlossaryEntries.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsModels' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsModels.php',
    'Google\\Service\\Translate\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Translate/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Translate\\Romanization' => $vendorDir . '/google/apiclient-services/src/Translate/Romanization.php',
    'Google\\Service\\Translate\\RomanizeTextRequest' => $vendorDir . '/google/apiclient-services/src/Translate/RomanizeTextRequest.php',
    'Google\\Service\\Translate\\RomanizeTextResponse' => $vendorDir . '/google/apiclient-services/src/Translate/RomanizeTextResponse.php',
    'Google\\Service\\Translate\\Status' => $vendorDir . '/google/apiclient-services/src/Translate/Status.php',
    'Google\\Service\\Translate\\SupportedLanguage' => $vendorDir . '/google/apiclient-services/src/Translate/SupportedLanguage.php',
    'Google\\Service\\Translate\\SupportedLanguages' => $vendorDir . '/google/apiclient-services/src/Translate/SupportedLanguages.php',
    'Google\\Service\\Translate\\TranslateDocumentRequest' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateDocumentRequest.php',
    'Google\\Service\\Translate\\TranslateDocumentResponse' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateDocumentResponse.php',
    'Google\\Service\\Translate\\TranslateEmpty' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateEmpty.php',
    'Google\\Service\\Translate\\TranslateTextGlossaryConfig' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateTextGlossaryConfig.php',
    'Google\\Service\\Translate\\TranslateTextRequest' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateTextRequest.php',
    'Google\\Service\\Translate\\TranslateTextResponse' => $vendorDir . '/google/apiclient-services/src/Translate/TranslateTextResponse.php',
    'Google\\Service\\Translate\\Translation' => $vendorDir . '/google/apiclient-services/src/Translate/Translation.php',
    'Google\\Service\\Translate\\TransliterationConfig' => $vendorDir . '/google/apiclient-services/src/Translate/TransliterationConfig.php',
    'Google\\Service\\Translate\\WaitOperationRequest' => $vendorDir . '/google/apiclient-services/src/Translate/WaitOperationRequest.php',
    'Google\\Service\\TravelImpactModel' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel.php',
    'Google\\Service\\TravelImpactModel\\ComputeFlightEmissionsRequest' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/ComputeFlightEmissionsRequest.php',
    'Google\\Service\\TravelImpactModel\\ComputeFlightEmissionsResponse' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/ComputeFlightEmissionsResponse.php',
    'Google\\Service\\TravelImpactModel\\Date' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/Date.php',
    'Google\\Service\\TravelImpactModel\\EmissionsGramsPerPax' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/EmissionsGramsPerPax.php',
    'Google\\Service\\TravelImpactModel\\Flight' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/Flight.php',
    'Google\\Service\\TravelImpactModel\\FlightWithEmissions' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/FlightWithEmissions.php',
    'Google\\Service\\TravelImpactModel\\ModelVersion' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/ModelVersion.php',
    'Google\\Service\\TravelImpactModel\\Resource\\Flights' => $vendorDir . '/google/apiclient-services/src/TravelImpactModel/Resource/Flights.php',
    'Google\\Service\\VMMigrationService' => $vendorDir . '/google/apiclient-services/src/VMMigrationService.php',
    'Google\\Service\\VMMigrationService\\AccessKeyCredentials' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AccessKeyCredentials.php',
    'Google\\Service\\VMMigrationService\\AdaptingOSStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AdaptingOSStep.php',
    'Google\\Service\\VMMigrationService\\AddGroupMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AddGroupMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\AddGroupMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AddGroupMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\ApplianceVersion' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ApplianceVersion.php',
    'Google\\Service\\VMMigrationService\\AppliedLicense' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AppliedLicense.php',
    'Google\\Service\\VMMigrationService\\AvailableUpdates' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AvailableUpdates.php',
    'Google\\Service\\VMMigrationService\\AwsDiskDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsDiskDetails.php',
    'Google\\Service\\VMMigrationService\\AwsSecurityGroup' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsSecurityGroup.php',
    'Google\\Service\\VMMigrationService\\AwsSourceDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsSourceDetails.php',
    'Google\\Service\\VMMigrationService\\AwsSourceVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsSourceVmDetails.php',
    'Google\\Service\\VMMigrationService\\AwsVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsVmDetails.php',
    'Google\\Service\\VMMigrationService\\AwsVmsDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AwsVmsDetails.php',
    'Google\\Service\\VMMigrationService\\AzureDiskDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AzureDiskDetails.php',
    'Google\\Service\\VMMigrationService\\AzureSourceDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AzureSourceDetails.php',
    'Google\\Service\\VMMigrationService\\AzureSourceVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AzureSourceVmDetails.php',
    'Google\\Service\\VMMigrationService\\AzureVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AzureVmDetails.php',
    'Google\\Service\\VMMigrationService\\AzureVmsDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/AzureVmsDetails.php',
    'Google\\Service\\VMMigrationService\\BootDiskDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/BootDiskDefaults.php',
    'Google\\Service\\VMMigrationService\\CancelCloneJobRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelCloneJobRequest.php',
    'Google\\Service\\VMMigrationService\\CancelCloneJobResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelCloneJobResponse.php',
    'Google\\Service\\VMMigrationService\\CancelCutoverJobRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelCutoverJobRequest.php',
    'Google\\Service\\VMMigrationService\\CancelCutoverJobResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelCutoverJobResponse.php',
    'Google\\Service\\VMMigrationService\\CancelDiskMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelDiskMigrationJobRequest.php',
    'Google\\Service\\VMMigrationService\\CancelImageImportJobRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelImageImportJobRequest.php',
    'Google\\Service\\VMMigrationService\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CancelOperationRequest.php',
    'Google\\Service\\VMMigrationService\\ClientSecretCredentials' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ClientSecretCredentials.php',
    'Google\\Service\\VMMigrationService\\CloneJob' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CloneJob.php',
    'Google\\Service\\VMMigrationService\\CloneStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CloneStep.php',
    'Google\\Service\\VMMigrationService\\ComputeEngineDisksTargetDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ComputeEngineDisksTargetDefaults.php',
    'Google\\Service\\VMMigrationService\\ComputeEngineDisksTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ComputeEngineDisksTargetDetails.php',
    'Google\\Service\\VMMigrationService\\ComputeEngineTargetDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ComputeEngineTargetDefaults.php',
    'Google\\Service\\VMMigrationService\\ComputeEngineTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ComputeEngineTargetDetails.php',
    'Google\\Service\\VMMigrationService\\ComputeScheduling' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ComputeScheduling.php',
    'Google\\Service\\VMMigrationService\\CreatingImageStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CreatingImageStep.php',
    'Google\\Service\\VMMigrationService\\CutoverForecast' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CutoverForecast.php',
    'Google\\Service\\VMMigrationService\\CutoverJob' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CutoverJob.php',
    'Google\\Service\\VMMigrationService\\CutoverStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CutoverStep.php',
    'Google\\Service\\VMMigrationService\\CycleStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/CycleStep.php',
    'Google\\Service\\VMMigrationService\\DataDiskImageImport' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DataDiskImageImport.php',
    'Google\\Service\\VMMigrationService\\DatacenterConnector' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DatacenterConnector.php',
    'Google\\Service\\VMMigrationService\\Disk' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Disk.php',
    'Google\\Service\\VMMigrationService\\DiskImageDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DiskImageDefaults.php',
    'Google\\Service\\VMMigrationService\\DiskImageTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DiskImageTargetDetails.php',
    'Google\\Service\\VMMigrationService\\DisksMigrationDisksTargetDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DisksMigrationDisksTargetDefaults.php',
    'Google\\Service\\VMMigrationService\\DisksMigrationDisksTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DisksMigrationDisksTargetDetails.php',
    'Google\\Service\\VMMigrationService\\DisksMigrationVmTargetDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DisksMigrationVmTargetDefaults.php',
    'Google\\Service\\VMMigrationService\\DisksMigrationVmTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/DisksMigrationVmTargetDetails.php',
    'Google\\Service\\VMMigrationService\\Encryption' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Encryption.php',
    'Google\\Service\\VMMigrationService\\FetchInventoryResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/FetchInventoryResponse.php',
    'Google\\Service\\VMMigrationService\\FinalizeMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/FinalizeMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\FinalizeMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/FinalizeMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\Group' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Group.php',
    'Google\\Service\\VMMigrationService\\ImageImport' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ImageImport.php',
    'Google\\Service\\VMMigrationService\\ImageImportJob' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ImageImportJob.php',
    'Google\\Service\\VMMigrationService\\ImageImportOsAdaptationParameters' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ImageImportOsAdaptationParameters.php',
    'Google\\Service\\VMMigrationService\\ImageImportStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ImageImportStep.php',
    'Google\\Service\\VMMigrationService\\InitializingImageImportStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/InitializingImageImportStep.php',
    'Google\\Service\\VMMigrationService\\InitializingReplicationStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/InitializingReplicationStep.php',
    'Google\\Service\\VMMigrationService\\InstantiatingMigratedVMStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/InstantiatingMigratedVMStep.php',
    'Google\\Service\\VMMigrationService\\Link' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Link.php',
    'Google\\Service\\VMMigrationService\\ListCloneJobsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListCloneJobsResponse.php',
    'Google\\Service\\VMMigrationService\\ListCutoverJobsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListCutoverJobsResponse.php',
    'Google\\Service\\VMMigrationService\\ListDatacenterConnectorsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListDatacenterConnectorsResponse.php',
    'Google\\Service\\VMMigrationService\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListGroupsResponse.php',
    'Google\\Service\\VMMigrationService\\ListImageImportJobsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListImageImportJobsResponse.php',
    'Google\\Service\\VMMigrationService\\ListImageImportsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListImageImportsResponse.php',
    'Google\\Service\\VMMigrationService\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListLocationsResponse.php',
    'Google\\Service\\VMMigrationService\\ListMigratingVmsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListMigratingVmsResponse.php',
    'Google\\Service\\VMMigrationService\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListOperationsResponse.php',
    'Google\\Service\\VMMigrationService\\ListReplicationCyclesResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListReplicationCyclesResponse.php',
    'Google\\Service\\VMMigrationService\\ListSourcesResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListSourcesResponse.php',
    'Google\\Service\\VMMigrationService\\ListTargetProjectsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListTargetProjectsResponse.php',
    'Google\\Service\\VMMigrationService\\ListUtilizationReportsResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ListUtilizationReportsResponse.php',
    'Google\\Service\\VMMigrationService\\LoadingImageSourceFilesStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/LoadingImageSourceFilesStep.php',
    'Google\\Service\\VMMigrationService\\LocalizedMessage' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/LocalizedMessage.php',
    'Google\\Service\\VMMigrationService\\Location' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Location.php',
    'Google\\Service\\VMMigrationService\\MachineImageParametersOverrides' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/MachineImageParametersOverrides.php',
    'Google\\Service\\VMMigrationService\\MachineImageTargetDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/MachineImageTargetDetails.php',
    'Google\\Service\\VMMigrationService\\MigratingVm' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/MigratingVm.php',
    'Google\\Service\\VMMigrationService\\MigrationError' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/MigrationError.php',
    'Google\\Service\\VMMigrationService\\MigrationWarning' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/MigrationWarning.php',
    'Google\\Service\\VMMigrationService\\NetworkInsights' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/NetworkInsights.php',
    'Google\\Service\\VMMigrationService\\NetworkInterface' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/NetworkInterface.php',
    'Google\\Service\\VMMigrationService\\OSDescription' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/OSDescription.php',
    'Google\\Service\\VMMigrationService\\OSDisk' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/OSDisk.php',
    'Google\\Service\\VMMigrationService\\Operation' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Operation.php',
    'Google\\Service\\VMMigrationService\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/OperationMetadata.php',
    'Google\\Service\\VMMigrationService\\PauseMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PauseMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\PauseMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PauseMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\PersistentDisk' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PersistentDisk.php',
    'Google\\Service\\VMMigrationService\\PersistentDiskDefaults' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PersistentDiskDefaults.php',
    'Google\\Service\\VMMigrationService\\PostProcessingStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PostProcessingStep.php',
    'Google\\Service\\VMMigrationService\\PreparingVMDisksStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/PreparingVMDisksStep.php',
    'Google\\Service\\VMMigrationService\\RemoveGroupMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/RemoveGroupMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\RemoveGroupMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/RemoveGroupMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\ReplicatingStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ReplicatingStep.php',
    'Google\\Service\\VMMigrationService\\ReplicationCycle' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ReplicationCycle.php',
    'Google\\Service\\VMMigrationService\\ReplicationSync' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ReplicationSync.php',
    'Google\\Service\\VMMigrationService\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/Projects.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocations.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsGroups' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsGroups.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsImageImports' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsImageImports.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsImageImportsImageImportJobs' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsImageImportsImageImportJobs.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSources' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSources.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesDatacenterConnectors' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesDatacenterConnectors.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesDiskMigrationJobs' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesDiskMigrationJobs.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesMigratingVms' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesMigratingVms.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesMigratingVmsCloneJobs' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesMigratingVmsCloneJobs.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesMigratingVmsCutoverJobs' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesMigratingVmsCutoverJobs.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesMigratingVmsReplicationCycles' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesMigratingVmsReplicationCycles.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsSourcesUtilizationReports' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsSourcesUtilizationReports.php',
    'Google\\Service\\VMMigrationService\\Resource\\ProjectsLocationsTargetProjects' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Resource/ProjectsLocationsTargetProjects.php',
    'Google\\Service\\VMMigrationService\\ResumeMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ResumeMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\ResumeMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ResumeMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\RunDiskMigrationJobRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/RunDiskMigrationJobRequest.php',
    'Google\\Service\\VMMigrationService\\SchedulePolicy' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/SchedulePolicy.php',
    'Google\\Service\\VMMigrationService\\SchedulingNodeAffinity' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/SchedulingNodeAffinity.php',
    'Google\\Service\\VMMigrationService\\ServiceAccount' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ServiceAccount.php',
    'Google\\Service\\VMMigrationService\\ShieldedInstanceConfig' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ShieldedInstanceConfig.php',
    'Google\\Service\\VMMigrationService\\ShuttingDownSourceVMStep' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/ShuttingDownSourceVMStep.php',
    'Google\\Service\\VMMigrationService\\SkipOsAdaptation' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/SkipOsAdaptation.php',
    'Google\\Service\\VMMigrationService\\Source' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Source.php',
    'Google\\Service\\VMMigrationService\\StartMigrationRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/StartMigrationRequest.php',
    'Google\\Service\\VMMigrationService\\StartMigrationResponse' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/StartMigrationResponse.php',
    'Google\\Service\\VMMigrationService\\Status' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Status.php',
    'Google\\Service\\VMMigrationService\\Tag' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/Tag.php',
    'Google\\Service\\VMMigrationService\\TargetProject' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/TargetProject.php',
    'Google\\Service\\VMMigrationService\\UpgradeApplianceRequest' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/UpgradeApplianceRequest.php',
    'Google\\Service\\VMMigrationService\\UpgradeStatus' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/UpgradeStatus.php',
    'Google\\Service\\VMMigrationService\\UtilizationReport' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/UtilizationReport.php',
    'Google\\Service\\VMMigrationService\\VmAttachmentDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmAttachmentDetails.php',
    'Google\\Service\\VMMigrationService\\VmCapabilities' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmCapabilities.php',
    'Google\\Service\\VMMigrationService\\VmUtilizationInfo' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmUtilizationInfo.php',
    'Google\\Service\\VMMigrationService\\VmUtilizationMetrics' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmUtilizationMetrics.php',
    'Google\\Service\\VMMigrationService\\VmmigrationEmpty' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmmigrationEmpty.php',
    'Google\\Service\\VMMigrationService\\VmwareDiskDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmwareDiskDetails.php',
    'Google\\Service\\VMMigrationService\\VmwareSourceDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmwareSourceDetails.php',
    'Google\\Service\\VMMigrationService\\VmwareSourceVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmwareSourceVmDetails.php',
    'Google\\Service\\VMMigrationService\\VmwareVmDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmwareVmDetails.php',
    'Google\\Service\\VMMigrationService\\VmwareVmsDetails' => $vendorDir . '/google/apiclient-services/src/VMMigrationService/VmwareVmsDetails.php',
    'Google\\Service\\VMwareEngine' => $vendorDir . '/google/apiclient-services/src/VMwareEngine.php',
    'Google\\Service\\VMwareEngine\\AuditConfig' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/AuditConfig.php',
    'Google\\Service\\VMwareEngine\\AuditLogConfig' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/AuditLogConfig.php',
    'Google\\Service\\VMwareEngine\\AutoscalingPolicy' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/AutoscalingPolicy.php',
    'Google\\Service\\VMwareEngine\\AutoscalingSettings' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/AutoscalingSettings.php',
    'Google\\Service\\VMwareEngine\\Binding' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Binding.php',
    'Google\\Service\\VMwareEngine\\Cluster' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Cluster.php',
    'Google\\Service\\VMwareEngine\\Credentials' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Credentials.php',
    'Google\\Service\\VMwareEngine\\DnsBindPermission' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/DnsBindPermission.php',
    'Google\\Service\\VMwareEngine\\DnsForwarding' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/DnsForwarding.php',
    'Google\\Service\\VMwareEngine\\Expr' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Expr.php',
    'Google\\Service\\VMwareEngine\\ExternalAccessRule' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ExternalAccessRule.php',
    'Google\\Service\\VMwareEngine\\ExternalAddress' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ExternalAddress.php',
    'Google\\Service\\VMwareEngine\\FetchNetworkPolicyExternalAddressesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/FetchNetworkPolicyExternalAddressesResponse.php',
    'Google\\Service\\VMwareEngine\\ForwardingRule' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ForwardingRule.php',
    'Google\\Service\\VMwareEngine\\GrantDnsBindPermissionRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/GrantDnsBindPermissionRequest.php',
    'Google\\Service\\VMwareEngine\\Hcx' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Hcx.php',
    'Google\\Service\\VMwareEngine\\HcxActivationKey' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/HcxActivationKey.php',
    'Google\\Service\\VMwareEngine\\IpRange' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/IpRange.php',
    'Google\\Service\\VMwareEngine\\ListClustersResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListClustersResponse.php',
    'Google\\Service\\VMwareEngine\\ListExternalAccessRulesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListExternalAccessRulesResponse.php',
    'Google\\Service\\VMwareEngine\\ListExternalAddressesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListExternalAddressesResponse.php',
    'Google\\Service\\VMwareEngine\\ListHcxActivationKeysResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListHcxActivationKeysResponse.php',
    'Google\\Service\\VMwareEngine\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListLocationsResponse.php',
    'Google\\Service\\VMwareEngine\\ListLoggingServersResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListLoggingServersResponse.php',
    'Google\\Service\\VMwareEngine\\ListManagementDnsZoneBindingsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListManagementDnsZoneBindingsResponse.php',
    'Google\\Service\\VMwareEngine\\ListNetworkPeeringsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListNetworkPeeringsResponse.php',
    'Google\\Service\\VMwareEngine\\ListNetworkPoliciesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListNetworkPoliciesResponse.php',
    'Google\\Service\\VMwareEngine\\ListNodeTypesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListNodeTypesResponse.php',
    'Google\\Service\\VMwareEngine\\ListNodesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListNodesResponse.php',
    'Google\\Service\\VMwareEngine\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListOperationsResponse.php',
    'Google\\Service\\VMwareEngine\\ListPeeringRoutesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListPeeringRoutesResponse.php',
    'Google\\Service\\VMwareEngine\\ListPrivateCloudsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListPrivateCloudsResponse.php',
    'Google\\Service\\VMwareEngine\\ListPrivateConnectionPeeringRoutesResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListPrivateConnectionPeeringRoutesResponse.php',
    'Google\\Service\\VMwareEngine\\ListPrivateConnectionsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListPrivateConnectionsResponse.php',
    'Google\\Service\\VMwareEngine\\ListSubnetsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListSubnetsResponse.php',
    'Google\\Service\\VMwareEngine\\ListVmwareEngineNetworksResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ListVmwareEngineNetworksResponse.php',
    'Google\\Service\\VMwareEngine\\Location' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Location.php',
    'Google\\Service\\VMwareEngine\\LocationMetadata' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/LocationMetadata.php',
    'Google\\Service\\VMwareEngine\\LoggingServer' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/LoggingServer.php',
    'Google\\Service\\VMwareEngine\\ManagementCluster' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ManagementCluster.php',
    'Google\\Service\\VMwareEngine\\ManagementDnsZoneBinding' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ManagementDnsZoneBinding.php',
    'Google\\Service\\VMwareEngine\\NetworkConfig' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NetworkConfig.php',
    'Google\\Service\\VMwareEngine\\NetworkPeering' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NetworkPeering.php',
    'Google\\Service\\VMwareEngine\\NetworkPolicy' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NetworkPolicy.php',
    'Google\\Service\\VMwareEngine\\NetworkService' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NetworkService.php',
    'Google\\Service\\VMwareEngine\\Node' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Node.php',
    'Google\\Service\\VMwareEngine\\NodeType' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NodeType.php',
    'Google\\Service\\VMwareEngine\\NodeTypeConfig' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/NodeTypeConfig.php',
    'Google\\Service\\VMwareEngine\\Nsx' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Nsx.php',
    'Google\\Service\\VMwareEngine\\Operation' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Operation.php',
    'Google\\Service\\VMwareEngine\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/OperationMetadata.php',
    'Google\\Service\\VMwareEngine\\PeeringRoute' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/PeeringRoute.php',
    'Google\\Service\\VMwareEngine\\Policy' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Policy.php',
    'Google\\Service\\VMwareEngine\\Principal' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Principal.php',
    'Google\\Service\\VMwareEngine\\PrivateCloud' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/PrivateCloud.php',
    'Google\\Service\\VMwareEngine\\PrivateConnection' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/PrivateConnection.php',
    'Google\\Service\\VMwareEngine\\RepairManagementDnsZoneBindingRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/RepairManagementDnsZoneBindingRequest.php',
    'Google\\Service\\VMwareEngine\\ResetNsxCredentialsRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ResetNsxCredentialsRequest.php',
    'Google\\Service\\VMwareEngine\\ResetVcenterCredentialsRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/ResetVcenterCredentialsRequest.php',
    'Google\\Service\\VMwareEngine\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/Projects.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocations.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsDnsBindPermission' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsDnsBindPermission.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsNetworkPeerings' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsNetworkPeerings.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsNetworkPeeringsPeeringRoutes' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsNetworkPeeringsPeeringRoutes.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsNetworkPolicies' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsNetworkPolicies.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsNetworkPoliciesExternalAccessRules' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsNetworkPoliciesExternalAccessRules.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsNodeTypes' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsNodeTypes.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateClouds' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateClouds.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsClusters' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsClusters.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsClustersNodes' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsClustersNodes.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsExternalAddresses' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsExternalAddresses.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsHcxActivationKeys' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsHcxActivationKeys.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsLoggingServers' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsLoggingServers.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsManagementDnsZoneBindings' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsManagementDnsZoneBindings.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateCloudsSubnets' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateCloudsSubnets.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateConnections' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateConnections.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsPrivateConnectionsPeeringRoutes' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsPrivateConnectionsPeeringRoutes.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsVmwareEngineNetworks' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsVmwareEngineNetworks.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsVmwareengineGlobal' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsVmwareengineGlobal.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsVmwareengineGlobalDnsBindPermission' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsVmwareengineGlobalDnsBindPermission.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsVmwareengineGlobalNetworkPeerings' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsVmwareengineGlobalNetworkPeerings.php',
    'Google\\Service\\VMwareEngine\\Resource\\ProjectsLocationsVmwareengineGlobalNetworkPeeringsPeeringRoutes' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Resource/ProjectsLocationsVmwareengineGlobalNetworkPeeringsPeeringRoutes.php',
    'Google\\Service\\VMwareEngine\\RevokeDnsBindPermissionRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/RevokeDnsBindPermissionRequest.php',
    'Google\\Service\\VMwareEngine\\SetIamPolicyRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/SetIamPolicyRequest.php',
    'Google\\Service\\VMwareEngine\\Status' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Status.php',
    'Google\\Service\\VMwareEngine\\StretchedClusterConfig' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/StretchedClusterConfig.php',
    'Google\\Service\\VMwareEngine\\Subnet' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Subnet.php',
    'Google\\Service\\VMwareEngine\\TestIamPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/TestIamPermissionsRequest.php',
    'Google\\Service\\VMwareEngine\\TestIamPermissionsResponse' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/TestIamPermissionsResponse.php',
    'Google\\Service\\VMwareEngine\\Thresholds' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Thresholds.php',
    'Google\\Service\\VMwareEngine\\UndeletePrivateCloudRequest' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/UndeletePrivateCloudRequest.php',
    'Google\\Service\\VMwareEngine\\Vcenter' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/Vcenter.php',
    'Google\\Service\\VMwareEngine\\VmwareEngineNetwork' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/VmwareEngineNetwork.php',
    'Google\\Service\\VMwareEngine\\VmwareengineEmpty' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/VmwareengineEmpty.php',
    'Google\\Service\\VMwareEngine\\VpcNetwork' => $vendorDir . '/google/apiclient-services/src/VMwareEngine/VpcNetwork.php',
    'Google\\Service\\Vault' => $vendorDir . '/google/apiclient-services/src/Vault.php',
    'Google\\Service\\Vault\\AccountCount' => $vendorDir . '/google/apiclient-services/src/Vault/AccountCount.php',
    'Google\\Service\\Vault\\AccountCountError' => $vendorDir . '/google/apiclient-services/src/Vault/AccountCountError.php',
    'Google\\Service\\Vault\\AccountInfo' => $vendorDir . '/google/apiclient-services/src/Vault/AccountInfo.php',
    'Google\\Service\\Vault\\AddHeldAccountResult' => $vendorDir . '/google/apiclient-services/src/Vault/AddHeldAccountResult.php',
    'Google\\Service\\Vault\\AddHeldAccountsRequest' => $vendorDir . '/google/apiclient-services/src/Vault/AddHeldAccountsRequest.php',
    'Google\\Service\\Vault\\AddHeldAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/AddHeldAccountsResponse.php',
    'Google\\Service\\Vault\\AddMatterPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Vault/AddMatterPermissionsRequest.php',
    'Google\\Service\\Vault\\CalendarExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/CalendarExportOptions.php',
    'Google\\Service\\Vault\\CalendarOptions' => $vendorDir . '/google/apiclient-services/src/Vault/CalendarOptions.php',
    'Google\\Service\\Vault\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Vault/CancelOperationRequest.php',
    'Google\\Service\\Vault\\CloseMatterRequest' => $vendorDir . '/google/apiclient-services/src/Vault/CloseMatterRequest.php',
    'Google\\Service\\Vault\\CloseMatterResponse' => $vendorDir . '/google/apiclient-services/src/Vault/CloseMatterResponse.php',
    'Google\\Service\\Vault\\CloudStorageFile' => $vendorDir . '/google/apiclient-services/src/Vault/CloudStorageFile.php',
    'Google\\Service\\Vault\\CloudStorageSink' => $vendorDir . '/google/apiclient-services/src/Vault/CloudStorageSink.php',
    'Google\\Service\\Vault\\CorpusQuery' => $vendorDir . '/google/apiclient-services/src/Vault/CorpusQuery.php',
    'Google\\Service\\Vault\\CountArtifactsMetadata' => $vendorDir . '/google/apiclient-services/src/Vault/CountArtifactsMetadata.php',
    'Google\\Service\\Vault\\CountArtifactsRequest' => $vendorDir . '/google/apiclient-services/src/Vault/CountArtifactsRequest.php',
    'Google\\Service\\Vault\\CountArtifactsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/CountArtifactsResponse.php',
    'Google\\Service\\Vault\\DriveExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/DriveExportOptions.php',
    'Google\\Service\\Vault\\DriveOptions' => $vendorDir . '/google/apiclient-services/src/Vault/DriveOptions.php',
    'Google\\Service\\Vault\\Export' => $vendorDir . '/google/apiclient-services/src/Vault/Export.php',
    'Google\\Service\\Vault\\ExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/ExportOptions.php',
    'Google\\Service\\Vault\\ExportStats' => $vendorDir . '/google/apiclient-services/src/Vault/ExportStats.php',
    'Google\\Service\\Vault\\GroupsCountResult' => $vendorDir . '/google/apiclient-services/src/Vault/GroupsCountResult.php',
    'Google\\Service\\Vault\\GroupsExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/GroupsExportOptions.php',
    'Google\\Service\\Vault\\HangoutsChatExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/HangoutsChatExportOptions.php',
    'Google\\Service\\Vault\\HangoutsChatInfo' => $vendorDir . '/google/apiclient-services/src/Vault/HangoutsChatInfo.php',
    'Google\\Service\\Vault\\HangoutsChatOptions' => $vendorDir . '/google/apiclient-services/src/Vault/HangoutsChatOptions.php',
    'Google\\Service\\Vault\\HeldAccount' => $vendorDir . '/google/apiclient-services/src/Vault/HeldAccount.php',
    'Google\\Service\\Vault\\HeldCalendarQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldCalendarQuery.php',
    'Google\\Service\\Vault\\HeldDriveQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldDriveQuery.php',
    'Google\\Service\\Vault\\HeldGroupsQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldGroupsQuery.php',
    'Google\\Service\\Vault\\HeldHangoutsChatQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldHangoutsChatQuery.php',
    'Google\\Service\\Vault\\HeldMailQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldMailQuery.php',
    'Google\\Service\\Vault\\HeldOrgUnit' => $vendorDir . '/google/apiclient-services/src/Vault/HeldOrgUnit.php',
    'Google\\Service\\Vault\\HeldVoiceQuery' => $vendorDir . '/google/apiclient-services/src/Vault/HeldVoiceQuery.php',
    'Google\\Service\\Vault\\Hold' => $vendorDir . '/google/apiclient-services/src/Vault/Hold.php',
    'Google\\Service\\Vault\\ListExportsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListExportsResponse.php',
    'Google\\Service\\Vault\\ListHeldAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListHeldAccountsResponse.php',
    'Google\\Service\\Vault\\ListHoldsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListHoldsResponse.php',
    'Google\\Service\\Vault\\ListMattersResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListMattersResponse.php',
    'Google\\Service\\Vault\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListOperationsResponse.php',
    'Google\\Service\\Vault\\ListSavedQueriesResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ListSavedQueriesResponse.php',
    'Google\\Service\\Vault\\MailCountResult' => $vendorDir . '/google/apiclient-services/src/Vault/MailCountResult.php',
    'Google\\Service\\Vault\\MailExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/MailExportOptions.php',
    'Google\\Service\\Vault\\MailOptions' => $vendorDir . '/google/apiclient-services/src/Vault/MailOptions.php',
    'Google\\Service\\Vault\\Matter' => $vendorDir . '/google/apiclient-services/src/Vault/Matter.php',
    'Google\\Service\\Vault\\MatterPermission' => $vendorDir . '/google/apiclient-services/src/Vault/MatterPermission.php',
    'Google\\Service\\Vault\\Operation' => $vendorDir . '/google/apiclient-services/src/Vault/Operation.php',
    'Google\\Service\\Vault\\OrgUnitInfo' => $vendorDir . '/google/apiclient-services/src/Vault/OrgUnitInfo.php',
    'Google\\Service\\Vault\\Query' => $vendorDir . '/google/apiclient-services/src/Vault/Query.php',
    'Google\\Service\\Vault\\RemoveHeldAccountsRequest' => $vendorDir . '/google/apiclient-services/src/Vault/RemoveHeldAccountsRequest.php',
    'Google\\Service\\Vault\\RemoveHeldAccountsResponse' => $vendorDir . '/google/apiclient-services/src/Vault/RemoveHeldAccountsResponse.php',
    'Google\\Service\\Vault\\RemoveMatterPermissionsRequest' => $vendorDir . '/google/apiclient-services/src/Vault/RemoveMatterPermissionsRequest.php',
    'Google\\Service\\Vault\\ReopenMatterRequest' => $vendorDir . '/google/apiclient-services/src/Vault/ReopenMatterRequest.php',
    'Google\\Service\\Vault\\ReopenMatterResponse' => $vendorDir . '/google/apiclient-services/src/Vault/ReopenMatterResponse.php',
    'Google\\Service\\Vault\\Resource\\Matters' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/Matters.php',
    'Google\\Service\\Vault\\Resource\\MattersExports' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/MattersExports.php',
    'Google\\Service\\Vault\\Resource\\MattersHolds' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/MattersHolds.php',
    'Google\\Service\\Vault\\Resource\\MattersHoldsAccounts' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/MattersHoldsAccounts.php',
    'Google\\Service\\Vault\\Resource\\MattersSavedQueries' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/MattersSavedQueries.php',
    'Google\\Service\\Vault\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Vault/Resource/Operations.php',
    'Google\\Service\\Vault\\SavedQuery' => $vendorDir . '/google/apiclient-services/src/Vault/SavedQuery.php',
    'Google\\Service\\Vault\\SharedDriveInfo' => $vendorDir . '/google/apiclient-services/src/Vault/SharedDriveInfo.php',
    'Google\\Service\\Vault\\SitesUrlInfo' => $vendorDir . '/google/apiclient-services/src/Vault/SitesUrlInfo.php',
    'Google\\Service\\Vault\\Status' => $vendorDir . '/google/apiclient-services/src/Vault/Status.php',
    'Google\\Service\\Vault\\TeamDriveInfo' => $vendorDir . '/google/apiclient-services/src/Vault/TeamDriveInfo.php',
    'Google\\Service\\Vault\\UndeleteMatterRequest' => $vendorDir . '/google/apiclient-services/src/Vault/UndeleteMatterRequest.php',
    'Google\\Service\\Vault\\UserInfo' => $vendorDir . '/google/apiclient-services/src/Vault/UserInfo.php',
    'Google\\Service\\Vault\\VaultEmpty' => $vendorDir . '/google/apiclient-services/src/Vault/VaultEmpty.php',
    'Google\\Service\\Vault\\VoiceExportOptions' => $vendorDir . '/google/apiclient-services/src/Vault/VoiceExportOptions.php',
    'Google\\Service\\Vault\\VoiceOptions' => $vendorDir . '/google/apiclient-services/src/Vault/VoiceOptions.php',
    'Google\\Service\\Verifiedaccess' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess.php',
    'Google\\Service\\Verifiedaccess\\Challenge' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/Challenge.php',
    'Google\\Service\\Verifiedaccess\\CrowdStrikeAgent' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/CrowdStrikeAgent.php',
    'Google\\Service\\Verifiedaccess\\DeviceSignals' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/DeviceSignals.php',
    'Google\\Service\\Verifiedaccess\\Resource\\Challenge' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/Resource/Challenge.php',
    'Google\\Service\\Verifiedaccess\\SignedData' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/SignedData.php',
    'Google\\Service\\Verifiedaccess\\VerifiedaccessEmpty' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/VerifiedaccessEmpty.php',
    'Google\\Service\\Verifiedaccess\\VerifyChallengeResponseRequest' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/VerifyChallengeResponseRequest.php',
    'Google\\Service\\Verifiedaccess\\VerifyChallengeResponseResult' => $vendorDir . '/google/apiclient-services/src/Verifiedaccess/VerifyChallengeResponseResult.php',
    'Google\\Service\\VersionHistory' => $vendorDir . '/google/apiclient-services/src/VersionHistory.php',
    'Google\\Service\\VersionHistory\\Channel' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Channel.php',
    'Google\\Service\\VersionHistory\\Interval' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Interval.php',
    'Google\\Service\\VersionHistory\\ListChannelsResponse' => $vendorDir . '/google/apiclient-services/src/VersionHistory/ListChannelsResponse.php',
    'Google\\Service\\VersionHistory\\ListPlatformsResponse' => $vendorDir . '/google/apiclient-services/src/VersionHistory/ListPlatformsResponse.php',
    'Google\\Service\\VersionHistory\\ListReleasesResponse' => $vendorDir . '/google/apiclient-services/src/VersionHistory/ListReleasesResponse.php',
    'Google\\Service\\VersionHistory\\ListVersionsResponse' => $vendorDir . '/google/apiclient-services/src/VersionHistory/ListVersionsResponse.php',
    'Google\\Service\\VersionHistory\\Platform' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Platform.php',
    'Google\\Service\\VersionHistory\\Release' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Release.php',
    'Google\\Service\\VersionHistory\\Resource\\Platforms' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Resource/Platforms.php',
    'Google\\Service\\VersionHistory\\Resource\\PlatformsChannels' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Resource/PlatformsChannels.php',
    'Google\\Service\\VersionHistory\\Resource\\PlatformsChannelsVersions' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Resource/PlatformsChannelsVersions.php',
    'Google\\Service\\VersionHistory\\Resource\\PlatformsChannelsVersionsReleases' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Resource/PlatformsChannelsVersionsReleases.php',
    'Google\\Service\\VersionHistory\\Version' => $vendorDir . '/google/apiclient-services/src/VersionHistory/Version.php',
    'Google\\Service\\Vision' => $vendorDir . '/google/apiclient-services/src/Vision.php',
    'Google\\Service\\Vision\\AddProductToProductSetRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AddProductToProductSetRequest.php',
    'Google\\Service\\Vision\\AnnotateFileRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AnnotateFileRequest.php',
    'Google\\Service\\Vision\\AnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/AnnotateFileResponse.php',
    'Google\\Service\\Vision\\AnnotateImageRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AnnotateImageRequest.php',
    'Google\\Service\\Vision\\AnnotateImageResponse' => $vendorDir . '/google/apiclient-services/src/Vision/AnnotateImageResponse.php',
    'Google\\Service\\Vision\\AsyncAnnotateFileRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncAnnotateFileRequest.php',
    'Google\\Service\\Vision\\AsyncAnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncAnnotateFileResponse.php',
    'Google\\Service\\Vision\\AsyncBatchAnnotateFilesRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncBatchAnnotateFilesRequest.php',
    'Google\\Service\\Vision\\AsyncBatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncBatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\AsyncBatchAnnotateImagesRequest' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncBatchAnnotateImagesRequest.php',
    'Google\\Service\\Vision\\AsyncBatchAnnotateImagesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/AsyncBatchAnnotateImagesResponse.php',
    'Google\\Service\\Vision\\BatchAnnotateFilesRequest' => $vendorDir . '/google/apiclient-services/src/Vision/BatchAnnotateFilesRequest.php',
    'Google\\Service\\Vision\\BatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/BatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\BatchAnnotateImagesRequest' => $vendorDir . '/google/apiclient-services/src/Vision/BatchAnnotateImagesRequest.php',
    'Google\\Service\\Vision\\BatchAnnotateImagesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/BatchAnnotateImagesResponse.php',
    'Google\\Service\\Vision\\BatchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/BatchOperationMetadata.php',
    'Google\\Service\\Vision\\Block' => $vendorDir . '/google/apiclient-services/src/Vision/Block.php',
    'Google\\Service\\Vision\\BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Vision/BoundingPoly.php',
    'Google\\Service\\Vision\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/Vision/CancelOperationRequest.php',
    'Google\\Service\\Vision\\Color' => $vendorDir . '/google/apiclient-services/src/Vision/Color.php',
    'Google\\Service\\Vision\\ColorInfo' => $vendorDir . '/google/apiclient-services/src/Vision/ColorInfo.php',
    'Google\\Service\\Vision\\CropHint' => $vendorDir . '/google/apiclient-services/src/Vision/CropHint.php',
    'Google\\Service\\Vision\\CropHintsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/CropHintsAnnotation.php',
    'Google\\Service\\Vision\\CropHintsParams' => $vendorDir . '/google/apiclient-services/src/Vision/CropHintsParams.php',
    'Google\\Service\\Vision\\DetectedBreak' => $vendorDir . '/google/apiclient-services/src/Vision/DetectedBreak.php',
    'Google\\Service\\Vision\\DetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Vision/DetectedLanguage.php',
    'Google\\Service\\Vision\\DominantColorsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/DominantColorsAnnotation.php',
    'Google\\Service\\Vision\\EntityAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/EntityAnnotation.php',
    'Google\\Service\\Vision\\FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/FaceAnnotation.php',
    'Google\\Service\\Vision\\Feature' => $vendorDir . '/google/apiclient-services/src/Vision/Feature.php',
    'Google\\Service\\Vision\\GcsDestination' => $vendorDir . '/google/apiclient-services/src/Vision/GcsDestination.php',
    'Google\\Service\\Vision\\GcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/GcsSource.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1AnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1AnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1AnnotateImageResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1AnnotateImageResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1AsyncAnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1AsyncAnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1AsyncBatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1AsyncBatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Block' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Block.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1BoundingPoly.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ColorInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ColorInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1CropHint' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1CropHint.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1CropHintsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1CropHintsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1DominantColorsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1DominantColorsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1EntityAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1EntityAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1FaceAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1FaceAnnotationLandmark' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1FaceAnnotationLandmark.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1GcsDestination.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1GcsSource.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ImageAnnotationContext' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ImageAnnotationContext.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ImageProperties' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ImageProperties.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1InputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1LocalizedObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1LocalizedObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1LocationInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1LocationInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1NormalizedVertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1OperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1OutputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Page' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Page.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Paragraph' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Paragraph.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Position' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Position.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Product' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Product.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ProductKeyValue' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ProductKeyValue.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ProductSearchResults' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ProductSearchResults.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ProductSearchResultsGroupedResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ProductSearchResultsGroupedResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ProductSearchResultsObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ProductSearchResultsObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1ProductSearchResultsResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1ProductSearchResultsResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Property' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Property.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1SafeSearchAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1SafeSearchAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Symbol' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Symbol.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1TextAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1TextAnnotationDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1TextAnnotationDetectedBreak.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1TextAnnotationDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1TextAnnotationDetectedLanguage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1TextAnnotationTextProperty' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1TextAnnotationTextProperty.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Vertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Vertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1WebDetection' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1WebDetection.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1WebDetectionWebEntity' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1WebDetectionWebEntity.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1WebDetectionWebImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1WebDetectionWebImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1WebDetectionWebLabel' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1WebDetectionWebLabel.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1WebDetectionWebPage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1WebDetectionWebPage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p1beta1Word' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p1beta1Word.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1AnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1AnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1AnnotateImageResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1AnnotateImageResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1AsyncAnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1AsyncAnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Block' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Block.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1BoundingPoly.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ColorInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ColorInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1CropHint' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1CropHint.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1CropHintsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1CropHintsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1DominantColorsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1DominantColorsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1EntityAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1EntityAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1FaceAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1FaceAnnotationLandmark' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1FaceAnnotationLandmark.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1GcsDestination.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1GcsSource.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ImageAnnotationContext' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ImageAnnotationContext.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ImageProperties' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ImageProperties.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1InputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1LocalizedObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1LocalizedObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1LocationInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1LocationInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1NormalizedVertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1OperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1OutputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Page' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Page.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Paragraph' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Paragraph.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Position' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Position.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Product' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Product.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ProductKeyValue' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ProductKeyValue.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ProductSearchResults' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ProductSearchResults.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ProductSearchResultsGroupedResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ProductSearchResultsGroupedResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ProductSearchResultsObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ProductSearchResultsObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1ProductSearchResultsResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1ProductSearchResultsResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Property' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Property.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1SafeSearchAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1SafeSearchAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Symbol' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Symbol.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1TextAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1TextAnnotationDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1TextAnnotationDetectedBreak.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1TextAnnotationDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1TextAnnotationDetectedLanguage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1TextAnnotationTextProperty' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1TextAnnotationTextProperty.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Vertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Vertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1WebDetection' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1WebDetection.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1WebDetectionWebEntity' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1WebDetectionWebEntity.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1WebDetectionWebImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1WebDetectionWebImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1WebDetectionWebLabel' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1WebDetectionWebLabel.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1WebDetectionWebPage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1WebDetectionWebPage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p2beta1Word' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p2beta1Word.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1AnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1AnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1AnnotateImageResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1AnnotateImageResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1AsyncAnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1AsyncAnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1BatchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1BatchOperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Block' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Block.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1BoundingPoly.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ColorInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ColorInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1CropHint' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1CropHint.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1CropHintsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1CropHintsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1DominantColorsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1DominantColorsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1EntityAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1EntityAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1FaceAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1FaceAnnotationLandmark' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1FaceAnnotationLandmark.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1GcsDestination.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1GcsSource.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ImageAnnotationContext' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ImageAnnotationContext.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ImageProperties' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ImageProperties.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ImportProductSetsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ImportProductSetsResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1InputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1LocalizedObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1LocalizedObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1LocationInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1LocationInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1NormalizedVertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1OperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1OutputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Page' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Page.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Paragraph' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Paragraph.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Position' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Position.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Product' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Product.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ProductKeyValue' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ProductKeyValue.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ProductSearchResults' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ProductSearchResults.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ProductSearchResultsGroupedResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ProductSearchResultsGroupedResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ProductSearchResultsObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ProductSearchResultsObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ProductSearchResultsResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ProductSearchResultsResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Property' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Property.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1ReferenceImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1ReferenceImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1SafeSearchAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1SafeSearchAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Symbol' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Symbol.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1TextAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1TextAnnotationDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1TextAnnotationDetectedBreak.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1TextAnnotationDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1TextAnnotationDetectedLanguage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1TextAnnotationTextProperty' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1TextAnnotationTextProperty.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Vertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Vertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1WebDetection' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1WebDetection.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1WebDetectionWebEntity' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1WebDetectionWebEntity.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1WebDetectionWebImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1WebDetectionWebImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1WebDetectionWebLabel' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1WebDetectionWebLabel.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1WebDetectionWebPage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1WebDetectionWebPage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p3beta1Word' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p3beta1Word.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1AnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1AnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1AnnotateImageResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1AnnotateImageResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1AsyncAnnotateFileResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1AsyncAnnotateFileResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1AsyncBatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1AsyncBatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1AsyncBatchAnnotateImagesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1AsyncBatchAnnotateImagesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1BatchAnnotateFilesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1BatchAnnotateFilesResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1BatchOperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1BatchOperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Block' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Block.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1BoundingPoly' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1BoundingPoly.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Celebrity' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Celebrity.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ColorInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ColorInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1CropHint' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1CropHint.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1CropHintsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1CropHintsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1DominantColorsAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1DominantColorsAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1EntityAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1EntityAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1FaceAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1FaceAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1FaceAnnotationLandmark' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1FaceAnnotationLandmark.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1FaceRecognitionResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1FaceRecognitionResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1GcsDestination' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1GcsDestination.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1GcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1GcsSource.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ImageAnnotationContext' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ImageAnnotationContext.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ImageProperties' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ImageProperties.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ImportProductSetsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ImportProductSetsResponse.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1InputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1InputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1LocalizedObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1LocalizedObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1LocationInfo' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1LocationInfo.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1NormalizedVertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1OperationMetadata.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1OutputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1OutputConfig.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Page' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Page.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Paragraph' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Paragraph.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Position' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Position.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Product' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Product.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ProductKeyValue' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ProductKeyValue.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ProductSearchResults' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ProductSearchResults.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ProductSearchResultsGroupedResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ProductSearchResultsGroupedResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ProductSearchResultsObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ProductSearchResultsObjectAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ProductSearchResultsResult' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ProductSearchResultsResult.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Property' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Property.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1ReferenceImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1ReferenceImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1SafeSearchAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1SafeSearchAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Symbol' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Symbol.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1TextAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1TextAnnotation.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1TextAnnotationDetectedBreak' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1TextAnnotationDetectedBreak.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1TextAnnotationDetectedLanguage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1TextAnnotationDetectedLanguage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1TextAnnotationTextProperty' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1TextAnnotationTextProperty.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Vertex' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Vertex.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1WebDetection' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1WebDetection.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1WebDetectionWebEntity' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1WebDetectionWebEntity.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1WebDetectionWebImage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1WebDetectionWebImage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1WebDetectionWebLabel' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1WebDetectionWebLabel.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1WebDetectionWebPage' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1WebDetectionWebPage.php',
    'Google\\Service\\Vision\\GoogleCloudVisionV1p4beta1Word' => $vendorDir . '/google/apiclient-services/src/Vision/GoogleCloudVisionV1p4beta1Word.php',
    'Google\\Service\\Vision\\GroupedResult' => $vendorDir . '/google/apiclient-services/src/Vision/GroupedResult.php',
    'Google\\Service\\Vision\\Image' => $vendorDir . '/google/apiclient-services/src/Vision/Image.php',
    'Google\\Service\\Vision\\ImageAnnotationContext' => $vendorDir . '/google/apiclient-services/src/Vision/ImageAnnotationContext.php',
    'Google\\Service\\Vision\\ImageContext' => $vendorDir . '/google/apiclient-services/src/Vision/ImageContext.php',
    'Google\\Service\\Vision\\ImageProperties' => $vendorDir . '/google/apiclient-services/src/Vision/ImageProperties.php',
    'Google\\Service\\Vision\\ImageSource' => $vendorDir . '/google/apiclient-services/src/Vision/ImageSource.php',
    'Google\\Service\\Vision\\ImportProductSetsGcsSource' => $vendorDir . '/google/apiclient-services/src/Vision/ImportProductSetsGcsSource.php',
    'Google\\Service\\Vision\\ImportProductSetsInputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/ImportProductSetsInputConfig.php',
    'Google\\Service\\Vision\\ImportProductSetsRequest' => $vendorDir . '/google/apiclient-services/src/Vision/ImportProductSetsRequest.php',
    'Google\\Service\\Vision\\ImportProductSetsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ImportProductSetsResponse.php',
    'Google\\Service\\Vision\\InputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/InputConfig.php',
    'Google\\Service\\Vision\\KeyValue' => $vendorDir . '/google/apiclient-services/src/Vision/KeyValue.php',
    'Google\\Service\\Vision\\Landmark' => $vendorDir . '/google/apiclient-services/src/Vision/Landmark.php',
    'Google\\Service\\Vision\\LatLng' => $vendorDir . '/google/apiclient-services/src/Vision/LatLng.php',
    'Google\\Service\\Vision\\LatLongRect' => $vendorDir . '/google/apiclient-services/src/Vision/LatLongRect.php',
    'Google\\Service\\Vision\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ListOperationsResponse.php',
    'Google\\Service\\Vision\\ListProductSetsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ListProductSetsResponse.php',
    'Google\\Service\\Vision\\ListProductsInProductSetResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ListProductsInProductSetResponse.php',
    'Google\\Service\\Vision\\ListProductsResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ListProductsResponse.php',
    'Google\\Service\\Vision\\ListReferenceImagesResponse' => $vendorDir . '/google/apiclient-services/src/Vision/ListReferenceImagesResponse.php',
    'Google\\Service\\Vision\\LocalizedObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/LocalizedObjectAnnotation.php',
    'Google\\Service\\Vision\\LocationInfo' => $vendorDir . '/google/apiclient-services/src/Vision/LocationInfo.php',
    'Google\\Service\\Vision\\NormalizedVertex' => $vendorDir . '/google/apiclient-services/src/Vision/NormalizedVertex.php',
    'Google\\Service\\Vision\\ObjectAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/ObjectAnnotation.php',
    'Google\\Service\\Vision\\Operation' => $vendorDir . '/google/apiclient-services/src/Vision/Operation.php',
    'Google\\Service\\Vision\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Vision/OperationMetadata.php',
    'Google\\Service\\Vision\\OutputConfig' => $vendorDir . '/google/apiclient-services/src/Vision/OutputConfig.php',
    'Google\\Service\\Vision\\Page' => $vendorDir . '/google/apiclient-services/src/Vision/Page.php',
    'Google\\Service\\Vision\\Paragraph' => $vendorDir . '/google/apiclient-services/src/Vision/Paragraph.php',
    'Google\\Service\\Vision\\Position' => $vendorDir . '/google/apiclient-services/src/Vision/Position.php',
    'Google\\Service\\Vision\\Product' => $vendorDir . '/google/apiclient-services/src/Vision/Product.php',
    'Google\\Service\\Vision\\ProductSearchParams' => $vendorDir . '/google/apiclient-services/src/Vision/ProductSearchParams.php',
    'Google\\Service\\Vision\\ProductSearchResults' => $vendorDir . '/google/apiclient-services/src/Vision/ProductSearchResults.php',
    'Google\\Service\\Vision\\ProductSet' => $vendorDir . '/google/apiclient-services/src/Vision/ProductSet.php',
    'Google\\Service\\Vision\\ProductSetPurgeConfig' => $vendorDir . '/google/apiclient-services/src/Vision/ProductSetPurgeConfig.php',
    'Google\\Service\\Vision\\Property' => $vendorDir . '/google/apiclient-services/src/Vision/Property.php',
    'Google\\Service\\Vision\\PurgeProductsRequest' => $vendorDir . '/google/apiclient-services/src/Vision/PurgeProductsRequest.php',
    'Google\\Service\\Vision\\ReferenceImage' => $vendorDir . '/google/apiclient-services/src/Vision/ReferenceImage.php',
    'Google\\Service\\Vision\\RemoveProductFromProductSetRequest' => $vendorDir . '/google/apiclient-services/src/Vision/RemoveProductFromProductSetRequest.php',
    'Google\\Service\\Vision\\Resource\\Files' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/Files.php',
    'Google\\Service\\Vision\\Resource\\Images' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/Images.php',
    'Google\\Service\\Vision\\Resource\\Locations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/Locations.php',
    'Google\\Service\\Vision\\Resource\\LocationsOperations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/LocationsOperations.php',
    'Google\\Service\\Vision\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/Operations.php',
    'Google\\Service\\Vision\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/Projects.php',
    'Google\\Service\\Vision\\Resource\\ProjectsFiles' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsFiles.php',
    'Google\\Service\\Vision\\Resource\\ProjectsImages' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsImages.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocations.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsFiles' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsFiles.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsImages' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsImages.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsProductSets' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsProductSets.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsProductSetsProducts' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsProductSetsProducts.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsProducts' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsProducts.php',
    'Google\\Service\\Vision\\Resource\\ProjectsLocationsProductsReferenceImages' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsLocationsProductsReferenceImages.php',
    'Google\\Service\\Vision\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/Vision/Resource/ProjectsOperations.php',
    'Google\\Service\\Vision\\Result' => $vendorDir . '/google/apiclient-services/src/Vision/Result.php',
    'Google\\Service\\Vision\\SafeSearchAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/SafeSearchAnnotation.php',
    'Google\\Service\\Vision\\Status' => $vendorDir . '/google/apiclient-services/src/Vision/Status.php',
    'Google\\Service\\Vision\\Symbol' => $vendorDir . '/google/apiclient-services/src/Vision/Symbol.php',
    'Google\\Service\\Vision\\TextAnnotation' => $vendorDir . '/google/apiclient-services/src/Vision/TextAnnotation.php',
    'Google\\Service\\Vision\\TextDetectionParams' => $vendorDir . '/google/apiclient-services/src/Vision/TextDetectionParams.php',
    'Google\\Service\\Vision\\TextProperty' => $vendorDir . '/google/apiclient-services/src/Vision/TextProperty.php',
    'Google\\Service\\Vision\\Vertex' => $vendorDir . '/google/apiclient-services/src/Vision/Vertex.php',
    'Google\\Service\\Vision\\VisionEmpty' => $vendorDir . '/google/apiclient-services/src/Vision/VisionEmpty.php',
    'Google\\Service\\Vision\\WebDetection' => $vendorDir . '/google/apiclient-services/src/Vision/WebDetection.php',
    'Google\\Service\\Vision\\WebDetectionParams' => $vendorDir . '/google/apiclient-services/src/Vision/WebDetectionParams.php',
    'Google\\Service\\Vision\\WebEntity' => $vendorDir . '/google/apiclient-services/src/Vision/WebEntity.php',
    'Google\\Service\\Vision\\WebImage' => $vendorDir . '/google/apiclient-services/src/Vision/WebImage.php',
    'Google\\Service\\Vision\\WebLabel' => $vendorDir . '/google/apiclient-services/src/Vision/WebLabel.php',
    'Google\\Service\\Vision\\WebPage' => $vendorDir . '/google/apiclient-services/src/Vision/WebPage.php',
    'Google\\Service\\Vision\\Word' => $vendorDir . '/google/apiclient-services/src/Vision/Word.php',
    'Google\\Service\\Walletobjects' => $vendorDir . '/google/apiclient-services/src/Walletobjects.php',
    'Google\\Service\\Walletobjects\\ActivationOptions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ActivationOptions.php',
    'Google\\Service\\Walletobjects\\ActivationStatus' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ActivationStatus.php',
    'Google\\Service\\Walletobjects\\AddMessageRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AddMessageRequest.php',
    'Google\\Service\\Walletobjects\\AirportInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AirportInfo.php',
    'Google\\Service\\Walletobjects\\AppLinkData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AppLinkData.php',
    'Google\\Service\\Walletobjects\\AppLinkDataAppLinkInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AppLinkDataAppLinkInfo.php',
    'Google\\Service\\Walletobjects\\AppLinkDataAppLinkInfoAppTarget' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AppLinkDataAppLinkInfoAppTarget.php',
    'Google\\Service\\Walletobjects\\AuthenticationKey' => $vendorDir . '/google/apiclient-services/src/Walletobjects/AuthenticationKey.php',
    'Google\\Service\\Walletobjects\\Barcode' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Barcode.php',
    'Google\\Service\\Walletobjects\\BarcodeSectionDetail' => $vendorDir . '/google/apiclient-services/src/Walletobjects/BarcodeSectionDetail.php',
    'Google\\Service\\Walletobjects\\Blobstore2Info' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Blobstore2Info.php',
    'Google\\Service\\Walletobjects\\BoardingAndSeatingInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/BoardingAndSeatingInfo.php',
    'Google\\Service\\Walletobjects\\BoardingAndSeatingPolicy' => $vendorDir . '/google/apiclient-services/src/Walletobjects/BoardingAndSeatingPolicy.php',
    'Google\\Service\\Walletobjects\\CallbackOptions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CallbackOptions.php',
    'Google\\Service\\Walletobjects\\CardBarcodeSectionDetails' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardBarcodeSectionDetails.php',
    'Google\\Service\\Walletobjects\\CardRowOneItem' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardRowOneItem.php',
    'Google\\Service\\Walletobjects\\CardRowTemplateInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardRowTemplateInfo.php',
    'Google\\Service\\Walletobjects\\CardRowThreeItems' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardRowThreeItems.php',
    'Google\\Service\\Walletobjects\\CardRowTwoItems' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardRowTwoItems.php',
    'Google\\Service\\Walletobjects\\CardTemplateOverride' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CardTemplateOverride.php',
    'Google\\Service\\Walletobjects\\ClassTemplateInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ClassTemplateInfo.php',
    'Google\\Service\\Walletobjects\\CompositeMedia' => $vendorDir . '/google/apiclient-services/src/Walletobjects/CompositeMedia.php',
    'Google\\Service\\Walletobjects\\ContentTypeInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ContentTypeInfo.php',
    'Google\\Service\\Walletobjects\\DateTime' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DateTime.php',
    'Google\\Service\\Walletobjects\\DetailsItemInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DetailsItemInfo.php',
    'Google\\Service\\Walletobjects\\DetailsTemplateOverride' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DetailsTemplateOverride.php',
    'Google\\Service\\Walletobjects\\DeviceContext' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DeviceContext.php',
    'Google\\Service\\Walletobjects\\DiffChecksumsResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiffChecksumsResponse.php',
    'Google\\Service\\Walletobjects\\DiffDownloadResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiffDownloadResponse.php',
    'Google\\Service\\Walletobjects\\DiffUploadRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiffUploadRequest.php',
    'Google\\Service\\Walletobjects\\DiffUploadResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiffUploadResponse.php',
    'Google\\Service\\Walletobjects\\DiffVersionResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiffVersionResponse.php',
    'Google\\Service\\Walletobjects\\DiscoverableProgram' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiscoverableProgram.php',
    'Google\\Service\\Walletobjects\\DiscoverableProgramMerchantSigninInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiscoverableProgramMerchantSigninInfo.php',
    'Google\\Service\\Walletobjects\\DiscoverableProgramMerchantSignupInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DiscoverableProgramMerchantSignupInfo.php',
    'Google\\Service\\Walletobjects\\DownloadParameters' => $vendorDir . '/google/apiclient-services/src/Walletobjects/DownloadParameters.php',
    'Google\\Service\\Walletobjects\\EventDateTime' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventDateTime.php',
    'Google\\Service\\Walletobjects\\EventReservationInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventReservationInfo.php',
    'Google\\Service\\Walletobjects\\EventSeat' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventSeat.php',
    'Google\\Service\\Walletobjects\\EventTicketClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketClass.php',
    'Google\\Service\\Walletobjects\\EventTicketClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\EventTicketClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketClassListResponse.php',
    'Google\\Service\\Walletobjects\\EventTicketObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketObject.php',
    'Google\\Service\\Walletobjects\\EventTicketObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\EventTicketObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventTicketObjectListResponse.php',
    'Google\\Service\\Walletobjects\\EventVenue' => $vendorDir . '/google/apiclient-services/src/Walletobjects/EventVenue.php',
    'Google\\Service\\Walletobjects\\ExpiryNotification' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ExpiryNotification.php',
    'Google\\Service\\Walletobjects\\FieldReference' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FieldReference.php',
    'Google\\Service\\Walletobjects\\FieldSelector' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FieldSelector.php',
    'Google\\Service\\Walletobjects\\FirstRowOption' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FirstRowOption.php',
    'Google\\Service\\Walletobjects\\FlightCarrier' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightCarrier.php',
    'Google\\Service\\Walletobjects\\FlightClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightClass.php',
    'Google\\Service\\Walletobjects\\FlightClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\FlightClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightClassListResponse.php',
    'Google\\Service\\Walletobjects\\FlightHeader' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightHeader.php',
    'Google\\Service\\Walletobjects\\FlightObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightObject.php',
    'Google\\Service\\Walletobjects\\FlightObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\FlightObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FlightObjectListResponse.php',
    'Google\\Service\\Walletobjects\\FrequentFlyerInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/FrequentFlyerInfo.php',
    'Google\\Service\\Walletobjects\\GenericClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericClass.php',
    'Google\\Service\\Walletobjects\\GenericClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\GenericClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericClassListResponse.php',
    'Google\\Service\\Walletobjects\\GenericObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericObject.php',
    'Google\\Service\\Walletobjects\\GenericObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\GenericObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GenericObjectListResponse.php',
    'Google\\Service\\Walletobjects\\GiftCardClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardClass.php',
    'Google\\Service\\Walletobjects\\GiftCardClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\GiftCardClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardClassListResponse.php',
    'Google\\Service\\Walletobjects\\GiftCardObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardObject.php',
    'Google\\Service\\Walletobjects\\GiftCardObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\GiftCardObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GiftCardObjectListResponse.php',
    'Google\\Service\\Walletobjects\\GroupingInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/GroupingInfo.php',
    'Google\\Service\\Walletobjects\\Image' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Image.php',
    'Google\\Service\\Walletobjects\\ImageModuleData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ImageModuleData.php',
    'Google\\Service\\Walletobjects\\ImageUri' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ImageUri.php',
    'Google\\Service\\Walletobjects\\InfoModuleData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/InfoModuleData.php',
    'Google\\Service\\Walletobjects\\Issuer' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Issuer.php',
    'Google\\Service\\Walletobjects\\IssuerContactInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/IssuerContactInfo.php',
    'Google\\Service\\Walletobjects\\IssuerListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/IssuerListResponse.php',
    'Google\\Service\\Walletobjects\\IssuerToUserInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/IssuerToUserInfo.php',
    'Google\\Service\\Walletobjects\\JwtInsertResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/JwtInsertResponse.php',
    'Google\\Service\\Walletobjects\\JwtResource' => $vendorDir . '/google/apiclient-services/src/Walletobjects/JwtResource.php',
    'Google\\Service\\Walletobjects\\LabelValue' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LabelValue.php',
    'Google\\Service\\Walletobjects\\LabelValueRow' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LabelValueRow.php',
    'Google\\Service\\Walletobjects\\LatLongPoint' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LatLongPoint.php',
    'Google\\Service\\Walletobjects\\LinksModuleData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LinksModuleData.php',
    'Google\\Service\\Walletobjects\\ListTemplateOverride' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ListTemplateOverride.php',
    'Google\\Service\\Walletobjects\\LocalizedString' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LocalizedString.php',
    'Google\\Service\\Walletobjects\\LoyaltyClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyClass.php',
    'Google\\Service\\Walletobjects\\LoyaltyClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\LoyaltyClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyClassListResponse.php',
    'Google\\Service\\Walletobjects\\LoyaltyObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyObject.php',
    'Google\\Service\\Walletobjects\\LoyaltyObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\LoyaltyObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyObjectListResponse.php',
    'Google\\Service\\Walletobjects\\LoyaltyPoints' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyPoints.php',
    'Google\\Service\\Walletobjects\\LoyaltyPointsBalance' => $vendorDir . '/google/apiclient-services/src/Walletobjects/LoyaltyPointsBalance.php',
    'Google\\Service\\Walletobjects\\Media' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Media.php',
    'Google\\Service\\Walletobjects\\MediaRequestInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/MediaRequestInfo.php',
    'Google\\Service\\Walletobjects\\Message' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Message.php',
    'Google\\Service\\Walletobjects\\ModifyLinkedOfferObjects' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ModifyLinkedOfferObjects.php',
    'Google\\Service\\Walletobjects\\ModifyLinkedOfferObjectsRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ModifyLinkedOfferObjectsRequest.php',
    'Google\\Service\\Walletobjects\\Money' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Money.php',
    'Google\\Service\\Walletobjects\\Notifications' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Notifications.php',
    'Google\\Service\\Walletobjects\\ObjectId' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ObjectId.php',
    'Google\\Service\\Walletobjects\\OfferClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferClass.php',
    'Google\\Service\\Walletobjects\\OfferClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\OfferClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferClassListResponse.php',
    'Google\\Service\\Walletobjects\\OfferObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferObject.php',
    'Google\\Service\\Walletobjects\\OfferObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\OfferObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/OfferObjectListResponse.php',
    'Google\\Service\\Walletobjects\\Pagination' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Pagination.php',
    'Google\\Service\\Walletobjects\\PassConstraints' => $vendorDir . '/google/apiclient-services/src/Walletobjects/PassConstraints.php',
    'Google\\Service\\Walletobjects\\Permission' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Permission.php',
    'Google\\Service\\Walletobjects\\Permissions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Permissions.php',
    'Google\\Service\\Walletobjects\\PrivateText' => $vendorDir . '/google/apiclient-services/src/Walletobjects/PrivateText.php',
    'Google\\Service\\Walletobjects\\PrivateUri' => $vendorDir . '/google/apiclient-services/src/Walletobjects/PrivateUri.php',
    'Google\\Service\\Walletobjects\\PurchaseDetails' => $vendorDir . '/google/apiclient-services/src/Walletobjects/PurchaseDetails.php',
    'Google\\Service\\Walletobjects\\ReservationInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/ReservationInfo.php',
    'Google\\Service\\Walletobjects\\Resource\\Eventticketclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Eventticketclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Eventticketobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Eventticketobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Flightclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Flightclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Flightobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Flightobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Genericclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Genericclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Genericobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Genericobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Giftcardclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Giftcardclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Giftcardobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Giftcardobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Issuer' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Issuer.php',
    'Google\\Service\\Walletobjects\\Resource\\Jwt' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Jwt.php',
    'Google\\Service\\Walletobjects\\Resource\\Loyaltyclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Loyaltyclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Loyaltyobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Loyaltyobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Media.php',
    'Google\\Service\\Walletobjects\\Resource\\Offerclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Offerclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Offerobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Offerobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Permissions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Permissions.php',
    'Google\\Service\\Walletobjects\\Resource\\Smarttap' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Smarttap.php',
    'Google\\Service\\Walletobjects\\Resource\\Transitclass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Transitclass.php',
    'Google\\Service\\Walletobjects\\Resource\\Transitobject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Transitobject.php',
    'Google\\Service\\Walletobjects\\Resource\\Walletobjects' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/Walletobjects.php',
    'Google\\Service\\Walletobjects\\Resource\\WalletobjectsV1' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/WalletobjectsV1.php',
    'Google\\Service\\Walletobjects\\Resource\\WalletobjectsV1PrivateContent' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resource/WalletobjectsV1PrivateContent.php',
    'Google\\Service\\Walletobjects\\Resources' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Resources.php',
    'Google\\Service\\Walletobjects\\Review' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Review.php',
    'Google\\Service\\Walletobjects\\RotatingBarcode' => $vendorDir . '/google/apiclient-services/src/Walletobjects/RotatingBarcode.php',
    'Google\\Service\\Walletobjects\\RotatingBarcodeTotpDetails' => $vendorDir . '/google/apiclient-services/src/Walletobjects/RotatingBarcodeTotpDetails.php',
    'Google\\Service\\Walletobjects\\RotatingBarcodeTotpDetailsTotpParameters' => $vendorDir . '/google/apiclient-services/src/Walletobjects/RotatingBarcodeTotpDetailsTotpParameters.php',
    'Google\\Service\\Walletobjects\\RotatingBarcodeValues' => $vendorDir . '/google/apiclient-services/src/Walletobjects/RotatingBarcodeValues.php',
    'Google\\Service\\Walletobjects\\SaveRestrictions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SaveRestrictions.php',
    'Google\\Service\\Walletobjects\\SecurityAnimation' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SecurityAnimation.php',
    'Google\\Service\\Walletobjects\\SetPassUpdateNoticeRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SetPassUpdateNoticeRequest.php',
    'Google\\Service\\Walletobjects\\SetPassUpdateNoticeResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SetPassUpdateNoticeResponse.php',
    'Google\\Service\\Walletobjects\\SignUpInfo' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SignUpInfo.php',
    'Google\\Service\\Walletobjects\\SmartTap' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SmartTap.php',
    'Google\\Service\\Walletobjects\\SmartTapMerchantData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/SmartTapMerchantData.php',
    'Google\\Service\\Walletobjects\\TemplateItem' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TemplateItem.php',
    'Google\\Service\\Walletobjects\\TextModuleData' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TextModuleData.php',
    'Google\\Service\\Walletobjects\\TicketCost' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TicketCost.php',
    'Google\\Service\\Walletobjects\\TicketLeg' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TicketLeg.php',
    'Google\\Service\\Walletobjects\\TicketRestrictions' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TicketRestrictions.php',
    'Google\\Service\\Walletobjects\\TicketSeat' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TicketSeat.php',
    'Google\\Service\\Walletobjects\\TimeInterval' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TimeInterval.php',
    'Google\\Service\\Walletobjects\\TransitClass' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitClass.php',
    'Google\\Service\\Walletobjects\\TransitClassAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitClassAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\TransitClassListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitClassListResponse.php',
    'Google\\Service\\Walletobjects\\TransitObject' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitObject.php',
    'Google\\Service\\Walletobjects\\TransitObjectAddMessageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitObjectAddMessageResponse.php',
    'Google\\Service\\Walletobjects\\TransitObjectListResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitObjectListResponse.php',
    'Google\\Service\\Walletobjects\\TransitObjectUploadRotatingBarcodeValuesRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitObjectUploadRotatingBarcodeValuesRequest.php',
    'Google\\Service\\Walletobjects\\TransitObjectUploadRotatingBarcodeValuesResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TransitObjectUploadRotatingBarcodeValuesResponse.php',
    'Google\\Service\\Walletobjects\\TranslatedString' => $vendorDir . '/google/apiclient-services/src/Walletobjects/TranslatedString.php',
    'Google\\Service\\Walletobjects\\UpcomingNotification' => $vendorDir . '/google/apiclient-services/src/Walletobjects/UpcomingNotification.php',
    'Google\\Service\\Walletobjects\\UploadPrivateDataRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/UploadPrivateDataRequest.php',
    'Google\\Service\\Walletobjects\\UploadPrivateDataResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/UploadPrivateDataResponse.php',
    'Google\\Service\\Walletobjects\\UploadPrivateImageRequest' => $vendorDir . '/google/apiclient-services/src/Walletobjects/UploadPrivateImageRequest.php',
    'Google\\Service\\Walletobjects\\UploadPrivateImageResponse' => $vendorDir . '/google/apiclient-services/src/Walletobjects/UploadPrivateImageResponse.php',
    'Google\\Service\\Walletobjects\\Uri' => $vendorDir . '/google/apiclient-services/src/Walletobjects/Uri.php',
    'Google\\Service\\WebRisk' => $vendorDir . '/google/apiclient-services/src/WebRisk.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1ComputeThreatListDiffResponse' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1ComputeThreatListDiffResponse.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1ComputeThreatListDiffResponseChecksum' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1ComputeThreatListDiffResponseChecksum.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1RawHashes' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1RawHashes.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1RawIndices' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1RawIndices.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1RiceDeltaEncoding' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1RiceDeltaEncoding.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SearchHashesResponse' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SearchHashesResponse.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SearchHashesResponseThreatHash' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SearchHashesResponseThreatHash.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SearchUrisResponse' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SearchUrisResponse.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SearchUrisResponseThreatUri' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SearchUrisResponseThreatUri.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1Submission' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1Submission.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SubmitUriMetadata' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SubmitUriMetadata.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1SubmitUriRequest' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1SubmitUriRequest.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1ThreatEntryAdditions' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1ThreatEntryAdditions.php',
    'Google\\Service\\WebRisk\\GoogleCloudWebriskV1ThreatEntryRemovals' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleCloudWebriskV1ThreatEntryRemovals.php',
    'Google\\Service\\WebRisk\\GoogleLongrunningCancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleLongrunningCancelOperationRequest.php',
    'Google\\Service\\WebRisk\\GoogleLongrunningListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleLongrunningListOperationsResponse.php',
    'Google\\Service\\WebRisk\\GoogleLongrunningOperation' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleLongrunningOperation.php',
    'Google\\Service\\WebRisk\\GoogleProtobufEmpty' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleProtobufEmpty.php',
    'Google\\Service\\WebRisk\\GoogleRpcStatus' => $vendorDir . '/google/apiclient-services/src/WebRisk/GoogleRpcStatus.php',
    'Google\\Service\\WebRisk\\Resource\\Hashes' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/Hashes.php',
    'Google\\Service\\WebRisk\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/Projects.php',
    'Google\\Service\\WebRisk\\Resource\\ProjectsOperations' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/ProjectsOperations.php',
    'Google\\Service\\WebRisk\\Resource\\ProjectsSubmissions' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/ProjectsSubmissions.php',
    'Google\\Service\\WebRisk\\Resource\\ProjectsUris' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/ProjectsUris.php',
    'Google\\Service\\WebRisk\\Resource\\ThreatLists' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/ThreatLists.php',
    'Google\\Service\\WebRisk\\Resource\\Uris' => $vendorDir . '/google/apiclient-services/src/WebRisk/Resource/Uris.php',
    'Google\\Service\\Webfonts' => $vendorDir . '/google/apiclient-services/src/Webfonts.php',
    'Google\\Service\\Webfonts\\Axis' => $vendorDir . '/google/apiclient-services/src/Webfonts/Axis.php',
    'Google\\Service\\Webfonts\\Resource\\Webfonts' => $vendorDir . '/google/apiclient-services/src/Webfonts/Resource/Webfonts.php',
    'Google\\Service\\Webfonts\\Webfont' => $vendorDir . '/google/apiclient-services/src/Webfonts/Webfont.php',
    'Google\\Service\\Webfonts\\WebfontList' => $vendorDir . '/google/apiclient-services/src/Webfonts/WebfontList.php',
    'Google\\Service\\Webmasters' => $vendorDir . '/google/apiclient-services/src/Webmasters.php',
    'Google\\Service\\Webmasters\\ApiDataRow' => $vendorDir . '/google/apiclient-services/src/Webmasters/ApiDataRow.php',
    'Google\\Service\\Webmasters\\ApiDimensionFilter' => $vendorDir . '/google/apiclient-services/src/Webmasters/ApiDimensionFilter.php',
    'Google\\Service\\Webmasters\\ApiDimensionFilterGroup' => $vendorDir . '/google/apiclient-services/src/Webmasters/ApiDimensionFilterGroup.php',
    'Google\\Service\\Webmasters\\Resource\\Searchanalytics' => $vendorDir . '/google/apiclient-services/src/Webmasters/Resource/Searchanalytics.php',
    'Google\\Service\\Webmasters\\Resource\\Sitemaps' => $vendorDir . '/google/apiclient-services/src/Webmasters/Resource/Sitemaps.php',
    'Google\\Service\\Webmasters\\Resource\\Sites' => $vendorDir . '/google/apiclient-services/src/Webmasters/Resource/Sites.php',
    'Google\\Service\\Webmasters\\SearchAnalyticsQueryRequest' => $vendorDir . '/google/apiclient-services/src/Webmasters/SearchAnalyticsQueryRequest.php',
    'Google\\Service\\Webmasters\\SearchAnalyticsQueryResponse' => $vendorDir . '/google/apiclient-services/src/Webmasters/SearchAnalyticsQueryResponse.php',
    'Google\\Service\\Webmasters\\SitemapsListResponse' => $vendorDir . '/google/apiclient-services/src/Webmasters/SitemapsListResponse.php',
    'Google\\Service\\Webmasters\\SitesListResponse' => $vendorDir . '/google/apiclient-services/src/Webmasters/SitesListResponse.php',
    'Google\\Service\\Webmasters\\WmxSite' => $vendorDir . '/google/apiclient-services/src/Webmasters/WmxSite.php',
    'Google\\Service\\Webmasters\\WmxSitemap' => $vendorDir . '/google/apiclient-services/src/Webmasters/WmxSitemap.php',
    'Google\\Service\\Webmasters\\WmxSitemapContent' => $vendorDir . '/google/apiclient-services/src/Webmasters/WmxSitemapContent.php',
    'Google\\Service\\WorkflowExecutions' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions.php',
    'Google\\Service\\WorkflowExecutions\\Callback' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Callback.php',
    'Google\\Service\\WorkflowExecutions\\CancelExecutionRequest' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/CancelExecutionRequest.php',
    'Google\\Service\\WorkflowExecutions\\DeleteExecutionHistoryRequest' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/DeleteExecutionHistoryRequest.php',
    'Google\\Service\\WorkflowExecutions\\Error' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Error.php',
    'Google\\Service\\WorkflowExecutions\\Exception' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Exception.php',
    'Google\\Service\\WorkflowExecutions\\Execution' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Execution.php',
    'Google\\Service\\WorkflowExecutions\\ExportDataResponse' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/ExportDataResponse.php',
    'Google\\Service\\WorkflowExecutions\\ListCallbacksResponse' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/ListCallbacksResponse.php',
    'Google\\Service\\WorkflowExecutions\\ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/ListExecutionsResponse.php',
    'Google\\Service\\WorkflowExecutions\\ListStepEntriesResponse' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/ListStepEntriesResponse.php',
    'Google\\Service\\WorkflowExecutions\\NavigationInfo' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/NavigationInfo.php',
    'Google\\Service\\WorkflowExecutions\\Position' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Position.php',
    'Google\\Service\\WorkflowExecutions\\PubsubMessage' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/PubsubMessage.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/Projects.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/ProjectsLocations.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\ProjectsLocationsWorkflows' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/ProjectsLocationsWorkflows.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\ProjectsLocationsWorkflowsExecutions' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/ProjectsLocationsWorkflowsExecutions.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\ProjectsLocationsWorkflowsExecutionsCallbacks' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/ProjectsLocationsWorkflowsExecutionsCallbacks.php',
    'Google\\Service\\WorkflowExecutions\\Resource\\ProjectsLocationsWorkflowsExecutionsStepEntries' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Resource/ProjectsLocationsWorkflowsExecutionsStepEntries.php',
    'Google\\Service\\WorkflowExecutions\\StackTrace' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/StackTrace.php',
    'Google\\Service\\WorkflowExecutions\\StackTraceElement' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/StackTraceElement.php',
    'Google\\Service\\WorkflowExecutions\\StateError' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/StateError.php',
    'Google\\Service\\WorkflowExecutions\\Status' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Status.php',
    'Google\\Service\\WorkflowExecutions\\Step' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/Step.php',
    'Google\\Service\\WorkflowExecutions\\StepEntry' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/StepEntry.php',
    'Google\\Service\\WorkflowExecutions\\StepEntryMetadata' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/StepEntryMetadata.php',
    'Google\\Service\\WorkflowExecutions\\TriggerPubsubExecutionRequest' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/TriggerPubsubExecutionRequest.php',
    'Google\\Service\\WorkflowExecutions\\VariableData' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/VariableData.php',
    'Google\\Service\\WorkflowExecutions\\WorkflowexecutionsEmpty' => $vendorDir . '/google/apiclient-services/src/WorkflowExecutions/WorkflowexecutionsEmpty.php',
    'Google\\Service\\Workflows' => $vendorDir . '/google/apiclient-services/src/Workflows.php',
    'Google\\Service\\Workflows\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/Workflows/ListLocationsResponse.php',
    'Google\\Service\\Workflows\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/Workflows/ListOperationsResponse.php',
    'Google\\Service\\Workflows\\ListWorkflowRevisionsResponse' => $vendorDir . '/google/apiclient-services/src/Workflows/ListWorkflowRevisionsResponse.php',
    'Google\\Service\\Workflows\\ListWorkflowsResponse' => $vendorDir . '/google/apiclient-services/src/Workflows/ListWorkflowsResponse.php',
    'Google\\Service\\Workflows\\Location' => $vendorDir . '/google/apiclient-services/src/Workflows/Location.php',
    'Google\\Service\\Workflows\\Operation' => $vendorDir . '/google/apiclient-services/src/Workflows/Operation.php',
    'Google\\Service\\Workflows\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/Workflows/OperationMetadata.php',
    'Google\\Service\\Workflows\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/Workflows/Resource/Projects.php',
    'Google\\Service\\Workflows\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/Workflows/Resource/ProjectsLocations.php',
    'Google\\Service\\Workflows\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/Workflows/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\Workflows\\Resource\\ProjectsLocationsWorkflows' => $vendorDir . '/google/apiclient-services/src/Workflows/Resource/ProjectsLocationsWorkflows.php',
    'Google\\Service\\Workflows\\StateError' => $vendorDir . '/google/apiclient-services/src/Workflows/StateError.php',
    'Google\\Service\\Workflows\\Status' => $vendorDir . '/google/apiclient-services/src/Workflows/Status.php',
    'Google\\Service\\Workflows\\Workflow' => $vendorDir . '/google/apiclient-services/src/Workflows/Workflow.php',
    'Google\\Service\\Workflows\\WorkflowsEmpty' => $vendorDir . '/google/apiclient-services/src/Workflows/WorkflowsEmpty.php',
    'Google\\Service\\WorkloadManager' => $vendorDir . '/google/apiclient-services/src/WorkloadManager.php',
    'Google\\Service\\WorkloadManager\\APILayerServer' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/APILayerServer.php',
    'Google\\Service\\WorkloadManager\\AgentCommand' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/AgentCommand.php',
    'Google\\Service\\WorkloadManager\\AssetLocation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/AssetLocation.php',
    'Google\\Service\\WorkloadManager\\AvailabilityGroup' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/AvailabilityGroup.php',
    'Google\\Service\\WorkloadManager\\BackendServer' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/BackendServer.php',
    'Google\\Service\\WorkloadManager\\BigQueryDestination' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/BigQueryDestination.php',
    'Google\\Service\\WorkloadManager\\BlobstoreLocation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/BlobstoreLocation.php',
    'Google\\Service\\WorkloadManager\\CancelOperationRequest' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/CancelOperationRequest.php',
    'Google\\Service\\WorkloadManager\\CloudAsset' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/CloudAsset.php',
    'Google\\Service\\WorkloadManager\\CloudAssetComposition' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/CloudAssetComposition.php',
    'Google\\Service\\WorkloadManager\\CloudResource' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/CloudResource.php',
    'Google\\Service\\WorkloadManager\\Cluster' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Cluster.php',
    'Google\\Service\\WorkloadManager\\Command' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Command.php',
    'Google\\Service\\WorkloadManager\\Database' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Database.php',
    'Google\\Service\\WorkloadManager\\DirectLocationAssignment' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/DirectLocationAssignment.php',
    'Google\\Service\\WorkloadManager\\Evaluation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Evaluation.php',
    'Google\\Service\\WorkloadManager\\Execution' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Execution.php',
    'Google\\Service\\WorkloadManager\\ExecutionResult' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ExecutionResult.php',
    'Google\\Service\\WorkloadManager\\ExternalDataSources' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ExternalDataSources.php',
    'Google\\Service\\WorkloadManager\\ExtraParameter' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ExtraParameter.php',
    'Google\\Service\\WorkloadManager\\FrontEndServer' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/FrontEndServer.php',
    'Google\\Service\\WorkloadManager\\GceInstanceFilter' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/GceInstanceFilter.php',
    'Google\\Service\\WorkloadManager\\Insight' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Insight.php',
    'Google\\Service\\WorkloadManager\\Instance' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Instance.php',
    'Google\\Service\\WorkloadManager\\IsolationExpectations' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/IsolationExpectations.php',
    'Google\\Service\\WorkloadManager\\Layer' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Layer.php',
    'Google\\Service\\WorkloadManager\\ListEvaluationsResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListEvaluationsResponse.php',
    'Google\\Service\\WorkloadManager\\ListExecutionResultsResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListExecutionResultsResponse.php',
    'Google\\Service\\WorkloadManager\\ListExecutionsResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListExecutionsResponse.php',
    'Google\\Service\\WorkloadManager\\ListLocationsResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListLocationsResponse.php',
    'Google\\Service\\WorkloadManager\\ListOperationsResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListOperationsResponse.php',
    'Google\\Service\\WorkloadManager\\ListRulesResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListRulesResponse.php',
    'Google\\Service\\WorkloadManager\\ListScannedResourcesResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListScannedResourcesResponse.php',
    'Google\\Service\\WorkloadManager\\ListWorkloadProfilesResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ListWorkloadProfilesResponse.php',
    'Google\\Service\\WorkloadManager\\LoadBalancerServer' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/LoadBalancerServer.php',
    'Google\\Service\\WorkloadManager\\Location' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Location.php',
    'Google\\Service\\WorkloadManager\\LocationAssignment' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/LocationAssignment.php',
    'Google\\Service\\WorkloadManager\\LocationData' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/LocationData.php',
    'Google\\Service\\WorkloadManager\\Operation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Operation.php',
    'Google\\Service\\WorkloadManager\\OperationMetadata' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/OperationMetadata.php',
    'Google\\Service\\WorkloadManager\\PlacerLocation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/PlacerLocation.php',
    'Google\\Service\\WorkloadManager\\RegionalMigDistributionPolicy' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/RegionalMigDistributionPolicy.php',
    'Google\\Service\\WorkloadManager\\RequirementOverride' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/RequirementOverride.php',
    'Google\\Service\\WorkloadManager\\ResourceFilter' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ResourceFilter.php',
    'Google\\Service\\WorkloadManager\\ResourceStatus' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ResourceStatus.php',
    'Google\\Service\\WorkloadManager\\Resource\\Projects' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/Projects.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocations' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocations.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsEvaluations' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsEvaluations.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsEvaluationsExecutions' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsEvaluationsExecutions.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsEvaluationsExecutionsResults' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsEvaluationsExecutionsResults.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsEvaluationsExecutionsScannedResources' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsEvaluationsExecutionsScannedResources.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsInsights' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsInsights.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsOperations' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsOperations.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsRules' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsRules.php',
    'Google\\Service\\WorkloadManager\\Resource\\ProjectsLocationsWorkloadProfiles' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Resource/ProjectsLocationsWorkloadProfiles.php',
    'Google\\Service\\WorkloadManager\\Rule' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Rule.php',
    'Google\\Service\\WorkloadManager\\RunEvaluationRequest' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/RunEvaluationRequest.php',
    'Google\\Service\\WorkloadManager\\SapComponent' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapComponent.php',
    'Google\\Service\\WorkloadManager\\SapDiscovery' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscovery.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryComponent' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryComponent.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryComponentApplicationProperties' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryComponentApplicationProperties.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryComponentDatabaseProperties' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryComponentDatabaseProperties.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryMetadata' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryMetadata.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryResource' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryResource.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryResourceInstanceProperties' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryResourceInstanceProperties.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryResourceInstancePropertiesAppInstance' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryResourceInstancePropertiesAppInstance.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryWorkloadProperties' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryWorkloadProperties.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryWorkloadPropertiesProductVersion' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryWorkloadPropertiesProductVersion.php',
    'Google\\Service\\WorkloadManager\\SapDiscoveryWorkloadPropertiesSoftwareComponentProperties' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapDiscoveryWorkloadPropertiesSoftwareComponentProperties.php',
    'Google\\Service\\WorkloadManager\\SapValidation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapValidation.php',
    'Google\\Service\\WorkloadManager\\SapValidationValidationDetail' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapValidationValidationDetail.php',
    'Google\\Service\\WorkloadManager\\SapWorkload' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapWorkload.php',
    'Google\\Service\\WorkloadManager\\SapWorkloadOverview' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SapWorkloadOverview.php',
    'Google\\Service\\WorkloadManager\\ScannedResource' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ScannedResource.php',
    'Google\\Service\\WorkloadManager\\ShellCommand' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ShellCommand.php',
    'Google\\Service\\WorkloadManager\\SpannerLocation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SpannerLocation.php',
    'Google\\Service\\WorkloadManager\\SqlserverValidation' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SqlserverValidation.php',
    'Google\\Service\\WorkloadManager\\SqlserverValidationDetails' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SqlserverValidationDetails.php',
    'Google\\Service\\WorkloadManager\\SqlserverValidationValidationDetail' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SqlserverValidationValidationDetail.php',
    'Google\\Service\\WorkloadManager\\SqlserverWorkload' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SqlserverWorkload.php',
    'Google\\Service\\WorkloadManager\\SqlserverWorkloadOverview' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/SqlserverWorkloadOverview.php',
    'Google\\Service\\WorkloadManager\\Status' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/Status.php',
    'Google\\Service\\WorkloadManager\\TenantProjectProxy' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/TenantProjectProxy.php',
    'Google\\Service\\WorkloadManager\\ThreeTierWorkload' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ThreeTierWorkload.php',
    'Google\\Service\\WorkloadManager\\ThreeTierWorkloadOverview' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ThreeTierWorkloadOverview.php',
    'Google\\Service\\WorkloadManager\\ViolationDetails' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ViolationDetails.php',
    'Google\\Service\\WorkloadManager\\WorkloadProfile' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WorkloadProfile.php',
    'Google\\Service\\WorkloadManager\\WorkloadProfileOverview' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WorkloadProfileOverview.php',
    'Google\\Service\\WorkloadManager\\WorkloadmanagerEmpty' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WorkloadmanagerEmpty.php',
    'Google\\Service\\WorkloadManager\\WorkloadmanagerResource' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WorkloadmanagerResource.php',
    'Google\\Service\\WorkloadManager\\WriteInsightRequest' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WriteInsightRequest.php',
    'Google\\Service\\WorkloadManager\\WriteInsightResponse' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/WriteInsightResponse.php',
    'Google\\Service\\WorkloadManager\\ZoneConfiguration' => $vendorDir . '/google/apiclient-services/src/WorkloadManager/ZoneConfiguration.php',
    'Google\\Service\\WorkspaceEvents' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents.php',
    'Google\\Service\\WorkspaceEvents\\ListSubscriptionsResponse' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/ListSubscriptionsResponse.php',
    'Google\\Service\\WorkspaceEvents\\NotificationEndpoint' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/NotificationEndpoint.php',
    'Google\\Service\\WorkspaceEvents\\Operation' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/Operation.php',
    'Google\\Service\\WorkspaceEvents\\PayloadOptions' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/PayloadOptions.php',
    'Google\\Service\\WorkspaceEvents\\ReactivateSubscriptionRequest' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/ReactivateSubscriptionRequest.php',
    'Google\\Service\\WorkspaceEvents\\Resource\\Operations' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/Resource/Operations.php',
    'Google\\Service\\WorkspaceEvents\\Resource\\Subscriptions' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/Resource/Subscriptions.php',
    'Google\\Service\\WorkspaceEvents\\Status' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/Status.php',
    'Google\\Service\\WorkspaceEvents\\Subscription' => $vendorDir . '/google/apiclient-services/src/WorkspaceEvents/Subscription.php',
    'Google\\Service\\YouTube' => $vendorDir . '/google/apiclient-services/src/YouTube.php',
    'Google\\Service\\YouTubeAnalytics' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics.php',
    'Google\\Service\\YouTubeAnalytics\\EmptyResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/EmptyResponse.php',
    'Google\\Service\\YouTubeAnalytics\\ErrorProto' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/ErrorProto.php',
    'Google\\Service\\YouTubeAnalytics\\Errors' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/Errors.php',
    'Google\\Service\\YouTubeAnalytics\\Group' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/Group.php',
    'Google\\Service\\YouTubeAnalytics\\GroupContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/GroupContentDetails.php',
    'Google\\Service\\YouTubeAnalytics\\GroupItem' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/GroupItem.php',
    'Google\\Service\\YouTubeAnalytics\\GroupItemResource' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/GroupItemResource.php',
    'Google\\Service\\YouTubeAnalytics\\GroupSnippet' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/GroupSnippet.php',
    'Google\\Service\\YouTubeAnalytics\\ListGroupItemsResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/ListGroupItemsResponse.php',
    'Google\\Service\\YouTubeAnalytics\\ListGroupsResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/ListGroupsResponse.php',
    'Google\\Service\\YouTubeAnalytics\\QueryResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/QueryResponse.php',
    'Google\\Service\\YouTubeAnalytics\\Resource\\GroupItems' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/Resource/GroupItems.php',
    'Google\\Service\\YouTubeAnalytics\\Resource\\Groups' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/Resource/Groups.php',
    'Google\\Service\\YouTubeAnalytics\\Resource\\Reports' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/Resource/Reports.php',
    'Google\\Service\\YouTubeAnalytics\\ResultTableColumnHeader' => $vendorDir . '/google/apiclient-services/src/YouTubeAnalytics/ResultTableColumnHeader.php',
    'Google\\Service\\YouTubeReporting' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting.php',
    'Google\\Service\\YouTubeReporting\\GdataBlobstore2Info' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataBlobstore2Info.php',
    'Google\\Service\\YouTubeReporting\\GdataCompositeMedia' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataCompositeMedia.php',
    'Google\\Service\\YouTubeReporting\\GdataContentTypeInfo' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataContentTypeInfo.php',
    'Google\\Service\\YouTubeReporting\\GdataDiffChecksumsResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDiffChecksumsResponse.php',
    'Google\\Service\\YouTubeReporting\\GdataDiffDownloadResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDiffDownloadResponse.php',
    'Google\\Service\\YouTubeReporting\\GdataDiffUploadRequest' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDiffUploadRequest.php',
    'Google\\Service\\YouTubeReporting\\GdataDiffUploadResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDiffUploadResponse.php',
    'Google\\Service\\YouTubeReporting\\GdataDiffVersionResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDiffVersionResponse.php',
    'Google\\Service\\YouTubeReporting\\GdataDownloadParameters' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataDownloadParameters.php',
    'Google\\Service\\YouTubeReporting\\GdataMedia' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataMedia.php',
    'Google\\Service\\YouTubeReporting\\GdataObjectId' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/GdataObjectId.php',
    'Google\\Service\\YouTubeReporting\\Job' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Job.php',
    'Google\\Service\\YouTubeReporting\\ListJobsResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/ListJobsResponse.php',
    'Google\\Service\\YouTubeReporting\\ListReportTypesResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/ListReportTypesResponse.php',
    'Google\\Service\\YouTubeReporting\\ListReportsResponse' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/ListReportsResponse.php',
    'Google\\Service\\YouTubeReporting\\Report' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Report.php',
    'Google\\Service\\YouTubeReporting\\ReportType' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/ReportType.php',
    'Google\\Service\\YouTubeReporting\\Resource\\Jobs' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Resource/Jobs.php',
    'Google\\Service\\YouTubeReporting\\Resource\\JobsReports' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Resource/JobsReports.php',
    'Google\\Service\\YouTubeReporting\\Resource\\Media' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Resource/Media.php',
    'Google\\Service\\YouTubeReporting\\Resource\\ReportTypes' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/Resource/ReportTypes.php',
    'Google\\Service\\YouTubeReporting\\YoutubereportingEmpty' => $vendorDir . '/google/apiclient-services/src/YouTubeReporting/YoutubereportingEmpty.php',
    'Google\\Service\\YouTube\\AbuseReport' => $vendorDir . '/google/apiclient-services/src/YouTube/AbuseReport.php',
    'Google\\Service\\YouTube\\AbuseType' => $vendorDir . '/google/apiclient-services/src/YouTube/AbuseType.php',
    'Google\\Service\\YouTube\\AccessPolicy' => $vendorDir . '/google/apiclient-services/src/YouTube/AccessPolicy.php',
    'Google\\Service\\YouTube\\Activity' => $vendorDir . '/google/apiclient-services/src/YouTube/Activity.php',
    'Google\\Service\\YouTube\\ActivityContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetails.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsBulletin' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsBulletin.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsChannelItem' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsChannelItem.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsComment' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsComment.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsFavorite' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsFavorite.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsLike' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsLike.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsPlaylistItem' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsPlaylistItem.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsPromotedItem' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsPromotedItem.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsRecommendation' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsRecommendation.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsSocial' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsSocial.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsSubscription' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsSubscription.php',
    'Google\\Service\\YouTube\\ActivityContentDetailsUpload' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityContentDetailsUpload.php',
    'Google\\Service\\YouTube\\ActivityListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivityListResponse.php',
    'Google\\Service\\YouTube\\ActivitySnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/ActivitySnippet.php',
    'Google\\Service\\YouTube\\Caption' => $vendorDir . '/google/apiclient-services/src/YouTube/Caption.php',
    'Google\\Service\\YouTube\\CaptionListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/CaptionListResponse.php',
    'Google\\Service\\YouTube\\CaptionSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/CaptionSnippet.php',
    'Google\\Service\\YouTube\\CdnSettings' => $vendorDir . '/google/apiclient-services/src/YouTube/CdnSettings.php',
    'Google\\Service\\YouTube\\Channel' => $vendorDir . '/google/apiclient-services/src/YouTube/Channel.php',
    'Google\\Service\\YouTube\\ChannelAuditDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelAuditDetails.php',
    'Google\\Service\\YouTube\\ChannelBannerResource' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelBannerResource.php',
    'Google\\Service\\YouTube\\ChannelBrandingSettings' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelBrandingSettings.php',
    'Google\\Service\\YouTube\\ChannelContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelContentDetails.php',
    'Google\\Service\\YouTube\\ChannelContentDetailsRelatedPlaylists' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelContentDetailsRelatedPlaylists.php',
    'Google\\Service\\YouTube\\ChannelContentOwnerDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelContentOwnerDetails.php',
    'Google\\Service\\YouTube\\ChannelConversionPing' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelConversionPing.php',
    'Google\\Service\\YouTube\\ChannelConversionPings' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelConversionPings.php',
    'Google\\Service\\YouTube\\ChannelListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelListResponse.php',
    'Google\\Service\\YouTube\\ChannelLocalization' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelLocalization.php',
    'Google\\Service\\YouTube\\ChannelProfileDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelProfileDetails.php',
    'Google\\Service\\YouTube\\ChannelSection' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSection.php',
    'Google\\Service\\YouTube\\ChannelSectionContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSectionContentDetails.php',
    'Google\\Service\\YouTube\\ChannelSectionListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSectionListResponse.php',
    'Google\\Service\\YouTube\\ChannelSectionLocalization' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSectionLocalization.php',
    'Google\\Service\\YouTube\\ChannelSectionSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSectionSnippet.php',
    'Google\\Service\\YouTube\\ChannelSectionTargeting' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSectionTargeting.php',
    'Google\\Service\\YouTube\\ChannelSettings' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSettings.php',
    'Google\\Service\\YouTube\\ChannelSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelSnippet.php',
    'Google\\Service\\YouTube\\ChannelStatistics' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelStatistics.php',
    'Google\\Service\\YouTube\\ChannelStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelStatus.php',
    'Google\\Service\\YouTube\\ChannelToStoreLinkDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelToStoreLinkDetails.php',
    'Google\\Service\\YouTube\\ChannelToStoreLinkDetailsBillingDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelToStoreLinkDetailsBillingDetails.php',
    'Google\\Service\\YouTube\\ChannelTopicDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ChannelTopicDetails.php',
    'Google\\Service\\YouTube\\Comment' => $vendorDir . '/google/apiclient-services/src/YouTube/Comment.php',
    'Google\\Service\\YouTube\\CommentListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentListResponse.php',
    'Google\\Service\\YouTube\\CommentSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentSnippet.php',
    'Google\\Service\\YouTube\\CommentSnippetAuthorChannelId' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentSnippetAuthorChannelId.php',
    'Google\\Service\\YouTube\\CommentThread' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentThread.php',
    'Google\\Service\\YouTube\\CommentThreadListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentThreadListResponse.php',
    'Google\\Service\\YouTube\\CommentThreadReplies' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentThreadReplies.php',
    'Google\\Service\\YouTube\\CommentThreadSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/CommentThreadSnippet.php',
    'Google\\Service\\YouTube\\ContentRating' => $vendorDir . '/google/apiclient-services/src/YouTube/ContentRating.php',
    'Google\\Service\\YouTube\\Cuepoint' => $vendorDir . '/google/apiclient-services/src/YouTube/Cuepoint.php',
    'Google\\Service\\YouTube\\CuepointSchedule' => $vendorDir . '/google/apiclient-services/src/YouTube/CuepointSchedule.php',
    'Google\\Service\\YouTube\\Entity' => $vendorDir . '/google/apiclient-services/src/YouTube/Entity.php',
    'Google\\Service\\YouTube\\GeoPoint' => $vendorDir . '/google/apiclient-services/src/YouTube/GeoPoint.php',
    'Google\\Service\\YouTube\\I18nLanguage' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nLanguage.php',
    'Google\\Service\\YouTube\\I18nLanguageListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nLanguageListResponse.php',
    'Google\\Service\\YouTube\\I18nLanguageSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nLanguageSnippet.php',
    'Google\\Service\\YouTube\\I18nRegion' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nRegion.php',
    'Google\\Service\\YouTube\\I18nRegionListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nRegionListResponse.php',
    'Google\\Service\\YouTube\\I18nRegionSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/I18nRegionSnippet.php',
    'Google\\Service\\YouTube\\ImageSettings' => $vendorDir . '/google/apiclient-services/src/YouTube/ImageSettings.php',
    'Google\\Service\\YouTube\\IngestionInfo' => $vendorDir . '/google/apiclient-services/src/YouTube/IngestionInfo.php',
    'Google\\Service\\YouTube\\InvideoBranding' => $vendorDir . '/google/apiclient-services/src/YouTube/InvideoBranding.php',
    'Google\\Service\\YouTube\\InvideoPosition' => $vendorDir . '/google/apiclient-services/src/YouTube/InvideoPosition.php',
    'Google\\Service\\YouTube\\InvideoTiming' => $vendorDir . '/google/apiclient-services/src/YouTube/InvideoTiming.php',
    'Google\\Service\\YouTube\\LanguageTag' => $vendorDir . '/google/apiclient-services/src/YouTube/LanguageTag.php',
    'Google\\Service\\YouTube\\LevelDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LevelDetails.php',
    'Google\\Service\\YouTube\\LiveBroadcast' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcast.php',
    'Google\\Service\\YouTube\\LiveBroadcastContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastContentDetails.php',
    'Google\\Service\\YouTube\\LiveBroadcastListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastListResponse.php',
    'Google\\Service\\YouTube\\LiveBroadcastMonetizationDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastMonetizationDetails.php',
    'Google\\Service\\YouTube\\LiveBroadcastSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastSnippet.php',
    'Google\\Service\\YouTube\\LiveBroadcastStatistics' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastStatistics.php',
    'Google\\Service\\YouTube\\LiveBroadcastStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveBroadcastStatus.php',
    'Google\\Service\\YouTube\\LiveChatBan' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatBan.php',
    'Google\\Service\\YouTube\\LiveChatBanSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatBanSnippet.php',
    'Google\\Service\\YouTube\\LiveChatFanFundingEventDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatFanFundingEventDetails.php',
    'Google\\Service\\YouTube\\LiveChatGiftMembershipReceivedDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatGiftMembershipReceivedDetails.php',
    'Google\\Service\\YouTube\\LiveChatMemberMilestoneChatDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMemberMilestoneChatDetails.php',
    'Google\\Service\\YouTube\\LiveChatMembershipGiftingDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMembershipGiftingDetails.php',
    'Google\\Service\\YouTube\\LiveChatMessage' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessage.php',
    'Google\\Service\\YouTube\\LiveChatMessageAuthorDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessageAuthorDetails.php',
    'Google\\Service\\YouTube\\LiveChatMessageDeletedDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessageDeletedDetails.php',
    'Google\\Service\\YouTube\\LiveChatMessageListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessageListResponse.php',
    'Google\\Service\\YouTube\\LiveChatMessageRetractedDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessageRetractedDetails.php',
    'Google\\Service\\YouTube\\LiveChatMessageSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatMessageSnippet.php',
    'Google\\Service\\YouTube\\LiveChatModerator' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatModerator.php',
    'Google\\Service\\YouTube\\LiveChatModeratorListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatModeratorListResponse.php',
    'Google\\Service\\YouTube\\LiveChatModeratorSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatModeratorSnippet.php',
    'Google\\Service\\YouTube\\LiveChatNewSponsorDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatNewSponsorDetails.php',
    'Google\\Service\\YouTube\\LiveChatPollDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatPollDetails.php',
    'Google\\Service\\YouTube\\LiveChatPollDetailsPollMetadata' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatPollDetailsPollMetadata.php',
    'Google\\Service\\YouTube\\LiveChatPollDetailsPollMetadataPollOption' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatPollDetailsPollMetadataPollOption.php',
    'Google\\Service\\YouTube\\LiveChatSuperChatDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatSuperChatDetails.php',
    'Google\\Service\\YouTube\\LiveChatSuperStickerDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatSuperStickerDetails.php',
    'Google\\Service\\YouTube\\LiveChatTextMessageDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatTextMessageDetails.php',
    'Google\\Service\\YouTube\\LiveChatUserBannedMessageDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveChatUserBannedMessageDetails.php',
    'Google\\Service\\YouTube\\LiveStream' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStream.php',
    'Google\\Service\\YouTube\\LiveStreamConfigurationIssue' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamConfigurationIssue.php',
    'Google\\Service\\YouTube\\LiveStreamContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamContentDetails.php',
    'Google\\Service\\YouTube\\LiveStreamHealthStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamHealthStatus.php',
    'Google\\Service\\YouTube\\LiveStreamListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamListResponse.php',
    'Google\\Service\\YouTube\\LiveStreamSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamSnippet.php',
    'Google\\Service\\YouTube\\LiveStreamStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/LiveStreamStatus.php',
    'Google\\Service\\YouTube\\LocalizedProperty' => $vendorDir . '/google/apiclient-services/src/YouTube/LocalizedProperty.php',
    'Google\\Service\\YouTube\\LocalizedString' => $vendorDir . '/google/apiclient-services/src/YouTube/LocalizedString.php',
    'Google\\Service\\YouTube\\Member' => $vendorDir . '/google/apiclient-services/src/YouTube/Member.php',
    'Google\\Service\\YouTube\\MemberListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/MemberListResponse.php',
    'Google\\Service\\YouTube\\MemberSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/MemberSnippet.php',
    'Google\\Service\\YouTube\\MembershipsDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsDetails.php',
    'Google\\Service\\YouTube\\MembershipsDuration' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsDuration.php',
    'Google\\Service\\YouTube\\MembershipsDurationAtLevel' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsDurationAtLevel.php',
    'Google\\Service\\YouTube\\MembershipsLevel' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsLevel.php',
    'Google\\Service\\YouTube\\MembershipsLevelListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsLevelListResponse.php',
    'Google\\Service\\YouTube\\MembershipsLevelSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/MembershipsLevelSnippet.php',
    'Google\\Service\\YouTube\\MonitorStreamInfo' => $vendorDir . '/google/apiclient-services/src/YouTube/MonitorStreamInfo.php',
    'Google\\Service\\YouTube\\PageInfo' => $vendorDir . '/google/apiclient-services/src/YouTube/PageInfo.php',
    'Google\\Service\\YouTube\\Playlist' => $vendorDir . '/google/apiclient-services/src/YouTube/Playlist.php',
    'Google\\Service\\YouTube\\PlaylistContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistContentDetails.php',
    'Google\\Service\\YouTube\\PlaylistImage' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistImage.php',
    'Google\\Service\\YouTube\\PlaylistImageListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistImageListResponse.php',
    'Google\\Service\\YouTube\\PlaylistImageSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistImageSnippet.php',
    'Google\\Service\\YouTube\\PlaylistItem' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistItem.php',
    'Google\\Service\\YouTube\\PlaylistItemContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistItemContentDetails.php',
    'Google\\Service\\YouTube\\PlaylistItemListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistItemListResponse.php',
    'Google\\Service\\YouTube\\PlaylistItemSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistItemSnippet.php',
    'Google\\Service\\YouTube\\PlaylistItemStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistItemStatus.php',
    'Google\\Service\\YouTube\\PlaylistListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistListResponse.php',
    'Google\\Service\\YouTube\\PlaylistLocalization' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistLocalization.php',
    'Google\\Service\\YouTube\\PlaylistPlayer' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistPlayer.php',
    'Google\\Service\\YouTube\\PlaylistSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistSnippet.php',
    'Google\\Service\\YouTube\\PlaylistStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/PlaylistStatus.php',
    'Google\\Service\\YouTube\\PropertyValue' => $vendorDir . '/google/apiclient-services/src/YouTube/PropertyValue.php',
    'Google\\Service\\YouTube\\RelatedEntity' => $vendorDir . '/google/apiclient-services/src/YouTube/RelatedEntity.php',
    'Google\\Service\\YouTube\\ResourceId' => $vendorDir . '/google/apiclient-services/src/YouTube/ResourceId.php',
    'Google\\Service\\YouTube\\Resource\\AbuseReports' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/AbuseReports.php',
    'Google\\Service\\YouTube\\Resource\\Activities' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Activities.php',
    'Google\\Service\\YouTube\\Resource\\Captions' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Captions.php',
    'Google\\Service\\YouTube\\Resource\\ChannelBanners' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/ChannelBanners.php',
    'Google\\Service\\YouTube\\Resource\\ChannelSections' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/ChannelSections.php',
    'Google\\Service\\YouTube\\Resource\\Channels' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Channels.php',
    'Google\\Service\\YouTube\\Resource\\CommentThreads' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/CommentThreads.php',
    'Google\\Service\\YouTube\\Resource\\Comments' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Comments.php',
    'Google\\Service\\YouTube\\Resource\\I18nLanguages' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/I18nLanguages.php',
    'Google\\Service\\YouTube\\Resource\\I18nRegions' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/I18nRegions.php',
    'Google\\Service\\YouTube\\Resource\\LiveBroadcasts' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/LiveBroadcasts.php',
    'Google\\Service\\YouTube\\Resource\\LiveChatBans' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/LiveChatBans.php',
    'Google\\Service\\YouTube\\Resource\\LiveChatMessages' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/LiveChatMessages.php',
    'Google\\Service\\YouTube\\Resource\\LiveChatModerators' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/LiveChatModerators.php',
    'Google\\Service\\YouTube\\Resource\\LiveStreams' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/LiveStreams.php',
    'Google\\Service\\YouTube\\Resource\\Members' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Members.php',
    'Google\\Service\\YouTube\\Resource\\MembershipsLevels' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/MembershipsLevels.php',
    'Google\\Service\\YouTube\\Resource\\PlaylistImages' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/PlaylistImages.php',
    'Google\\Service\\YouTube\\Resource\\PlaylistItems' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/PlaylistItems.php',
    'Google\\Service\\YouTube\\Resource\\Playlists' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Playlists.php',
    'Google\\Service\\YouTube\\Resource\\Search' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Search.php',
    'Google\\Service\\YouTube\\Resource\\Subscriptions' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Subscriptions.php',
    'Google\\Service\\YouTube\\Resource\\SuperChatEvents' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/SuperChatEvents.php',
    'Google\\Service\\YouTube\\Resource\\Tests' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Tests.php',
    'Google\\Service\\YouTube\\Resource\\ThirdPartyLinks' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/ThirdPartyLinks.php',
    'Google\\Service\\YouTube\\Resource\\Thumbnails' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Thumbnails.php',
    'Google\\Service\\YouTube\\Resource\\VideoAbuseReportReasons' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/VideoAbuseReportReasons.php',
    'Google\\Service\\YouTube\\Resource\\VideoCategories' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/VideoCategories.php',
    'Google\\Service\\YouTube\\Resource\\Videos' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Videos.php',
    'Google\\Service\\YouTube\\Resource\\Watermarks' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Watermarks.php',
    'Google\\Service\\YouTube\\Resource\\Youtube' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/Youtube.php',
    'Google\\Service\\YouTube\\Resource\\YoutubeV3' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/YoutubeV3.php',
    'Google\\Service\\YouTube\\Resource\\YoutubeV3LiveBroadcasts' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/YoutubeV3LiveBroadcasts.php',
    'Google\\Service\\YouTube\\Resource\\YoutubeV3LiveBroadcastsCuepoint' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/YoutubeV3LiveBroadcastsCuepoint.php',
    'Google\\Service\\YouTube\\Resource\\YoutubeV3LiveChat' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/YoutubeV3LiveChat.php',
    'Google\\Service\\YouTube\\Resource\\YoutubeV3LiveChatMessages' => $vendorDir . '/google/apiclient-services/src/YouTube/Resource/YoutubeV3LiveChatMessages.php',
    'Google\\Service\\YouTube\\SearchListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/SearchListResponse.php',
    'Google\\Service\\YouTube\\SearchResult' => $vendorDir . '/google/apiclient-services/src/YouTube/SearchResult.php',
    'Google\\Service\\YouTube\\SearchResultSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/SearchResultSnippet.php',
    'Google\\Service\\YouTube\\Subscription' => $vendorDir . '/google/apiclient-services/src/YouTube/Subscription.php',
    'Google\\Service\\YouTube\\SubscriptionContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/SubscriptionContentDetails.php',
    'Google\\Service\\YouTube\\SubscriptionListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/SubscriptionListResponse.php',
    'Google\\Service\\YouTube\\SubscriptionSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/SubscriptionSnippet.php',
    'Google\\Service\\YouTube\\SubscriptionSubscriberSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/SubscriptionSubscriberSnippet.php',
    'Google\\Service\\YouTube\\SuperChatEvent' => $vendorDir . '/google/apiclient-services/src/YouTube/SuperChatEvent.php',
    'Google\\Service\\YouTube\\SuperChatEventListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/SuperChatEventListResponse.php',
    'Google\\Service\\YouTube\\SuperChatEventSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/SuperChatEventSnippet.php',
    'Google\\Service\\YouTube\\SuperStickerMetadata' => $vendorDir . '/google/apiclient-services/src/YouTube/SuperStickerMetadata.php',
    'Google\\Service\\YouTube\\TestItem' => $vendorDir . '/google/apiclient-services/src/YouTube/TestItem.php',
    'Google\\Service\\YouTube\\TestItemTestItemSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/TestItemTestItemSnippet.php',
    'Google\\Service\\YouTube\\ThirdPartyLink' => $vendorDir . '/google/apiclient-services/src/YouTube/ThirdPartyLink.php',
    'Google\\Service\\YouTube\\ThirdPartyLinkListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/ThirdPartyLinkListResponse.php',
    'Google\\Service\\YouTube\\ThirdPartyLinkSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/ThirdPartyLinkSnippet.php',
    'Google\\Service\\YouTube\\ThirdPartyLinkStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/ThirdPartyLinkStatus.php',
    'Google\\Service\\YouTube\\Thumbnail' => $vendorDir . '/google/apiclient-services/src/YouTube/Thumbnail.php',
    'Google\\Service\\YouTube\\ThumbnailDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/ThumbnailDetails.php',
    'Google\\Service\\YouTube\\ThumbnailSetResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/ThumbnailSetResponse.php',
    'Google\\Service\\YouTube\\TokenPagination' => $vendorDir . '/google/apiclient-services/src/YouTube/TokenPagination.php',
    'Google\\Service\\YouTube\\Video' => $vendorDir . '/google/apiclient-services/src/YouTube/Video.php',
    'Google\\Service\\YouTube\\VideoAbuseReport' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAbuseReport.php',
    'Google\\Service\\YouTube\\VideoAbuseReportReason' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAbuseReportReason.php',
    'Google\\Service\\YouTube\\VideoAbuseReportReasonListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAbuseReportReasonListResponse.php',
    'Google\\Service\\YouTube\\VideoAbuseReportReasonSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAbuseReportReasonSnippet.php',
    'Google\\Service\\YouTube\\VideoAbuseReportSecondaryReason' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAbuseReportSecondaryReason.php',
    'Google\\Service\\YouTube\\VideoAgeGating' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoAgeGating.php',
    'Google\\Service\\YouTube\\VideoCategory' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoCategory.php',
    'Google\\Service\\YouTube\\VideoCategoryListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoCategoryListResponse.php',
    'Google\\Service\\YouTube\\VideoCategorySnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoCategorySnippet.php',
    'Google\\Service\\YouTube\\VideoContentDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoContentDetails.php',
    'Google\\Service\\YouTube\\VideoContentDetailsRegionRestriction' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoContentDetailsRegionRestriction.php',
    'Google\\Service\\YouTube\\VideoFileDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoFileDetails.php',
    'Google\\Service\\YouTube\\VideoFileDetailsAudioStream' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoFileDetailsAudioStream.php',
    'Google\\Service\\YouTube\\VideoFileDetailsVideoStream' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoFileDetailsVideoStream.php',
    'Google\\Service\\YouTube\\VideoGetRatingResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoGetRatingResponse.php',
    'Google\\Service\\YouTube\\VideoListResponse' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoListResponse.php',
    'Google\\Service\\YouTube\\VideoLiveStreamingDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoLiveStreamingDetails.php',
    'Google\\Service\\YouTube\\VideoLocalization' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoLocalization.php',
    'Google\\Service\\YouTube\\VideoMonetizationDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoMonetizationDetails.php',
    'Google\\Service\\YouTube\\VideoPlayer' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoPlayer.php',
    'Google\\Service\\YouTube\\VideoProcessingDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoProcessingDetails.php',
    'Google\\Service\\YouTube\\VideoProcessingDetailsProcessingProgress' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoProcessingDetailsProcessingProgress.php',
    'Google\\Service\\YouTube\\VideoProjectDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoProjectDetails.php',
    'Google\\Service\\YouTube\\VideoRating' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoRating.php',
    'Google\\Service\\YouTube\\VideoRecordingDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoRecordingDetails.php',
    'Google\\Service\\YouTube\\VideoSnippet' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoSnippet.php',
    'Google\\Service\\YouTube\\VideoStatistics' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoStatistics.php',
    'Google\\Service\\YouTube\\VideoStatus' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoStatus.php',
    'Google\\Service\\YouTube\\VideoSuggestions' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoSuggestions.php',
    'Google\\Service\\YouTube\\VideoSuggestionsTagSuggestion' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoSuggestionsTagSuggestion.php',
    'Google\\Service\\YouTube\\VideoTopicDetails' => $vendorDir . '/google/apiclient-services/src/YouTube/VideoTopicDetails.php',
    'Google\\Service\\YouTube\\WatchSettings' => $vendorDir . '/google/apiclient-services/src/YouTube/WatchSettings.php',
    'Google\\Task\\Composer' => $vendorDir . '/google/apiclient/src/Task/Composer.php',
    'Google\\Task\\Exception' => $vendorDir . '/google/apiclient/src/Task/Exception.php',
    'Google\\Task\\Retryable' => $vendorDir . '/google/apiclient/src/Task/Retryable.php',
    'Google\\Task\\Runner' => $vendorDir . '/google/apiclient/src/Task/Runner.php',
    'Google\\Utils\\UriTemplate' => $vendorDir . '/google/apiclient/src/Utils/UriTemplate.php',
    'Google_AccessToken_Revoke' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_AccessToken_Verify' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_AuthHandler_AuthHandlerFactory' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_AuthHandler_Guzzle6AuthHandler' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_AuthHandler_Guzzle7AuthHandler' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Client' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Collection' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Exception' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Http_Batch' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Http_MediaFileUpload' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Http_REST' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Model' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Service' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Service_Exception' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Service_Resource' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Task_Composer' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Task_Exception' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Task_Retryable' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Task_Runner' => $vendorDir . '/google/apiclient/src/aliases.php',
    'Google_Utils_UriTemplate' => $vendorDir . '/google/apiclient/src/aliases.php',
    'GrahamCampbell\\ResultType\\Error' => $vendorDir . '/graham-campbell/result-type/src/Error.php',
    'GrahamCampbell\\ResultType\\Result' => $vendorDir . '/graham-campbell/result-type/src/Result.php',
    'GrahamCampbell\\ResultType\\Success' => $vendorDir . '/graham-campbell/result-type/src/Success.php',
    'GuzzleHttp\\BodySummarizer' => $vendorDir . '/guzzlehttp/guzzle/src/BodySummarizer.php',
    'GuzzleHttp\\BodySummarizerInterface' => $vendorDir . '/guzzlehttp/guzzle/src/BodySummarizerInterface.php',
    'GuzzleHttp\\Client' => $vendorDir . '/guzzlehttp/guzzle/src/Client.php',
    'GuzzleHttp\\ClientInterface' => $vendorDir . '/guzzlehttp/guzzle/src/ClientInterface.php',
    'GuzzleHttp\\ClientTrait' => $vendorDir . '/guzzlehttp/guzzle/src/ClientTrait.php',
    'GuzzleHttp\\Cookie\\CookieJar' => $vendorDir . '/guzzlehttp/guzzle/src/Cookie/CookieJar.php',
    'GuzzleHttp\\Cookie\\CookieJarInterface' => $vendorDir . '/guzzlehttp/guzzle/src/Cookie/CookieJarInterface.php',
    'GuzzleHttp\\Cookie\\FileCookieJar' => $vendorDir . '/guzzlehttp/guzzle/src/Cookie/FileCookieJar.php',
    'GuzzleHttp\\Cookie\\SessionCookieJar' => $vendorDir . '/guzzlehttp/guzzle/src/Cookie/SessionCookieJar.php',
    'GuzzleHttp\\Cookie\\SetCookie' => $vendorDir . '/guzzlehttp/guzzle/src/Cookie/SetCookie.php',
    'GuzzleHttp\\Exception\\BadResponseException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/BadResponseException.php',
    'GuzzleHttp\\Exception\\ClientException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/ClientException.php',
    'GuzzleHttp\\Exception\\ConnectException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/ConnectException.php',
    'GuzzleHttp\\Exception\\GuzzleException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/GuzzleException.php',
    'GuzzleHttp\\Exception\\InvalidArgumentException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/InvalidArgumentException.php',
    'GuzzleHttp\\Exception\\RequestException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/RequestException.php',
    'GuzzleHttp\\Exception\\ServerException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/ServerException.php',
    'GuzzleHttp\\Exception\\TooManyRedirectsException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/TooManyRedirectsException.php',
    'GuzzleHttp\\Exception\\TransferException' => $vendorDir . '/guzzlehttp/guzzle/src/Exception/TransferException.php',
    'GuzzleHttp\\HandlerStack' => $vendorDir . '/guzzlehttp/guzzle/src/HandlerStack.php',
    'GuzzleHttp\\Handler\\CurlFactory' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/CurlFactory.php',
    'GuzzleHttp\\Handler\\CurlFactoryInterface' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/CurlFactoryInterface.php',
    'GuzzleHttp\\Handler\\CurlHandler' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/CurlHandler.php',
    'GuzzleHttp\\Handler\\CurlMultiHandler' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/CurlMultiHandler.php',
    'GuzzleHttp\\Handler\\EasyHandle' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/EasyHandle.php',
    'GuzzleHttp\\Handler\\HeaderProcessor' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/HeaderProcessor.php',
    'GuzzleHttp\\Handler\\MockHandler' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/MockHandler.php',
    'GuzzleHttp\\Handler\\Proxy' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/Proxy.php',
    'GuzzleHttp\\Handler\\StreamHandler' => $vendorDir . '/guzzlehttp/guzzle/src/Handler/StreamHandler.php',
    'GuzzleHttp\\MessageFormatter' => $vendorDir . '/guzzlehttp/guzzle/src/MessageFormatter.php',
    'GuzzleHttp\\MessageFormatterInterface' => $vendorDir . '/guzzlehttp/guzzle/src/MessageFormatterInterface.php',
    'GuzzleHttp\\Middleware' => $vendorDir . '/guzzlehttp/guzzle/src/Middleware.php',
    'GuzzleHttp\\Pool' => $vendorDir . '/guzzlehttp/guzzle/src/Pool.php',
    'GuzzleHttp\\PrepareBodyMiddleware' => $vendorDir . '/guzzlehttp/guzzle/src/PrepareBodyMiddleware.php',
    'GuzzleHttp\\Promise\\AggregateException' => $vendorDir . '/guzzlehttp/promises/src/AggregateException.php',
    'GuzzleHttp\\Promise\\CancellationException' => $vendorDir . '/guzzlehttp/promises/src/CancellationException.php',
    'GuzzleHttp\\Promise\\Coroutine' => $vendorDir . '/guzzlehttp/promises/src/Coroutine.php',
    'GuzzleHttp\\Promise\\Create' => $vendorDir . '/guzzlehttp/promises/src/Create.php',
    'GuzzleHttp\\Promise\\Each' => $vendorDir . '/guzzlehttp/promises/src/Each.php',
    'GuzzleHttp\\Promise\\EachPromise' => $vendorDir . '/guzzlehttp/promises/src/EachPromise.php',
    'GuzzleHttp\\Promise\\FulfilledPromise' => $vendorDir . '/guzzlehttp/promises/src/FulfilledPromise.php',
    'GuzzleHttp\\Promise\\Is' => $vendorDir . '/guzzlehttp/promises/src/Is.php',
    'GuzzleHttp\\Promise\\Promise' => $vendorDir . '/guzzlehttp/promises/src/Promise.php',
    'GuzzleHttp\\Promise\\PromiseInterface' => $vendorDir . '/guzzlehttp/promises/src/PromiseInterface.php',
    'GuzzleHttp\\Promise\\PromisorInterface' => $vendorDir . '/guzzlehttp/promises/src/PromisorInterface.php',
    'GuzzleHttp\\Promise\\RejectedPromise' => $vendorDir . '/guzzlehttp/promises/src/RejectedPromise.php',
    'GuzzleHttp\\Promise\\RejectionException' => $vendorDir . '/guzzlehttp/promises/src/RejectionException.php',
    'GuzzleHttp\\Promise\\TaskQueue' => $vendorDir . '/guzzlehttp/promises/src/TaskQueue.php',
    'GuzzleHttp\\Promise\\TaskQueueInterface' => $vendorDir . '/guzzlehttp/promises/src/TaskQueueInterface.php',
    'GuzzleHttp\\Promise\\Utils' => $vendorDir . '/guzzlehttp/promises/src/Utils.php',
    'GuzzleHttp\\Psr7\\AppendStream' => $vendorDir . '/guzzlehttp/psr7/src/AppendStream.php',
    'GuzzleHttp\\Psr7\\BufferStream' => $vendorDir . '/guzzlehttp/psr7/src/BufferStream.php',
    'GuzzleHttp\\Psr7\\CachingStream' => $vendorDir . '/guzzlehttp/psr7/src/CachingStream.php',
    'GuzzleHttp\\Psr7\\DroppingStream' => $vendorDir . '/guzzlehttp/psr7/src/DroppingStream.php',
    'GuzzleHttp\\Psr7\\Exception\\MalformedUriException' => $vendorDir . '/guzzlehttp/psr7/src/Exception/MalformedUriException.php',
    'GuzzleHttp\\Psr7\\FnStream' => $vendorDir . '/guzzlehttp/psr7/src/FnStream.php',
    'GuzzleHttp\\Psr7\\Header' => $vendorDir . '/guzzlehttp/psr7/src/Header.php',
    'GuzzleHttp\\Psr7\\HttpFactory' => $vendorDir . '/guzzlehttp/psr7/src/HttpFactory.php',
    'GuzzleHttp\\Psr7\\InflateStream' => $vendorDir . '/guzzlehttp/psr7/src/InflateStream.php',
    'GuzzleHttp\\Psr7\\LazyOpenStream' => $vendorDir . '/guzzlehttp/psr7/src/LazyOpenStream.php',
    'GuzzleHttp\\Psr7\\LimitStream' => $vendorDir . '/guzzlehttp/psr7/src/LimitStream.php',
    'GuzzleHttp\\Psr7\\Message' => $vendorDir . '/guzzlehttp/psr7/src/Message.php',
    'GuzzleHttp\\Psr7\\MessageTrait' => $vendorDir . '/guzzlehttp/psr7/src/MessageTrait.php',
    'GuzzleHttp\\Psr7\\MimeType' => $vendorDir . '/guzzlehttp/psr7/src/MimeType.php',
    'GuzzleHttp\\Psr7\\MultipartStream' => $vendorDir . '/guzzlehttp/psr7/src/MultipartStream.php',
    'GuzzleHttp\\Psr7\\NoSeekStream' => $vendorDir . '/guzzlehttp/psr7/src/NoSeekStream.php',
    'GuzzleHttp\\Psr7\\PumpStream' => $vendorDir . '/guzzlehttp/psr7/src/PumpStream.php',
    'GuzzleHttp\\Psr7\\Query' => $vendorDir . '/guzzlehttp/psr7/src/Query.php',
    'GuzzleHttp\\Psr7\\Request' => $vendorDir . '/guzzlehttp/psr7/src/Request.php',
    'GuzzleHttp\\Psr7\\Response' => $vendorDir . '/guzzlehttp/psr7/src/Response.php',
    'GuzzleHttp\\Psr7\\Rfc7230' => $vendorDir . '/guzzlehttp/psr7/src/Rfc7230.php',
    'GuzzleHttp\\Psr7\\ServerRequest' => $vendorDir . '/guzzlehttp/psr7/src/ServerRequest.php',
    'GuzzleHttp\\Psr7\\Stream' => $vendorDir . '/guzzlehttp/psr7/src/Stream.php',
    'GuzzleHttp\\Psr7\\StreamDecoratorTrait' => $vendorDir . '/guzzlehttp/psr7/src/StreamDecoratorTrait.php',
    'GuzzleHttp\\Psr7\\StreamWrapper' => $vendorDir . '/guzzlehttp/psr7/src/StreamWrapper.php',
    'GuzzleHttp\\Psr7\\UploadedFile' => $vendorDir . '/guzzlehttp/psr7/src/UploadedFile.php',
    'GuzzleHttp\\Psr7\\Uri' => $vendorDir . '/guzzlehttp/psr7/src/Uri.php',
    'GuzzleHttp\\Psr7\\UriComparator' => $vendorDir . '/guzzlehttp/psr7/src/UriComparator.php',
    'GuzzleHttp\\Psr7\\UriNormalizer' => $vendorDir . '/guzzlehttp/psr7/src/UriNormalizer.php',
    'GuzzleHttp\\Psr7\\UriResolver' => $vendorDir . '/guzzlehttp/psr7/src/UriResolver.php',
    'GuzzleHttp\\Psr7\\Utils' => $vendorDir . '/guzzlehttp/psr7/src/Utils.php',
    'GuzzleHttp\\RedirectMiddleware' => $vendorDir . '/guzzlehttp/guzzle/src/RedirectMiddleware.php',
    'GuzzleHttp\\RequestOptions' => $vendorDir . '/guzzlehttp/guzzle/src/RequestOptions.php',
    'GuzzleHttp\\RetryMiddleware' => $vendorDir . '/guzzlehttp/guzzle/src/RetryMiddleware.php',
    'GuzzleHttp\\TransferStats' => $vendorDir . '/guzzlehttp/guzzle/src/TransferStats.php',
    'GuzzleHttp\\UriTemplate\\UriTemplate' => $vendorDir . '/guzzlehttp/uri-template/src/UriTemplate.php',
    'GuzzleHttp\\Utils' => $vendorDir . '/guzzlehttp/guzzle/src/Utils.php',
    'HTMLPurifier' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier.php',
    'HTMLPurifier_Arborize' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Arborize.php',
    'HTMLPurifier_AttrCollections' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrCollections.php',
    'HTMLPurifier_AttrDef' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef.php',
    'HTMLPurifier_AttrDef_CSS' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS.php',
    'HTMLPurifier_AttrDef_CSS_AlphaValue' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/AlphaValue.php',
    'HTMLPurifier_AttrDef_CSS_Background' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Background.php',
    'HTMLPurifier_AttrDef_CSS_BackgroundPosition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/BackgroundPosition.php',
    'HTMLPurifier_AttrDef_CSS_Border' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Border.php',
    'HTMLPurifier_AttrDef_CSS_Color' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Color.php',
    'HTMLPurifier_AttrDef_CSS_Composite' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Composite.php',
    'HTMLPurifier_AttrDef_CSS_DenyElementDecorator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/DenyElementDecorator.php',
    'HTMLPurifier_AttrDef_CSS_Filter' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Filter.php',
    'HTMLPurifier_AttrDef_CSS_Font' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Font.php',
    'HTMLPurifier_AttrDef_CSS_FontFamily' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/FontFamily.php',
    'HTMLPurifier_AttrDef_CSS_Ident' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Ident.php',
    'HTMLPurifier_AttrDef_CSS_ImportantDecorator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/ImportantDecorator.php',
    'HTMLPurifier_AttrDef_CSS_Length' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Length.php',
    'HTMLPurifier_AttrDef_CSS_ListStyle' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/ListStyle.php',
    'HTMLPurifier_AttrDef_CSS_Multiple' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Multiple.php',
    'HTMLPurifier_AttrDef_CSS_Number' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Number.php',
    'HTMLPurifier_AttrDef_CSS_Percentage' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Percentage.php',
    'HTMLPurifier_AttrDef_CSS_TextDecoration' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/TextDecoration.php',
    'HTMLPurifier_AttrDef_CSS_URI' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/URI.php',
    'HTMLPurifier_AttrDef_Clone' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Clone.php',
    'HTMLPurifier_AttrDef_Enum' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Enum.php',
    'HTMLPurifier_AttrDef_HTML_Bool' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Bool.php',
    'HTMLPurifier_AttrDef_HTML_Class' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Class.php',
    'HTMLPurifier_AttrDef_HTML_Color' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Color.php',
    'HTMLPurifier_AttrDef_HTML_ContentEditable' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/ContentEditable.php',
    'HTMLPurifier_AttrDef_HTML_FrameTarget' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/FrameTarget.php',
    'HTMLPurifier_AttrDef_HTML_ID' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/ID.php',
    'HTMLPurifier_AttrDef_HTML_Length' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Length.php',
    'HTMLPurifier_AttrDef_HTML_LinkTypes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/LinkTypes.php',
    'HTMLPurifier_AttrDef_HTML_MultiLength' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/MultiLength.php',
    'HTMLPurifier_AttrDef_HTML_Nmtokens' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Nmtokens.php',
    'HTMLPurifier_AttrDef_HTML_Pixels' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Pixels.php',
    'HTMLPurifier_AttrDef_Integer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Integer.php',
    'HTMLPurifier_AttrDef_Lang' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Lang.php',
    'HTMLPurifier_AttrDef_Switch' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Switch.php',
    'HTMLPurifier_AttrDef_Text' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Text.php',
    'HTMLPurifier_AttrDef_URI' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI.php',
    'HTMLPurifier_AttrDef_URI_Email' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Email.php',
    'HTMLPurifier_AttrDef_URI_Email_SimpleCheck' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Email/SimpleCheck.php',
    'HTMLPurifier_AttrDef_URI_Host' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Host.php',
    'HTMLPurifier_AttrDef_URI_IPv4' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/IPv4.php',
    'HTMLPurifier_AttrDef_URI_IPv6' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/IPv6.php',
    'HTMLPurifier_AttrTransform' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform.php',
    'HTMLPurifier_AttrTransform_Background' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Background.php',
    'HTMLPurifier_AttrTransform_BdoDir' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BdoDir.php',
    'HTMLPurifier_AttrTransform_BgColor' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BgColor.php',
    'HTMLPurifier_AttrTransform_BoolToCSS' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BoolToCSS.php',
    'HTMLPurifier_AttrTransform_Border' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Border.php',
    'HTMLPurifier_AttrTransform_EnumToCSS' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/EnumToCSS.php',
    'HTMLPurifier_AttrTransform_ImgRequired' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ImgRequired.php',
    'HTMLPurifier_AttrTransform_ImgSpace' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ImgSpace.php',
    'HTMLPurifier_AttrTransform_Input' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Input.php',
    'HTMLPurifier_AttrTransform_Lang' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Lang.php',
    'HTMLPurifier_AttrTransform_Length' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Length.php',
    'HTMLPurifier_AttrTransform_Name' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Name.php',
    'HTMLPurifier_AttrTransform_NameSync' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/NameSync.php',
    'HTMLPurifier_AttrTransform_Nofollow' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Nofollow.php',
    'HTMLPurifier_AttrTransform_SafeEmbed' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeEmbed.php',
    'HTMLPurifier_AttrTransform_SafeObject' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeObject.php',
    'HTMLPurifier_AttrTransform_SafeParam' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeParam.php',
    'HTMLPurifier_AttrTransform_ScriptRequired' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ScriptRequired.php',
    'HTMLPurifier_AttrTransform_TargetBlank' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetBlank.php',
    'HTMLPurifier_AttrTransform_TargetNoopener' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetNoopener.php',
    'HTMLPurifier_AttrTransform_TargetNoreferrer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetNoreferrer.php',
    'HTMLPurifier_AttrTransform_Textarea' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Textarea.php',
    'HTMLPurifier_AttrTypes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrTypes.php',
    'HTMLPurifier_AttrValidator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/AttrValidator.php',
    'HTMLPurifier_Bootstrap' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Bootstrap.php',
    'HTMLPurifier_CSSDefinition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/CSSDefinition.php',
    'HTMLPurifier_ChildDef' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef.php',
    'HTMLPurifier_ChildDef_Chameleon' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Chameleon.php',
    'HTMLPurifier_ChildDef_Custom' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Custom.php',
    'HTMLPurifier_ChildDef_Empty' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Empty.php',
    'HTMLPurifier_ChildDef_List' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/List.php',
    'HTMLPurifier_ChildDef_Optional' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Optional.php',
    'HTMLPurifier_ChildDef_Required' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Required.php',
    'HTMLPurifier_ChildDef_StrictBlockquote' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/StrictBlockquote.php',
    'HTMLPurifier_ChildDef_Table' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Table.php',
    'HTMLPurifier_Config' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Config.php',
    'HTMLPurifier_ConfigSchema' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema.php',
    'HTMLPurifier_ConfigSchema_Builder_ConfigSchema' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Builder/ConfigSchema.php',
    'HTMLPurifier_ConfigSchema_Builder_Xml' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Builder/Xml.php',
    'HTMLPurifier_ConfigSchema_Exception' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Exception.php',
    'HTMLPurifier_ConfigSchema_Interchange' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange.php',
    'HTMLPurifier_ConfigSchema_InterchangeBuilder' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/InterchangeBuilder.php',
    'HTMLPurifier_ConfigSchema_Interchange_Directive' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange/Directive.php',
    'HTMLPurifier_ConfigSchema_Interchange_Id' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange/Id.php',
    'HTMLPurifier_ConfigSchema_Validator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Validator.php',
    'HTMLPurifier_ConfigSchema_ValidatorAtom' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/ValidatorAtom.php',
    'HTMLPurifier_ContentSets' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ContentSets.php',
    'HTMLPurifier_Context' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Context.php',
    'HTMLPurifier_Definition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Definition.php',
    'HTMLPurifier_DefinitionCache' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache.php',
    'HTMLPurifier_DefinitionCacheFactory' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCacheFactory.php',
    'HTMLPurifier_DefinitionCache_Decorator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator.php',
    'HTMLPurifier_DefinitionCache_Decorator_Cleanup' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator/Cleanup.php',
    'HTMLPurifier_DefinitionCache_Decorator_Memory' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator/Memory.php',
    'HTMLPurifier_DefinitionCache_Null' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Null.php',
    'HTMLPurifier_DefinitionCache_Serializer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Serializer.php',
    'HTMLPurifier_Doctype' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Doctype.php',
    'HTMLPurifier_DoctypeRegistry' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/DoctypeRegistry.php',
    'HTMLPurifier_ElementDef' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ElementDef.php',
    'HTMLPurifier_Encoder' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Encoder.php',
    'HTMLPurifier_EntityLookup' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/EntityLookup.php',
    'HTMLPurifier_EntityParser' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/EntityParser.php',
    'HTMLPurifier_ErrorCollector' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ErrorCollector.php',
    'HTMLPurifier_ErrorStruct' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/ErrorStruct.php',
    'HTMLPurifier_Exception' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Exception.php',
    'HTMLPurifier_Filter' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Filter.php',
    'HTMLPurifier_Filter_ExtractStyleBlocks' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Filter/ExtractStyleBlocks.php',
    'HTMLPurifier_Filter_YouTube' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Filter/YouTube.php',
    'HTMLPurifier_Generator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Generator.php',
    'HTMLPurifier_HTMLDefinition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLDefinition.php',
    'HTMLPurifier_HTMLModule' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule.php',
    'HTMLPurifier_HTMLModuleManager' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModuleManager.php',
    'HTMLPurifier_HTMLModule_Bdo' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Bdo.php',
    'HTMLPurifier_HTMLModule_CommonAttributes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/CommonAttributes.php',
    'HTMLPurifier_HTMLModule_Edit' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Edit.php',
    'HTMLPurifier_HTMLModule_Forms' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Forms.php',
    'HTMLPurifier_HTMLModule_Hypertext' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Hypertext.php',
    'HTMLPurifier_HTMLModule_Iframe' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Iframe.php',
    'HTMLPurifier_HTMLModule_Image' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Image.php',
    'HTMLPurifier_HTMLModule_Legacy' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Legacy.php',
    'HTMLPurifier_HTMLModule_List' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/List.php',
    'HTMLPurifier_HTMLModule_Name' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Name.php',
    'HTMLPurifier_HTMLModule_Nofollow' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Nofollow.php',
    'HTMLPurifier_HTMLModule_NonXMLCommonAttributes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/NonXMLCommonAttributes.php',
    'HTMLPurifier_HTMLModule_Object' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Object.php',
    'HTMLPurifier_HTMLModule_Presentation' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Presentation.php',
    'HTMLPurifier_HTMLModule_Proprietary' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Proprietary.php',
    'HTMLPurifier_HTMLModule_Ruby' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Ruby.php',
    'HTMLPurifier_HTMLModule_SafeEmbed' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeEmbed.php',
    'HTMLPurifier_HTMLModule_SafeObject' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeObject.php',
    'HTMLPurifier_HTMLModule_SafeScripting' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeScripting.php',
    'HTMLPurifier_HTMLModule_Scripting' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Scripting.php',
    'HTMLPurifier_HTMLModule_StyleAttribute' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/StyleAttribute.php',
    'HTMLPurifier_HTMLModule_Tables' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tables.php',
    'HTMLPurifier_HTMLModule_Target' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Target.php',
    'HTMLPurifier_HTMLModule_TargetBlank' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetBlank.php',
    'HTMLPurifier_HTMLModule_TargetNoopener' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetNoopener.php',
    'HTMLPurifier_HTMLModule_TargetNoreferrer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetNoreferrer.php',
    'HTMLPurifier_HTMLModule_Text' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Text.php',
    'HTMLPurifier_HTMLModule_Tidy' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy.php',
    'HTMLPurifier_HTMLModule_Tidy_Name' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Name.php',
    'HTMLPurifier_HTMLModule_Tidy_Proprietary' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Proprietary.php',
    'HTMLPurifier_HTMLModule_Tidy_Strict' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Strict.php',
    'HTMLPurifier_HTMLModule_Tidy_Transitional' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Transitional.php',
    'HTMLPurifier_HTMLModule_Tidy_XHTML' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/XHTML.php',
    'HTMLPurifier_HTMLModule_Tidy_XHTMLAndHTML4' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/XHTMLAndHTML4.php',
    'HTMLPurifier_HTMLModule_XMLCommonAttributes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/XMLCommonAttributes.php',
    'HTMLPurifier_IDAccumulator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/IDAccumulator.php',
    'HTMLPurifier_Injector' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector.php',
    'HTMLPurifier_Injector_AutoParagraph' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/AutoParagraph.php',
    'HTMLPurifier_Injector_DisplayLinkURI' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/DisplayLinkURI.php',
    'HTMLPurifier_Injector_Linkify' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/Linkify.php',
    'HTMLPurifier_Injector_PurifierLinkify' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/PurifierLinkify.php',
    'HTMLPurifier_Injector_RemoveEmpty' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/RemoveEmpty.php',
    'HTMLPurifier_Injector_RemoveSpansWithoutAttributes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/RemoveSpansWithoutAttributes.php',
    'HTMLPurifier_Injector_SafeObject' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Injector/SafeObject.php',
    'HTMLPurifier_Language' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Language.php',
    'HTMLPurifier_LanguageFactory' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/LanguageFactory.php',
    'HTMLPurifier_Length' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Length.php',
    'HTMLPurifier_Lexer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Lexer.php',
    'HTMLPurifier_Lexer_DOMLex' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/DOMLex.php',
    'HTMLPurifier_Lexer_DirectLex' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/DirectLex.php',
    'HTMLPurifier_Lexer_PH5P' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/PH5P.php',
    'HTMLPurifier_Node' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Node.php',
    'HTMLPurifier_Node_Comment' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Node/Comment.php',
    'HTMLPurifier_Node_Element' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Node/Element.php',
    'HTMLPurifier_Node_Text' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Node/Text.php',
    'HTMLPurifier_PercentEncoder' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/PercentEncoder.php',
    'HTMLPurifier_Printer' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Printer.php',
    'HTMLPurifier_Printer_CSSDefinition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Printer/CSSDefinition.php',
    'HTMLPurifier_Printer_ConfigForm' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Printer/ConfigForm.php',
    'HTMLPurifier_Printer_HTMLDefinition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Printer/HTMLDefinition.php',
    'HTMLPurifier_PropertyList' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/PropertyList.php',
    'HTMLPurifier_PropertyListIterator' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/PropertyListIterator.php',
    'HTMLPurifier_Queue' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Queue.php',
    'HTMLPurifier_Strategy' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy.php',
    'HTMLPurifier_Strategy_Composite' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/Composite.php',
    'HTMLPurifier_Strategy_Core' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/Core.php',
    'HTMLPurifier_Strategy_FixNesting' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/FixNesting.php',
    'HTMLPurifier_Strategy_MakeWellFormed' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/MakeWellFormed.php',
    'HTMLPurifier_Strategy_RemoveForeignElements' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/RemoveForeignElements.php',
    'HTMLPurifier_Strategy_ValidateAttributes' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/ValidateAttributes.php',
    'HTMLPurifier_StringHash' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/StringHash.php',
    'HTMLPurifier_StringHashParser' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/StringHashParser.php',
    'HTMLPurifier_TagTransform' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform.php',
    'HTMLPurifier_TagTransform_Font' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform/Font.php',
    'HTMLPurifier_TagTransform_Simple' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform/Simple.php',
    'HTMLPurifier_Token' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token.php',
    'HTMLPurifier_TokenFactory' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/TokenFactory.php',
    'HTMLPurifier_Token_Comment' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/Comment.php',
    'HTMLPurifier_Token_Empty' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/Empty.php',
    'HTMLPurifier_Token_End' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/End.php',
    'HTMLPurifier_Token_Start' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/Start.php',
    'HTMLPurifier_Token_Tag' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/Tag.php',
    'HTMLPurifier_Token_Text' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Token/Text.php',
    'HTMLPurifier_URI' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URI.php',
    'HTMLPurifier_URIDefinition' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIDefinition.php',
    'HTMLPurifier_URIFilter' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter.php',
    'HTMLPurifier_URIFilter_DisableExternal' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableExternal.php',
    'HTMLPurifier_URIFilter_DisableExternalResources' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableExternalResources.php',
    'HTMLPurifier_URIFilter_DisableResources' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableResources.php',
    'HTMLPurifier_URIFilter_HostBlacklist' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/HostBlacklist.php',
    'HTMLPurifier_URIFilter_MakeAbsolute' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/MakeAbsolute.php',
    'HTMLPurifier_URIFilter_Munge' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/Munge.php',
    'HTMLPurifier_URIFilter_SafeIframe' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/SafeIframe.php',
    'HTMLPurifier_URIParser' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIParser.php',
    'HTMLPurifier_URIScheme' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme.php',
    'HTMLPurifier_URISchemeRegistry' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URISchemeRegistry.php',
    'HTMLPurifier_URIScheme_data' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/data.php',
    'HTMLPurifier_URIScheme_file' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/file.php',
    'HTMLPurifier_URIScheme_ftp' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/ftp.php',
    'HTMLPurifier_URIScheme_http' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/http.php',
    'HTMLPurifier_URIScheme_https' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/https.php',
    'HTMLPurifier_URIScheme_mailto' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/mailto.php',
    'HTMLPurifier_URIScheme_news' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/news.php',
    'HTMLPurifier_URIScheme_nntp' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/nntp.php',
    'HTMLPurifier_URIScheme_tel' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/tel.php',
    'HTMLPurifier_UnitConverter' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/UnitConverter.php',
    'HTMLPurifier_VarParser' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/VarParser.php',
    'HTMLPurifier_VarParserException' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/VarParserException.php',
    'HTMLPurifier_VarParser_Flexible' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/VarParser/Flexible.php',
    'HTMLPurifier_VarParser_Native' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/VarParser/Native.php',
    'HTMLPurifier_Zipper' => $vendorDir . '/ezyang/htmlpurifier/library/HTMLPurifier/Zipper.php',
    'Hamcrest\\Arrays\\IsArray' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArray.php',
    'Hamcrest\\Arrays\\IsArrayContaining' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayContaining.php',
    'Hamcrest\\Arrays\\IsArrayContainingInAnyOrder' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayContainingInAnyOrder.php',
    'Hamcrest\\Arrays\\IsArrayContainingInOrder' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayContainingInOrder.php',
    'Hamcrest\\Arrays\\IsArrayContainingKey' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayContainingKey.php',
    'Hamcrest\\Arrays\\IsArrayContainingKeyValuePair' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayContainingKeyValuePair.php',
    'Hamcrest\\Arrays\\IsArrayWithSize' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/IsArrayWithSize.php',
    'Hamcrest\\Arrays\\MatchingOnce' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/MatchingOnce.php',
    'Hamcrest\\Arrays\\SeriesMatchingOnce' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Arrays/SeriesMatchingOnce.php',
    'Hamcrest\\AssertionError' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/AssertionError.php',
    'Hamcrest\\BaseDescription' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/BaseDescription.php',
    'Hamcrest\\BaseMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/BaseMatcher.php',
    'Hamcrest\\Collection\\IsEmptyTraversable' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Collection/IsEmptyTraversable.php',
    'Hamcrest\\Collection\\IsTraversableWithSize' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Collection/IsTraversableWithSize.php',
    'Hamcrest\\Core\\AllOf' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/AllOf.php',
    'Hamcrest\\Core\\AnyOf' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/AnyOf.php',
    'Hamcrest\\Core\\CombinableMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/CombinableMatcher.php',
    'Hamcrest\\Core\\DescribedAs' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/DescribedAs.php',
    'Hamcrest\\Core\\Every' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/Every.php',
    'Hamcrest\\Core\\HasToString' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/HasToString.php',
    'Hamcrest\\Core\\Is' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/Is.php',
    'Hamcrest\\Core\\IsAnything' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsAnything.php',
    'Hamcrest\\Core\\IsCollectionContaining' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsCollectionContaining.php',
    'Hamcrest\\Core\\IsEqual' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsEqual.php',
    'Hamcrest\\Core\\IsIdentical' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsIdentical.php',
    'Hamcrest\\Core\\IsInstanceOf' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsInstanceOf.php',
    'Hamcrest\\Core\\IsNot' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsNot.php',
    'Hamcrest\\Core\\IsNull' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsNull.php',
    'Hamcrest\\Core\\IsSame' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsSame.php',
    'Hamcrest\\Core\\IsTypeOf' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/IsTypeOf.php',
    'Hamcrest\\Core\\Set' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/Set.php',
    'Hamcrest\\Core\\ShortcutCombination' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Core/ShortcutCombination.php',
    'Hamcrest\\Description' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Description.php',
    'Hamcrest\\DiagnosingMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/DiagnosingMatcher.php',
    'Hamcrest\\FeatureMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/FeatureMatcher.php',
    'Hamcrest\\Internal\\SelfDescribingValue' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Internal/SelfDescribingValue.php',
    'Hamcrest\\Matcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Matcher.php',
    'Hamcrest\\MatcherAssert' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/MatcherAssert.php',
    'Hamcrest\\Matchers' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Matchers.php',
    'Hamcrest\\NullDescription' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/NullDescription.php',
    'Hamcrest\\Number\\IsCloseTo' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Number/IsCloseTo.php',
    'Hamcrest\\Number\\OrderingComparison' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Number/OrderingComparison.php',
    'Hamcrest\\SelfDescribing' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/SelfDescribing.php',
    'Hamcrest\\StringDescription' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/StringDescription.php',
    'Hamcrest\\Text\\IsEmptyString' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/IsEmptyString.php',
    'Hamcrest\\Text\\IsEqualIgnoringCase' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/IsEqualIgnoringCase.php',
    'Hamcrest\\Text\\IsEqualIgnoringWhiteSpace' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/IsEqualIgnoringWhiteSpace.php',
    'Hamcrest\\Text\\MatchesPattern' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/MatchesPattern.php',
    'Hamcrest\\Text\\StringContains' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/StringContains.php',
    'Hamcrest\\Text\\StringContainsIgnoringCase' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/StringContainsIgnoringCase.php',
    'Hamcrest\\Text\\StringContainsInOrder' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/StringContainsInOrder.php',
    'Hamcrest\\Text\\StringEndsWith' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/StringEndsWith.php',
    'Hamcrest\\Text\\StringStartsWith' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/StringStartsWith.php',
    'Hamcrest\\Text\\SubstringMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Text/SubstringMatcher.php',
    'Hamcrest\\TypeSafeDiagnosingMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/TypeSafeDiagnosingMatcher.php',
    'Hamcrest\\TypeSafeMatcher' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/TypeSafeMatcher.php',
    'Hamcrest\\Type\\IsArray' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsArray.php',
    'Hamcrest\\Type\\IsBoolean' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsBoolean.php',
    'Hamcrest\\Type\\IsCallable' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsCallable.php',
    'Hamcrest\\Type\\IsDouble' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsDouble.php',
    'Hamcrest\\Type\\IsInteger' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsInteger.php',
    'Hamcrest\\Type\\IsNumeric' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsNumeric.php',
    'Hamcrest\\Type\\IsObject' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsObject.php',
    'Hamcrest\\Type\\IsResource' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsResource.php',
    'Hamcrest\\Type\\IsScalar' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsScalar.php',
    'Hamcrest\\Type\\IsString' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Type/IsString.php',
    'Hamcrest\\Util' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Util.php',
    'Hamcrest\\Xml\\HasXPath' => $vendorDir . '/hamcrest/hamcrest-php/hamcrest/Hamcrest/Xml/HasXPath.php',
    'Illuminate\\Auth\\Access\\AuthorizationException' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Access/AuthorizationException.php',
    'Illuminate\\Auth\\Access\\Events\\GateEvaluated' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Access/Events/GateEvaluated.php',
    'Illuminate\\Auth\\Access\\Gate' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Access/Gate.php',
    'Illuminate\\Auth\\Access\\HandlesAuthorization' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Access/HandlesAuthorization.php',
    'Illuminate\\Auth\\Access\\Response' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Access/Response.php',
    'Illuminate\\Auth\\AuthManager' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/AuthManager.php',
    'Illuminate\\Auth\\AuthServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/AuthServiceProvider.php',
    'Illuminate\\Auth\\Authenticatable' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Authenticatable.php',
    'Illuminate\\Auth\\AuthenticationException' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/AuthenticationException.php',
    'Illuminate\\Auth\\Console\\ClearResetsCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Console/ClearResetsCommand.php',
    'Illuminate\\Auth\\CreatesUserProviders' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/CreatesUserProviders.php',
    'Illuminate\\Auth\\DatabaseUserProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/DatabaseUserProvider.php',
    'Illuminate\\Auth\\EloquentUserProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/EloquentUserProvider.php',
    'Illuminate\\Auth\\Events\\Attempting' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Attempting.php',
    'Illuminate\\Auth\\Events\\Authenticated' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Authenticated.php',
    'Illuminate\\Auth\\Events\\CurrentDeviceLogout' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/CurrentDeviceLogout.php',
    'Illuminate\\Auth\\Events\\Failed' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Failed.php',
    'Illuminate\\Auth\\Events\\Lockout' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Lockout.php',
    'Illuminate\\Auth\\Events\\Login' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Login.php',
    'Illuminate\\Auth\\Events\\Logout' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Logout.php',
    'Illuminate\\Auth\\Events\\OtherDeviceLogout' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/OtherDeviceLogout.php',
    'Illuminate\\Auth\\Events\\PasswordReset' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/PasswordReset.php',
    'Illuminate\\Auth\\Events\\PasswordResetLinkSent' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/PasswordResetLinkSent.php',
    'Illuminate\\Auth\\Events\\Registered' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Registered.php',
    'Illuminate\\Auth\\Events\\Validated' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Validated.php',
    'Illuminate\\Auth\\Events\\Verified' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Events/Verified.php',
    'Illuminate\\Auth\\GenericUser' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/GenericUser.php',
    'Illuminate\\Auth\\GuardHelpers' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/GuardHelpers.php',
    'Illuminate\\Auth\\Listeners\\SendEmailVerificationNotification' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Listeners/SendEmailVerificationNotification.php',
    'Illuminate\\Auth\\Middleware\\Authenticate' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/Authenticate.php',
    'Illuminate\\Auth\\Middleware\\AuthenticateWithBasicAuth' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/AuthenticateWithBasicAuth.php',
    'Illuminate\\Auth\\Middleware\\Authorize' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/Authorize.php',
    'Illuminate\\Auth\\Middleware\\EnsureEmailIsVerified' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/EnsureEmailIsVerified.php',
    'Illuminate\\Auth\\Middleware\\RedirectIfAuthenticated' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/RedirectIfAuthenticated.php',
    'Illuminate\\Auth\\Middleware\\RequirePassword' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Middleware/RequirePassword.php',
    'Illuminate\\Auth\\MustVerifyEmail' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/MustVerifyEmail.php',
    'Illuminate\\Auth\\Notifications\\ResetPassword' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Notifications/ResetPassword.php',
    'Illuminate\\Auth\\Notifications\\VerifyEmail' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Notifications/VerifyEmail.php',
    'Illuminate\\Auth\\Passwords\\CanResetPassword' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/CanResetPassword.php',
    'Illuminate\\Auth\\Passwords\\DatabaseTokenRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/DatabaseTokenRepository.php',
    'Illuminate\\Auth\\Passwords\\PasswordBroker' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/PasswordBroker.php',
    'Illuminate\\Auth\\Passwords\\PasswordBrokerManager' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/PasswordBrokerManager.php',
    'Illuminate\\Auth\\Passwords\\PasswordResetServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/PasswordResetServiceProvider.php',
    'Illuminate\\Auth\\Passwords\\TokenRepositoryInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Passwords/TokenRepositoryInterface.php',
    'Illuminate\\Auth\\Recaller' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/Recaller.php',
    'Illuminate\\Auth\\RequestGuard' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/RequestGuard.php',
    'Illuminate\\Auth\\SessionGuard' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/SessionGuard.php',
    'Illuminate\\Auth\\TokenGuard' => $vendorDir . '/laravel/framework/src/Illuminate/Auth/TokenGuard.php',
    'Illuminate\\Broadcasting\\AnonymousEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/AnonymousEvent.php',
    'Illuminate\\Broadcasting\\BroadcastController' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/BroadcastController.php',
    'Illuminate\\Broadcasting\\BroadcastEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/BroadcastEvent.php',
    'Illuminate\\Broadcasting\\BroadcastException' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/BroadcastException.php',
    'Illuminate\\Broadcasting\\BroadcastManager' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/BroadcastManager.php',
    'Illuminate\\Broadcasting\\BroadcastServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/BroadcastServiceProvider.php',
    'Illuminate\\Broadcasting\\Broadcasters\\AblyBroadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/AblyBroadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\Broadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/Broadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\LogBroadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/LogBroadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\NullBroadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/NullBroadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\PusherBroadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/PusherBroadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\RedisBroadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/RedisBroadcaster.php',
    'Illuminate\\Broadcasting\\Broadcasters\\UsePusherChannelConventions' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Broadcasters/UsePusherChannelConventions.php',
    'Illuminate\\Broadcasting\\Channel' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/Channel.php',
    'Illuminate\\Broadcasting\\EncryptedPrivateChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/EncryptedPrivateChannel.php',
    'Illuminate\\Broadcasting\\InteractsWithBroadcasting' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/InteractsWithBroadcasting.php',
    'Illuminate\\Broadcasting\\InteractsWithSockets' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/InteractsWithSockets.php',
    'Illuminate\\Broadcasting\\PendingBroadcast' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/PendingBroadcast.php',
    'Illuminate\\Broadcasting\\PresenceChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/PresenceChannel.php',
    'Illuminate\\Broadcasting\\PrivateChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/PrivateChannel.php',
    'Illuminate\\Broadcasting\\UniqueBroadcastEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Broadcasting/UniqueBroadcastEvent.php',
    'Illuminate\\Bus\\Batch' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/Batch.php',
    'Illuminate\\Bus\\BatchFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/BatchFactory.php',
    'Illuminate\\Bus\\BatchRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/BatchRepository.php',
    'Illuminate\\Bus\\Batchable' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/Batchable.php',
    'Illuminate\\Bus\\BusServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/BusServiceProvider.php',
    'Illuminate\\Bus\\ChainedBatch' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/ChainedBatch.php',
    'Illuminate\\Bus\\DatabaseBatchRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/DatabaseBatchRepository.php',
    'Illuminate\\Bus\\Dispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/Dispatcher.php',
    'Illuminate\\Bus\\DynamoBatchRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/DynamoBatchRepository.php',
    'Illuminate\\Bus\\Events\\BatchDispatched' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/Events/BatchDispatched.php',
    'Illuminate\\Bus\\PendingBatch' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/PendingBatch.php',
    'Illuminate\\Bus\\PrunableBatchRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/PrunableBatchRepository.php',
    'Illuminate\\Bus\\Queueable' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/Queueable.php',
    'Illuminate\\Bus\\UniqueLock' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/UniqueLock.php',
    'Illuminate\\Bus\\UpdatedBatchJobCounts' => $vendorDir . '/laravel/framework/src/Illuminate/Bus/UpdatedBatchJobCounts.php',
    'Illuminate\\Cache\\ApcStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/ApcStore.php',
    'Illuminate\\Cache\\ApcWrapper' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/ApcWrapper.php',
    'Illuminate\\Cache\\ArrayLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/ArrayLock.php',
    'Illuminate\\Cache\\ArrayStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/ArrayStore.php',
    'Illuminate\\Cache\\CacheLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/CacheLock.php',
    'Illuminate\\Cache\\CacheManager' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/CacheManager.php',
    'Illuminate\\Cache\\CacheServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/CacheServiceProvider.php',
    'Illuminate\\Cache\\Console\\CacheTableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Console/CacheTableCommand.php',
    'Illuminate\\Cache\\Console\\ClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Console/ClearCommand.php',
    'Illuminate\\Cache\\Console\\ForgetCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Console/ForgetCommand.php',
    'Illuminate\\Cache\\Console\\PruneStaleTagsCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Console/PruneStaleTagsCommand.php',
    'Illuminate\\Cache\\DatabaseLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/DatabaseLock.php',
    'Illuminate\\Cache\\DatabaseStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/DatabaseStore.php',
    'Illuminate\\Cache\\DynamoDbLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/DynamoDbLock.php',
    'Illuminate\\Cache\\DynamoDbStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/DynamoDbStore.php',
    'Illuminate\\Cache\\Events\\CacheEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/CacheEvent.php',
    'Illuminate\\Cache\\Events\\CacheHit' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/CacheHit.php',
    'Illuminate\\Cache\\Events\\CacheMissed' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/CacheMissed.php',
    'Illuminate\\Cache\\Events\\ForgettingKey' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/ForgettingKey.php',
    'Illuminate\\Cache\\Events\\KeyForgetFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/KeyForgetFailed.php',
    'Illuminate\\Cache\\Events\\KeyForgotten' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/KeyForgotten.php',
    'Illuminate\\Cache\\Events\\KeyWriteFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/KeyWriteFailed.php',
    'Illuminate\\Cache\\Events\\KeyWritten' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/KeyWritten.php',
    'Illuminate\\Cache\\Events\\RetrievingKey' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/RetrievingKey.php',
    'Illuminate\\Cache\\Events\\RetrievingManyKeys' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/RetrievingManyKeys.php',
    'Illuminate\\Cache\\Events\\WritingKey' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/WritingKey.php',
    'Illuminate\\Cache\\Events\\WritingManyKeys' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Events/WritingManyKeys.php',
    'Illuminate\\Cache\\FileLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/FileLock.php',
    'Illuminate\\Cache\\FileStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/FileStore.php',
    'Illuminate\\Cache\\HasCacheLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/HasCacheLock.php',
    'Illuminate\\Cache\\Lock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Lock.php',
    'Illuminate\\Cache\\LuaScripts' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/LuaScripts.php',
    'Illuminate\\Cache\\MemcachedConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/MemcachedConnector.php',
    'Illuminate\\Cache\\MemcachedLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/MemcachedLock.php',
    'Illuminate\\Cache\\MemcachedStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/MemcachedStore.php',
    'Illuminate\\Cache\\NoLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/NoLock.php',
    'Illuminate\\Cache\\NullStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/NullStore.php',
    'Illuminate\\Cache\\PhpRedisLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/PhpRedisLock.php',
    'Illuminate\\Cache\\RateLimiter' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RateLimiter.php',
    'Illuminate\\Cache\\RateLimiting\\GlobalLimit' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RateLimiting/GlobalLimit.php',
    'Illuminate\\Cache\\RateLimiting\\Limit' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RateLimiting/Limit.php',
    'Illuminate\\Cache\\RateLimiting\\Unlimited' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RateLimiting/Unlimited.php',
    'Illuminate\\Cache\\RedisLock' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RedisLock.php',
    'Illuminate\\Cache\\RedisStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RedisStore.php',
    'Illuminate\\Cache\\RedisTagSet' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RedisTagSet.php',
    'Illuminate\\Cache\\RedisTaggedCache' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RedisTaggedCache.php',
    'Illuminate\\Cache\\Repository' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/Repository.php',
    'Illuminate\\Cache\\RetrievesMultipleKeys' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/RetrievesMultipleKeys.php',
    'Illuminate\\Cache\\TagSet' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/TagSet.php',
    'Illuminate\\Cache\\TaggableStore' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/TaggableStore.php',
    'Illuminate\\Cache\\TaggedCache' => $vendorDir . '/laravel/framework/src/Illuminate/Cache/TaggedCache.php',
    'Illuminate\\Config\\Repository' => $vendorDir . '/laravel/framework/src/Illuminate/Config/Repository.php',
    'Illuminate\\Console\\Application' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Application.php',
    'Illuminate\\Console\\BufferedConsoleOutput' => $vendorDir . '/laravel/framework/src/Illuminate/Console/BufferedConsoleOutput.php',
    'Illuminate\\Console\\CacheCommandMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/CacheCommandMutex.php',
    'Illuminate\\Console\\Command' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Command.php',
    'Illuminate\\Console\\CommandMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/CommandMutex.php',
    'Illuminate\\Console\\Concerns\\CallsCommands' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/CallsCommands.php',
    'Illuminate\\Console\\Concerns\\ConfiguresPrompts' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/ConfiguresPrompts.php',
    'Illuminate\\Console\\Concerns\\CreatesMatchingTest' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/CreatesMatchingTest.php',
    'Illuminate\\Console\\Concerns\\HasParameters' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/HasParameters.php',
    'Illuminate\\Console\\Concerns\\InteractsWithIO' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/InteractsWithIO.php',
    'Illuminate\\Console\\Concerns\\InteractsWithSignals' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/InteractsWithSignals.php',
    'Illuminate\\Console\\Concerns\\PromptsForMissingInput' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Concerns/PromptsForMissingInput.php',
    'Illuminate\\Console\\ConfirmableTrait' => $vendorDir . '/laravel/framework/src/Illuminate/Console/ConfirmableTrait.php',
    'Illuminate\\Console\\ContainerCommandLoader' => $vendorDir . '/laravel/framework/src/Illuminate/Console/ContainerCommandLoader.php',
    'Illuminate\\Console\\Contracts\\NewLineAware' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Contracts/NewLineAware.php',
    'Illuminate\\Console\\Events\\ArtisanStarting' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ArtisanStarting.php',
    'Illuminate\\Console\\Events\\CommandFinished' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/CommandFinished.php',
    'Illuminate\\Console\\Events\\CommandStarting' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/CommandStarting.php',
    'Illuminate\\Console\\Events\\ScheduledBackgroundTaskFinished' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ScheduledBackgroundTaskFinished.php',
    'Illuminate\\Console\\Events\\ScheduledTaskFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ScheduledTaskFailed.php',
    'Illuminate\\Console\\Events\\ScheduledTaskFinished' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ScheduledTaskFinished.php',
    'Illuminate\\Console\\Events\\ScheduledTaskSkipped' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ScheduledTaskSkipped.php',
    'Illuminate\\Console\\Events\\ScheduledTaskStarting' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Events/ScheduledTaskStarting.php',
    'Illuminate\\Console\\GeneratorCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/GeneratorCommand.php',
    'Illuminate\\Console\\ManuallyFailedException' => $vendorDir . '/laravel/framework/src/Illuminate/Console/ManuallyFailedException.php',
    'Illuminate\\Console\\MigrationGeneratorCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/MigrationGeneratorCommand.php',
    'Illuminate\\Console\\OutputStyle' => $vendorDir . '/laravel/framework/src/Illuminate/Console/OutputStyle.php',
    'Illuminate\\Console\\Parser' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Parser.php',
    'Illuminate\\Console\\Prohibitable' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Prohibitable.php',
    'Illuminate\\Console\\PromptValidationException' => $vendorDir . '/laravel/framework/src/Illuminate/Console/PromptValidationException.php',
    'Illuminate\\Console\\QuestionHelper' => $vendorDir . '/laravel/framework/src/Illuminate/Console/QuestionHelper.php',
    'Illuminate\\Console\\Scheduling\\CacheAware' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/CacheAware.php',
    'Illuminate\\Console\\Scheduling\\CacheEventMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/CacheEventMutex.php',
    'Illuminate\\Console\\Scheduling\\CacheSchedulingMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/CacheSchedulingMutex.php',
    'Illuminate\\Console\\Scheduling\\CallbackEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/CallbackEvent.php',
    'Illuminate\\Console\\Scheduling\\CommandBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/CommandBuilder.php',
    'Illuminate\\Console\\Scheduling\\Event' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/Event.php',
    'Illuminate\\Console\\Scheduling\\EventMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/EventMutex.php',
    'Illuminate\\Console\\Scheduling\\ManagesFrequencies' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ManagesFrequencies.php',
    'Illuminate\\Console\\Scheduling\\Schedule' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/Schedule.php',
    'Illuminate\\Console\\Scheduling\\ScheduleClearCacheCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleClearCacheCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleFinishCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleFinishCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleInterruptCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleInterruptCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleListCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleListCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleRunCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleRunCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleTestCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleTestCommand.php',
    'Illuminate\\Console\\Scheduling\\ScheduleWorkCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/ScheduleWorkCommand.php',
    'Illuminate\\Console\\Scheduling\\SchedulingMutex' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Scheduling/SchedulingMutex.php',
    'Illuminate\\Console\\Signals' => $vendorDir . '/laravel/framework/src/Illuminate/Console/Signals.php',
    'Illuminate\\Console\\View\\Components\\Alert' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Alert.php',
    'Illuminate\\Console\\View\\Components\\Ask' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Ask.php',
    'Illuminate\\Console\\View\\Components\\AskWithCompletion' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/AskWithCompletion.php',
    'Illuminate\\Console\\View\\Components\\BulletList' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/BulletList.php',
    'Illuminate\\Console\\View\\Components\\Choice' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Choice.php',
    'Illuminate\\Console\\View\\Components\\Component' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Component.php',
    'Illuminate\\Console\\View\\Components\\Confirm' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Confirm.php',
    'Illuminate\\Console\\View\\Components\\Error' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Error.php',
    'Illuminate\\Console\\View\\Components\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Factory.php',
    'Illuminate\\Console\\View\\Components\\Info' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Info.php',
    'Illuminate\\Console\\View\\Components\\Line' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Line.php',
    'Illuminate\\Console\\View\\Components\\Mutators\\EnsureDynamicContentIsHighlighted' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Mutators/EnsureDynamicContentIsHighlighted.php',
    'Illuminate\\Console\\View\\Components\\Mutators\\EnsureNoPunctuation' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Mutators/EnsureNoPunctuation.php',
    'Illuminate\\Console\\View\\Components\\Mutators\\EnsurePunctuation' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Mutators/EnsurePunctuation.php',
    'Illuminate\\Console\\View\\Components\\Mutators\\EnsureRelativePaths' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Mutators/EnsureRelativePaths.php',
    'Illuminate\\Console\\View\\Components\\Secret' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Secret.php',
    'Illuminate\\Console\\View\\Components\\Success' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Success.php',
    'Illuminate\\Console\\View\\Components\\Task' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Task.php',
    'Illuminate\\Console\\View\\Components\\TwoColumnDetail' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/TwoColumnDetail.php',
    'Illuminate\\Console\\View\\Components\\Warn' => $vendorDir . '/laravel/framework/src/Illuminate/Console/View/Components/Warn.php',
    'Illuminate\\Container\\Attributes\\Auth' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Auth.php',
    'Illuminate\\Container\\Attributes\\Authenticated' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Authenticated.php',
    'Illuminate\\Container\\Attributes\\Cache' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Cache.php',
    'Illuminate\\Container\\Attributes\\Config' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Config.php',
    'Illuminate\\Container\\Attributes\\CurrentUser' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/CurrentUser.php',
    'Illuminate\\Container\\Attributes\\DB' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/DB.php',
    'Illuminate\\Container\\Attributes\\Database' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Database.php',
    'Illuminate\\Container\\Attributes\\Log' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Log.php',
    'Illuminate\\Container\\Attributes\\Storage' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Attributes/Storage.php',
    'Illuminate\\Container\\BoundMethod' => $vendorDir . '/laravel/framework/src/Illuminate/Container/BoundMethod.php',
    'Illuminate\\Container\\Container' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Container.php',
    'Illuminate\\Container\\ContextualBindingBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Container/ContextualBindingBuilder.php',
    'Illuminate\\Container\\EntryNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Container/EntryNotFoundException.php',
    'Illuminate\\Container\\RewindableGenerator' => $vendorDir . '/laravel/framework/src/Illuminate/Container/RewindableGenerator.php',
    'Illuminate\\Container\\Util' => $vendorDir . '/laravel/framework/src/Illuminate/Container/Util.php',
    'Illuminate\\Contracts\\Auth\\Access\\Authorizable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Access/Authorizable.php',
    'Illuminate\\Contracts\\Auth\\Access\\Gate' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Access/Gate.php',
    'Illuminate\\Contracts\\Auth\\Authenticatable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Authenticatable.php',
    'Illuminate\\Contracts\\Auth\\CanResetPassword' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/CanResetPassword.php',
    'Illuminate\\Contracts\\Auth\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Factory.php',
    'Illuminate\\Contracts\\Auth\\Guard' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Guard.php',
    'Illuminate\\Contracts\\Auth\\Middleware\\AuthenticatesRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/Middleware/AuthenticatesRequests.php',
    'Illuminate\\Contracts\\Auth\\MustVerifyEmail' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/MustVerifyEmail.php',
    'Illuminate\\Contracts\\Auth\\PasswordBroker' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/PasswordBroker.php',
    'Illuminate\\Contracts\\Auth\\PasswordBrokerFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/PasswordBrokerFactory.php',
    'Illuminate\\Contracts\\Auth\\StatefulGuard' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/StatefulGuard.php',
    'Illuminate\\Contracts\\Auth\\SupportsBasicAuth' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/SupportsBasicAuth.php',
    'Illuminate\\Contracts\\Auth\\UserProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Auth/UserProvider.php',
    'Illuminate\\Contracts\\Broadcasting\\Broadcaster' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/Broadcaster.php',
    'Illuminate\\Contracts\\Broadcasting\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/Factory.php',
    'Illuminate\\Contracts\\Broadcasting\\HasBroadcastChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/HasBroadcastChannel.php',
    'Illuminate\\Contracts\\Broadcasting\\ShouldBeUnique' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/ShouldBeUnique.php',
    'Illuminate\\Contracts\\Broadcasting\\ShouldBroadcast' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/ShouldBroadcast.php',
    'Illuminate\\Contracts\\Broadcasting\\ShouldBroadcastNow' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Broadcasting/ShouldBroadcastNow.php',
    'Illuminate\\Contracts\\Bus\\Dispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Bus/Dispatcher.php',
    'Illuminate\\Contracts\\Bus\\QueueingDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Bus/QueueingDispatcher.php',
    'Illuminate\\Contracts\\Cache\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/Factory.php',
    'Illuminate\\Contracts\\Cache\\Lock' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/Lock.php',
    'Illuminate\\Contracts\\Cache\\LockProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/LockProvider.php',
    'Illuminate\\Contracts\\Cache\\LockTimeoutException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/LockTimeoutException.php',
    'Illuminate\\Contracts\\Cache\\Repository' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/Repository.php',
    'Illuminate\\Contracts\\Cache\\Store' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cache/Store.php',
    'Illuminate\\Contracts\\Config\\Repository' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Config/Repository.php',
    'Illuminate\\Contracts\\Console\\Application' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Console/Application.php',
    'Illuminate\\Contracts\\Console\\Isolatable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Console/Isolatable.php',
    'Illuminate\\Contracts\\Console\\Kernel' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Console/Kernel.php',
    'Illuminate\\Contracts\\Console\\PromptsForMissingInput' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Console/PromptsForMissingInput.php',
    'Illuminate\\Contracts\\Container\\BindingResolutionException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Container/BindingResolutionException.php',
    'Illuminate\\Contracts\\Container\\CircularDependencyException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Container/CircularDependencyException.php',
    'Illuminate\\Contracts\\Container\\Container' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Container/Container.php',
    'Illuminate\\Contracts\\Container\\ContextualAttribute' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Container/ContextualAttribute.php',
    'Illuminate\\Contracts\\Container\\ContextualBindingBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Container/ContextualBindingBuilder.php',
    'Illuminate\\Contracts\\Cookie\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cookie/Factory.php',
    'Illuminate\\Contracts\\Cookie\\QueueingFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Cookie/QueueingFactory.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\Builder' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/Builder.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\Castable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/Castable.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\CastsAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/CastsAttributes.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\CastsInboundAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/CastsInboundAttributes.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\DeviatesCastableAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/DeviatesCastableAttributes.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\SerializesCastableAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/SerializesCastableAttributes.php',
    'Illuminate\\Contracts\\Database\\Eloquent\\SupportsPartialRelations' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Eloquent/SupportsPartialRelations.php',
    'Illuminate\\Contracts\\Database\\Events\\MigrationEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Events/MigrationEvent.php',
    'Illuminate\\Contracts\\Database\\ModelIdentifier' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/ModelIdentifier.php',
    'Illuminate\\Contracts\\Database\\Query\\Builder' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Query/Builder.php',
    'Illuminate\\Contracts\\Database\\Query\\ConditionExpression' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Query/ConditionExpression.php',
    'Illuminate\\Contracts\\Database\\Query\\Expression' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Database/Query/Expression.php',
    'Illuminate\\Contracts\\Debug\\ExceptionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Debug/ExceptionHandler.php',
    'Illuminate\\Contracts\\Debug\\ShouldntReport' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Debug/ShouldntReport.php',
    'Illuminate\\Contracts\\Encryption\\DecryptException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Encryption/DecryptException.php',
    'Illuminate\\Contracts\\Encryption\\EncryptException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Encryption/EncryptException.php',
    'Illuminate\\Contracts\\Encryption\\Encrypter' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Encryption/Encrypter.php',
    'Illuminate\\Contracts\\Encryption\\StringEncrypter' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Encryption/StringEncrypter.php',
    'Illuminate\\Contracts\\Events\\Dispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Events/Dispatcher.php',
    'Illuminate\\Contracts\\Events\\ShouldDispatchAfterCommit' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Events/ShouldDispatchAfterCommit.php',
    'Illuminate\\Contracts\\Events\\ShouldHandleEventsAfterCommit' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Events/ShouldHandleEventsAfterCommit.php',
    'Illuminate\\Contracts\\Filesystem\\Cloud' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Filesystem/Cloud.php',
    'Illuminate\\Contracts\\Filesystem\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Filesystem/Factory.php',
    'Illuminate\\Contracts\\Filesystem\\FileNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Filesystem/FileNotFoundException.php',
    'Illuminate\\Contracts\\Filesystem\\Filesystem' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Filesystem/Filesystem.php',
    'Illuminate\\Contracts\\Filesystem\\LockTimeoutException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Filesystem/LockTimeoutException.php',
    'Illuminate\\Contracts\\Foundation\\Application' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Foundation/Application.php',
    'Illuminate\\Contracts\\Foundation\\CachesConfiguration' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Foundation/CachesConfiguration.php',
    'Illuminate\\Contracts\\Foundation\\CachesRoutes' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Foundation/CachesRoutes.php',
    'Illuminate\\Contracts\\Foundation\\ExceptionRenderer' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Foundation/ExceptionRenderer.php',
    'Illuminate\\Contracts\\Foundation\\MaintenanceMode' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Foundation/MaintenanceMode.php',
    'Illuminate\\Contracts\\Hashing\\Hasher' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Hashing/Hasher.php',
    'Illuminate\\Contracts\\Http\\Kernel' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Http/Kernel.php',
    'Illuminate\\Contracts\\Mail\\Attachable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Mail/Attachable.php',
    'Illuminate\\Contracts\\Mail\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Mail/Factory.php',
    'Illuminate\\Contracts\\Mail\\MailQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Mail/MailQueue.php',
    'Illuminate\\Contracts\\Mail\\Mailable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Mail/Mailable.php',
    'Illuminate\\Contracts\\Mail\\Mailer' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Mail/Mailer.php',
    'Illuminate\\Contracts\\Notifications\\Dispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Notifications/Dispatcher.php',
    'Illuminate\\Contracts\\Notifications\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Notifications/Factory.php',
    'Illuminate\\Contracts\\Pagination\\CursorPaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Pagination/CursorPaginator.php',
    'Illuminate\\Contracts\\Pagination\\LengthAwarePaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Pagination/LengthAwarePaginator.php',
    'Illuminate\\Contracts\\Pagination\\Paginator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Pagination/Paginator.php',
    'Illuminate\\Contracts\\Pipeline\\Hub' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Pipeline/Hub.php',
    'Illuminate\\Contracts\\Pipeline\\Pipeline' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Pipeline/Pipeline.php',
    'Illuminate\\Contracts\\Process\\InvokedProcess' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Process/InvokedProcess.php',
    'Illuminate\\Contracts\\Process\\ProcessResult' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Process/ProcessResult.php',
    'Illuminate\\Contracts\\Queue\\ClearableQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ClearableQueue.php',
    'Illuminate\\Contracts\\Queue\\EntityNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/EntityNotFoundException.php',
    'Illuminate\\Contracts\\Queue\\EntityResolver' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/EntityResolver.php',
    'Illuminate\\Contracts\\Queue\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/Factory.php',
    'Illuminate\\Contracts\\Queue\\Job' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/Job.php',
    'Illuminate\\Contracts\\Queue\\Monitor' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/Monitor.php',
    'Illuminate\\Contracts\\Queue\\Queue' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/Queue.php',
    'Illuminate\\Contracts\\Queue\\QueueableCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/QueueableCollection.php',
    'Illuminate\\Contracts\\Queue\\QueueableEntity' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/QueueableEntity.php',
    'Illuminate\\Contracts\\Queue\\ShouldBeEncrypted' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ShouldBeEncrypted.php',
    'Illuminate\\Contracts\\Queue\\ShouldBeUnique' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ShouldBeUnique.php',
    'Illuminate\\Contracts\\Queue\\ShouldBeUniqueUntilProcessing' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ShouldBeUniqueUntilProcessing.php',
    'Illuminate\\Contracts\\Queue\\ShouldQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ShouldQueue.php',
    'Illuminate\\Contracts\\Queue\\ShouldQueueAfterCommit' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Queue/ShouldQueueAfterCommit.php',
    'Illuminate\\Contracts\\Redis\\Connection' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Redis/Connection.php',
    'Illuminate\\Contracts\\Redis\\Connector' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Redis/Connector.php',
    'Illuminate\\Contracts\\Redis\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Redis/Factory.php',
    'Illuminate\\Contracts\\Redis\\LimiterTimeoutException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Redis/LimiterTimeoutException.php',
    'Illuminate\\Contracts\\Routing\\BindingRegistrar' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Routing/BindingRegistrar.php',
    'Illuminate\\Contracts\\Routing\\Registrar' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Routing/Registrar.php',
    'Illuminate\\Contracts\\Routing\\ResponseFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Routing/ResponseFactory.php',
    'Illuminate\\Contracts\\Routing\\UrlGenerator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Routing/UrlGenerator.php',
    'Illuminate\\Contracts\\Routing\\UrlRoutable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Routing/UrlRoutable.php',
    'Illuminate\\Contracts\\Session\\Middleware\\AuthenticatesSessions' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Session/Middleware/AuthenticatesSessions.php',
    'Illuminate\\Contracts\\Session\\Session' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Session/Session.php',
    'Illuminate\\Contracts\\Support\\Arrayable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/Arrayable.php',
    'Illuminate\\Contracts\\Support\\CanBeEscapedWhenCastToString' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/CanBeEscapedWhenCastToString.php',
    'Illuminate\\Contracts\\Support\\DeferrableProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/DeferrableProvider.php',
    'Illuminate\\Contracts\\Support\\DeferringDisplayableValue' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/DeferringDisplayableValue.php',
    'Illuminate\\Contracts\\Support\\Htmlable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/Htmlable.php',
    'Illuminate\\Contracts\\Support\\Jsonable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/Jsonable.php',
    'Illuminate\\Contracts\\Support\\MessageBag' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/MessageBag.php',
    'Illuminate\\Contracts\\Support\\MessageProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/MessageProvider.php',
    'Illuminate\\Contracts\\Support\\Renderable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/Renderable.php',
    'Illuminate\\Contracts\\Support\\Responsable' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/Responsable.php',
    'Illuminate\\Contracts\\Support\\ValidatedData' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Support/ValidatedData.php',
    'Illuminate\\Contracts\\Translation\\HasLocalePreference' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Translation/HasLocalePreference.php',
    'Illuminate\\Contracts\\Translation\\Loader' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Translation/Loader.php',
    'Illuminate\\Contracts\\Translation\\Translator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Translation/Translator.php',
    'Illuminate\\Contracts\\Validation\\DataAwareRule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/DataAwareRule.php',
    'Illuminate\\Contracts\\Validation\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/Factory.php',
    'Illuminate\\Contracts\\Validation\\ImplicitRule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/ImplicitRule.php',
    'Illuminate\\Contracts\\Validation\\InvokableRule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/InvokableRule.php',
    'Illuminate\\Contracts\\Validation\\Rule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/Rule.php',
    'Illuminate\\Contracts\\Validation\\UncompromisedVerifier' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/UncompromisedVerifier.php',
    'Illuminate\\Contracts\\Validation\\ValidatesWhenResolved' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/ValidatesWhenResolved.php',
    'Illuminate\\Contracts\\Validation\\ValidationRule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/ValidationRule.php',
    'Illuminate\\Contracts\\Validation\\Validator' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/Validator.php',
    'Illuminate\\Contracts\\Validation\\ValidatorAwareRule' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/Validation/ValidatorAwareRule.php',
    'Illuminate\\Contracts\\View\\Engine' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/View/Engine.php',
    'Illuminate\\Contracts\\View\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/View/Factory.php',
    'Illuminate\\Contracts\\View\\View' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/View/View.php',
    'Illuminate\\Contracts\\View\\ViewCompilationException' => $vendorDir . '/laravel/framework/src/Illuminate/Contracts/View/ViewCompilationException.php',
    'Illuminate\\Cookie\\CookieJar' => $vendorDir . '/laravel/framework/src/Illuminate/Cookie/CookieJar.php',
    'Illuminate\\Cookie\\CookieServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Cookie/CookieServiceProvider.php',
    'Illuminate\\Cookie\\CookieValuePrefix' => $vendorDir . '/laravel/framework/src/Illuminate/Cookie/CookieValuePrefix.php',
    'Illuminate\\Cookie\\Middleware\\AddQueuedCookiesToResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Cookie/Middleware/AddQueuedCookiesToResponse.php',
    'Illuminate\\Cookie\\Middleware\\EncryptCookies' => $vendorDir . '/laravel/framework/src/Illuminate/Cookie/Middleware/EncryptCookies.php',
    'Illuminate\\Database\\Capsule\\Manager' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Capsule/Manager.php',
    'Illuminate\\Database\\ClassMorphViolationException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/ClassMorphViolationException.php',
    'Illuminate\\Database\\Concerns\\BuildsQueries' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Concerns/BuildsQueries.php',
    'Illuminate\\Database\\Concerns\\CompilesJsonPaths' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Concerns/CompilesJsonPaths.php',
    'Illuminate\\Database\\Concerns\\ExplainsQueries' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Concerns/ExplainsQueries.php',
    'Illuminate\\Database\\Concerns\\ManagesTransactions' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Concerns/ManagesTransactions.php',
    'Illuminate\\Database\\Concerns\\ParsesSearchPath' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Concerns/ParsesSearchPath.php',
    'Illuminate\\Database\\ConfigurationUrlParser' => $vendorDir . '/laravel/framework/src/Illuminate/Database/ConfigurationUrlParser.php',
    'Illuminate\\Database\\Connection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connection.php',
    'Illuminate\\Database\\ConnectionInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Database/ConnectionInterface.php',
    'Illuminate\\Database\\ConnectionResolver' => $vendorDir . '/laravel/framework/src/Illuminate/Database/ConnectionResolver.php',
    'Illuminate\\Database\\ConnectionResolverInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Database/ConnectionResolverInterface.php',
    'Illuminate\\Database\\Connectors\\ConnectionFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/ConnectionFactory.php',
    'Illuminate\\Database\\Connectors\\Connector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/Connector.php',
    'Illuminate\\Database\\Connectors\\ConnectorInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/ConnectorInterface.php',
    'Illuminate\\Database\\Connectors\\MariaDbConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/MariaDbConnector.php',
    'Illuminate\\Database\\Connectors\\MySqlConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/MySqlConnector.php',
    'Illuminate\\Database\\Connectors\\PostgresConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/PostgresConnector.php',
    'Illuminate\\Database\\Connectors\\SQLiteConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/SQLiteConnector.php',
    'Illuminate\\Database\\Connectors\\SqlServerConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Connectors/SqlServerConnector.php',
    'Illuminate\\Database\\Console\\DatabaseInspectionCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/DatabaseInspectionCommand.php',
    'Illuminate\\Database\\Console\\DbCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/DbCommand.php',
    'Illuminate\\Database\\Console\\DumpCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/DumpCommand.php',
    'Illuminate\\Database\\Console\\Factories\\FactoryMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Factories/FactoryMakeCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\BaseCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/BaseCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\FreshCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/FreshCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\InstallCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/InstallCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\MigrateCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/MigrateCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\MigrateMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/MigrateMakeCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\RefreshCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/RefreshCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\ResetCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/ResetCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\RollbackCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/RollbackCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\StatusCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/StatusCommand.php',
    'Illuminate\\Database\\Console\\Migrations\\TableGuesser' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Migrations/TableGuesser.php',
    'Illuminate\\Database\\Console\\MonitorCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/MonitorCommand.php',
    'Illuminate\\Database\\Console\\PruneCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/PruneCommand.php',
    'Illuminate\\Database\\Console\\Seeds\\SeedCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Seeds/SeedCommand.php',
    'Illuminate\\Database\\Console\\Seeds\\SeederMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Seeds/SeederMakeCommand.php',
    'Illuminate\\Database\\Console\\Seeds\\WithoutModelEvents' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/Seeds/WithoutModelEvents.php',
    'Illuminate\\Database\\Console\\ShowCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/ShowCommand.php',
    'Illuminate\\Database\\Console\\ShowModelCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/ShowModelCommand.php',
    'Illuminate\\Database\\Console\\TableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/TableCommand.php',
    'Illuminate\\Database\\Console\\WipeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Console/WipeCommand.php',
    'Illuminate\\Database\\DatabaseManager' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DatabaseManager.php',
    'Illuminate\\Database\\DatabaseServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DatabaseServiceProvider.php',
    'Illuminate\\Database\\DatabaseTransactionRecord' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DatabaseTransactionRecord.php',
    'Illuminate\\Database\\DatabaseTransactionsManager' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DatabaseTransactionsManager.php',
    'Illuminate\\Database\\DeadlockException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DeadlockException.php',
    'Illuminate\\Database\\DetectsConcurrencyErrors' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DetectsConcurrencyErrors.php',
    'Illuminate\\Database\\DetectsLostConnections' => $vendorDir . '/laravel/framework/src/Illuminate/Database/DetectsLostConnections.php',
    'Illuminate\\Database\\Eloquent\\Attributes\\ObservedBy' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Attributes/ObservedBy.php',
    'Illuminate\\Database\\Eloquent\\Attributes\\ScopedBy' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Attributes/ScopedBy.php',
    'Illuminate\\Database\\Eloquent\\BroadcastableModelEventOccurred' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/BroadcastableModelEventOccurred.php',
    'Illuminate\\Database\\Eloquent\\BroadcastsEvents' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/BroadcastsEvents.php',
    'Illuminate\\Database\\Eloquent\\BroadcastsEventsAfterCommit' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/BroadcastsEventsAfterCommit.php',
    'Illuminate\\Database\\Eloquent\\Builder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Builder.php',
    'Illuminate\\Database\\Eloquent\\Casts\\ArrayObject' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/ArrayObject.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsArrayObject' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsArrayObject.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsCollection.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsEncryptedArrayObject' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsEncryptedArrayObject.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsEncryptedCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsEncryptedCollection.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsEnumArrayObject' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsEnumArrayObject.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsEnumCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsEnumCollection.php',
    'Illuminate\\Database\\Eloquent\\Casts\\AsStringable' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/AsStringable.php',
    'Illuminate\\Database\\Eloquent\\Casts\\Attribute' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/Attribute.php',
    'Illuminate\\Database\\Eloquent\\Casts\\Json' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Casts/Json.php',
    'Illuminate\\Database\\Eloquent\\Collection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Collection.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\GuardsAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/GuardsAttributes.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasAttributes.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasEvents' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasEvents.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasGlobalScopes' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasGlobalScopes.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasRelationships' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasRelationships.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasTimestamps' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasTimestamps.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasUlids' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasUlids.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasUniqueIds' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasUniqueIds.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasUuids' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasUuids.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HasVersion7Uuids' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HasVersion7Uuids.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\HidesAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/HidesAttributes.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\PreventsCircularRecursion' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/PreventsCircularRecursion.php',
    'Illuminate\\Database\\Eloquent\\Concerns\\QueriesRelationships' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Concerns/QueriesRelationships.php',
    'Illuminate\\Database\\Eloquent\\Factories\\BelongsToManyRelationship' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/BelongsToManyRelationship.php',
    'Illuminate\\Database\\Eloquent\\Factories\\BelongsToRelationship' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/BelongsToRelationship.php',
    'Illuminate\\Database\\Eloquent\\Factories\\CrossJoinSequence' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/CrossJoinSequence.php',
    'Illuminate\\Database\\Eloquent\\Factories\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/Factory.php',
    'Illuminate\\Database\\Eloquent\\Factories\\HasFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/HasFactory.php',
    'Illuminate\\Database\\Eloquent\\Factories\\Relationship' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/Relationship.php',
    'Illuminate\\Database\\Eloquent\\Factories\\Sequence' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Factories/Sequence.php',
    'Illuminate\\Database\\Eloquent\\HasBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/HasBuilder.php',
    'Illuminate\\Database\\Eloquent\\HasCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/HasCollection.php',
    'Illuminate\\Database\\Eloquent\\HigherOrderBuilderProxy' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/HigherOrderBuilderProxy.php',
    'Illuminate\\Database\\Eloquent\\InvalidCastException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/InvalidCastException.php',
    'Illuminate\\Database\\Eloquent\\JsonEncodingException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/JsonEncodingException.php',
    'Illuminate\\Database\\Eloquent\\MassAssignmentException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/MassAssignmentException.php',
    'Illuminate\\Database\\Eloquent\\MassPrunable' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/MassPrunable.php',
    'Illuminate\\Database\\Eloquent\\MissingAttributeException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/MissingAttributeException.php',
    'Illuminate\\Database\\Eloquent\\Model' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Model.php',
    'Illuminate\\Database\\Eloquent\\ModelNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/ModelNotFoundException.php',
    'Illuminate\\Database\\Eloquent\\PendingHasThroughRelationship' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/PendingHasThroughRelationship.php',
    'Illuminate\\Database\\Eloquent\\Prunable' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Prunable.php',
    'Illuminate\\Database\\Eloquent\\QueueEntityResolver' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/QueueEntityResolver.php',
    'Illuminate\\Database\\Eloquent\\RelationNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/RelationNotFoundException.php',
    'Illuminate\\Database\\Eloquent\\Relations\\BelongsTo' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/BelongsTo.php',
    'Illuminate\\Database\\Eloquent\\Relations\\BelongsToMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/BelongsToMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\AsPivot' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/AsPivot.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\CanBeOneOfMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/CanBeOneOfMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\ComparesRelatedModels' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/ComparesRelatedModels.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\InteractsWithDictionary' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/InteractsWithDictionary.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\InteractsWithPivotTable' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/InteractsWithPivotTable.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\SupportsDefaultModels' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/SupportsDefaultModels.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Concerns\\SupportsInverseRelations' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Concerns/SupportsInverseRelations.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasManyThrough' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasManyThrough.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasOne' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasOne.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasOneOrMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasOneOrMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasOneOrManyThrough' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasOneOrManyThrough.php',
    'Illuminate\\Database\\Eloquent\\Relations\\HasOneThrough' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/HasOneThrough.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphOne' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphOne.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphOneOrMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphOneOrMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphPivot' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphPivot.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphTo' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphTo.php',
    'Illuminate\\Database\\Eloquent\\Relations\\MorphToMany' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/MorphToMany.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Pivot' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Pivot.php',
    'Illuminate\\Database\\Eloquent\\Relations\\Relation' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Relations/Relation.php',
    'Illuminate\\Database\\Eloquent\\Scope' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/Scope.php',
    'Illuminate\\Database\\Eloquent\\SoftDeletes' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/SoftDeletes.php',
    'Illuminate\\Database\\Eloquent\\SoftDeletingScope' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Eloquent/SoftDeletingScope.php',
    'Illuminate\\Database\\Events\\ConnectionEstablished' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/ConnectionEstablished.php',
    'Illuminate\\Database\\Events\\ConnectionEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/ConnectionEvent.php',
    'Illuminate\\Database\\Events\\DatabaseBusy' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/DatabaseBusy.php',
    'Illuminate\\Database\\Events\\DatabaseRefreshed' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/DatabaseRefreshed.php',
    'Illuminate\\Database\\Events\\MigrationEnded' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationEnded.php',
    'Illuminate\\Database\\Events\\MigrationEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationEvent.php',
    'Illuminate\\Database\\Events\\MigrationStarted' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationStarted.php',
    'Illuminate\\Database\\Events\\MigrationsEnded' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationsEnded.php',
    'Illuminate\\Database\\Events\\MigrationsEvent' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationsEvent.php',
    'Illuminate\\Database\\Events\\MigrationsStarted' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/MigrationsStarted.php',
    'Illuminate\\Database\\Events\\ModelPruningFinished' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/ModelPruningFinished.php',
    'Illuminate\\Database\\Events\\ModelPruningStarting' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/ModelPruningStarting.php',
    'Illuminate\\Database\\Events\\ModelsPruned' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/ModelsPruned.php',
    'Illuminate\\Database\\Events\\NoPendingMigrations' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/NoPendingMigrations.php',
    'Illuminate\\Database\\Events\\QueryExecuted' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/QueryExecuted.php',
    'Illuminate\\Database\\Events\\SchemaDumped' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/SchemaDumped.php',
    'Illuminate\\Database\\Events\\SchemaLoaded' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/SchemaLoaded.php',
    'Illuminate\\Database\\Events\\StatementPrepared' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/StatementPrepared.php',
    'Illuminate\\Database\\Events\\TransactionBeginning' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/TransactionBeginning.php',
    'Illuminate\\Database\\Events\\TransactionCommitted' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/TransactionCommitted.php',
    'Illuminate\\Database\\Events\\TransactionCommitting' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/TransactionCommitting.php',
    'Illuminate\\Database\\Events\\TransactionRolledBack' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Events/TransactionRolledBack.php',
    'Illuminate\\Database\\Grammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Grammar.php',
    'Illuminate\\Database\\LazyLoadingViolationException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/LazyLoadingViolationException.php',
    'Illuminate\\Database\\LostConnectionException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/LostConnectionException.php',
    'Illuminate\\Database\\MariaDbConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/MariaDbConnection.php',
    'Illuminate\\Database\\MigrationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Database/MigrationServiceProvider.php',
    'Illuminate\\Database\\Migrations\\DatabaseMigrationRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Migrations/DatabaseMigrationRepository.php',
    'Illuminate\\Database\\Migrations\\Migration' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Migrations/Migration.php',
    'Illuminate\\Database\\Migrations\\MigrationCreator' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Migrations/MigrationCreator.php',
    'Illuminate\\Database\\Migrations\\MigrationRepositoryInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Migrations/MigrationRepositoryInterface.php',
    'Illuminate\\Database\\Migrations\\Migrator' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Migrations/Migrator.php',
    'Illuminate\\Database\\MultipleColumnsSelectedException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/MultipleColumnsSelectedException.php',
    'Illuminate\\Database\\MultipleRecordsFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/MultipleRecordsFoundException.php',
    'Illuminate\\Database\\MySqlConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/MySqlConnection.php',
    'Illuminate\\Database\\PostgresConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/PostgresConnection.php',
    'Illuminate\\Database\\QueryException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/QueryException.php',
    'Illuminate\\Database\\Query\\Builder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Builder.php',
    'Illuminate\\Database\\Query\\Expression' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Expression.php',
    'Illuminate\\Database\\Query\\Grammars\\Grammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/Grammar.php',
    'Illuminate\\Database\\Query\\Grammars\\MariaDbGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/MariaDbGrammar.php',
    'Illuminate\\Database\\Query\\Grammars\\MySqlGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/MySqlGrammar.php',
    'Illuminate\\Database\\Query\\Grammars\\PostgresGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/PostgresGrammar.php',
    'Illuminate\\Database\\Query\\Grammars\\SQLiteGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/SQLiteGrammar.php',
    'Illuminate\\Database\\Query\\Grammars\\SqlServerGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Grammars/SqlServerGrammar.php',
    'Illuminate\\Database\\Query\\IndexHint' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/IndexHint.php',
    'Illuminate\\Database\\Query\\JoinClause' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/JoinClause.php',
    'Illuminate\\Database\\Query\\JoinLateralClause' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/JoinLateralClause.php',
    'Illuminate\\Database\\Query\\Processors\\MariaDbProcessor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/MariaDbProcessor.php',
    'Illuminate\\Database\\Query\\Processors\\MySqlProcessor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/MySqlProcessor.php',
    'Illuminate\\Database\\Query\\Processors\\PostgresProcessor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/PostgresProcessor.php',
    'Illuminate\\Database\\Query\\Processors\\Processor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/Processor.php',
    'Illuminate\\Database\\Query\\Processors\\SQLiteProcessor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/SQLiteProcessor.php',
    'Illuminate\\Database\\Query\\Processors\\SqlServerProcessor' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Query/Processors/SqlServerProcessor.php',
    'Illuminate\\Database\\RecordsNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/RecordsNotFoundException.php',
    'Illuminate\\Database\\SQLiteConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/SQLiteConnection.php',
    'Illuminate\\Database\\SQLiteDatabaseDoesNotExistException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/SQLiteDatabaseDoesNotExistException.php',
    'Illuminate\\Database\\Schema\\Blueprint' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Blueprint.php',
    'Illuminate\\Database\\Schema\\BlueprintState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/BlueprintState.php',
    'Illuminate\\Database\\Schema\\Builder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Builder.php',
    'Illuminate\\Database\\Schema\\ColumnDefinition' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/ColumnDefinition.php',
    'Illuminate\\Database\\Schema\\ForeignIdColumnDefinition' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/ForeignIdColumnDefinition.php',
    'Illuminate\\Database\\Schema\\ForeignKeyDefinition' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/ForeignKeyDefinition.php',
    'Illuminate\\Database\\Schema\\Grammars\\Grammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/Grammar.php',
    'Illuminate\\Database\\Schema\\Grammars\\MariaDbGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/MariaDbGrammar.php',
    'Illuminate\\Database\\Schema\\Grammars\\MySqlGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/MySqlGrammar.php',
    'Illuminate\\Database\\Schema\\Grammars\\PostgresGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/PostgresGrammar.php',
    'Illuminate\\Database\\Schema\\Grammars\\SQLiteGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/SQLiteGrammar.php',
    'Illuminate\\Database\\Schema\\Grammars\\SqlServerGrammar' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/Grammars/SqlServerGrammar.php',
    'Illuminate\\Database\\Schema\\IndexDefinition' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/IndexDefinition.php',
    'Illuminate\\Database\\Schema\\MariaDbBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/MariaDbBuilder.php',
    'Illuminate\\Database\\Schema\\MariaDbSchemaState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/MariaDbSchemaState.php',
    'Illuminate\\Database\\Schema\\MySqlBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/MySqlBuilder.php',
    'Illuminate\\Database\\Schema\\MySqlSchemaState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/MySqlSchemaState.php',
    'Illuminate\\Database\\Schema\\PostgresBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/PostgresBuilder.php',
    'Illuminate\\Database\\Schema\\PostgresSchemaState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/PostgresSchemaState.php',
    'Illuminate\\Database\\Schema\\SQLiteBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/SQLiteBuilder.php',
    'Illuminate\\Database\\Schema\\SchemaState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/SchemaState.php',
    'Illuminate\\Database\\Schema\\SqlServerBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/SqlServerBuilder.php',
    'Illuminate\\Database\\Schema\\SqliteSchemaState' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Schema/SqliteSchemaState.php',
    'Illuminate\\Database\\Seeder' => $vendorDir . '/laravel/framework/src/Illuminate/Database/Seeder.php',
    'Illuminate\\Database\\SqlServerConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Database/SqlServerConnection.php',
    'Illuminate\\Database\\UniqueConstraintViolationException' => $vendorDir . '/laravel/framework/src/Illuminate/Database/UniqueConstraintViolationException.php',
    'Illuminate\\Encryption\\Encrypter' => $vendorDir . '/laravel/framework/src/Illuminate/Encryption/Encrypter.php',
    'Illuminate\\Encryption\\EncryptionServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Encryption/EncryptionServiceProvider.php',
    'Illuminate\\Encryption\\MissingAppKeyException' => $vendorDir . '/laravel/framework/src/Illuminate/Encryption/MissingAppKeyException.php',
    'Illuminate\\Events\\CallQueuedListener' => $vendorDir . '/laravel/framework/src/Illuminate/Events/CallQueuedListener.php',
    'Illuminate\\Events\\Dispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Events/Dispatcher.php',
    'Illuminate\\Events\\EventServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Events/EventServiceProvider.php',
    'Illuminate\\Events\\InvokeQueuedClosure' => $vendorDir . '/laravel/framework/src/Illuminate/Events/InvokeQueuedClosure.php',
    'Illuminate\\Events\\NullDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Events/NullDispatcher.php',
    'Illuminate\\Events\\QueuedClosure' => $vendorDir . '/laravel/framework/src/Illuminate/Events/QueuedClosure.php',
    'Illuminate\\Filesystem\\AwsS3V3Adapter' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/AwsS3V3Adapter.php',
    'Illuminate\\Filesystem\\Filesystem' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/Filesystem.php',
    'Illuminate\\Filesystem\\FilesystemAdapter' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/FilesystemAdapter.php',
    'Illuminate\\Filesystem\\FilesystemManager' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/FilesystemManager.php',
    'Illuminate\\Filesystem\\FilesystemServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/FilesystemServiceProvider.php',
    'Illuminate\\Filesystem\\LockableFile' => $vendorDir . '/laravel/framework/src/Illuminate/Filesystem/LockableFile.php',
    'Illuminate\\Foundation\\AliasLoader' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/AliasLoader.php',
    'Illuminate\\Foundation\\Application' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Application.php',
    'Illuminate\\Foundation\\Auth\\Access\\Authorizable' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Auth/Access/Authorizable.php',
    'Illuminate\\Foundation\\Auth\\Access\\AuthorizesRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Auth/Access/AuthorizesRequests.php',
    'Illuminate\\Foundation\\Auth\\EmailVerificationRequest' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Auth/EmailVerificationRequest.php',
    'Illuminate\\Foundation\\Auth\\User' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Auth/User.php',
    'Illuminate\\Foundation\\Bootstrap\\BootProviders' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/BootProviders.php',
    'Illuminate\\Foundation\\Bootstrap\\HandleExceptions' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/HandleExceptions.php',
    'Illuminate\\Foundation\\Bootstrap\\LoadConfiguration' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/LoadConfiguration.php',
    'Illuminate\\Foundation\\Bootstrap\\LoadEnvironmentVariables' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/LoadEnvironmentVariables.php',
    'Illuminate\\Foundation\\Bootstrap\\RegisterFacades' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/RegisterFacades.php',
    'Illuminate\\Foundation\\Bootstrap\\RegisterProviders' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/RegisterProviders.php',
    'Illuminate\\Foundation\\Bootstrap\\SetRequestForConsole' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bootstrap/SetRequestForConsole.php',
    'Illuminate\\Foundation\\Bus\\Dispatchable' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bus/Dispatchable.php',
    'Illuminate\\Foundation\\Bus\\DispatchesJobs' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bus/DispatchesJobs.php',
    'Illuminate\\Foundation\\Bus\\PendingChain' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bus/PendingChain.php',
    'Illuminate\\Foundation\\Bus\\PendingClosureDispatch' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bus/PendingClosureDispatch.php',
    'Illuminate\\Foundation\\Bus\\PendingDispatch' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Bus/PendingDispatch.php',
    'Illuminate\\Foundation\\CacheBasedMaintenanceMode' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/CacheBasedMaintenanceMode.php',
    'Illuminate\\Foundation\\ComposerScripts' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/ComposerScripts.php',
    'Illuminate\\Foundation\\Concerns\\ResolvesDumpSource' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Concerns/ResolvesDumpSource.php',
    'Illuminate\\Foundation\\Configuration\\ApplicationBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Configuration/ApplicationBuilder.php',
    'Illuminate\\Foundation\\Configuration\\Exceptions' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Configuration/Exceptions.php',
    'Illuminate\\Foundation\\Configuration\\Middleware' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Configuration/Middleware.php',
    'Illuminate\\Foundation\\Console\\AboutCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/AboutCommand.php',
    'Illuminate\\Foundation\\Console\\ApiInstallCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ApiInstallCommand.php',
    'Illuminate\\Foundation\\Console\\BroadcastingInstallCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/BroadcastingInstallCommand.php',
    'Illuminate\\Foundation\\Console\\CastMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/CastMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ChannelListCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ChannelListCommand.php',
    'Illuminate\\Foundation\\Console\\ChannelMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ChannelMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ClassMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ClassMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ClearCompiledCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ClearCompiledCommand.php',
    'Illuminate\\Foundation\\Console\\CliDumper' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/CliDumper.php',
    'Illuminate\\Foundation\\Console\\ClosureCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ClosureCommand.php',
    'Illuminate\\Foundation\\Console\\ComponentMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ComponentMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ConfigCacheCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ConfigCacheCommand.php',
    'Illuminate\\Foundation\\Console\\ConfigClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ConfigClearCommand.php',
    'Illuminate\\Foundation\\Console\\ConfigPublishCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ConfigPublishCommand.php',
    'Illuminate\\Foundation\\Console\\ConfigShowCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ConfigShowCommand.php',
    'Illuminate\\Foundation\\Console\\ConsoleMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ConsoleMakeCommand.php',
    'Illuminate\\Foundation\\Console\\DocsCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/DocsCommand.php',
    'Illuminate\\Foundation\\Console\\DownCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/DownCommand.php',
    'Illuminate\\Foundation\\Console\\EnumMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EnumMakeCommand.php',
    'Illuminate\\Foundation\\Console\\EnvironmentCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EnvironmentCommand.php',
    'Illuminate\\Foundation\\Console\\EnvironmentDecryptCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EnvironmentDecryptCommand.php',
    'Illuminate\\Foundation\\Console\\EnvironmentEncryptCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EnvironmentEncryptCommand.php',
    'Illuminate\\Foundation\\Console\\EventCacheCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EventCacheCommand.php',
    'Illuminate\\Foundation\\Console\\EventClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EventClearCommand.php',
    'Illuminate\\Foundation\\Console\\EventGenerateCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EventGenerateCommand.php',
    'Illuminate\\Foundation\\Console\\EventListCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EventListCommand.php',
    'Illuminate\\Foundation\\Console\\EventMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/EventMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ExceptionMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ExceptionMakeCommand.php',
    'Illuminate\\Foundation\\Console\\InteractsWithComposerPackages' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/InteractsWithComposerPackages.php',
    'Illuminate\\Foundation\\Console\\InterfaceMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/InterfaceMakeCommand.php',
    'Illuminate\\Foundation\\Console\\JobMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/JobMakeCommand.php',
    'Illuminate\\Foundation\\Console\\Kernel' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/Kernel.php',
    'Illuminate\\Foundation\\Console\\KeyGenerateCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/KeyGenerateCommand.php',
    'Illuminate\\Foundation\\Console\\LangPublishCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/LangPublishCommand.php',
    'Illuminate\\Foundation\\Console\\ListenerMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ListenerMakeCommand.php',
    'Illuminate\\Foundation\\Console\\MailMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/MailMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ModelMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ModelMakeCommand.php',
    'Illuminate\\Foundation\\Console\\NotificationMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/NotificationMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ObserverMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ObserverMakeCommand.php',
    'Illuminate\\Foundation\\Console\\OptimizeClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/OptimizeClearCommand.php',
    'Illuminate\\Foundation\\Console\\OptimizeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/OptimizeCommand.php',
    'Illuminate\\Foundation\\Console\\PackageDiscoverCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/PackageDiscoverCommand.php',
    'Illuminate\\Foundation\\Console\\PolicyMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/PolicyMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ProviderMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ProviderMakeCommand.php',
    'Illuminate\\Foundation\\Console\\QueuedCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/QueuedCommand.php',
    'Illuminate\\Foundation\\Console\\RequestMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/RequestMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ResourceMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ResourceMakeCommand.php',
    'Illuminate\\Foundation\\Console\\RouteCacheCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/RouteCacheCommand.php',
    'Illuminate\\Foundation\\Console\\RouteClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/RouteClearCommand.php',
    'Illuminate\\Foundation\\Console\\RouteListCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/RouteListCommand.php',
    'Illuminate\\Foundation\\Console\\RuleMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/RuleMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ScopeMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ScopeMakeCommand.php',
    'Illuminate\\Foundation\\Console\\ServeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ServeCommand.php',
    'Illuminate\\Foundation\\Console\\StorageLinkCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/StorageLinkCommand.php',
    'Illuminate\\Foundation\\Console\\StorageUnlinkCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/StorageUnlinkCommand.php',
    'Illuminate\\Foundation\\Console\\StubPublishCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/StubPublishCommand.php',
    'Illuminate\\Foundation\\Console\\TestMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/TestMakeCommand.php',
    'Illuminate\\Foundation\\Console\\TraitMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/TraitMakeCommand.php',
    'Illuminate\\Foundation\\Console\\UpCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/UpCommand.php',
    'Illuminate\\Foundation\\Console\\VendorPublishCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/VendorPublishCommand.php',
    'Illuminate\\Foundation\\Console\\ViewCacheCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ViewCacheCommand.php',
    'Illuminate\\Foundation\\Console\\ViewClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ViewClearCommand.php',
    'Illuminate\\Foundation\\Console\\ViewMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Console/ViewMakeCommand.php',
    'Illuminate\\Foundation\\EnvironmentDetector' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/EnvironmentDetector.php',
    'Illuminate\\Foundation\\Events\\DiagnosingHealth' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/DiagnosingHealth.php',
    'Illuminate\\Foundation\\Events\\DiscoverEvents' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/DiscoverEvents.php',
    'Illuminate\\Foundation\\Events\\Dispatchable' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/Dispatchable.php',
    'Illuminate\\Foundation\\Events\\LocaleUpdated' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/LocaleUpdated.php',
    'Illuminate\\Foundation\\Events\\MaintenanceModeDisabled' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/MaintenanceModeDisabled.php',
    'Illuminate\\Foundation\\Events\\MaintenanceModeEnabled' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/MaintenanceModeEnabled.php',
    'Illuminate\\Foundation\\Events\\PublishingStubs' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/PublishingStubs.php',
    'Illuminate\\Foundation\\Events\\Terminating' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/Terminating.php',
    'Illuminate\\Foundation\\Events\\VendorTagPublished' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Events/VendorTagPublished.php',
    'Illuminate\\Foundation\\Exceptions\\Handler' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Handler.php',
    'Illuminate\\Foundation\\Exceptions\\RegisterErrorViewPaths' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/RegisterErrorViewPaths.php',
    'Illuminate\\Foundation\\Exceptions\\Renderer\\Exception' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Renderer/Exception.php',
    'Illuminate\\Foundation\\Exceptions\\Renderer\\Frame' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Renderer/Frame.php',
    'Illuminate\\Foundation\\Exceptions\\Renderer\\Listener' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Renderer/Listener.php',
    'Illuminate\\Foundation\\Exceptions\\Renderer\\Mappers\\BladeMapper' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Renderer/Mappers/BladeMapper.php',
    'Illuminate\\Foundation\\Exceptions\\Renderer\\Renderer' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Renderer/Renderer.php',
    'Illuminate\\Foundation\\Exceptions\\ReportableHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/ReportableHandler.php',
    'Illuminate\\Foundation\\Exceptions\\Whoops\\WhoopsExceptionRenderer' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Whoops/WhoopsExceptionRenderer.php',
    'Illuminate\\Foundation\\Exceptions\\Whoops\\WhoopsHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Exceptions/Whoops/WhoopsHandler.php',
    'Illuminate\\Foundation\\FileBasedMaintenanceMode' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/FileBasedMaintenanceMode.php',
    'Illuminate\\Foundation\\Http\\Events\\RequestHandled' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Events/RequestHandled.php',
    'Illuminate\\Foundation\\Http\\FormRequest' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/FormRequest.php',
    'Illuminate\\Foundation\\Http\\HtmlDumper' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/HtmlDumper.php',
    'Illuminate\\Foundation\\Http\\Kernel' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Kernel.php',
    'Illuminate\\Foundation\\Http\\MaintenanceModeBypassCookie' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/MaintenanceModeBypassCookie.php',
    'Illuminate\\Foundation\\Http\\Middleware\\CheckForMaintenanceMode' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/CheckForMaintenanceMode.php',
    'Illuminate\\Foundation\\Http\\Middleware\\Concerns\\ExcludesPaths' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/Concerns/ExcludesPaths.php',
    'Illuminate\\Foundation\\Http\\Middleware\\ConvertEmptyStringsToNull' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/ConvertEmptyStringsToNull.php',
    'Illuminate\\Foundation\\Http\\Middleware\\HandlePrecognitiveRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/HandlePrecognitiveRequests.php',
    'Illuminate\\Foundation\\Http\\Middleware\\PreventRequestsDuringMaintenance' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/PreventRequestsDuringMaintenance.php',
    'Illuminate\\Foundation\\Http\\Middleware\\TransformsRequest' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/TransformsRequest.php',
    'Illuminate\\Foundation\\Http\\Middleware\\TrimStrings' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/TrimStrings.php',
    'Illuminate\\Foundation\\Http\\Middleware\\ValidateCsrfToken' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/ValidateCsrfToken.php',
    'Illuminate\\Foundation\\Http\\Middleware\\ValidatePostSize' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/ValidatePostSize.php',
    'Illuminate\\Foundation\\Http\\Middleware\\VerifyCsrfToken' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Http/Middleware/VerifyCsrfToken.php',
    'Illuminate\\Foundation\\Inspiring' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Inspiring.php',
    'Illuminate\\Foundation\\MaintenanceModeManager' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/MaintenanceModeManager.php',
    'Illuminate\\Foundation\\Mix' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Mix.php',
    'Illuminate\\Foundation\\MixFileNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/MixFileNotFoundException.php',
    'Illuminate\\Foundation\\MixManifestNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/MixManifestNotFoundException.php',
    'Illuminate\\Foundation\\PackageManifest' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/PackageManifest.php',
    'Illuminate\\Foundation\\Precognition' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Precognition.php',
    'Illuminate\\Foundation\\ProviderRepository' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/ProviderRepository.php',
    'Illuminate\\Foundation\\Providers\\ArtisanServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Providers/ArtisanServiceProvider.php',
    'Illuminate\\Foundation\\Providers\\ComposerServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Providers/ComposerServiceProvider.php',
    'Illuminate\\Foundation\\Providers\\ConsoleSupportServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Providers/ConsoleSupportServiceProvider.php',
    'Illuminate\\Foundation\\Providers\\FormRequestServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Providers/FormRequestServiceProvider.php',
    'Illuminate\\Foundation\\Providers\\FoundationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Providers/FoundationServiceProvider.php',
    'Illuminate\\Foundation\\Queue\\Queueable' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Queue/Queueable.php',
    'Illuminate\\Foundation\\Routing\\PrecognitionCallableDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Routing/PrecognitionCallableDispatcher.php',
    'Illuminate\\Foundation\\Routing\\PrecognitionControllerDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Routing/PrecognitionControllerDispatcher.php',
    'Illuminate\\Foundation\\Support\\Providers\\AuthServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Support/Providers/AuthServiceProvider.php',
    'Illuminate\\Foundation\\Support\\Providers\\EventServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Support/Providers/EventServiceProvider.php',
    'Illuminate\\Foundation\\Support\\Providers\\RouteServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Support/Providers/RouteServiceProvider.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithAuthentication' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithAuthentication.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithConsole' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithConsole.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithContainer' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithContainer.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithDatabase.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithDeprecationHandling' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithDeprecationHandling.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithExceptionHandling' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithExceptionHandling.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithRedis' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithRedis.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithSession' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithSession.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithTestCaseLifecycle' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithTestCaseLifecycle.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithTime' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithTime.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\InteractsWithViews' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/InteractsWithViews.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\MakesHttpRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/MakesHttpRequests.php',
    'Illuminate\\Foundation\\Testing\\Concerns\\WithoutExceptionHandlingHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Concerns/WithoutExceptionHandlingHandler.php',
    'Illuminate\\Foundation\\Testing\\DatabaseMigrations' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/DatabaseMigrations.php',
    'Illuminate\\Foundation\\Testing\\DatabaseTransactions' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/DatabaseTransactions.php',
    'Illuminate\\Foundation\\Testing\\DatabaseTransactionsManager' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/DatabaseTransactionsManager.php',
    'Illuminate\\Foundation\\Testing\\DatabaseTruncation' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/DatabaseTruncation.php',
    'Illuminate\\Foundation\\Testing\\LazilyRefreshDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/LazilyRefreshDatabase.php',
    'Illuminate\\Foundation\\Testing\\RefreshDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/RefreshDatabase.php',
    'Illuminate\\Foundation\\Testing\\RefreshDatabaseState' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/RefreshDatabaseState.php',
    'Illuminate\\Foundation\\Testing\\TestCase' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/TestCase.php',
    'Illuminate\\Foundation\\Testing\\Traits\\CanConfigureMigrationCommands' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Traits/CanConfigureMigrationCommands.php',
    'Illuminate\\Foundation\\Testing\\WithConsoleEvents' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/WithConsoleEvents.php',
    'Illuminate\\Foundation\\Testing\\WithFaker' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/WithFaker.php',
    'Illuminate\\Foundation\\Testing\\WithoutMiddleware' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/WithoutMiddleware.php',
    'Illuminate\\Foundation\\Testing\\Wormhole' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Testing/Wormhole.php',
    'Illuminate\\Foundation\\Validation\\ValidatesRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Validation/ValidatesRequests.php',
    'Illuminate\\Foundation\\Vite' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/Vite.php',
    'Illuminate\\Foundation\\ViteException' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/ViteException.php',
    'Illuminate\\Foundation\\ViteManifestNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Foundation/ViteManifestNotFoundException.php',
    'Illuminate\\Hashing\\AbstractHasher' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/AbstractHasher.php',
    'Illuminate\\Hashing\\Argon2IdHasher' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/Argon2IdHasher.php',
    'Illuminate\\Hashing\\ArgonHasher' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/ArgonHasher.php',
    'Illuminate\\Hashing\\BcryptHasher' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/BcryptHasher.php',
    'Illuminate\\Hashing\\HashManager' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/HashManager.php',
    'Illuminate\\Hashing\\HashServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Hashing/HashServiceProvider.php',
    'Illuminate\\Http\\Client\\Concerns\\DeterminesStatusCode' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Concerns/DeterminesStatusCode.php',
    'Illuminate\\Http\\Client\\ConnectionException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/ConnectionException.php',
    'Illuminate\\Http\\Client\\Events\\ConnectionFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Events/ConnectionFailed.php',
    'Illuminate\\Http\\Client\\Events\\RequestSending' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Events/RequestSending.php',
    'Illuminate\\Http\\Client\\Events\\ResponseReceived' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Events/ResponseReceived.php',
    'Illuminate\\Http\\Client\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Factory.php',
    'Illuminate\\Http\\Client\\HttpClientException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/HttpClientException.php',
    'Illuminate\\Http\\Client\\PendingRequest' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/PendingRequest.php',
    'Illuminate\\Http\\Client\\Pool' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Pool.php',
    'Illuminate\\Http\\Client\\Request' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Request.php',
    'Illuminate\\Http\\Client\\RequestException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/RequestException.php',
    'Illuminate\\Http\\Client\\Response' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/Response.php',
    'Illuminate\\Http\\Client\\ResponseSequence' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Client/ResponseSequence.php',
    'Illuminate\\Http\\Concerns\\CanBePrecognitive' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Concerns/CanBePrecognitive.php',
    'Illuminate\\Http\\Concerns\\InteractsWithContentTypes' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Concerns/InteractsWithContentTypes.php',
    'Illuminate\\Http\\Concerns\\InteractsWithFlashData' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Concerns/InteractsWithFlashData.php',
    'Illuminate\\Http\\Concerns\\InteractsWithInput' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Concerns/InteractsWithInput.php',
    'Illuminate\\Http\\Exceptions\\HttpResponseException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Exceptions/HttpResponseException.php',
    'Illuminate\\Http\\Exceptions\\PostTooLargeException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Exceptions/PostTooLargeException.php',
    'Illuminate\\Http\\Exceptions\\ThrottleRequestsException' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Exceptions/ThrottleRequestsException.php',
    'Illuminate\\Http\\File' => $vendorDir . '/laravel/framework/src/Illuminate/Http/File.php',
    'Illuminate\\Http\\FileHelpers' => $vendorDir . '/laravel/framework/src/Illuminate/Http/FileHelpers.php',
    'Illuminate\\Http\\JsonResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Http/JsonResponse.php',
    'Illuminate\\Http\\Middleware\\AddLinkHeadersForPreloadedAssets' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/AddLinkHeadersForPreloadedAssets.php',
    'Illuminate\\Http\\Middleware\\CheckResponseForModifications' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/CheckResponseForModifications.php',
    'Illuminate\\Http\\Middleware\\FrameGuard' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/FrameGuard.php',
    'Illuminate\\Http\\Middleware\\HandleCors' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/HandleCors.php',
    'Illuminate\\Http\\Middleware\\SetCacheHeaders' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/SetCacheHeaders.php',
    'Illuminate\\Http\\Middleware\\TrustHosts' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/TrustHosts.php',
    'Illuminate\\Http\\Middleware\\TrustProxies' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/TrustProxies.php',
    'Illuminate\\Http\\Middleware\\ValidatePostSize' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Middleware/ValidatePostSize.php',
    'Illuminate\\Http\\RedirectResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Http/RedirectResponse.php',
    'Illuminate\\Http\\Request' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Request.php',
    'Illuminate\\Http\\Resources\\CollectsResources' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/CollectsResources.php',
    'Illuminate\\Http\\Resources\\ConditionallyLoadsAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/ConditionallyLoadsAttributes.php',
    'Illuminate\\Http\\Resources\\DelegatesToResource' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/DelegatesToResource.php',
    'Illuminate\\Http\\Resources\\Json\\AnonymousResourceCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/Json/AnonymousResourceCollection.php',
    'Illuminate\\Http\\Resources\\Json\\JsonResource' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/Json/JsonResource.php',
    'Illuminate\\Http\\Resources\\Json\\PaginatedResourceResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/Json/PaginatedResourceResponse.php',
    'Illuminate\\Http\\Resources\\Json\\ResourceCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/Json/ResourceCollection.php',
    'Illuminate\\Http\\Resources\\Json\\ResourceResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/Json/ResourceResponse.php',
    'Illuminate\\Http\\Resources\\MergeValue' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/MergeValue.php',
    'Illuminate\\Http\\Resources\\MissingValue' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/MissingValue.php',
    'Illuminate\\Http\\Resources\\PotentiallyMissing' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Resources/PotentiallyMissing.php',
    'Illuminate\\Http\\Response' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Response.php',
    'Illuminate\\Http\\ResponseTrait' => $vendorDir . '/laravel/framework/src/Illuminate/Http/ResponseTrait.php',
    'Illuminate\\Http\\Testing\\File' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Testing/File.php',
    'Illuminate\\Http\\Testing\\FileFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Testing/FileFactory.php',
    'Illuminate\\Http\\Testing\\MimeType' => $vendorDir . '/laravel/framework/src/Illuminate/Http/Testing/MimeType.php',
    'Illuminate\\Http\\UploadedFile' => $vendorDir . '/laravel/framework/src/Illuminate/Http/UploadedFile.php',
    'Illuminate\\Log\\Context\\ContextServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Context/ContextServiceProvider.php',
    'Illuminate\\Log\\Context\\Events\\ContextDehydrating' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Context/Events/ContextDehydrating.php',
    'Illuminate\\Log\\Context\\Events\\ContextHydrated' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Context/Events/ContextHydrated.php',
    'Illuminate\\Log\\Context\\Repository' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Context/Repository.php',
    'Illuminate\\Log\\Events\\MessageLogged' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Events/MessageLogged.php',
    'Illuminate\\Log\\LogManager' => $vendorDir . '/laravel/framework/src/Illuminate/Log/LogManager.php',
    'Illuminate\\Log\\LogServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Log/LogServiceProvider.php',
    'Illuminate\\Log\\Logger' => $vendorDir . '/laravel/framework/src/Illuminate/Log/Logger.php',
    'Illuminate\\Log\\ParsesLogConfiguration' => $vendorDir . '/laravel/framework/src/Illuminate/Log/ParsesLogConfiguration.php',
    'Illuminate\\Mail\\Attachment' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Attachment.php',
    'Illuminate\\Mail\\Events\\MessageSending' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Events/MessageSending.php',
    'Illuminate\\Mail\\Events\\MessageSent' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Events/MessageSent.php',
    'Illuminate\\Mail\\MailManager' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/MailManager.php',
    'Illuminate\\Mail\\MailServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/MailServiceProvider.php',
    'Illuminate\\Mail\\Mailable' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailable.php',
    'Illuminate\\Mail\\Mailables\\Address' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailables/Address.php',
    'Illuminate\\Mail\\Mailables\\Attachment' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailables/Attachment.php',
    'Illuminate\\Mail\\Mailables\\Content' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailables/Content.php',
    'Illuminate\\Mail\\Mailables\\Envelope' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailables/Envelope.php',
    'Illuminate\\Mail\\Mailables\\Headers' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailables/Headers.php',
    'Illuminate\\Mail\\Mailer' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Mailer.php',
    'Illuminate\\Mail\\Markdown' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Markdown.php',
    'Illuminate\\Mail\\Message' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Message.php',
    'Illuminate\\Mail\\PendingMail' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/PendingMail.php',
    'Illuminate\\Mail\\SendQueuedMailable' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/SendQueuedMailable.php',
    'Illuminate\\Mail\\SentMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/SentMessage.php',
    'Illuminate\\Mail\\TextMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/TextMessage.php',
    'Illuminate\\Mail\\Transport\\ArrayTransport' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Transport/ArrayTransport.php',
    'Illuminate\\Mail\\Transport\\LogTransport' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Transport/LogTransport.php',
    'Illuminate\\Mail\\Transport\\ResendTransport' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Transport/ResendTransport.php',
    'Illuminate\\Mail\\Transport\\SesTransport' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Transport/SesTransport.php',
    'Illuminate\\Mail\\Transport\\SesV2Transport' => $vendorDir . '/laravel/framework/src/Illuminate/Mail/Transport/SesV2Transport.php',
    'Illuminate\\Notifications\\Action' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Action.php',
    'Illuminate\\Notifications\\AnonymousNotifiable' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/AnonymousNotifiable.php',
    'Illuminate\\Notifications\\ChannelManager' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/ChannelManager.php',
    'Illuminate\\Notifications\\Channels\\BroadcastChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Channels/BroadcastChannel.php',
    'Illuminate\\Notifications\\Channels\\DatabaseChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Channels/DatabaseChannel.php',
    'Illuminate\\Notifications\\Channels\\MailChannel' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Channels/MailChannel.php',
    'Illuminate\\Notifications\\Console\\NotificationTableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Console/NotificationTableCommand.php',
    'Illuminate\\Notifications\\DatabaseNotification' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/DatabaseNotification.php',
    'Illuminate\\Notifications\\DatabaseNotificationCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/DatabaseNotificationCollection.php',
    'Illuminate\\Notifications\\Events\\BroadcastNotificationCreated' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Events/BroadcastNotificationCreated.php',
    'Illuminate\\Notifications\\Events\\NotificationFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Events/NotificationFailed.php',
    'Illuminate\\Notifications\\Events\\NotificationSending' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Events/NotificationSending.php',
    'Illuminate\\Notifications\\Events\\NotificationSent' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Events/NotificationSent.php',
    'Illuminate\\Notifications\\HasDatabaseNotifications' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/HasDatabaseNotifications.php',
    'Illuminate\\Notifications\\Messages\\BroadcastMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Messages/BroadcastMessage.php',
    'Illuminate\\Notifications\\Messages\\DatabaseMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Messages/DatabaseMessage.php',
    'Illuminate\\Notifications\\Messages\\MailMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Messages/MailMessage.php',
    'Illuminate\\Notifications\\Messages\\SimpleMessage' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Messages/SimpleMessage.php',
    'Illuminate\\Notifications\\Notifiable' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Notifiable.php',
    'Illuminate\\Notifications\\Notification' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/Notification.php',
    'Illuminate\\Notifications\\NotificationSender' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/NotificationSender.php',
    'Illuminate\\Notifications\\NotificationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/NotificationServiceProvider.php',
    'Illuminate\\Notifications\\RoutesNotifications' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/RoutesNotifications.php',
    'Illuminate\\Notifications\\SendQueuedNotifications' => $vendorDir . '/laravel/framework/src/Illuminate/Notifications/SendQueuedNotifications.php',
    'Illuminate\\Pagination\\AbstractCursorPaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/AbstractCursorPaginator.php',
    'Illuminate\\Pagination\\AbstractPaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/AbstractPaginator.php',
    'Illuminate\\Pagination\\Cursor' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/Cursor.php',
    'Illuminate\\Pagination\\CursorPaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/CursorPaginator.php',
    'Illuminate\\Pagination\\LengthAwarePaginator' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/LengthAwarePaginator.php',
    'Illuminate\\Pagination\\PaginationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/PaginationServiceProvider.php',
    'Illuminate\\Pagination\\PaginationState' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/PaginationState.php',
    'Illuminate\\Pagination\\Paginator' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/Paginator.php',
    'Illuminate\\Pagination\\UrlWindow' => $vendorDir . '/laravel/framework/src/Illuminate/Pagination/UrlWindow.php',
    'Illuminate\\Pipeline\\Hub' => $vendorDir . '/laravel/framework/src/Illuminate/Pipeline/Hub.php',
    'Illuminate\\Pipeline\\Pipeline' => $vendorDir . '/laravel/framework/src/Illuminate/Pipeline/Pipeline.php',
    'Illuminate\\Pipeline\\PipelineServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Pipeline/PipelineServiceProvider.php',
    'Illuminate\\Process\\Exceptions\\ProcessFailedException' => $vendorDir . '/laravel/framework/src/Illuminate/Process/Exceptions/ProcessFailedException.php',
    'Illuminate\\Process\\Exceptions\\ProcessTimedOutException' => $vendorDir . '/laravel/framework/src/Illuminate/Process/Exceptions/ProcessTimedOutException.php',
    'Illuminate\\Process\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Process/Factory.php',
    'Illuminate\\Process\\FakeInvokedProcess' => $vendorDir . '/laravel/framework/src/Illuminate/Process/FakeInvokedProcess.php',
    'Illuminate\\Process\\FakeProcessDescription' => $vendorDir . '/laravel/framework/src/Illuminate/Process/FakeProcessDescription.php',
    'Illuminate\\Process\\FakeProcessResult' => $vendorDir . '/laravel/framework/src/Illuminate/Process/FakeProcessResult.php',
    'Illuminate\\Process\\FakeProcessSequence' => $vendorDir . '/laravel/framework/src/Illuminate/Process/FakeProcessSequence.php',
    'Illuminate\\Process\\InvokedProcess' => $vendorDir . '/laravel/framework/src/Illuminate/Process/InvokedProcess.php',
    'Illuminate\\Process\\InvokedProcessPool' => $vendorDir . '/laravel/framework/src/Illuminate/Process/InvokedProcessPool.php',
    'Illuminate\\Process\\PendingProcess' => $vendorDir . '/laravel/framework/src/Illuminate/Process/PendingProcess.php',
    'Illuminate\\Process\\Pipe' => $vendorDir . '/laravel/framework/src/Illuminate/Process/Pipe.php',
    'Illuminate\\Process\\Pool' => $vendorDir . '/laravel/framework/src/Illuminate/Process/Pool.php',
    'Illuminate\\Process\\ProcessPoolResults' => $vendorDir . '/laravel/framework/src/Illuminate/Process/ProcessPoolResults.php',
    'Illuminate\\Process\\ProcessResult' => $vendorDir . '/laravel/framework/src/Illuminate/Process/ProcessResult.php',
    'Illuminate\\Queue\\Attributes\\DeleteWhenMissingModels' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Attributes/DeleteWhenMissingModels.php',
    'Illuminate\\Queue\\Attributes\\WithoutRelations' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Attributes/WithoutRelations.php',
    'Illuminate\\Queue\\BeanstalkdQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/BeanstalkdQueue.php',
    'Illuminate\\Queue\\CallQueuedClosure' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/CallQueuedClosure.php',
    'Illuminate\\Queue\\CallQueuedHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/CallQueuedHandler.php',
    'Illuminate\\Queue\\Capsule\\Manager' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Capsule/Manager.php',
    'Illuminate\\Queue\\Connectors\\BeanstalkdConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/BeanstalkdConnector.php',
    'Illuminate\\Queue\\Connectors\\ConnectorInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/ConnectorInterface.php',
    'Illuminate\\Queue\\Connectors\\DatabaseConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/DatabaseConnector.php',
    'Illuminate\\Queue\\Connectors\\NullConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/NullConnector.php',
    'Illuminate\\Queue\\Connectors\\RedisConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/RedisConnector.php',
    'Illuminate\\Queue\\Connectors\\SqsConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/SqsConnector.php',
    'Illuminate\\Queue\\Connectors\\SyncConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Connectors/SyncConnector.php',
    'Illuminate\\Queue\\Console\\BatchesTableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/BatchesTableCommand.php',
    'Illuminate\\Queue\\Console\\ClearCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/ClearCommand.php',
    'Illuminate\\Queue\\Console\\FailedTableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/FailedTableCommand.php',
    'Illuminate\\Queue\\Console\\FlushFailedCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/FlushFailedCommand.php',
    'Illuminate\\Queue\\Console\\ForgetFailedCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/ForgetFailedCommand.php',
    'Illuminate\\Queue\\Console\\ListFailedCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/ListFailedCommand.php',
    'Illuminate\\Queue\\Console\\ListenCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/ListenCommand.php',
    'Illuminate\\Queue\\Console\\MonitorCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/MonitorCommand.php',
    'Illuminate\\Queue\\Console\\PruneBatchesCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/PruneBatchesCommand.php',
    'Illuminate\\Queue\\Console\\PruneFailedJobsCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/PruneFailedJobsCommand.php',
    'Illuminate\\Queue\\Console\\RestartCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/RestartCommand.php',
    'Illuminate\\Queue\\Console\\RetryBatchCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/RetryBatchCommand.php',
    'Illuminate\\Queue\\Console\\RetryCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/RetryCommand.php',
    'Illuminate\\Queue\\Console\\TableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/TableCommand.php',
    'Illuminate\\Queue\\Console\\WorkCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Console/WorkCommand.php',
    'Illuminate\\Queue\\DatabaseQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/DatabaseQueue.php',
    'Illuminate\\Queue\\Events\\JobExceptionOccurred' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobExceptionOccurred.php',
    'Illuminate\\Queue\\Events\\JobFailed' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobFailed.php',
    'Illuminate\\Queue\\Events\\JobPopped' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobPopped.php',
    'Illuminate\\Queue\\Events\\JobPopping' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobPopping.php',
    'Illuminate\\Queue\\Events\\JobProcessed' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobProcessed.php',
    'Illuminate\\Queue\\Events\\JobProcessing' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobProcessing.php',
    'Illuminate\\Queue\\Events\\JobQueued' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobQueued.php',
    'Illuminate\\Queue\\Events\\JobQueueing' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobQueueing.php',
    'Illuminate\\Queue\\Events\\JobReleasedAfterException' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobReleasedAfterException.php',
    'Illuminate\\Queue\\Events\\JobRetryRequested' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobRetryRequested.php',
    'Illuminate\\Queue\\Events\\JobTimedOut' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/JobTimedOut.php',
    'Illuminate\\Queue\\Events\\Looping' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/Looping.php',
    'Illuminate\\Queue\\Events\\QueueBusy' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/QueueBusy.php',
    'Illuminate\\Queue\\Events\\WorkerStopping' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Events/WorkerStopping.php',
    'Illuminate\\Queue\\Failed\\CountableFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/CountableFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\DatabaseFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/DatabaseFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\DatabaseUuidFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/DatabaseUuidFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\DynamoDbFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/DynamoDbFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\FailedJobProviderInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/FailedJobProviderInterface.php',
    'Illuminate\\Queue\\Failed\\FileFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/FileFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\NullFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/NullFailedJobProvider.php',
    'Illuminate\\Queue\\Failed\\PrunableFailedJobProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Failed/PrunableFailedJobProvider.php',
    'Illuminate\\Queue\\InteractsWithQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/InteractsWithQueue.php',
    'Illuminate\\Queue\\InvalidPayloadException' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/InvalidPayloadException.php',
    'Illuminate\\Queue\\Jobs\\BeanstalkdJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/BeanstalkdJob.php',
    'Illuminate\\Queue\\Jobs\\DatabaseJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/DatabaseJob.php',
    'Illuminate\\Queue\\Jobs\\DatabaseJobRecord' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/DatabaseJobRecord.php',
    'Illuminate\\Queue\\Jobs\\FakeJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/FakeJob.php',
    'Illuminate\\Queue\\Jobs\\Job' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/Job.php',
    'Illuminate\\Queue\\Jobs\\JobName' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/JobName.php',
    'Illuminate\\Queue\\Jobs\\RedisJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/RedisJob.php',
    'Illuminate\\Queue\\Jobs\\SqsJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/SqsJob.php',
    'Illuminate\\Queue\\Jobs\\SyncJob' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Jobs/SyncJob.php',
    'Illuminate\\Queue\\Listener' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Listener.php',
    'Illuminate\\Queue\\ListenerOptions' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/ListenerOptions.php',
    'Illuminate\\Queue\\LuaScripts' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/LuaScripts.php',
    'Illuminate\\Queue\\ManuallyFailedException' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/ManuallyFailedException.php',
    'Illuminate\\Queue\\MaxAttemptsExceededException' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/MaxAttemptsExceededException.php',
    'Illuminate\\Queue\\Middleware\\RateLimited' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/RateLimited.php',
    'Illuminate\\Queue\\Middleware\\RateLimitedWithRedis' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/RateLimitedWithRedis.php',
    'Illuminate\\Queue\\Middleware\\SkipIfBatchCancelled' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/SkipIfBatchCancelled.php',
    'Illuminate\\Queue\\Middleware\\ThrottlesExceptions' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/ThrottlesExceptions.php',
    'Illuminate\\Queue\\Middleware\\ThrottlesExceptionsWithRedis' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/ThrottlesExceptionsWithRedis.php',
    'Illuminate\\Queue\\Middleware\\WithoutOverlapping' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Middleware/WithoutOverlapping.php',
    'Illuminate\\Queue\\NullQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/NullQueue.php',
    'Illuminate\\Queue\\Queue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Queue.php',
    'Illuminate\\Queue\\QueueManager' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/QueueManager.php',
    'Illuminate\\Queue\\QueueServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/QueueServiceProvider.php',
    'Illuminate\\Queue\\RedisQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/RedisQueue.php',
    'Illuminate\\Queue\\SerializesAndRestoresModelIdentifiers' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/SerializesAndRestoresModelIdentifiers.php',
    'Illuminate\\Queue\\SerializesModels' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/SerializesModels.php',
    'Illuminate\\Queue\\SqsQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/SqsQueue.php',
    'Illuminate\\Queue\\SyncQueue' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/SyncQueue.php',
    'Illuminate\\Queue\\TimeoutExceededException' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/TimeoutExceededException.php',
    'Illuminate\\Queue\\Worker' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/Worker.php',
    'Illuminate\\Queue\\WorkerOptions' => $vendorDir . '/laravel/framework/src/Illuminate/Queue/WorkerOptions.php',
    'Illuminate\\Redis\\Connections\\Connection' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/Connection.php',
    'Illuminate\\Redis\\Connections\\PacksPhpRedisValues' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/PacksPhpRedisValues.php',
    'Illuminate\\Redis\\Connections\\PhpRedisClusterConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/PhpRedisClusterConnection.php',
    'Illuminate\\Redis\\Connections\\PhpRedisConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/PhpRedisConnection.php',
    'Illuminate\\Redis\\Connections\\PredisClusterConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/PredisClusterConnection.php',
    'Illuminate\\Redis\\Connections\\PredisConnection' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connections/PredisConnection.php',
    'Illuminate\\Redis\\Connectors\\PhpRedisConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connectors/PhpRedisConnector.php',
    'Illuminate\\Redis\\Connectors\\PredisConnector' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Connectors/PredisConnector.php',
    'Illuminate\\Redis\\Events\\CommandExecuted' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Events/CommandExecuted.php',
    'Illuminate\\Redis\\Limiters\\ConcurrencyLimiter' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Limiters/ConcurrencyLimiter.php',
    'Illuminate\\Redis\\Limiters\\ConcurrencyLimiterBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Limiters/ConcurrencyLimiterBuilder.php',
    'Illuminate\\Redis\\Limiters\\DurationLimiter' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Limiters/DurationLimiter.php',
    'Illuminate\\Redis\\Limiters\\DurationLimiterBuilder' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/Limiters/DurationLimiterBuilder.php',
    'Illuminate\\Redis\\RedisManager' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/RedisManager.php',
    'Illuminate\\Redis\\RedisServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Redis/RedisServiceProvider.php',
    'Illuminate\\Routing\\AbstractRouteCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/AbstractRouteCollection.php',
    'Illuminate\\Routing\\CallableDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/CallableDispatcher.php',
    'Illuminate\\Routing\\CompiledRouteCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/CompiledRouteCollection.php',
    'Illuminate\\Routing\\Console\\ControllerMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Console/ControllerMakeCommand.php',
    'Illuminate\\Routing\\Console\\MiddlewareMakeCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Console/MiddlewareMakeCommand.php',
    'Illuminate\\Routing\\Contracts\\CallableDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Contracts/CallableDispatcher.php',
    'Illuminate\\Routing\\Contracts\\ControllerDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Contracts/ControllerDispatcher.php',
    'Illuminate\\Routing\\Controller' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Controller.php',
    'Illuminate\\Routing\\ControllerDispatcher' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ControllerDispatcher.php',
    'Illuminate\\Routing\\ControllerMiddlewareOptions' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ControllerMiddlewareOptions.php',
    'Illuminate\\Routing\\Controllers\\HasMiddleware' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Controllers/HasMiddleware.php',
    'Illuminate\\Routing\\Controllers\\Middleware' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Controllers/Middleware.php',
    'Illuminate\\Routing\\CreatesRegularExpressionRouteConstraints' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/CreatesRegularExpressionRouteConstraints.php',
    'Illuminate\\Routing\\Events\\PreparingResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Events/PreparingResponse.php',
    'Illuminate\\Routing\\Events\\ResponsePrepared' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Events/ResponsePrepared.php',
    'Illuminate\\Routing\\Events\\RouteMatched' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Events/RouteMatched.php',
    'Illuminate\\Routing\\Events\\Routing' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Events/Routing.php',
    'Illuminate\\Routing\\Exceptions\\BackedEnumCaseNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Exceptions/BackedEnumCaseNotFoundException.php',
    'Illuminate\\Routing\\Exceptions\\InvalidSignatureException' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Exceptions/InvalidSignatureException.php',
    'Illuminate\\Routing\\Exceptions\\MissingRateLimiterException' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Exceptions/MissingRateLimiterException.php',
    'Illuminate\\Routing\\Exceptions\\StreamedResponseException' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Exceptions/StreamedResponseException.php',
    'Illuminate\\Routing\\Exceptions\\UrlGenerationException' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Exceptions/UrlGenerationException.php',
    'Illuminate\\Routing\\FiltersControllerMiddleware' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/FiltersControllerMiddleware.php',
    'Illuminate\\Routing\\ImplicitRouteBinding' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ImplicitRouteBinding.php',
    'Illuminate\\Routing\\Matching\\HostValidator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Matching/HostValidator.php',
    'Illuminate\\Routing\\Matching\\MethodValidator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Matching/MethodValidator.php',
    'Illuminate\\Routing\\Matching\\SchemeValidator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Matching/SchemeValidator.php',
    'Illuminate\\Routing\\Matching\\UriValidator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Matching/UriValidator.php',
    'Illuminate\\Routing\\Matching\\ValidatorInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Matching/ValidatorInterface.php',
    'Illuminate\\Routing\\MiddlewareNameResolver' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/MiddlewareNameResolver.php',
    'Illuminate\\Routing\\Middleware\\SubstituteBindings' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Middleware/SubstituteBindings.php',
    'Illuminate\\Routing\\Middleware\\ThrottleRequests' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Middleware/ThrottleRequests.php',
    'Illuminate\\Routing\\Middleware\\ThrottleRequestsWithRedis' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Middleware/ThrottleRequestsWithRedis.php',
    'Illuminate\\Routing\\Middleware\\ValidateSignature' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Middleware/ValidateSignature.php',
    'Illuminate\\Routing\\PendingResourceRegistration' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/PendingResourceRegistration.php',
    'Illuminate\\Routing\\PendingSingletonResourceRegistration' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/PendingSingletonResourceRegistration.php',
    'Illuminate\\Routing\\Pipeline' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Pipeline.php',
    'Illuminate\\Routing\\RedirectController' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RedirectController.php',
    'Illuminate\\Routing\\Redirector' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Redirector.php',
    'Illuminate\\Routing\\ResolvesRouteDependencies' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ResolvesRouteDependencies.php',
    'Illuminate\\Routing\\ResourceRegistrar' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ResourceRegistrar.php',
    'Illuminate\\Routing\\ResponseFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ResponseFactory.php',
    'Illuminate\\Routing\\Route' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Route.php',
    'Illuminate\\Routing\\RouteAction' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteAction.php',
    'Illuminate\\Routing\\RouteBinding' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteBinding.php',
    'Illuminate\\Routing\\RouteCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteCollection.php',
    'Illuminate\\Routing\\RouteCollectionInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteCollectionInterface.php',
    'Illuminate\\Routing\\RouteDependencyResolverTrait' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteDependencyResolverTrait.php',
    'Illuminate\\Routing\\RouteFileRegistrar' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteFileRegistrar.php',
    'Illuminate\\Routing\\RouteGroup' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteGroup.php',
    'Illuminate\\Routing\\RouteParameterBinder' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteParameterBinder.php',
    'Illuminate\\Routing\\RouteRegistrar' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteRegistrar.php',
    'Illuminate\\Routing\\RouteSignatureParameters' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteSignatureParameters.php',
    'Illuminate\\Routing\\RouteUri' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteUri.php',
    'Illuminate\\Routing\\RouteUrlGenerator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RouteUrlGenerator.php',
    'Illuminate\\Routing\\Router' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/Router.php',
    'Illuminate\\Routing\\RoutingServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/RoutingServiceProvider.php',
    'Illuminate\\Routing\\SortedMiddleware' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/SortedMiddleware.php',
    'Illuminate\\Routing\\UrlGenerator' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/UrlGenerator.php',
    'Illuminate\\Routing\\ViewController' => $vendorDir . '/laravel/framework/src/Illuminate/Routing/ViewController.php',
    'Illuminate\\Session\\ArraySessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/ArraySessionHandler.php',
    'Illuminate\\Session\\CacheBasedSessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/CacheBasedSessionHandler.php',
    'Illuminate\\Session\\Console\\SessionTableCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Session/Console/SessionTableCommand.php',
    'Illuminate\\Session\\CookieSessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/CookieSessionHandler.php',
    'Illuminate\\Session\\DatabaseSessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/DatabaseSessionHandler.php',
    'Illuminate\\Session\\EncryptedStore' => $vendorDir . '/laravel/framework/src/Illuminate/Session/EncryptedStore.php',
    'Illuminate\\Session\\ExistenceAwareInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Session/ExistenceAwareInterface.php',
    'Illuminate\\Session\\FileSessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/FileSessionHandler.php',
    'Illuminate\\Session\\Middleware\\AuthenticateSession' => $vendorDir . '/laravel/framework/src/Illuminate/Session/Middleware/AuthenticateSession.php',
    'Illuminate\\Session\\Middleware\\StartSession' => $vendorDir . '/laravel/framework/src/Illuminate/Session/Middleware/StartSession.php',
    'Illuminate\\Session\\NullSessionHandler' => $vendorDir . '/laravel/framework/src/Illuminate/Session/NullSessionHandler.php',
    'Illuminate\\Session\\SessionManager' => $vendorDir . '/laravel/framework/src/Illuminate/Session/SessionManager.php',
    'Illuminate\\Session\\SessionServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Session/SessionServiceProvider.php',
    'Illuminate\\Session\\Store' => $vendorDir . '/laravel/framework/src/Illuminate/Session/Store.php',
    'Illuminate\\Session\\SymfonySessionDecorator' => $vendorDir . '/laravel/framework/src/Illuminate/Session/SymfonySessionDecorator.php',
    'Illuminate\\Session\\TokenMismatchException' => $vendorDir . '/laravel/framework/src/Illuminate/Session/TokenMismatchException.php',
    'Illuminate\\Support\\AggregateServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Support/AggregateServiceProvider.php',
    'Illuminate\\Support\\Arr' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/Arr.php',
    'Illuminate\\Support\\Benchmark' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Benchmark.php',
    'Illuminate\\Support\\Carbon' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Carbon.php',
    'Illuminate\\Support\\Collection' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/Collection.php',
    'Illuminate\\Support\\Composer' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Composer.php',
    'Illuminate\\Support\\ConfigurationUrlParser' => $vendorDir . '/laravel/framework/src/Illuminate/Support/ConfigurationUrlParser.php',
    'Illuminate\\Support\\DateFactory' => $vendorDir . '/laravel/framework/src/Illuminate/Support/DateFactory.php',
    'Illuminate\\Support\\DefaultProviders' => $vendorDir . '/laravel/framework/src/Illuminate/Support/DefaultProviders.php',
    'Illuminate\\Support\\Enumerable' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/Enumerable.php',
    'Illuminate\\Support\\Env' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Env.php',
    'Illuminate\\Support\\Exceptions\\MathException' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Exceptions/MathException.php',
    'Illuminate\\Support\\Facades\\App' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/App.php',
    'Illuminate\\Support\\Facades\\Artisan' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Artisan.php',
    'Illuminate\\Support\\Facades\\Auth' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Auth.php',
    'Illuminate\\Support\\Facades\\Blade' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Blade.php',
    'Illuminate\\Support\\Facades\\Broadcast' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Broadcast.php',
    'Illuminate\\Support\\Facades\\Bus' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Bus.php',
    'Illuminate\\Support\\Facades\\Cache' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Cache.php',
    'Illuminate\\Support\\Facades\\Config' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Config.php',
    'Illuminate\\Support\\Facades\\Context' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Context.php',
    'Illuminate\\Support\\Facades\\Cookie' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Cookie.php',
    'Illuminate\\Support\\Facades\\Crypt' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Crypt.php',
    'Illuminate\\Support\\Facades\\DB' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/DB.php',
    'Illuminate\\Support\\Facades\\Date' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Date.php',
    'Illuminate\\Support\\Facades\\Event' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Event.php',
    'Illuminate\\Support\\Facades\\Exceptions' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Exceptions.php',
    'Illuminate\\Support\\Facades\\Facade' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Facade.php',
    'Illuminate\\Support\\Facades\\File' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/File.php',
    'Illuminate\\Support\\Facades\\Gate' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Gate.php',
    'Illuminate\\Support\\Facades\\Hash' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Hash.php',
    'Illuminate\\Support\\Facades\\Http' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Http.php',
    'Illuminate\\Support\\Facades\\Lang' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Lang.php',
    'Illuminate\\Support\\Facades\\Log' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Log.php',
    'Illuminate\\Support\\Facades\\Mail' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Mail.php',
    'Illuminate\\Support\\Facades\\Notification' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Notification.php',
    'Illuminate\\Support\\Facades\\ParallelTesting' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/ParallelTesting.php',
    'Illuminate\\Support\\Facades\\Password' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Password.php',
    'Illuminate\\Support\\Facades\\Pipeline' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Pipeline.php',
    'Illuminate\\Support\\Facades\\Process' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Process.php',
    'Illuminate\\Support\\Facades\\Queue' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Queue.php',
    'Illuminate\\Support\\Facades\\RateLimiter' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/RateLimiter.php',
    'Illuminate\\Support\\Facades\\Redirect' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Redirect.php',
    'Illuminate\\Support\\Facades\\Redis' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Redis.php',
    'Illuminate\\Support\\Facades\\Request' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Request.php',
    'Illuminate\\Support\\Facades\\Response' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Response.php',
    'Illuminate\\Support\\Facades\\Route' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Route.php',
    'Illuminate\\Support\\Facades\\Schedule' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Schedule.php',
    'Illuminate\\Support\\Facades\\Schema' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Schema.php',
    'Illuminate\\Support\\Facades\\Session' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Session.php',
    'Illuminate\\Support\\Facades\\Storage' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Storage.php',
    'Illuminate\\Support\\Facades\\URL' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/URL.php',
    'Illuminate\\Support\\Facades\\Validator' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Validator.php',
    'Illuminate\\Support\\Facades\\View' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/View.php',
    'Illuminate\\Support\\Facades\\Vite' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Facades/Vite.php',
    'Illuminate\\Support\\Fluent' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Fluent.php',
    'Illuminate\\Support\\HigherOrderCollectionProxy' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/HigherOrderCollectionProxy.php',
    'Illuminate\\Support\\HigherOrderTapProxy' => $vendorDir . '/laravel/framework/src/Illuminate/Support/HigherOrderTapProxy.php',
    'Illuminate\\Support\\HigherOrderWhenProxy' => $vendorDir . '/laravel/framework/src/Illuminate/Conditionable/HigherOrderWhenProxy.php',
    'Illuminate\\Support\\HtmlString' => $vendorDir . '/laravel/framework/src/Illuminate/Support/HtmlString.php',
    'Illuminate\\Support\\InteractsWithTime' => $vendorDir . '/laravel/framework/src/Illuminate/Support/InteractsWithTime.php',
    'Illuminate\\Support\\ItemNotFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/ItemNotFoundException.php',
    'Illuminate\\Support\\Js' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Js.php',
    'Illuminate\\Support\\LazyCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/LazyCollection.php',
    'Illuminate\\Support\\Lottery' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Lottery.php',
    'Illuminate\\Support\\Manager' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Manager.php',
    'Illuminate\\Support\\MessageBag' => $vendorDir . '/laravel/framework/src/Illuminate/Support/MessageBag.php',
    'Illuminate\\Support\\MultipleInstanceManager' => $vendorDir . '/laravel/framework/src/Illuminate/Support/MultipleInstanceManager.php',
    'Illuminate\\Support\\MultipleItemsFoundException' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/MultipleItemsFoundException.php',
    'Illuminate\\Support\\NamespacedItemResolver' => $vendorDir . '/laravel/framework/src/Illuminate/Support/NamespacedItemResolver.php',
    'Illuminate\\Support\\Number' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Number.php',
    'Illuminate\\Support\\Once' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Once.php',
    'Illuminate\\Support\\Onceable' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Onceable.php',
    'Illuminate\\Support\\Optional' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Optional.php',
    'Illuminate\\Support\\Pluralizer' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Pluralizer.php',
    'Illuminate\\Support\\ProcessUtils' => $vendorDir . '/laravel/framework/src/Illuminate/Support/ProcessUtils.php',
    'Illuminate\\Support\\Reflector' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Reflector.php',
    'Illuminate\\Support\\ServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Support/ServiceProvider.php',
    'Illuminate\\Support\\Sleep' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Sleep.php',
    'Illuminate\\Support\\Str' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Str.php',
    'Illuminate\\Support\\Stringable' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Stringable.php',
    'Illuminate\\Support\\Testing\\Fakes\\BatchFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/BatchFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\BatchRepositoryFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/BatchRepositoryFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\BusFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/BusFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\ChainedBatchTruthTest' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/ChainedBatchTruthTest.php',
    'Illuminate\\Support\\Testing\\Fakes\\EventFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/EventFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\ExceptionHandlerFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/ExceptionHandlerFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\Fake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/Fake.php',
    'Illuminate\\Support\\Testing\\Fakes\\MailFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/MailFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\NotificationFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/NotificationFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\PendingBatchFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/PendingBatchFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\PendingChainFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/PendingChainFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\PendingMailFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/PendingMailFake.php',
    'Illuminate\\Support\\Testing\\Fakes\\QueueFake' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Testing/Fakes/QueueFake.php',
    'Illuminate\\Support\\Timebox' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Timebox.php',
    'Illuminate\\Support\\Traits\\CapsuleManagerTrait' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/CapsuleManagerTrait.php',
    'Illuminate\\Support\\Traits\\Conditionable' => $vendorDir . '/laravel/framework/src/Illuminate/Conditionable/Traits/Conditionable.php',
    'Illuminate\\Support\\Traits\\Dumpable' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/Dumpable.php',
    'Illuminate\\Support\\Traits\\EnumeratesValues' => $vendorDir . '/laravel/framework/src/Illuminate/Collections/Traits/EnumeratesValues.php',
    'Illuminate\\Support\\Traits\\ForwardsCalls' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/ForwardsCalls.php',
    'Illuminate\\Support\\Traits\\Localizable' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/Localizable.php',
    'Illuminate\\Support\\Traits\\Macroable' => $vendorDir . '/laravel/framework/src/Illuminate/Macroable/Traits/Macroable.php',
    'Illuminate\\Support\\Traits\\ReflectsClosures' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/ReflectsClosures.php',
    'Illuminate\\Support\\Traits\\Tappable' => $vendorDir . '/laravel/framework/src/Illuminate/Support/Traits/Tappable.php',
    'Illuminate\\Support\\ValidatedInput' => $vendorDir . '/laravel/framework/src/Illuminate/Support/ValidatedInput.php',
    'Illuminate\\Support\\ViewErrorBag' => $vendorDir . '/laravel/framework/src/Illuminate/Support/ViewErrorBag.php',
    'Illuminate\\Testing\\Assert' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Assert.php',
    'Illuminate\\Testing\\AssertableJsonString' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/AssertableJsonString.php',
    'Illuminate\\Testing\\Concerns\\AssertsStatusCodes' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Concerns/AssertsStatusCodes.php',
    'Illuminate\\Testing\\Concerns\\RunsInParallel' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Concerns/RunsInParallel.php',
    'Illuminate\\Testing\\Concerns\\TestDatabases' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Concerns/TestDatabases.php',
    'Illuminate\\Testing\\Constraints\\ArraySubset' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/ArraySubset.php',
    'Illuminate\\Testing\\Constraints\\CountInDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/CountInDatabase.php',
    'Illuminate\\Testing\\Constraints\\HasInDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/HasInDatabase.php',
    'Illuminate\\Testing\\Constraints\\NotSoftDeletedInDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/NotSoftDeletedInDatabase.php',
    'Illuminate\\Testing\\Constraints\\SeeInOrder' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/SeeInOrder.php',
    'Illuminate\\Testing\\Constraints\\SoftDeletedInDatabase' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Constraints/SoftDeletedInDatabase.php',
    'Illuminate\\Testing\\Exceptions\\InvalidArgumentException' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Exceptions/InvalidArgumentException.php',
    'Illuminate\\Testing\\Fluent\\AssertableJson' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Fluent/AssertableJson.php',
    'Illuminate\\Testing\\Fluent\\Concerns\\Debugging' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Fluent/Concerns/Debugging.php',
    'Illuminate\\Testing\\Fluent\\Concerns\\Has' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Fluent/Concerns/Has.php',
    'Illuminate\\Testing\\Fluent\\Concerns\\Interaction' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Fluent/Concerns/Interaction.php',
    'Illuminate\\Testing\\Fluent\\Concerns\\Matching' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/Fluent/Concerns/Matching.php',
    'Illuminate\\Testing\\LoggedExceptionCollection' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/LoggedExceptionCollection.php',
    'Illuminate\\Testing\\ParallelConsoleOutput' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/ParallelConsoleOutput.php',
    'Illuminate\\Testing\\ParallelRunner' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/ParallelRunner.php',
    'Illuminate\\Testing\\ParallelTesting' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/ParallelTesting.php',
    'Illuminate\\Testing\\ParallelTestingServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/ParallelTestingServiceProvider.php',
    'Illuminate\\Testing\\PendingCommand' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/PendingCommand.php',
    'Illuminate\\Testing\\TestComponent' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/TestComponent.php',
    'Illuminate\\Testing\\TestResponse' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/TestResponse.php',
    'Illuminate\\Testing\\TestResponseAssert' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/TestResponseAssert.php',
    'Illuminate\\Testing\\TestView' => $vendorDir . '/laravel/framework/src/Illuminate/Testing/TestView.php',
    'Illuminate\\Translation\\ArrayLoader' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/ArrayLoader.php',
    'Illuminate\\Translation\\CreatesPotentiallyTranslatedStrings' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/CreatesPotentiallyTranslatedStrings.php',
    'Illuminate\\Translation\\FileLoader' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/FileLoader.php',
    'Illuminate\\Translation\\MessageSelector' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/MessageSelector.php',
    'Illuminate\\Translation\\PotentiallyTranslatedString' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/PotentiallyTranslatedString.php',
    'Illuminate\\Translation\\TranslationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/TranslationServiceProvider.php',
    'Illuminate\\Translation\\Translator' => $vendorDir . '/laravel/framework/src/Illuminate/Translation/Translator.php',
    'Illuminate\\Validation\\ClosureValidationRule' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ClosureValidationRule.php',
    'Illuminate\\Validation\\Concerns\\FilterEmailValidation' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Concerns/FilterEmailValidation.php',
    'Illuminate\\Validation\\Concerns\\FormatsMessages' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Concerns/FormatsMessages.php',
    'Illuminate\\Validation\\Concerns\\ReplacesAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Concerns/ReplacesAttributes.php',
    'Illuminate\\Validation\\Concerns\\ValidatesAttributes' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Concerns/ValidatesAttributes.php',
    'Illuminate\\Validation\\ConditionalRules' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ConditionalRules.php',
    'Illuminate\\Validation\\DatabasePresenceVerifier' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/DatabasePresenceVerifier.php',
    'Illuminate\\Validation\\DatabasePresenceVerifierInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/DatabasePresenceVerifierInterface.php',
    'Illuminate\\Validation\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Factory.php',
    'Illuminate\\Validation\\InvokableValidationRule' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/InvokableValidationRule.php',
    'Illuminate\\Validation\\NestedRules' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/NestedRules.php',
    'Illuminate\\Validation\\NotPwnedVerifier' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/NotPwnedVerifier.php',
    'Illuminate\\Validation\\PresenceVerifierInterface' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/PresenceVerifierInterface.php',
    'Illuminate\\Validation\\Rule' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rule.php',
    'Illuminate\\Validation\\Rules\\ArrayRule' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/ArrayRule.php',
    'Illuminate\\Validation\\Rules\\Can' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Can.php',
    'Illuminate\\Validation\\Rules\\DatabaseRule' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/DatabaseRule.php',
    'Illuminate\\Validation\\Rules\\Dimensions' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Dimensions.php',
    'Illuminate\\Validation\\Rules\\Enum' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Enum.php',
    'Illuminate\\Validation\\Rules\\ExcludeIf' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/ExcludeIf.php',
    'Illuminate\\Validation\\Rules\\Exists' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Exists.php',
    'Illuminate\\Validation\\Rules\\File' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/File.php',
    'Illuminate\\Validation\\Rules\\ImageFile' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/ImageFile.php',
    'Illuminate\\Validation\\Rules\\In' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/In.php',
    'Illuminate\\Validation\\Rules\\NotIn' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/NotIn.php',
    'Illuminate\\Validation\\Rules\\Password' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Password.php',
    'Illuminate\\Validation\\Rules\\ProhibitedIf' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/ProhibitedIf.php',
    'Illuminate\\Validation\\Rules\\RequiredIf' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/RequiredIf.php',
    'Illuminate\\Validation\\Rules\\Unique' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Rules/Unique.php',
    'Illuminate\\Validation\\UnauthorizedException' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/UnauthorizedException.php',
    'Illuminate\\Validation\\ValidatesWhenResolvedTrait' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ValidatesWhenResolvedTrait.php',
    'Illuminate\\Validation\\ValidationData' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ValidationData.php',
    'Illuminate\\Validation\\ValidationException' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ValidationException.php',
    'Illuminate\\Validation\\ValidationRuleParser' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ValidationRuleParser.php',
    'Illuminate\\Validation\\ValidationServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/ValidationServiceProvider.php',
    'Illuminate\\Validation\\Validator' => $vendorDir . '/laravel/framework/src/Illuminate/Validation/Validator.php',
    'Illuminate\\View\\AnonymousComponent' => $vendorDir . '/laravel/framework/src/Illuminate/View/AnonymousComponent.php',
    'Illuminate\\View\\AppendableAttributeValue' => $vendorDir . '/laravel/framework/src/Illuminate/View/AppendableAttributeValue.php',
    'Illuminate\\View\\Compilers\\BladeCompiler' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/BladeCompiler.php',
    'Illuminate\\View\\Compilers\\Compiler' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Compiler.php',
    'Illuminate\\View\\Compilers\\CompilerInterface' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/CompilerInterface.php',
    'Illuminate\\View\\Compilers\\ComponentTagCompiler' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/ComponentTagCompiler.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesAuthorizations' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesAuthorizations.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesClasses' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesClasses.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesComments' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesComments.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesComponents' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesComponents.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesConditionals' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesConditionals.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesEchos' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesEchos.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesErrors' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesErrors.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesFragments' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesFragments.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesHelpers' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesHelpers.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesIncludes' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesIncludes.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesInjections' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesInjections.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesJs' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesJs.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesJson' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesJson.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesLayouts' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesLayouts.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesLoops' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesLoops.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesRawPhp' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesRawPhp.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesSessions' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesSessions.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesStacks' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesStacks.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesStyles' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesStyles.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesTranslations' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesTranslations.php',
    'Illuminate\\View\\Compilers\\Concerns\\CompilesUseStatements' => $vendorDir . '/laravel/framework/src/Illuminate/View/Compilers/Concerns/CompilesUseStatements.php',
    'Illuminate\\View\\Component' => $vendorDir . '/laravel/framework/src/Illuminate/View/Component.php',
    'Illuminate\\View\\ComponentAttributeBag' => $vendorDir . '/laravel/framework/src/Illuminate/View/ComponentAttributeBag.php',
    'Illuminate\\View\\ComponentSlot' => $vendorDir . '/laravel/framework/src/Illuminate/View/ComponentSlot.php',
    'Illuminate\\View\\Concerns\\ManagesComponents' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesComponents.php',
    'Illuminate\\View\\Concerns\\ManagesEvents' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesEvents.php',
    'Illuminate\\View\\Concerns\\ManagesFragments' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesFragments.php',
    'Illuminate\\View\\Concerns\\ManagesLayouts' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesLayouts.php',
    'Illuminate\\View\\Concerns\\ManagesLoops' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesLoops.php',
    'Illuminate\\View\\Concerns\\ManagesStacks' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesStacks.php',
    'Illuminate\\View\\Concerns\\ManagesTranslations' => $vendorDir . '/laravel/framework/src/Illuminate/View/Concerns/ManagesTranslations.php',
    'Illuminate\\View\\DynamicComponent' => $vendorDir . '/laravel/framework/src/Illuminate/View/DynamicComponent.php',
    'Illuminate\\View\\Engines\\CompilerEngine' => $vendorDir . '/laravel/framework/src/Illuminate/View/Engines/CompilerEngine.php',
    'Illuminate\\View\\Engines\\Engine' => $vendorDir . '/laravel/framework/src/Illuminate/View/Engines/Engine.php',
    'Illuminate\\View\\Engines\\EngineResolver' => $vendorDir . '/laravel/framework/src/Illuminate/View/Engines/EngineResolver.php',
    'Illuminate\\View\\Engines\\FileEngine' => $vendorDir . '/laravel/framework/src/Illuminate/View/Engines/FileEngine.php',
    'Illuminate\\View\\Engines\\PhpEngine' => $vendorDir . '/laravel/framework/src/Illuminate/View/Engines/PhpEngine.php',
    'Illuminate\\View\\Factory' => $vendorDir . '/laravel/framework/src/Illuminate/View/Factory.php',
    'Illuminate\\View\\FileViewFinder' => $vendorDir . '/laravel/framework/src/Illuminate/View/FileViewFinder.php',
    'Illuminate\\View\\InvokableComponentVariable' => $vendorDir . '/laravel/framework/src/Illuminate/View/InvokableComponentVariable.php',
    'Illuminate\\View\\Middleware\\ShareErrorsFromSession' => $vendorDir . '/laravel/framework/src/Illuminate/View/Middleware/ShareErrorsFromSession.php',
    'Illuminate\\View\\View' => $vendorDir . '/laravel/framework/src/Illuminate/View/View.php',
    'Illuminate\\View\\ViewException' => $vendorDir . '/laravel/framework/src/Illuminate/View/ViewException.php',
    'Illuminate\\View\\ViewFinderInterface' => $vendorDir . '/laravel/framework/src/Illuminate/View/ViewFinderInterface.php',
    'Illuminate\\View\\ViewName' => $vendorDir . '/laravel/framework/src/Illuminate/View/ViewName.php',
    'Illuminate\\View\\ViewServiceProvider' => $vendorDir . '/laravel/framework/src/Illuminate/View/ViewServiceProvider.php',
    'Iyzipay\\ApiResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/ApiResource.php',
    'Iyzipay\\BaseModel' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/BaseModel.php',
    'Iyzipay\\Constants' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Constants.php',
    'Iyzipay\\Curl' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Curl.php',
    'Iyzipay\\DefaultHttpClient' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/DefaultHttpClient.php',
    'Iyzipay\\FileBase64Encoder' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/FileBase64Encoder.php',
    'Iyzipay\\HashGenerator' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/HashGenerator.php',
    'Iyzipay\\HttpClient' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/HttpClient.php',
    'Iyzipay\\IyziAuthV2Generator' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/IyziAuthV2Generator.php',
    'Iyzipay\\IyzipayResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/IyzipayResource.php',
    'Iyzipay\\JsonBuilder' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/JsonBuilder.php',
    'Iyzipay\\JsonConvertible' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/JsonConvertible.php',
    'Iyzipay\\Model\\Address' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Address.php',
    'Iyzipay\\Model\\ApiTest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ApiTest.php',
    'Iyzipay\\Model\\Apm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Apm.php',
    'Iyzipay\\Model\\ApmResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ApmResource.php',
    'Iyzipay\\Model\\ApmType' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ApmType.php',
    'Iyzipay\\Model\\Approval' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Approval.php',
    'Iyzipay\\Model\\BankTransfer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BankTransfer.php',
    'Iyzipay\\Model\\BasicBkm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicBkm.php',
    'Iyzipay\\Model\\BasicBkmInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicBkmInitialize.php',
    'Iyzipay\\Model\\BasicPayment' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicPayment.php',
    'Iyzipay\\Model\\BasicPaymentPostAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicPaymentPostAuth.php',
    'Iyzipay\\Model\\BasicPaymentPreAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicPaymentPreAuth.php',
    'Iyzipay\\Model\\BasicPaymentResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicPaymentResource.php',
    'Iyzipay\\Model\\BasicThreedsInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicThreedsInitialize.php',
    'Iyzipay\\Model\\BasicThreedsInitializePreAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicThreedsInitializePreAuth.php',
    'Iyzipay\\Model\\BasicThreedsPayment' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasicThreedsPayment.php',
    'Iyzipay\\Model\\BasketItem' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasketItem.php',
    'Iyzipay\\Model\\BasketItemType' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BasketItemType.php',
    'Iyzipay\\Model\\BinNumber' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BinNumber.php',
    'Iyzipay\\Model\\Bkm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Bkm.php',
    'Iyzipay\\Model\\BkmInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BkmInitialize.php',
    'Iyzipay\\Model\\BkmInstallment' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BkmInstallment.php',
    'Iyzipay\\Model\\BkmInstallmentPrice' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BkmInstallmentPrice.php',
    'Iyzipay\\Model\\BouncedBankTransferList' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/BouncedBankTransferList.php',
    'Iyzipay\\Model\\Buyer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Buyer.php',
    'Iyzipay\\Model\\Cancel' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Cancel.php',
    'Iyzipay\\Model\\Card' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Card.php',
    'Iyzipay\\Model\\CardInformation' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CardInformation.php',
    'Iyzipay\\Model\\CardList' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CardList.php',
    'Iyzipay\\Model\\CheckoutForm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CheckoutForm.php',
    'Iyzipay\\Model\\CheckoutFormInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CheckoutFormInitialize.php',
    'Iyzipay\\Model\\CheckoutFormInitializePreAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CheckoutFormInitializePreAuth.php',
    'Iyzipay\\Model\\CheckoutFormInitializeResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CheckoutFormInitializeResource.php',
    'Iyzipay\\Model\\Consumer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Consumer.php',
    'Iyzipay\\Model\\ConvertedPayout' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ConvertedPayout.php',
    'Iyzipay\\Model\\CrossBookingFromSubMerchant' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CrossBookingFromSubMerchant.php',
    'Iyzipay\\Model\\CrossBookingToSubMerchant' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/CrossBookingToSubMerchant.php',
    'Iyzipay\\Model\\Currency' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Currency.php',
    'Iyzipay\\Model\\Customer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Customer.php',
    'Iyzipay\\Model\\Disapproval' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Disapproval.php',
    'Iyzipay\\Model\\InitialConsumer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/InitialConsumer.php',
    'Iyzipay\\Model\\InstallmentDetail' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/InstallmentDetail.php',
    'Iyzipay\\Model\\InstallmentHtml' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/InstallmentHtml.php',
    'Iyzipay\\Model\\InstallmentInfo' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/InstallmentInfo.php',
    'Iyzipay\\Model\\InstallmentPrice' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/InstallmentPrice.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkDeleteProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkDeleteProduct.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkDeleteProductResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkDeleteProductResource.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkRetrieveAllProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkRetrieveAllProduct.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkRetrieveAllProductResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkRetrieveAllProductResource.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkRetrieveProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkRetrieveProduct.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkRetrieveProductResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkRetrieveProductResource.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkSaveProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkSaveProduct.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkSaveProductResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkSaveProductResource.php',
    'Iyzipay\\Model\\Iyzilink\\IyziLinkUpdateProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Iyzilink/IyziLinkUpdateProduct.php',
    'Iyzipay\\Model\\IyziupAddress' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/IyziupAddress.php',
    'Iyzipay\\Model\\IyziupForm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/IyziupForm.php',
    'Iyzipay\\Model\\IyziupFormInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/IyziupFormInitialize.php',
    'Iyzipay\\Model\\IyziupFormInitializeResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/IyziupFormInitializeResource.php',
    'Iyzipay\\Model\\Locale' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Locale.php',
    'Iyzipay\\Model\\Loyalty' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Loyalty.php',
    'Iyzipay\\Model\\Mapper\\AddressMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/AddressMapper.php',
    'Iyzipay\\Model\\Mapper\\ApmMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ApmMapper.php',
    'Iyzipay\\Model\\Mapper\\ApmResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ApmResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\ApprovalMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ApprovalMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicBkmInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicBkmInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicBkmMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicBkmMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicPaymentMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicPaymentMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicPaymentPostAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicPaymentPostAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicPaymentPreAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicPaymentPreAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicPaymentResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicPaymentResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicThreedsInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicThreedsInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicThreedsInitializePreAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicThreedsInitializePreAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\BasicThreedsPaymentMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BasicThreedsPaymentMapper.php',
    'Iyzipay\\Model\\Mapper\\BinNumberMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BinNumberMapper.php',
    'Iyzipay\\Model\\Mapper\\BkmInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BkmInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\BkmMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BkmMapper.php',
    'Iyzipay\\Model\\Mapper\\BouncedBankTransferListMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/BouncedBankTransferListMapper.php',
    'Iyzipay\\Model\\Mapper\\CancelMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CancelMapper.php',
    'Iyzipay\\Model\\Mapper\\CardListMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CardListMapper.php',
    'Iyzipay\\Model\\Mapper\\CardMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CardMapper.php',
    'Iyzipay\\Model\\Mapper\\CheckoutFormInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CheckoutFormInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\CheckoutFormInitializePreAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CheckoutFormInitializePreAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\CheckoutFormInitializeResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CheckoutFormInitializeResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\CheckoutFormMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CheckoutFormMapper.php',
    'Iyzipay\\Model\\Mapper\\ConsumerMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ConsumerMapper.php',
    'Iyzipay\\Model\\Mapper\\CrossBookingFromSubMerchantMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CrossBookingFromSubMerchantMapper.php',
    'Iyzipay\\Model\\Mapper\\CrossBookingToSubMerchantMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/CrossBookingToSubMerchantMapper.php',
    'Iyzipay\\Model\\Mapper\\DisapprovalMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/DisapprovalMapper.php',
    'Iyzipay\\Model\\Mapper\\InstallmentHtmlMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/InstallmentHtmlMapper.php',
    'Iyzipay\\Model\\Mapper\\InstallmentInfoMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/InstallmentInfoMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkDeleteProductMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkDeleteProductMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkDeleteProductResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkDeleteProductResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkRetrieveAllProductMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkRetrieveAllProductMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkRetrieveAllProductResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkRetrieveAllProductResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkRetrieveProductMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkRetrieveProductMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkRetrieveProductResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkRetrieveProductResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkSaveProductMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkSaveProductMapper.php',
    'Iyzipay\\Model\\Mapper\\Iyzilink\\IyziLinkSaveProductResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Iyzilink/IyziLinkSaveProductResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\IyzipayResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/IyzipayResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\IyziupFormInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/IyziupFormInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\IyziupFormInitializeResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/IyziupFormInitializeResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\IyziupFormMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/IyziupFormMapper.php',
    'Iyzipay\\Model\\Mapper\\LoyaltyMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/LoyaltyMapper.php',
    'Iyzipay\\Model\\Mapper\\PayWithIyzicoInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PayWithIyzicoInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\PayWithIyzicoInitializeResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PayWithIyzicoInitializeResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\PayWithIyzicoMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PayWithIyzicoMapper.php',
    'Iyzipay\\Model\\Mapper\\PaymentItemMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PaymentItemMapper.php',
    'Iyzipay\\Model\\Mapper\\PaymentMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PaymentMapper.php',
    'Iyzipay\\Model\\Mapper\\PaymentPostAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PaymentPostAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\PaymentPreAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PaymentPreAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\PaymentResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PaymentResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\PayoutCompletedTransactionListMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/PayoutCompletedTransactionListMapper.php',
    'Iyzipay\\Model\\Mapper\\ProtectedOverleyScriptMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ProtectedOverleyScriptMapper.php',
    'Iyzipay\\Model\\Mapper\\RefundChargedFromMerchantMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/RefundChargedFromMerchantMapper.php',
    'Iyzipay\\Model\\Mapper\\RefundMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/RefundMapper.php',
    'Iyzipay\\Model\\Mapper\\RefundResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/RefundResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\RefundToBalanceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/RefundToBalanceMapper.php',
    'Iyzipay\\Model\\Mapper\\RefundToBalanceResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/RefundToBalanceResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\ReportingPaymentDetailMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ReportingPaymentDetailMapper.php',
    'Iyzipay\\Model\\Mapper\\ReportingPaymentDetailResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ReportingPaymentDetailResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\ReportingPaymentTransactionMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ReportingPaymentTransactionMapper.php',
    'Iyzipay\\Model\\Mapper\\ReportingPaymentTransactionResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ReportingPaymentTransactionResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\SettlementToBalanceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/SettlementToBalanceMapper.php',
    'Iyzipay\\Model\\Mapper\\SettlementToBalanceResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/SettlementToBalanceResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\SubMerchantMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/SubMerchantMapper.php',
    'Iyzipay\\Model\\Mapper\\SubMerchantPaymentItemMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/SubMerchantPaymentItemMapper.php',
    'Iyzipay\\Model\\Mapper\\SubMerchantPaymentItemResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/SubMerchantPaymentItemResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\RetrieveListMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/RetrieveListMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\RetrieveListResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/RetrieveListResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\RetrieveSubscriptionCheckoutFormMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/RetrieveSubscriptionCheckoutFormMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\RetrieveSubscriptionCheckoutFormResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/RetrieveSubscriptionCheckoutFormResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionActionMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionActionMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionActionResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionActionResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCardUpdateMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCardUpdateMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCardUpdateResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCardUpdateResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCreateCheckoutFormMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCreateCheckoutFormMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCreateCheckoutFormResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCreateCheckoutFormResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCreateMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCreateMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCreateResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCreateResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCustomerMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCustomerMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionCustomerResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionCustomerResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionDetailsMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionDetailsMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionDetailsResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionDetailsResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionPricingPlanMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionPricingPlanMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionPricingPlanResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionPricingPlanResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionProductMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionProductMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionProductResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionProductResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionUpgradeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionUpgradeMapper.php',
    'Iyzipay\\Model\\Mapper\\Subscription\\SubscriptionUpgradeResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/Subscription/SubscriptionUpgradeResourceMapper.php',
    'Iyzipay\\Model\\Mapper\\ThreedsInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ThreedsInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\ThreedsInitializePreAuthMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ThreedsInitializePreAuthMapper.php',
    'Iyzipay\\Model\\Mapper\\ThreedsPaymentMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/ThreedsPaymentMapper.php',
    'Iyzipay\\Model\\Mapper\\UCSInitializeMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/UCSInitializeMapper.php',
    'Iyzipay\\Model\\Mapper\\UCSInitializeResourceMapper' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Mapper/UCSInitializeResourceMapper.php',
    'Iyzipay\\Model\\OrderItem' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/OrderItem.php',
    'Iyzipay\\Model\\OrderItemType' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/OrderItemType.php',
    'Iyzipay\\Model\\PayWithIyzico' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PayWithIyzico.php',
    'Iyzipay\\Model\\PayWithIyzicoInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PayWithIyzicoInitialize.php',
    'Iyzipay\\Model\\PayWithIyzicoInitializeResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PayWithIyzicoInitializeResource.php',
    'Iyzipay\\Model\\Payment' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Payment.php',
    'Iyzipay\\Model\\PaymentCard' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentCard.php',
    'Iyzipay\\Model\\PaymentChannel' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentChannel.php',
    'Iyzipay\\Model\\PaymentGroup' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentGroup.php',
    'Iyzipay\\Model\\PaymentItem' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentItem.php',
    'Iyzipay\\Model\\PaymentPostAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentPostAuth.php',
    'Iyzipay\\Model\\PaymentPreAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentPreAuth.php',
    'Iyzipay\\Model\\PaymentResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PaymentResource.php',
    'Iyzipay\\Model\\PayoutCompletedTransaction' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PayoutCompletedTransaction.php',
    'Iyzipay\\Model\\PayoutCompletedTransactionList' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/PayoutCompletedTransactionList.php',
    'Iyzipay\\Model\\ProtectedOverleyScript' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ProtectedOverleyScript.php',
    'Iyzipay\\Model\\Refund' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Refund.php',
    'Iyzipay\\Model\\RefundChargedFromMerchant' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/RefundChargedFromMerchant.php',
    'Iyzipay\\Model\\RefundReason' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/RefundReason.php',
    'Iyzipay\\Model\\RefundResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/RefundResource.php',
    'Iyzipay\\Model\\RefundToBalance' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/RefundToBalance.php',
    'Iyzipay\\Model\\RefundToBalanceResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/RefundToBalanceResource.php',
    'Iyzipay\\Model\\ReportingPaymentDetail' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ReportingPaymentDetail.php',
    'Iyzipay\\Model\\ReportingPaymentDetailResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ReportingPaymentDetailResource.php',
    'Iyzipay\\Model\\ReportingPaymentTransaction' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ReportingPaymentTransaction.php',
    'Iyzipay\\Model\\ReportingPaymentTransactionResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ReportingPaymentTransactionResource.php',
    'Iyzipay\\Model\\Reward' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Reward.php',
    'Iyzipay\\Model\\SettlementToBalance' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SettlementToBalance.php',
    'Iyzipay\\Model\\SettlementToBalanceResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SettlementToBalanceResource.php',
    'Iyzipay\\Model\\Status' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Status.php',
    'Iyzipay\\Model\\SubMerchant' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SubMerchant.php',
    'Iyzipay\\Model\\SubMerchantPaymentItemResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SubMerchantPaymentItemResource.php',
    'Iyzipay\\Model\\SubMerchantPaymentItemUpdate' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SubMerchantPaymentItemUpdate.php',
    'Iyzipay\\Model\\SubMerchantType' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/SubMerchantType.php',
    'Iyzipay\\Model\\Subscription\\RetrieveList' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/RetrieveList.php',
    'Iyzipay\\Model\\Subscription\\RetrieveSubscriptionCheckoutForm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/RetrieveSubscriptionCheckoutForm.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionActivate' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionActivate.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCancel' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCancel.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCardUpdate' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCardUpdate.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCreate' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCreate.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCreateCheckoutForm' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCreateCheckoutForm.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCreateWithCustomer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCreateWithCustomer.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionCustomer' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionCustomer.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionDetails' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionDetails.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionPricingPlan' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionPricingPlan.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionProduct' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionProduct.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionRetry' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionRetry.php',
    'Iyzipay\\Model\\Subscription\\SubscriptionUpgrade' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/Subscription/SubscriptionUpgrade.php',
    'Iyzipay\\Model\\ThreedsInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ThreedsInitialize.php',
    'Iyzipay\\Model\\ThreedsInitializePreAuth' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ThreedsInitializePreAuth.php',
    'Iyzipay\\Model\\ThreedsPayment' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/ThreedsPayment.php',
    'Iyzipay\\Model\\UCSInitialize' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/UCSInitialize.php',
    'Iyzipay\\Model\\UCSInitializeResource' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Model/UCSInitializeResource.php',
    'Iyzipay\\Options' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Options.php',
    'Iyzipay\\Request' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request.php',
    'Iyzipay\\RequestFormatter' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/RequestFormatter.php',
    'Iyzipay\\RequestStringBuilder' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/RequestStringBuilder.php',
    'Iyzipay\\RequestStringConvertible' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/RequestStringConvertible.php',
    'Iyzipay\\Request\\CreateApmInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateApmInitializeRequest.php',
    'Iyzipay\\Request\\CreateApprovalRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateApprovalRequest.php',
    'Iyzipay\\Request\\CreateBasicBkmInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateBasicBkmInitializeRequest.php',
    'Iyzipay\\Request\\CreateBasicPaymentRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateBasicPaymentRequest.php',
    'Iyzipay\\Request\\CreateBkmInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateBkmInitializeRequest.php',
    'Iyzipay\\Request\\CreateCancelRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateCancelRequest.php',
    'Iyzipay\\Request\\CreateCardRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateCardRequest.php',
    'Iyzipay\\Request\\CreateCheckoutFormInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateCheckoutFormInitializeRequest.php',
    'Iyzipay\\Request\\CreateCrossBookingRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateCrossBookingRequest.php',
    'Iyzipay\\Request\\CreateIyziupFormInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateIyziupFormInitializeRequest.php',
    'Iyzipay\\Request\\CreatePayWithIyzicoInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreatePayWithIyzicoInitializeRequest.php',
    'Iyzipay\\Request\\CreatePaymentPostAuthRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreatePaymentPostAuthRequest.php',
    'Iyzipay\\Request\\CreatePaymentRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreatePaymentRequest.php',
    'Iyzipay\\Request\\CreateRefundRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateRefundRequest.php',
    'Iyzipay\\Request\\CreateRefundToBalanceRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateRefundToBalanceRequest.php',
    'Iyzipay\\Request\\CreateSettlementToBalanceRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateSettlementToBalanceRequest.php',
    'Iyzipay\\Request\\CreateSubMerchantRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateSubMerchantRequest.php',
    'Iyzipay\\Request\\CreateThreedsPaymentRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/CreateThreedsPaymentRequest.php',
    'Iyzipay\\Request\\DeleteCardRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/DeleteCardRequest.php',
    'Iyzipay\\Request\\Iyzilink\\IyziLinkSaveProductRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Iyzilink/IyziLinkSaveProductRequest.php',
    'Iyzipay\\Request\\PagininRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/PagininRequest.php',
    'Iyzipay\\Request\\ReportingPaymentDetailRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/ReportingPaymentDetailRequest.php',
    'Iyzipay\\Request\\ReportingPaymentTransactionRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/ReportingPaymentTransactionRequest.php',
    'Iyzipay\\Request\\RetrieveApmRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveApmRequest.php',
    'Iyzipay\\Request\\RetrieveBinNumberRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveBinNumberRequest.php',
    'Iyzipay\\Request\\RetrieveBkmRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveBkmRequest.php',
    'Iyzipay\\Request\\RetrieveCardListRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveCardListRequest.php',
    'Iyzipay\\Request\\RetrieveCheckoutFormRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveCheckoutFormRequest.php',
    'Iyzipay\\Request\\RetrieveInstallmentInfoRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveInstallmentInfoRequest.php',
    'Iyzipay\\Request\\RetrieveIyziupFormRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveIyziupFormRequest.php',
    'Iyzipay\\Request\\RetrieveLoyaltyRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveLoyaltyRequest.php',
    'Iyzipay\\Request\\RetrievePayWithIyzicoRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrievePayWithIyzicoRequest.php',
    'Iyzipay\\Request\\RetrievePaymentRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrievePaymentRequest.php',
    'Iyzipay\\Request\\RetrieveProtectedOverleyScriptRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveProtectedOverleyScriptRequest.php',
    'Iyzipay\\Request\\RetrieveSubMerchantRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveSubMerchantRequest.php',
    'Iyzipay\\Request\\RetrieveTransactionsRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/RetrieveTransactionsRequest.php',
    'Iyzipay\\Request\\SubMerchantPaymentItemUpdateRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/SubMerchantPaymentItemUpdateRequest.php',
    'Iyzipay\\Request\\Subscription\\RetrieveSubscriptionCreateCheckoutFormRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/RetrieveSubscriptionCreateCheckoutFormRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionActivateRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionActivateRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCancelRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCancelRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCardUpdateRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCardUpdateRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCardUpdateWithSubscriptionReferenceCodeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCardUpdateWithSubscriptionReferenceCodeRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreateCheckoutFormRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreateCheckoutFormRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreateCustomerRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreateCustomerRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreatePricingPlanRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreatePricingPlanRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreateProductRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreateProductRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreateRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreateRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionCreateWithCustomerRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionCreateWithCustomerRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionDeletePricingPlanRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionDeletePricingPlanRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionDeleteProductRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionDeleteProductRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionDetailsRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionDetailsRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionListCustomersRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionListCustomersRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionListPricingPlanRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionListPricingPlanRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionListProductsRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionListProductsRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionRetrieveCustomerRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionRetrieveCustomerRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionRetrievePricingPlanRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionRetrievePricingPlanRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionRetrieveProductRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionRetrieveProductRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionRetryRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionRetryRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionSearchRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionSearchRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionUpdateCustomerRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionUpdateCustomerRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionUpdatePricingPlanRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionUpdatePricingPlanRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionUpdateProductRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionUpdateProductRequest.php',
    'Iyzipay\\Request\\Subscription\\SubscriptionUpgradeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/Subscription/SubscriptionUpgradeRequest.php',
    'Iyzipay\\Request\\UCSInitializeRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/UCSInitializeRequest.php',
    'Iyzipay\\Request\\UpdateSubMerchantRequest' => $vendorDir . '/iyzico/iyzipay-php/src/Iyzipay/Request/UpdateSubMerchantRequest.php',
    'JmesPath\\AstRuntime' => $vendorDir . '/mtdowling/jmespath.php/src/AstRuntime.php',
    'JmesPath\\CompilerRuntime' => $vendorDir . '/mtdowling/jmespath.php/src/CompilerRuntime.php',
    'JmesPath\\DebugRuntime' => $vendorDir . '/mtdowling/jmespath.php/src/DebugRuntime.php',
    'JmesPath\\Env' => $vendorDir . '/mtdowling/jmespath.php/src/Env.php',
    'JmesPath\\FnDispatcher' => $vendorDir . '/mtdowling/jmespath.php/src/FnDispatcher.php',
    'JmesPath\\Lexer' => $vendorDir . '/mtdowling/jmespath.php/src/Lexer.php',
    'JmesPath\\Parser' => $vendorDir . '/mtdowling/jmespath.php/src/Parser.php',
    'JmesPath\\SyntaxErrorException' => $vendorDir . '/mtdowling/jmespath.php/src/SyntaxErrorException.php',
    'JmesPath\\TreeCompiler' => $vendorDir . '/mtdowling/jmespath.php/src/TreeCompiler.php',
    'JmesPath\\TreeInterpreter' => $vendorDir . '/mtdowling/jmespath.php/src/TreeInterpreter.php',
    'JmesPath\\Utils' => $vendorDir . '/mtdowling/jmespath.php/src/Utils.php',
    'KKomelin\\TranslatableStringExporter\\Console\\ExportCommand' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Console/ExportCommand.php',
    'KKomelin\\TranslatableStringExporter\\Console\\InspectTranslationsCommand' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Console/InspectTranslationsCommand.php',
    'KKomelin\\TranslatableStringExporter\\Core\\CodeParser' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/CodeParser.php',
    'KKomelin\\TranslatableStringExporter\\Core\\Exporter' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/Exporter.php',
    'KKomelin\\TranslatableStringExporter\\Core\\FileFinder' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/FileFinder.php',
    'KKomelin\\TranslatableStringExporter\\Core\\StringExtractor' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/StringExtractor.php',
    'KKomelin\\TranslatableStringExporter\\Core\\UntranslatedStringFinder' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/UntranslatedStringFinder.php',
    'KKomelin\\TranslatableStringExporter\\Core\\Utils\\IO' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/Utils/IO.php',
    'KKomelin\\TranslatableStringExporter\\Core\\Utils\\JSON' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Core/Utils/JSON.php',
    'KKomelin\\TranslatableStringExporter\\Providers\\ExporterServiceProvider' => $vendorDir . '/kkomelin/laravel-translatable-string-exporter/src/Providers/ExporterServiceProvider.php',
    'Lab404\\Impersonate\\Controllers\\ImpersonateController' => $vendorDir . '/lab404/laravel-impersonate/src/Controllers/ImpersonateController.php',
    'Lab404\\Impersonate\\Events\\LeaveImpersonation' => $vendorDir . '/lab404/laravel-impersonate/src/Events/LeaveImpersonation.php',
    'Lab404\\Impersonate\\Events\\TakeImpersonation' => $vendorDir . '/lab404/laravel-impersonate/src/Events/TakeImpersonation.php',
    'Lab404\\Impersonate\\Exceptions\\InvalidUserProvider' => $vendorDir . '/lab404/laravel-impersonate/src/Exceptions/InvalidUserProvider.php',
    'Lab404\\Impersonate\\Exceptions\\MissingUserProvider' => $vendorDir . '/lab404/laravel-impersonate/src/Exceptions/MissingUserProvider.php',
    'Lab404\\Impersonate\\Guard\\SessionGuard' => $vendorDir . '/lab404/laravel-impersonate/src/Guard/SessionGuard.php',
    'Lab404\\Impersonate\\Impersonate' => $vendorDir . '/lab404/laravel-impersonate/src/Impersonate.php',
    'Lab404\\Impersonate\\ImpersonateServiceProvider' => $vendorDir . '/lab404/laravel-impersonate/src/ImpersonateServiceProvider.php',
    'Lab404\\Impersonate\\Middleware\\ProtectFromImpersonation' => $vendorDir . '/lab404/laravel-impersonate/src/Middleware/ProtectFromImpersonation.php',
    'Lab404\\Impersonate\\Models\\Impersonate' => $vendorDir . '/lab404/laravel-impersonate/src/Models/Impersonate.php',
    'Lab404\\Impersonate\\Services\\ImpersonateManager' => $vendorDir . '/lab404/laravel-impersonate/src/Services/ImpersonateManager.php',
    'Lahirulhr\\PayHere\\Api\\Authorize' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Authorize.php',
    'Lahirulhr\\PayHere\\Api\\Capture' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Capture.php',
    'Lahirulhr\\PayHere\\Api\\Charge' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Charge.php',
    'Lahirulhr\\PayHere\\Api\\Checkout' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Checkout.php',
    'Lahirulhr\\PayHere\\Api\\PreApproval' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/PreApproval.php',
    'Lahirulhr\\PayHere\\Api\\Recurring' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Recurring.php',
    'Lahirulhr\\PayHere\\Api\\Refund' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Refund.php',
    'Lahirulhr\\PayHere\\Api\\Retrieve' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Retrieve.php',
    'Lahirulhr\\PayHere\\Api\\Subscription' => $vendorDir . '/lahirulhr/laravel-payhere/src/Api/Subscription.php',
    'Lahirulhr\\PayHere\\Commands\\PayHereCommand' => $vendorDir . '/lahirulhr/laravel-payhere/src/Commands/PayHereCommand.php',
    'Lahirulhr\\PayHere\\Controllers\\CallbackController' => $vendorDir . '/lahirulhr/laravel-payhere/src/Controllers/CallbackController.php',
    'Lahirulhr\\PayHere\\Controllers\\FormController' => $vendorDir . '/lahirulhr/laravel-payhere/src/Controllers/FormController.php',
    'Lahirulhr\\PayHere\\Events\\AuthorizeCallbackEvent' => $vendorDir . '/lahirulhr/laravel-payhere/src/Events/AuthorizeCallbackEvent.php',
    'Lahirulhr\\PayHere\\Events\\CheckoutCallbackEvent' => $vendorDir . '/lahirulhr/laravel-payhere/src/Events/CheckoutCallbackEvent.php',
    'Lahirulhr\\PayHere\\Events\\PreApprovalCallbackEvent' => $vendorDir . '/lahirulhr/laravel-payhere/src/Events/PreApprovalCallbackEvent.php',
    'Lahirulhr\\PayHere\\Events\\RecurringCallbackEvent' => $vendorDir . '/lahirulhr/laravel-payhere/src/Events/RecurringCallbackEvent.php',
    'Lahirulhr\\PayHere\\Exceptions\\PayHereException' => $vendorDir . '/lahirulhr/laravel-payhere/src/Exceptions/PayHereException.php',
    'Lahirulhr\\PayHere\\Helpers\\PayHereClient' => $vendorDir . '/lahirulhr/laravel-payhere/src/Helpers/PayHereClient.php',
    'Lahirulhr\\PayHere\\Helpers\\PayHereRestClient' => $vendorDir . '/lahirulhr/laravel-payhere/src/Helpers/PayHereRestClient.php',
    'Lahirulhr\\PayHere\\PayHere' => $vendorDir . '/lahirulhr/laravel-payhere/src/PayHere.php',
    'Lahirulhr\\PayHere\\PayHereFacade' => $vendorDir . '/lahirulhr/laravel-payhere/src/PayHereFacade.php',
    'Lahirulhr\\PayHere\\PayHereServiceProvider' => $vendorDir . '/lahirulhr/laravel-payhere/src/PayHereServiceProvider.php',
    'Laravel\\Prompts\\Concerns\\Colors' => $vendorDir . '/laravel/prompts/src/Concerns/Colors.php',
    'Laravel\\Prompts\\Concerns\\Cursor' => $vendorDir . '/laravel/prompts/src/Concerns/Cursor.php',
    'Laravel\\Prompts\\Concerns\\Erase' => $vendorDir . '/laravel/prompts/src/Concerns/Erase.php',
    'Laravel\\Prompts\\Concerns\\Events' => $vendorDir . '/laravel/prompts/src/Concerns/Events.php',
    'Laravel\\Prompts\\Concerns\\FakesInputOutput' => $vendorDir . '/laravel/prompts/src/Concerns/FakesInputOutput.php',
    'Laravel\\Prompts\\Concerns\\Fallback' => $vendorDir . '/laravel/prompts/src/Concerns/Fallback.php',
    'Laravel\\Prompts\\Concerns\\Interactivity' => $vendorDir . '/laravel/prompts/src/Concerns/Interactivity.php',
    'Laravel\\Prompts\\Concerns\\Scrolling' => $vendorDir . '/laravel/prompts/src/Concerns/Scrolling.php',
    'Laravel\\Prompts\\Concerns\\Termwind' => $vendorDir . '/laravel/prompts/src/Concerns/Termwind.php',
    'Laravel\\Prompts\\Concerns\\Themes' => $vendorDir . '/laravel/prompts/src/Concerns/Themes.php',
    'Laravel\\Prompts\\Concerns\\Truncation' => $vendorDir . '/laravel/prompts/src/Concerns/Truncation.php',
    'Laravel\\Prompts\\Concerns\\TypedValue' => $vendorDir . '/laravel/prompts/src/Concerns/TypedValue.php',
    'Laravel\\Prompts\\ConfirmPrompt' => $vendorDir . '/laravel/prompts/src/ConfirmPrompt.php',
    'Laravel\\Prompts\\Exceptions\\FormRevertedException' => $vendorDir . '/laravel/prompts/src/Exceptions/FormRevertedException.php',
    'Laravel\\Prompts\\Exceptions\\NonInteractiveValidationException' => $vendorDir . '/laravel/prompts/src/Exceptions/NonInteractiveValidationException.php',
    'Laravel\\Prompts\\FormBuilder' => $vendorDir . '/laravel/prompts/src/FormBuilder.php',
    'Laravel\\Prompts\\FormStep' => $vendorDir . '/laravel/prompts/src/FormStep.php',
    'Laravel\\Prompts\\Key' => $vendorDir . '/laravel/prompts/src/Key.php',
    'Laravel\\Prompts\\MultiSearchPrompt' => $vendorDir . '/laravel/prompts/src/MultiSearchPrompt.php',
    'Laravel\\Prompts\\MultiSelectPrompt' => $vendorDir . '/laravel/prompts/src/MultiSelectPrompt.php',
    'Laravel\\Prompts\\Note' => $vendorDir . '/laravel/prompts/src/Note.php',
    'Laravel\\Prompts\\Output\\BufferedConsoleOutput' => $vendorDir . '/laravel/prompts/src/Output/BufferedConsoleOutput.php',
    'Laravel\\Prompts\\Output\\ConsoleOutput' => $vendorDir . '/laravel/prompts/src/Output/ConsoleOutput.php',
    'Laravel\\Prompts\\PasswordPrompt' => $vendorDir . '/laravel/prompts/src/PasswordPrompt.php',
    'Laravel\\Prompts\\PausePrompt' => $vendorDir . '/laravel/prompts/src/PausePrompt.php',
    'Laravel\\Prompts\\Progress' => $vendorDir . '/laravel/prompts/src/Progress.php',
    'Laravel\\Prompts\\Prompt' => $vendorDir . '/laravel/prompts/src/Prompt.php',
    'Laravel\\Prompts\\SearchPrompt' => $vendorDir . '/laravel/prompts/src/SearchPrompt.php',
    'Laravel\\Prompts\\SelectPrompt' => $vendorDir . '/laravel/prompts/src/SelectPrompt.php',
    'Laravel\\Prompts\\Spinner' => $vendorDir . '/laravel/prompts/src/Spinner.php',
    'Laravel\\Prompts\\SuggestPrompt' => $vendorDir . '/laravel/prompts/src/SuggestPrompt.php',
    'Laravel\\Prompts\\Table' => $vendorDir . '/laravel/prompts/src/Table.php',
    'Laravel\\Prompts\\Terminal' => $vendorDir . '/laravel/prompts/src/Terminal.php',
    'Laravel\\Prompts\\TextPrompt' => $vendorDir . '/laravel/prompts/src/TextPrompt.php',
    'Laravel\\Prompts\\TextareaPrompt' => $vendorDir . '/laravel/prompts/src/TextareaPrompt.php',
    'Laravel\\Prompts\\Themes\\Contracts\\Scrolling' => $vendorDir . '/laravel/prompts/src/Themes/Contracts/Scrolling.php',
    'Laravel\\Prompts\\Themes\\Default\\Concerns\\DrawsBoxes' => $vendorDir . '/laravel/prompts/src/Themes/Default/Concerns/DrawsBoxes.php',
    'Laravel\\Prompts\\Themes\\Default\\Concerns\\DrawsScrollbars' => $vendorDir . '/laravel/prompts/src/Themes/Default/Concerns/DrawsScrollbars.php',
    'Laravel\\Prompts\\Themes\\Default\\Concerns\\InteractsWithStrings' => $vendorDir . '/laravel/prompts/src/Themes/Default/Concerns/InteractsWithStrings.php',
    'Laravel\\Prompts\\Themes\\Default\\ConfirmPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/ConfirmPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\MultiSearchPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/MultiSearchPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\MultiSelectPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/MultiSelectPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\NoteRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/NoteRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\PasswordPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/PasswordPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\PausePromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/PausePromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\ProgressRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/ProgressRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\Renderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/Renderer.php',
    'Laravel\\Prompts\\Themes\\Default\\SearchPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/SearchPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\SelectPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/SelectPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\SpinnerRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/SpinnerRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\SuggestPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/SuggestPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\TableRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/TableRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\TextPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/TextPromptRenderer.php',
    'Laravel\\Prompts\\Themes\\Default\\TextareaPromptRenderer' => $vendorDir . '/laravel/prompts/src/Themes/Default/TextareaPromptRenderer.php',
    'Laravel\\Sail\\Console\\AddCommand' => $vendorDir . '/laravel/sail/src/Console/AddCommand.php',
    'Laravel\\Sail\\Console\\Concerns\\InteractsWithDockerComposeServices' => $vendorDir . '/laravel/sail/src/Console/Concerns/InteractsWithDockerComposeServices.php',
    'Laravel\\Sail\\Console\\InstallCommand' => $vendorDir . '/laravel/sail/src/Console/InstallCommand.php',
    'Laravel\\Sail\\Console\\PublishCommand' => $vendorDir . '/laravel/sail/src/Console/PublishCommand.php',
    'Laravel\\Sail\\SailServiceProvider' => $vendorDir . '/laravel/sail/src/SailServiceProvider.php',
    'Laravel\\Sanctum\\Console\\Commands\\PruneExpired' => $vendorDir . '/laravel/sanctum/src/Console/Commands/PruneExpired.php',
    'Laravel\\Sanctum\\Contracts\\HasAbilities' => $vendorDir . '/laravel/sanctum/src/Contracts/HasAbilities.php',
    'Laravel\\Sanctum\\Contracts\\HasApiTokens' => $vendorDir . '/laravel/sanctum/src/Contracts/HasApiTokens.php',
    'Laravel\\Sanctum\\Events\\TokenAuthenticated' => $vendorDir . '/laravel/sanctum/src/Events/TokenAuthenticated.php',
    'Laravel\\Sanctum\\Exceptions\\MissingAbilityException' => $vendorDir . '/laravel/sanctum/src/Exceptions/MissingAbilityException.php',
    'Laravel\\Sanctum\\Exceptions\\MissingScopeException' => $vendorDir . '/laravel/sanctum/src/Exceptions/MissingScopeException.php',
    'Laravel\\Sanctum\\Guard' => $vendorDir . '/laravel/sanctum/src/Guard.php',
    'Laravel\\Sanctum\\HasApiTokens' => $vendorDir . '/laravel/sanctum/src/HasApiTokens.php',
    'Laravel\\Sanctum\\Http\\Controllers\\CsrfCookieController' => $vendorDir . '/laravel/sanctum/src/Http/Controllers/CsrfCookieController.php',
    'Laravel\\Sanctum\\Http\\Middleware\\AuthenticateSession' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/AuthenticateSession.php',
    'Laravel\\Sanctum\\Http\\Middleware\\CheckAbilities' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/CheckAbilities.php',
    'Laravel\\Sanctum\\Http\\Middleware\\CheckForAnyAbility' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/CheckForAnyAbility.php',
    'Laravel\\Sanctum\\Http\\Middleware\\CheckForAnyScope' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/CheckForAnyScope.php',
    'Laravel\\Sanctum\\Http\\Middleware\\CheckScopes' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/CheckScopes.php',
    'Laravel\\Sanctum\\Http\\Middleware\\EnsureFrontendRequestsAreStateful' => $vendorDir . '/laravel/sanctum/src/Http/Middleware/EnsureFrontendRequestsAreStateful.php',
    'Laravel\\Sanctum\\NewAccessToken' => $vendorDir . '/laravel/sanctum/src/NewAccessToken.php',
    'Laravel\\Sanctum\\PersonalAccessToken' => $vendorDir . '/laravel/sanctum/src/PersonalAccessToken.php',
    'Laravel\\Sanctum\\Sanctum' => $vendorDir . '/laravel/sanctum/src/Sanctum.php',
    'Laravel\\Sanctum\\SanctumServiceProvider' => $vendorDir . '/laravel/sanctum/src/SanctumServiceProvider.php',
    'Laravel\\Sanctum\\TransientToken' => $vendorDir . '/laravel/sanctum/src/TransientToken.php',
    'Laravel\\SerializableClosure\\Contracts\\Serializable' => $vendorDir . '/laravel/serializable-closure/src/Contracts/Serializable.php',
    'Laravel\\SerializableClosure\\Contracts\\Signer' => $vendorDir . '/laravel/serializable-closure/src/Contracts/Signer.php',
    'Laravel\\SerializableClosure\\Exceptions\\InvalidSignatureException' => $vendorDir . '/laravel/serializable-closure/src/Exceptions/InvalidSignatureException.php',
    'Laravel\\SerializableClosure\\Exceptions\\MissingSecretKeyException' => $vendorDir . '/laravel/serializable-closure/src/Exceptions/MissingSecretKeyException.php',
    'Laravel\\SerializableClosure\\Exceptions\\PhpVersionNotSupportedException' => $vendorDir . '/laravel/serializable-closure/src/Exceptions/PhpVersionNotSupportedException.php',
    'Laravel\\SerializableClosure\\SerializableClosure' => $vendorDir . '/laravel/serializable-closure/src/SerializableClosure.php',
    'Laravel\\SerializableClosure\\Serializers\\Native' => $vendorDir . '/laravel/serializable-closure/src/Serializers/Native.php',
    'Laravel\\SerializableClosure\\Serializers\\Signed' => $vendorDir . '/laravel/serializable-closure/src/Serializers/Signed.php',
    'Laravel\\SerializableClosure\\Signers\\Hmac' => $vendorDir . '/laravel/serializable-closure/src/Signers/Hmac.php',
    'Laravel\\SerializableClosure\\Support\\ClosureScope' => $vendorDir . '/laravel/serializable-closure/src/Support/ClosureScope.php',
    'Laravel\\SerializableClosure\\Support\\ClosureStream' => $vendorDir . '/laravel/serializable-closure/src/Support/ClosureStream.php',
    'Laravel\\SerializableClosure\\Support\\ReflectionClosure' => $vendorDir . '/laravel/serializable-closure/src/Support/ReflectionClosure.php',
    'Laravel\\SerializableClosure\\Support\\SelfReference' => $vendorDir . '/laravel/serializable-closure/src/Support/SelfReference.php',
    'Laravel\\SerializableClosure\\UnsignedSerializableClosure' => $vendorDir . '/laravel/serializable-closure/src/UnsignedSerializableClosure.php',
    'Laravel\\Tinker\\ClassAliasAutoloader' => $vendorDir . '/laravel/tinker/src/ClassAliasAutoloader.php',
    'Laravel\\Tinker\\Console\\TinkerCommand' => $vendorDir . '/laravel/tinker/src/Console/TinkerCommand.php',
    'Laravel\\Tinker\\TinkerCaster' => $vendorDir . '/laravel/tinker/src/TinkerCaster.php',
    'Laravel\\Tinker\\TinkerServiceProvider' => $vendorDir . '/laravel/tinker/src/TinkerServiceProvider.php',
    'League\\CommonMark\\CommonMarkConverter' => $vendorDir . '/league/commonmark/src/CommonMarkConverter.php',
    'League\\CommonMark\\ConverterInterface' => $vendorDir . '/league/commonmark/src/ConverterInterface.php',
    'League\\CommonMark\\Delimiter\\Delimiter' => $vendorDir . '/league/commonmark/src/Delimiter/Delimiter.php',
    'League\\CommonMark\\Delimiter\\DelimiterInterface' => $vendorDir . '/league/commonmark/src/Delimiter/DelimiterInterface.php',
    'League\\CommonMark\\Delimiter\\DelimiterParser' => $vendorDir . '/league/commonmark/src/Delimiter/DelimiterParser.php',
    'League\\CommonMark\\Delimiter\\DelimiterStack' => $vendorDir . '/league/commonmark/src/Delimiter/DelimiterStack.php',
    'League\\CommonMark\\Delimiter\\Processor\\DelimiterProcessorCollection' => $vendorDir . '/league/commonmark/src/Delimiter/Processor/DelimiterProcessorCollection.php',
    'League\\CommonMark\\Delimiter\\Processor\\DelimiterProcessorCollectionInterface' => $vendorDir . '/league/commonmark/src/Delimiter/Processor/DelimiterProcessorCollectionInterface.php',
    'League\\CommonMark\\Delimiter\\Processor\\DelimiterProcessorInterface' => $vendorDir . '/league/commonmark/src/Delimiter/Processor/DelimiterProcessorInterface.php',
    'League\\CommonMark\\Delimiter\\Processor\\StaggeredDelimiterProcessor' => $vendorDir . '/league/commonmark/src/Delimiter/Processor/StaggeredDelimiterProcessor.php',
    'League\\CommonMark\\Environment\\Environment' => $vendorDir . '/league/commonmark/src/Environment/Environment.php',
    'League\\CommonMark\\Environment\\EnvironmentAwareInterface' => $vendorDir . '/league/commonmark/src/Environment/EnvironmentAwareInterface.php',
    'League\\CommonMark\\Environment\\EnvironmentBuilderInterface' => $vendorDir . '/league/commonmark/src/Environment/EnvironmentBuilderInterface.php',
    'League\\CommonMark\\Environment\\EnvironmentInterface' => $vendorDir . '/league/commonmark/src/Environment/EnvironmentInterface.php',
    'League\\CommonMark\\Event\\AbstractEvent' => $vendorDir . '/league/commonmark/src/Event/AbstractEvent.php',
    'League\\CommonMark\\Event\\DocumentParsedEvent' => $vendorDir . '/league/commonmark/src/Event/DocumentParsedEvent.php',
    'League\\CommonMark\\Event\\DocumentPreParsedEvent' => $vendorDir . '/league/commonmark/src/Event/DocumentPreParsedEvent.php',
    'League\\CommonMark\\Event\\DocumentPreRenderEvent' => $vendorDir . '/league/commonmark/src/Event/DocumentPreRenderEvent.php',
    'League\\CommonMark\\Event\\DocumentRenderedEvent' => $vendorDir . '/league/commonmark/src/Event/DocumentRenderedEvent.php',
    'League\\CommonMark\\Event\\ListenerData' => $vendorDir . '/league/commonmark/src/Event/ListenerData.php',
    'League\\CommonMark\\Exception\\AlreadyInitializedException' => $vendorDir . '/league/commonmark/src/Exception/AlreadyInitializedException.php',
    'League\\CommonMark\\Exception\\CommonMarkException' => $vendorDir . '/league/commonmark/src/Exception/CommonMarkException.php',
    'League\\CommonMark\\Exception\\IOException' => $vendorDir . '/league/commonmark/src/Exception/IOException.php',
    'League\\CommonMark\\Exception\\InvalidArgumentException' => $vendorDir . '/league/commonmark/src/Exception/InvalidArgumentException.php',
    'League\\CommonMark\\Exception\\LogicException' => $vendorDir . '/league/commonmark/src/Exception/LogicException.php',
    'League\\CommonMark\\Exception\\MissingDependencyException' => $vendorDir . '/league/commonmark/src/Exception/MissingDependencyException.php',
    'League\\CommonMark\\Exception\\UnexpectedEncodingException' => $vendorDir . '/league/commonmark/src/Exception/UnexpectedEncodingException.php',
    'League\\CommonMark\\Extension\\Attributes\\AttributesExtension' => $vendorDir . '/league/commonmark/src/Extension/Attributes/AttributesExtension.php',
    'League\\CommonMark\\Extension\\Attributes\\Event\\AttributesListener' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Event/AttributesListener.php',
    'League\\CommonMark\\Extension\\Attributes\\Node\\Attributes' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Node/Attributes.php',
    'League\\CommonMark\\Extension\\Attributes\\Node\\AttributesInline' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Node/AttributesInline.php',
    'League\\CommonMark\\Extension\\Attributes\\Parser\\AttributesBlockContinueParser' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Parser/AttributesBlockContinueParser.php',
    'League\\CommonMark\\Extension\\Attributes\\Parser\\AttributesBlockStartParser' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Parser/AttributesBlockStartParser.php',
    'League\\CommonMark\\Extension\\Attributes\\Parser\\AttributesInlineParser' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Parser/AttributesInlineParser.php',
    'League\\CommonMark\\Extension\\Attributes\\Util\\AttributesHelper' => $vendorDir . '/league/commonmark/src/Extension/Attributes/Util/AttributesHelper.php',
    'League\\CommonMark\\Extension\\Autolink\\AutolinkExtension' => $vendorDir . '/league/commonmark/src/Extension/Autolink/AutolinkExtension.php',
    'League\\CommonMark\\Extension\\Autolink\\EmailAutolinkParser' => $vendorDir . '/league/commonmark/src/Extension/Autolink/EmailAutolinkParser.php',
    'League\\CommonMark\\Extension\\Autolink\\UrlAutolinkParser' => $vendorDir . '/league/commonmark/src/Extension/Autolink/UrlAutolinkParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\CommonMarkCoreExtension' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/CommonMarkCoreExtension.php',
    'League\\CommonMark\\Extension\\CommonMark\\Delimiter\\Processor\\EmphasisDelimiterProcessor' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Delimiter/Processor/EmphasisDelimiterProcessor.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\BlockQuote' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/BlockQuote.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\FencedCode' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/FencedCode.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\Heading' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/Heading.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\HtmlBlock' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/HtmlBlock.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\IndentedCode' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/IndentedCode.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\ListBlock' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/ListBlock.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\ListData' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/ListData.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\ListItem' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/ListItem.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Block\\ThematicBreak' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Block/ThematicBreak.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\AbstractWebResource' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/AbstractWebResource.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\Code' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/Code.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\Emphasis' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/Emphasis.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\HtmlInline' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/HtmlInline.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\Image' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/Image.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\Link' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/Link.php',
    'League\\CommonMark\\Extension\\CommonMark\\Node\\Inline\\Strong' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Node/Inline/Strong.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\BlockQuoteParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/BlockQuoteParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\BlockQuoteStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/BlockQuoteStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\FencedCodeParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/FencedCodeParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\FencedCodeStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/FencedCodeStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\HeadingParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/HeadingParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\HeadingStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/HeadingStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\HtmlBlockParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/HtmlBlockParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\HtmlBlockStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/HtmlBlockStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\IndentedCodeParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/IndentedCodeParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\IndentedCodeStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/IndentedCodeStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\ListBlockParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/ListBlockParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\ListBlockStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/ListBlockStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\ListItemParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/ListItemParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\ThematicBreakParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/ThematicBreakParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Block\\ThematicBreakStartParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Block/ThematicBreakStartParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\AutolinkParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/AutolinkParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\BacktickParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/BacktickParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\BangParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/BangParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\CloseBracketParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/CloseBracketParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\EntityParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/EntityParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\EscapableParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/EscapableParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\HtmlInlineParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/HtmlInlineParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Parser\\Inline\\OpenBracketParser' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Parser/Inline/OpenBracketParser.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\BlockQuoteRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/BlockQuoteRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\FencedCodeRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/FencedCodeRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\HeadingRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/HeadingRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\HtmlBlockRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/HtmlBlockRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\IndentedCodeRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/IndentedCodeRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\ListBlockRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/ListBlockRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\ListItemRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/ListItemRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Block\\ThematicBreakRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Block/ThematicBreakRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\CodeRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/CodeRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\EmphasisRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/EmphasisRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\HtmlInlineRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/HtmlInlineRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\ImageRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/ImageRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\LinkRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/LinkRenderer.php',
    'League\\CommonMark\\Extension\\CommonMark\\Renderer\\Inline\\StrongRenderer' => $vendorDir . '/league/commonmark/src/Extension/CommonMark/Renderer/Inline/StrongRenderer.php',
    'League\\CommonMark\\Extension\\ConfigurableExtensionInterface' => $vendorDir . '/league/commonmark/src/Extension/ConfigurableExtensionInterface.php',
    'League\\CommonMark\\Extension\\DefaultAttributes\\ApplyDefaultAttributesProcessor' => $vendorDir . '/league/commonmark/src/Extension/DefaultAttributes/ApplyDefaultAttributesProcessor.php',
    'League\\CommonMark\\Extension\\DefaultAttributes\\DefaultAttributesExtension' => $vendorDir . '/league/commonmark/src/Extension/DefaultAttributes/DefaultAttributesExtension.php',
    'League\\CommonMark\\Extension\\DescriptionList\\DescriptionListExtension' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/DescriptionListExtension.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Event\\ConsecutiveDescriptionListMerger' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Event/ConsecutiveDescriptionListMerger.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Event\\LooseDescriptionHandler' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Event/LooseDescriptionHandler.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Node\\Description' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Node/Description.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Node\\DescriptionList' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Node/DescriptionList.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Node\\DescriptionTerm' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Node/DescriptionTerm.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Parser\\DescriptionContinueParser' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Parser/DescriptionContinueParser.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Parser\\DescriptionListContinueParser' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Parser/DescriptionListContinueParser.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Parser\\DescriptionStartParser' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Parser/DescriptionStartParser.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Parser\\DescriptionTermContinueParser' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Parser/DescriptionTermContinueParser.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Renderer\\DescriptionListRenderer' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Renderer/DescriptionListRenderer.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Renderer\\DescriptionRenderer' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Renderer/DescriptionRenderer.php',
    'League\\CommonMark\\Extension\\DescriptionList\\Renderer\\DescriptionTermRenderer' => $vendorDir . '/league/commonmark/src/Extension/DescriptionList/Renderer/DescriptionTermRenderer.php',
    'League\\CommonMark\\Extension\\DisallowedRawHtml\\DisallowedRawHtmlExtension' => $vendorDir . '/league/commonmark/src/Extension/DisallowedRawHtml/DisallowedRawHtmlExtension.php',
    'League\\CommonMark\\Extension\\DisallowedRawHtml\\DisallowedRawHtmlRenderer' => $vendorDir . '/league/commonmark/src/Extension/DisallowedRawHtml/DisallowedRawHtmlRenderer.php',
    'League\\CommonMark\\Extension\\Embed\\Bridge\\OscaroteroEmbedAdapter' => $vendorDir . '/league/commonmark/src/Extension/Embed/Bridge/OscaroteroEmbedAdapter.php',
    'League\\CommonMark\\Extension\\Embed\\DomainFilteringAdapter' => $vendorDir . '/league/commonmark/src/Extension/Embed/DomainFilteringAdapter.php',
    'League\\CommonMark\\Extension\\Embed\\Embed' => $vendorDir . '/league/commonmark/src/Extension/Embed/Embed.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedAdapterInterface' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedAdapterInterface.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedExtension' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedExtension.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedParser' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedParser.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedProcessor' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedProcessor.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedRenderer' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedRenderer.php',
    'League\\CommonMark\\Extension\\Embed\\EmbedStartParser' => $vendorDir . '/league/commonmark/src/Extension/Embed/EmbedStartParser.php',
    'League\\CommonMark\\Extension\\ExtensionInterface' => $vendorDir . '/league/commonmark/src/Extension/ExtensionInterface.php',
    'League\\CommonMark\\Extension\\ExternalLink\\ExternalLinkExtension' => $vendorDir . '/league/commonmark/src/Extension/ExternalLink/ExternalLinkExtension.php',
    'League\\CommonMark\\Extension\\ExternalLink\\ExternalLinkProcessor' => $vendorDir . '/league/commonmark/src/Extension/ExternalLink/ExternalLinkProcessor.php',
    'League\\CommonMark\\Extension\\Footnote\\Event\\AnonymousFootnotesListener' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Event/AnonymousFootnotesListener.php',
    'League\\CommonMark\\Extension\\Footnote\\Event\\FixOrphanedFootnotesAndRefsListener' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Event/FixOrphanedFootnotesAndRefsListener.php',
    'League\\CommonMark\\Extension\\Footnote\\Event\\GatherFootnotesListener' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Event/GatherFootnotesListener.php',
    'League\\CommonMark\\Extension\\Footnote\\Event\\NumberFootnotesListener' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Event/NumberFootnotesListener.php',
    'League\\CommonMark\\Extension\\Footnote\\FootnoteExtension' => $vendorDir . '/league/commonmark/src/Extension/Footnote/FootnoteExtension.php',
    'League\\CommonMark\\Extension\\Footnote\\Node\\Footnote' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Node/Footnote.php',
    'League\\CommonMark\\Extension\\Footnote\\Node\\FootnoteBackref' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Node/FootnoteBackref.php',
    'League\\CommonMark\\Extension\\Footnote\\Node\\FootnoteContainer' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Node/FootnoteContainer.php',
    'League\\CommonMark\\Extension\\Footnote\\Node\\FootnoteRef' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Node/FootnoteRef.php',
    'League\\CommonMark\\Extension\\Footnote\\Parser\\AnonymousFootnoteRefParser' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Parser/AnonymousFootnoteRefParser.php',
    'League\\CommonMark\\Extension\\Footnote\\Parser\\FootnoteParser' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Parser/FootnoteParser.php',
    'League\\CommonMark\\Extension\\Footnote\\Parser\\FootnoteRefParser' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Parser/FootnoteRefParser.php',
    'League\\CommonMark\\Extension\\Footnote\\Parser\\FootnoteStartParser' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Parser/FootnoteStartParser.php',
    'League\\CommonMark\\Extension\\Footnote\\Renderer\\FootnoteBackrefRenderer' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Renderer/FootnoteBackrefRenderer.php',
    'League\\CommonMark\\Extension\\Footnote\\Renderer\\FootnoteContainerRenderer' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Renderer/FootnoteContainerRenderer.php',
    'League\\CommonMark\\Extension\\Footnote\\Renderer\\FootnoteRefRenderer' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Renderer/FootnoteRefRenderer.php',
    'League\\CommonMark\\Extension\\Footnote\\Renderer\\FootnoteRenderer' => $vendorDir . '/league/commonmark/src/Extension/Footnote/Renderer/FootnoteRenderer.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Data\\FrontMatterDataParserInterface' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Data/FrontMatterDataParserInterface.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Data\\LibYamlFrontMatterParser' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Data/LibYamlFrontMatterParser.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Data\\SymfonyYamlFrontMatterParser' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Data/SymfonyYamlFrontMatterParser.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Exception\\InvalidFrontMatterException' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Exception/InvalidFrontMatterException.php',
    'League\\CommonMark\\Extension\\FrontMatter\\FrontMatterExtension' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/FrontMatterExtension.php',
    'League\\CommonMark\\Extension\\FrontMatter\\FrontMatterParser' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/FrontMatterParser.php',
    'League\\CommonMark\\Extension\\FrontMatter\\FrontMatterParserInterface' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/FrontMatterParserInterface.php',
    'League\\CommonMark\\Extension\\FrontMatter\\FrontMatterProviderInterface' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/FrontMatterProviderInterface.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Input\\MarkdownInputWithFrontMatter' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Input/MarkdownInputWithFrontMatter.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Listener\\FrontMatterPostRenderListener' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Listener/FrontMatterPostRenderListener.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Listener\\FrontMatterPreParser' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Listener/FrontMatterPreParser.php',
    'League\\CommonMark\\Extension\\FrontMatter\\Output\\RenderedContentWithFrontMatter' => $vendorDir . '/league/commonmark/src/Extension/FrontMatter/Output/RenderedContentWithFrontMatter.php',
    'League\\CommonMark\\Extension\\GithubFlavoredMarkdownExtension' => $vendorDir . '/league/commonmark/src/Extension/GithubFlavoredMarkdownExtension.php',
    'League\\CommonMark\\Extension\\HeadingPermalink\\HeadingPermalink' => $vendorDir . '/league/commonmark/src/Extension/HeadingPermalink/HeadingPermalink.php',
    'League\\CommonMark\\Extension\\HeadingPermalink\\HeadingPermalinkExtension' => $vendorDir . '/league/commonmark/src/Extension/HeadingPermalink/HeadingPermalinkExtension.php',
    'League\\CommonMark\\Extension\\HeadingPermalink\\HeadingPermalinkProcessor' => $vendorDir . '/league/commonmark/src/Extension/HeadingPermalink/HeadingPermalinkProcessor.php',
    'League\\CommonMark\\Extension\\HeadingPermalink\\HeadingPermalinkRenderer' => $vendorDir . '/league/commonmark/src/Extension/HeadingPermalink/HeadingPermalinkRenderer.php',
    'League\\CommonMark\\Extension\\InlinesOnly\\ChildRenderer' => $vendorDir . '/league/commonmark/src/Extension/InlinesOnly/ChildRenderer.php',
    'League\\CommonMark\\Extension\\InlinesOnly\\InlinesOnlyExtension' => $vendorDir . '/league/commonmark/src/Extension/InlinesOnly/InlinesOnlyExtension.php',
    'League\\CommonMark\\Extension\\Mention\\Generator\\CallbackGenerator' => $vendorDir . '/league/commonmark/src/Extension/Mention/Generator/CallbackGenerator.php',
    'League\\CommonMark\\Extension\\Mention\\Generator\\MentionGeneratorInterface' => $vendorDir . '/league/commonmark/src/Extension/Mention/Generator/MentionGeneratorInterface.php',
    'League\\CommonMark\\Extension\\Mention\\Generator\\StringTemplateLinkGenerator' => $vendorDir . '/league/commonmark/src/Extension/Mention/Generator/StringTemplateLinkGenerator.php',
    'League\\CommonMark\\Extension\\Mention\\Mention' => $vendorDir . '/league/commonmark/src/Extension/Mention/Mention.php',
    'League\\CommonMark\\Extension\\Mention\\MentionExtension' => $vendorDir . '/league/commonmark/src/Extension/Mention/MentionExtension.php',
    'League\\CommonMark\\Extension\\Mention\\MentionParser' => $vendorDir . '/league/commonmark/src/Extension/Mention/MentionParser.php',
    'League\\CommonMark\\Extension\\SmartPunct\\DashParser' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/DashParser.php',
    'League\\CommonMark\\Extension\\SmartPunct\\EllipsesParser' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/EllipsesParser.php',
    'League\\CommonMark\\Extension\\SmartPunct\\Quote' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/Quote.php',
    'League\\CommonMark\\Extension\\SmartPunct\\QuoteParser' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/QuoteParser.php',
    'League\\CommonMark\\Extension\\SmartPunct\\QuoteProcessor' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/QuoteProcessor.php',
    'League\\CommonMark\\Extension\\SmartPunct\\ReplaceUnpairedQuotesListener' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/ReplaceUnpairedQuotesListener.php',
    'League\\CommonMark\\Extension\\SmartPunct\\SmartPunctExtension' => $vendorDir . '/league/commonmark/src/Extension/SmartPunct/SmartPunctExtension.php',
    'League\\CommonMark\\Extension\\Strikethrough\\Strikethrough' => $vendorDir . '/league/commonmark/src/Extension/Strikethrough/Strikethrough.php',
    'League\\CommonMark\\Extension\\Strikethrough\\StrikethroughDelimiterProcessor' => $vendorDir . '/league/commonmark/src/Extension/Strikethrough/StrikethroughDelimiterProcessor.php',
    'League\\CommonMark\\Extension\\Strikethrough\\StrikethroughExtension' => $vendorDir . '/league/commonmark/src/Extension/Strikethrough/StrikethroughExtension.php',
    'League\\CommonMark\\Extension\\Strikethrough\\StrikethroughRenderer' => $vendorDir . '/league/commonmark/src/Extension/Strikethrough/StrikethroughRenderer.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Node\\TableOfContents' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Node/TableOfContents.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Node\\TableOfContentsPlaceholder' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Node/TableOfContentsPlaceholder.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Normalizer\\AsIsNormalizerStrategy' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Normalizer/AsIsNormalizerStrategy.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Normalizer\\FlatNormalizerStrategy' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Normalizer/FlatNormalizerStrategy.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Normalizer\\NormalizerStrategyInterface' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Normalizer/NormalizerStrategyInterface.php',
    'League\\CommonMark\\Extension\\TableOfContents\\Normalizer\\RelativeNormalizerStrategy' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/Normalizer/RelativeNormalizerStrategy.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsBuilder' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsBuilder.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsExtension' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsExtension.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsGenerator' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsGenerator.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsGeneratorInterface' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsGeneratorInterface.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsPlaceholderParser' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsPlaceholderParser.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsPlaceholderRenderer' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsPlaceholderRenderer.php',
    'League\\CommonMark\\Extension\\TableOfContents\\TableOfContentsRenderer' => $vendorDir . '/league/commonmark/src/Extension/TableOfContents/TableOfContentsRenderer.php',
    'League\\CommonMark\\Extension\\Table\\Table' => $vendorDir . '/league/commonmark/src/Extension/Table/Table.php',
    'League\\CommonMark\\Extension\\Table\\TableCell' => $vendorDir . '/league/commonmark/src/Extension/Table/TableCell.php',
    'League\\CommonMark\\Extension\\Table\\TableCellRenderer' => $vendorDir . '/league/commonmark/src/Extension/Table/TableCellRenderer.php',
    'League\\CommonMark\\Extension\\Table\\TableExtension' => $vendorDir . '/league/commonmark/src/Extension/Table/TableExtension.php',
    'League\\CommonMark\\Extension\\Table\\TableParser' => $vendorDir . '/league/commonmark/src/Extension/Table/TableParser.php',
    'League\\CommonMark\\Extension\\Table\\TableRenderer' => $vendorDir . '/league/commonmark/src/Extension/Table/TableRenderer.php',
    'League\\CommonMark\\Extension\\Table\\TableRow' => $vendorDir . '/league/commonmark/src/Extension/Table/TableRow.php',
    'League\\CommonMark\\Extension\\Table\\TableRowRenderer' => $vendorDir . '/league/commonmark/src/Extension/Table/TableRowRenderer.php',
    'League\\CommonMark\\Extension\\Table\\TableSection' => $vendorDir . '/league/commonmark/src/Extension/Table/TableSection.php',
    'League\\CommonMark\\Extension\\Table\\TableSectionRenderer' => $vendorDir . '/league/commonmark/src/Extension/Table/TableSectionRenderer.php',
    'League\\CommonMark\\Extension\\Table\\TableStartParser' => $vendorDir . '/league/commonmark/src/Extension/Table/TableStartParser.php',
    'League\\CommonMark\\Extension\\TaskList\\TaskListExtension' => $vendorDir . '/league/commonmark/src/Extension/TaskList/TaskListExtension.php',
    'League\\CommonMark\\Extension\\TaskList\\TaskListItemMarker' => $vendorDir . '/league/commonmark/src/Extension/TaskList/TaskListItemMarker.php',
    'League\\CommonMark\\Extension\\TaskList\\TaskListItemMarkerParser' => $vendorDir . '/league/commonmark/src/Extension/TaskList/TaskListItemMarkerParser.php',
    'League\\CommonMark\\Extension\\TaskList\\TaskListItemMarkerRenderer' => $vendorDir . '/league/commonmark/src/Extension/TaskList/TaskListItemMarkerRenderer.php',
    'League\\CommonMark\\GithubFlavoredMarkdownConverter' => $vendorDir . '/league/commonmark/src/GithubFlavoredMarkdownConverter.php',
    'League\\CommonMark\\Input\\MarkdownInput' => $vendorDir . '/league/commonmark/src/Input/MarkdownInput.php',
    'League\\CommonMark\\Input\\MarkdownInputInterface' => $vendorDir . '/league/commonmark/src/Input/MarkdownInputInterface.php',
    'League\\CommonMark\\MarkdownConverter' => $vendorDir . '/league/commonmark/src/MarkdownConverter.php',
    'League\\CommonMark\\MarkdownConverterInterface' => $vendorDir . '/league/commonmark/src/MarkdownConverterInterface.php',
    'League\\CommonMark\\Node\\Block\\AbstractBlock' => $vendorDir . '/league/commonmark/src/Node/Block/AbstractBlock.php',
    'League\\CommonMark\\Node\\Block\\Document' => $vendorDir . '/league/commonmark/src/Node/Block/Document.php',
    'League\\CommonMark\\Node\\Block\\Paragraph' => $vendorDir . '/league/commonmark/src/Node/Block/Paragraph.php',
    'League\\CommonMark\\Node\\Block\\TightBlockInterface' => $vendorDir . '/league/commonmark/src/Node/Block/TightBlockInterface.php',
    'League\\CommonMark\\Node\\Inline\\AbstractInline' => $vendorDir . '/league/commonmark/src/Node/Inline/AbstractInline.php',
    'League\\CommonMark\\Node\\Inline\\AbstractStringContainer' => $vendorDir . '/league/commonmark/src/Node/Inline/AbstractStringContainer.php',
    'League\\CommonMark\\Node\\Inline\\AdjacentTextMerger' => $vendorDir . '/league/commonmark/src/Node/Inline/AdjacentTextMerger.php',
    'League\\CommonMark\\Node\\Inline\\DelimitedInterface' => $vendorDir . '/league/commonmark/src/Node/Inline/DelimitedInterface.php',
    'League\\CommonMark\\Node\\Inline\\Newline' => $vendorDir . '/league/commonmark/src/Node/Inline/Newline.php',
    'League\\CommonMark\\Node\\Inline\\Text' => $vendorDir . '/league/commonmark/src/Node/Inline/Text.php',
    'League\\CommonMark\\Node\\Node' => $vendorDir . '/league/commonmark/src/Node/Node.php',
    'League\\CommonMark\\Node\\NodeIterator' => $vendorDir . '/league/commonmark/src/Node/NodeIterator.php',
    'League\\CommonMark\\Node\\NodeWalker' => $vendorDir . '/league/commonmark/src/Node/NodeWalker.php',
    'League\\CommonMark\\Node\\NodeWalkerEvent' => $vendorDir . '/league/commonmark/src/Node/NodeWalkerEvent.php',
    'League\\CommonMark\\Node\\Query' => $vendorDir . '/league/commonmark/src/Node/Query.php',
    'League\\CommonMark\\Node\\Query\\AndExpr' => $vendorDir . '/league/commonmark/src/Node/Query/AndExpr.php',
    'League\\CommonMark\\Node\\Query\\ExpressionInterface' => $vendorDir . '/league/commonmark/src/Node/Query/ExpressionInterface.php',
    'League\\CommonMark\\Node\\Query\\OrExpr' => $vendorDir . '/league/commonmark/src/Node/Query/OrExpr.php',
    'League\\CommonMark\\Node\\RawMarkupContainerInterface' => $vendorDir . '/league/commonmark/src/Node/RawMarkupContainerInterface.php',
    'League\\CommonMark\\Node\\StringContainerHelper' => $vendorDir . '/league/commonmark/src/Node/StringContainerHelper.php',
    'League\\CommonMark\\Node\\StringContainerInterface' => $vendorDir . '/league/commonmark/src/Node/StringContainerInterface.php',
    'League\\CommonMark\\Normalizer\\SlugNormalizer' => $vendorDir . '/league/commonmark/src/Normalizer/SlugNormalizer.php',
    'League\\CommonMark\\Normalizer\\TextNormalizer' => $vendorDir . '/league/commonmark/src/Normalizer/TextNormalizer.php',
    'League\\CommonMark\\Normalizer\\TextNormalizerInterface' => $vendorDir . '/league/commonmark/src/Normalizer/TextNormalizerInterface.php',
    'League\\CommonMark\\Normalizer\\UniqueSlugNormalizer' => $vendorDir . '/league/commonmark/src/Normalizer/UniqueSlugNormalizer.php',
    'League\\CommonMark\\Normalizer\\UniqueSlugNormalizerInterface' => $vendorDir . '/league/commonmark/src/Normalizer/UniqueSlugNormalizerInterface.php',
    'League\\CommonMark\\Output\\RenderedContent' => $vendorDir . '/league/commonmark/src/Output/RenderedContent.php',
    'League\\CommonMark\\Output\\RenderedContentInterface' => $vendorDir . '/league/commonmark/src/Output/RenderedContentInterface.php',
    'League\\CommonMark\\Parser\\Block\\AbstractBlockContinueParser' => $vendorDir . '/league/commonmark/src/Parser/Block/AbstractBlockContinueParser.php',
    'League\\CommonMark\\Parser\\Block\\BlockContinue' => $vendorDir . '/league/commonmark/src/Parser/Block/BlockContinue.php',
    'League\\CommonMark\\Parser\\Block\\BlockContinueParserInterface' => $vendorDir . '/league/commonmark/src/Parser/Block/BlockContinueParserInterface.php',
    'League\\CommonMark\\Parser\\Block\\BlockContinueParserWithInlinesInterface' => $vendorDir . '/league/commonmark/src/Parser/Block/BlockContinueParserWithInlinesInterface.php',
    'League\\CommonMark\\Parser\\Block\\BlockStart' => $vendorDir . '/league/commonmark/src/Parser/Block/BlockStart.php',
    'League\\CommonMark\\Parser\\Block\\BlockStartParserInterface' => $vendorDir . '/league/commonmark/src/Parser/Block/BlockStartParserInterface.php',
    'League\\CommonMark\\Parser\\Block\\DocumentBlockParser' => $vendorDir . '/league/commonmark/src/Parser/Block/DocumentBlockParser.php',
    'League\\CommonMark\\Parser\\Block\\ParagraphParser' => $vendorDir . '/league/commonmark/src/Parser/Block/ParagraphParser.php',
    'League\\CommonMark\\Parser\\Block\\SkipLinesStartingWithLettersParser' => $vendorDir . '/league/commonmark/src/Parser/Block/SkipLinesStartingWithLettersParser.php',
    'League\\CommonMark\\Parser\\Cursor' => $vendorDir . '/league/commonmark/src/Parser/Cursor.php',
    'League\\CommonMark\\Parser\\CursorState' => $vendorDir . '/league/commonmark/src/Parser/CursorState.php',
    'League\\CommonMark\\Parser\\InlineParserContext' => $vendorDir . '/league/commonmark/src/Parser/InlineParserContext.php',
    'League\\CommonMark\\Parser\\InlineParserEngine' => $vendorDir . '/league/commonmark/src/Parser/InlineParserEngine.php',
    'League\\CommonMark\\Parser\\InlineParserEngineInterface' => $vendorDir . '/league/commonmark/src/Parser/InlineParserEngineInterface.php',
    'League\\CommonMark\\Parser\\Inline\\InlineParserInterface' => $vendorDir . '/league/commonmark/src/Parser/Inline/InlineParserInterface.php',
    'League\\CommonMark\\Parser\\Inline\\InlineParserMatch' => $vendorDir . '/league/commonmark/src/Parser/Inline/InlineParserMatch.php',
    'League\\CommonMark\\Parser\\Inline\\NewlineParser' => $vendorDir . '/league/commonmark/src/Parser/Inline/NewlineParser.php',
    'League\\CommonMark\\Parser\\MarkdownParser' => $vendorDir . '/league/commonmark/src/Parser/MarkdownParser.php',
    'League\\CommonMark\\Parser\\MarkdownParserInterface' => $vendorDir . '/league/commonmark/src/Parser/MarkdownParserInterface.php',
    'League\\CommonMark\\Parser\\MarkdownParserState' => $vendorDir . '/league/commonmark/src/Parser/MarkdownParserState.php',
    'League\\CommonMark\\Parser\\MarkdownParserStateInterface' => $vendorDir . '/league/commonmark/src/Parser/MarkdownParserStateInterface.php',
    'League\\CommonMark\\Parser\\ParserLogicException' => $vendorDir . '/league/commonmark/src/Parser/ParserLogicException.php',
    'League\\CommonMark\\Reference\\Reference' => $vendorDir . '/league/commonmark/src/Reference/Reference.php',
    'League\\CommonMark\\Reference\\ReferenceInterface' => $vendorDir . '/league/commonmark/src/Reference/ReferenceInterface.php',
    'League\\CommonMark\\Reference\\ReferenceMap' => $vendorDir . '/league/commonmark/src/Reference/ReferenceMap.php',
    'League\\CommonMark\\Reference\\ReferenceMapInterface' => $vendorDir . '/league/commonmark/src/Reference/ReferenceMapInterface.php',
    'League\\CommonMark\\Reference\\ReferenceParser' => $vendorDir . '/league/commonmark/src/Reference/ReferenceParser.php',
    'League\\CommonMark\\Reference\\ReferenceableInterface' => $vendorDir . '/league/commonmark/src/Reference/ReferenceableInterface.php',
    'League\\CommonMark\\Renderer\\Block\\DocumentRenderer' => $vendorDir . '/league/commonmark/src/Renderer/Block/DocumentRenderer.php',
    'League\\CommonMark\\Renderer\\Block\\ParagraphRenderer' => $vendorDir . '/league/commonmark/src/Renderer/Block/ParagraphRenderer.php',
    'League\\CommonMark\\Renderer\\ChildNodeRendererInterface' => $vendorDir . '/league/commonmark/src/Renderer/ChildNodeRendererInterface.php',
    'League\\CommonMark\\Renderer\\DocumentRendererInterface' => $vendorDir . '/league/commonmark/src/Renderer/DocumentRendererInterface.php',
    'League\\CommonMark\\Renderer\\HtmlDecorator' => $vendorDir . '/league/commonmark/src/Renderer/HtmlDecorator.php',
    'League\\CommonMark\\Renderer\\HtmlRenderer' => $vendorDir . '/league/commonmark/src/Renderer/HtmlRenderer.php',
    'League\\CommonMark\\Renderer\\Inline\\NewlineRenderer' => $vendorDir . '/league/commonmark/src/Renderer/Inline/NewlineRenderer.php',
    'League\\CommonMark\\Renderer\\Inline\\TextRenderer' => $vendorDir . '/league/commonmark/src/Renderer/Inline/TextRenderer.php',
    'League\\CommonMark\\Renderer\\MarkdownRendererInterface' => $vendorDir . '/league/commonmark/src/Renderer/MarkdownRendererInterface.php',
    'League\\CommonMark\\Renderer\\NoMatchingRendererException' => $vendorDir . '/league/commonmark/src/Renderer/NoMatchingRendererException.php',
    'League\\CommonMark\\Renderer\\NodeRendererInterface' => $vendorDir . '/league/commonmark/src/Renderer/NodeRendererInterface.php',
    'League\\CommonMark\\Util\\ArrayCollection' => $vendorDir . '/league/commonmark/src/Util/ArrayCollection.php',
    'League\\CommonMark\\Util\\Html5EntityDecoder' => $vendorDir . '/league/commonmark/src/Util/Html5EntityDecoder.php',
    'League\\CommonMark\\Util\\HtmlElement' => $vendorDir . '/league/commonmark/src/Util/HtmlElement.php',
    'League\\CommonMark\\Util\\HtmlFilter' => $vendorDir . '/league/commonmark/src/Util/HtmlFilter.php',
    'League\\CommonMark\\Util\\LinkParserHelper' => $vendorDir . '/league/commonmark/src/Util/LinkParserHelper.php',
    'League\\CommonMark\\Util\\PrioritizedList' => $vendorDir . '/league/commonmark/src/Util/PrioritizedList.php',
    'League\\CommonMark\\Util\\RegexHelper' => $vendorDir . '/league/commonmark/src/Util/RegexHelper.php',
    'League\\CommonMark\\Util\\SpecReader' => $vendorDir . '/league/commonmark/src/Util/SpecReader.php',
    'League\\CommonMark\\Util\\UrlEncoder' => $vendorDir . '/league/commonmark/src/Util/UrlEncoder.php',
    'League\\CommonMark\\Util\\Xml' => $vendorDir . '/league/commonmark/src/Util/Xml.php',
    'League\\CommonMark\\Xml\\FallbackNodeXmlRenderer' => $vendorDir . '/league/commonmark/src/Xml/FallbackNodeXmlRenderer.php',
    'League\\CommonMark\\Xml\\MarkdownToXmlConverter' => $vendorDir . '/league/commonmark/src/Xml/MarkdownToXmlConverter.php',
    'League\\CommonMark\\Xml\\XmlNodeRendererInterface' => $vendorDir . '/league/commonmark/src/Xml/XmlNodeRendererInterface.php',
    'League\\CommonMark\\Xml\\XmlRenderer' => $vendorDir . '/league/commonmark/src/Xml/XmlRenderer.php',
    'League\\Config\\Configuration' => $vendorDir . '/league/config/src/Configuration.php',
    'League\\Config\\ConfigurationAwareInterface' => $vendorDir . '/league/config/src/ConfigurationAwareInterface.php',
    'League\\Config\\ConfigurationBuilderInterface' => $vendorDir . '/league/config/src/ConfigurationBuilderInterface.php',
    'League\\Config\\ConfigurationInterface' => $vendorDir . '/league/config/src/ConfigurationInterface.php',
    'League\\Config\\ConfigurationProviderInterface' => $vendorDir . '/league/config/src/ConfigurationProviderInterface.php',
    'League\\Config\\Exception\\ConfigurationExceptionInterface' => $vendorDir . '/league/config/src/Exception/ConfigurationExceptionInterface.php',
    'League\\Config\\Exception\\InvalidConfigurationException' => $vendorDir . '/league/config/src/Exception/InvalidConfigurationException.php',
    'League\\Config\\Exception\\UnknownOptionException' => $vendorDir . '/league/config/src/Exception/UnknownOptionException.php',
    'League\\Config\\Exception\\ValidationException' => $vendorDir . '/league/config/src/Exception/ValidationException.php',
    'League\\Config\\MutableConfigurationInterface' => $vendorDir . '/league/config/src/MutableConfigurationInterface.php',
    'League\\Config\\ReadOnlyConfiguration' => $vendorDir . '/league/config/src/ReadOnlyConfiguration.php',
    'League\\Config\\SchemaBuilderInterface' => $vendorDir . '/league/config/src/SchemaBuilderInterface.php',
    'League\\Flysystem\\AwsS3V3\\AwsS3V3Adapter' => $vendorDir . '/league/flysystem-aws-s3-v3/AwsS3V3Adapter.php',
    'League\\Flysystem\\AwsS3V3\\PortableVisibilityConverter' => $vendorDir . '/league/flysystem-aws-s3-v3/PortableVisibilityConverter.php',
    'League\\Flysystem\\AwsS3V3\\VisibilityConverter' => $vendorDir . '/league/flysystem-aws-s3-v3/VisibilityConverter.php',
    'League\\Flysystem\\CalculateChecksumFromStream' => $vendorDir . '/league/flysystem/src/CalculateChecksumFromStream.php',
    'League\\Flysystem\\ChecksumAlgoIsNotSupported' => $vendorDir . '/league/flysystem/src/ChecksumAlgoIsNotSupported.php',
    'League\\Flysystem\\ChecksumProvider' => $vendorDir . '/league/flysystem/src/ChecksumProvider.php',
    'League\\Flysystem\\Config' => $vendorDir . '/league/flysystem/src/Config.php',
    'League\\Flysystem\\CorruptedPathDetected' => $vendorDir . '/league/flysystem/src/CorruptedPathDetected.php',
    'League\\Flysystem\\DecoratedAdapter' => $vendorDir . '/league/flysystem/src/DecoratedAdapter.php',
    'League\\Flysystem\\DirectoryAttributes' => $vendorDir . '/league/flysystem/src/DirectoryAttributes.php',
    'League\\Flysystem\\DirectoryListing' => $vendorDir . '/league/flysystem/src/DirectoryListing.php',
    'League\\Flysystem\\FileAttributes' => $vendorDir . '/league/flysystem/src/FileAttributes.php',
    'League\\Flysystem\\Filesystem' => $vendorDir . '/league/flysystem/src/Filesystem.php',
    'League\\Flysystem\\FilesystemAdapter' => $vendorDir . '/league/flysystem/src/FilesystemAdapter.php',
    'League\\Flysystem\\FilesystemException' => $vendorDir . '/league/flysystem/src/FilesystemException.php',
    'League\\Flysystem\\FilesystemOperationFailed' => $vendorDir . '/league/flysystem/src/FilesystemOperationFailed.php',
    'League\\Flysystem\\FilesystemOperator' => $vendorDir . '/league/flysystem/src/FilesystemOperator.php',
    'League\\Flysystem\\FilesystemReader' => $vendorDir . '/league/flysystem/src/FilesystemReader.php',
    'League\\Flysystem\\FilesystemWriter' => $vendorDir . '/league/flysystem/src/FilesystemWriter.php',
    'League\\Flysystem\\InvalidStreamProvided' => $vendorDir . '/league/flysystem/src/InvalidStreamProvided.php',
    'League\\Flysystem\\InvalidVisibilityProvided' => $vendorDir . '/league/flysystem/src/InvalidVisibilityProvided.php',
    'League\\Flysystem\\Local\\FallbackMimeTypeDetector' => $vendorDir . '/league/flysystem-local/FallbackMimeTypeDetector.php',
    'League\\Flysystem\\Local\\LocalFilesystemAdapter' => $vendorDir . '/league/flysystem-local/LocalFilesystemAdapter.php',
    'League\\Flysystem\\MountManager' => $vendorDir . '/league/flysystem/src/MountManager.php',
    'League\\Flysystem\\PathNormalizer' => $vendorDir . '/league/flysystem/src/PathNormalizer.php',
    'League\\Flysystem\\PathPrefixer' => $vendorDir . '/league/flysystem/src/PathPrefixer.php',
    'League\\Flysystem\\PathTraversalDetected' => $vendorDir . '/league/flysystem/src/PathTraversalDetected.php',
    'League\\Flysystem\\PortableVisibilityGuard' => $vendorDir . '/league/flysystem/src/PortableVisibilityGuard.php',
    'League\\Flysystem\\ProxyArrayAccessToProperties' => $vendorDir . '/league/flysystem/src/ProxyArrayAccessToProperties.php',
    'League\\Flysystem\\ResolveIdenticalPathConflict' => $vendorDir . '/league/flysystem/src/ResolveIdenticalPathConflict.php',
    'League\\Flysystem\\StorageAttributes' => $vendorDir . '/league/flysystem/src/StorageAttributes.php',
    'League\\Flysystem\\SymbolicLinkEncountered' => $vendorDir . '/league/flysystem/src/SymbolicLinkEncountered.php',
    'League\\Flysystem\\UnableToCheckDirectoryExistence' => $vendorDir . '/league/flysystem/src/UnableToCheckDirectoryExistence.php',
    'League\\Flysystem\\UnableToCheckExistence' => $vendorDir . '/league/flysystem/src/UnableToCheckExistence.php',
    'League\\Flysystem\\UnableToCheckFileExistence' => $vendorDir . '/league/flysystem/src/UnableToCheckFileExistence.php',
    'League\\Flysystem\\UnableToCopyFile' => $vendorDir . '/league/flysystem/src/UnableToCopyFile.php',
    'League\\Flysystem\\UnableToCreateDirectory' => $vendorDir . '/league/flysystem/src/UnableToCreateDirectory.php',
    'League\\Flysystem\\UnableToDeleteDirectory' => $vendorDir . '/league/flysystem/src/UnableToDeleteDirectory.php',
    'League\\Flysystem\\UnableToDeleteFile' => $vendorDir . '/league/flysystem/src/UnableToDeleteFile.php',
    'League\\Flysystem\\UnableToGeneratePublicUrl' => $vendorDir . '/league/flysystem/src/UnableToGeneratePublicUrl.php',
    'League\\Flysystem\\UnableToGenerateTemporaryUrl' => $vendorDir . '/league/flysystem/src/UnableToGenerateTemporaryUrl.php',
    'League\\Flysystem\\UnableToListContents' => $vendorDir . '/league/flysystem/src/UnableToListContents.php',
    'League\\Flysystem\\UnableToMountFilesystem' => $vendorDir . '/league/flysystem/src/UnableToMountFilesystem.php',
    'League\\Flysystem\\UnableToMoveFile' => $vendorDir . '/league/flysystem/src/UnableToMoveFile.php',
    'League\\Flysystem\\UnableToProvideChecksum' => $vendorDir . '/league/flysystem/src/UnableToProvideChecksum.php',
    'League\\Flysystem\\UnableToReadFile' => $vendorDir . '/league/flysystem/src/UnableToReadFile.php',
    'League\\Flysystem\\UnableToResolveFilesystemMount' => $vendorDir . '/league/flysystem/src/UnableToResolveFilesystemMount.php',
    'League\\Flysystem\\UnableToRetrieveMetadata' => $vendorDir . '/league/flysystem/src/UnableToRetrieveMetadata.php',
    'League\\Flysystem\\UnableToSetVisibility' => $vendorDir . '/league/flysystem/src/UnableToSetVisibility.php',
    'League\\Flysystem\\UnableToWriteFile' => $vendorDir . '/league/flysystem/src/UnableToWriteFile.php',
    'League\\Flysystem\\UnixVisibility\\PortableVisibilityConverter' => $vendorDir . '/league/flysystem/src/UnixVisibility/PortableVisibilityConverter.php',
    'League\\Flysystem\\UnixVisibility\\VisibilityConverter' => $vendorDir . '/league/flysystem/src/UnixVisibility/VisibilityConverter.php',
    'League\\Flysystem\\UnreadableFileEncountered' => $vendorDir . '/league/flysystem/src/UnreadableFileEncountered.php',
    'League\\Flysystem\\UrlGeneration\\ChainedPublicUrlGenerator' => $vendorDir . '/league/flysystem/src/UrlGeneration/ChainedPublicUrlGenerator.php',
    'League\\Flysystem\\UrlGeneration\\PrefixPublicUrlGenerator' => $vendorDir . '/league/flysystem/src/UrlGeneration/PrefixPublicUrlGenerator.php',
    'League\\Flysystem\\UrlGeneration\\PublicUrlGenerator' => $vendorDir . '/league/flysystem/src/UrlGeneration/PublicUrlGenerator.php',
    'League\\Flysystem\\UrlGeneration\\ShardedPrefixPublicUrlGenerator' => $vendorDir . '/league/flysystem/src/UrlGeneration/ShardedPrefixPublicUrlGenerator.php',
    'League\\Flysystem\\UrlGeneration\\TemporaryUrlGenerator' => $vendorDir . '/league/flysystem/src/UrlGeneration/TemporaryUrlGenerator.php',
    'League\\Flysystem\\Visibility' => $vendorDir . '/league/flysystem/src/Visibility.php',
    'League\\Flysystem\\WhitespacePathNormalizer' => $vendorDir . '/league/flysystem/src/WhitespacePathNormalizer.php',
    'League\\MimeTypeDetection\\EmptyExtensionToMimeTypeMap' => $vendorDir . '/league/mime-type-detection/src/EmptyExtensionToMimeTypeMap.php',
    'League\\MimeTypeDetection\\ExtensionLookup' => $vendorDir . '/league/mime-type-detection/src/ExtensionLookup.php',
    'League\\MimeTypeDetection\\ExtensionMimeTypeDetector' => $vendorDir . '/league/mime-type-detection/src/ExtensionMimeTypeDetector.php',
    'League\\MimeTypeDetection\\ExtensionToMimeTypeMap' => $vendorDir . '/league/mime-type-detection/src/ExtensionToMimeTypeMap.php',
    'League\\MimeTypeDetection\\FinfoMimeTypeDetector' => $vendorDir . '/league/mime-type-detection/src/FinfoMimeTypeDetector.php',
    'League\\MimeTypeDetection\\GeneratedExtensionToMimeTypeMap' => $vendorDir . '/league/mime-type-detection/src/GeneratedExtensionToMimeTypeMap.php',
    'League\\MimeTypeDetection\\MimeTypeDetector' => $vendorDir . '/league/mime-type-detection/src/MimeTypeDetector.php',
    'League\\MimeTypeDetection\\OverridingExtensionToMimeTypeMap' => $vendorDir . '/league/mime-type-detection/src/OverridingExtensionToMimeTypeMap.php',
    'Maatwebsite\\Excel\\Cache\\BatchCache' => $vendorDir . '/maatwebsite/excel/src/Cache/BatchCache.php',
    'Maatwebsite\\Excel\\Cache\\BatchCacheDeprecated' => $vendorDir . '/maatwebsite/excel/src/Cache/BatchCacheDeprecated.php',
    'Maatwebsite\\Excel\\Cache\\CacheManager' => $vendorDir . '/maatwebsite/excel/src/Cache/CacheManager.php',
    'Maatwebsite\\Excel\\Cache\\MemoryCache' => $vendorDir . '/maatwebsite/excel/src/Cache/MemoryCache.php',
    'Maatwebsite\\Excel\\Cache\\MemoryCacheDeprecated' => $vendorDir . '/maatwebsite/excel/src/Cache/MemoryCacheDeprecated.php',
    'Maatwebsite\\Excel\\Cell' => $vendorDir . '/maatwebsite/excel/src/Cell.php',
    'Maatwebsite\\Excel\\ChunkReader' => $vendorDir . '/maatwebsite/excel/src/ChunkReader.php',
    'Maatwebsite\\Excel\\Concerns\\Exportable' => $vendorDir . '/maatwebsite/excel/src/Concerns/Exportable.php',
    'Maatwebsite\\Excel\\Concerns\\FromArray' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromArray.php',
    'Maatwebsite\\Excel\\Concerns\\FromCollection' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromCollection.php',
    'Maatwebsite\\Excel\\Concerns\\FromGenerator' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromGenerator.php',
    'Maatwebsite\\Excel\\Concerns\\FromIterator' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromIterator.php',
    'Maatwebsite\\Excel\\Concerns\\FromQuery' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromQuery.php',
    'Maatwebsite\\Excel\\Concerns\\FromView' => $vendorDir . '/maatwebsite/excel/src/Concerns/FromView.php',
    'Maatwebsite\\Excel\\Concerns\\HasReferencesToOtherSheets' => $vendorDir . '/maatwebsite/excel/src/Concerns/HasReferencesToOtherSheets.php',
    'Maatwebsite\\Excel\\Concerns\\Importable' => $vendorDir . '/maatwebsite/excel/src/Concerns/Importable.php',
    'Maatwebsite\\Excel\\Concerns\\MapsCsvSettings' => $vendorDir . '/maatwebsite/excel/src/Concerns/MapsCsvSettings.php',
    'Maatwebsite\\Excel\\Concerns\\OnEachRow' => $vendorDir . '/maatwebsite/excel/src/Concerns/OnEachRow.php',
    'Maatwebsite\\Excel\\Concerns\\PersistRelations' => $vendorDir . '/maatwebsite/excel/src/Concerns/PersistRelations.php',
    'Maatwebsite\\Excel\\Concerns\\RegistersEventListeners' => $vendorDir . '/maatwebsite/excel/src/Concerns/RegistersEventListeners.php',
    'Maatwebsite\\Excel\\Concerns\\RemembersChunkOffset' => $vendorDir . '/maatwebsite/excel/src/Concerns/RemembersChunkOffset.php',
    'Maatwebsite\\Excel\\Concerns\\RemembersRowNumber' => $vendorDir . '/maatwebsite/excel/src/Concerns/RemembersRowNumber.php',
    'Maatwebsite\\Excel\\Concerns\\ShouldAutoSize' => $vendorDir . '/maatwebsite/excel/src/Concerns/ShouldAutoSize.php',
    'Maatwebsite\\Excel\\Concerns\\ShouldQueueWithoutChain' => $vendorDir . '/maatwebsite/excel/src/Concerns/ShouldQueueWithoutChain.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsEmptyRows' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsEmptyRows.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsErrors' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsErrors.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsFailures' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsFailures.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsOnError' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsOnError.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsOnFailure' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsOnFailure.php',
    'Maatwebsite\\Excel\\Concerns\\SkipsUnknownSheets' => $vendorDir . '/maatwebsite/excel/src/Concerns/SkipsUnknownSheets.php',
    'Maatwebsite\\Excel\\Concerns\\ToArray' => $vendorDir . '/maatwebsite/excel/src/Concerns/ToArray.php',
    'Maatwebsite\\Excel\\Concerns\\ToCollection' => $vendorDir . '/maatwebsite/excel/src/Concerns/ToCollection.php',
    'Maatwebsite\\Excel\\Concerns\\ToModel' => $vendorDir . '/maatwebsite/excel/src/Concerns/ToModel.php',
    'Maatwebsite\\Excel\\Concerns\\WithBackgroundColor' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithBackgroundColor.php',
    'Maatwebsite\\Excel\\Concerns\\WithBatchInserts' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithBatchInserts.php',
    'Maatwebsite\\Excel\\Concerns\\WithCalculatedFormulas' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCalculatedFormulas.php',
    'Maatwebsite\\Excel\\Concerns\\WithCharts' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCharts.php',
    'Maatwebsite\\Excel\\Concerns\\WithChunkReading' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithChunkReading.php',
    'Maatwebsite\\Excel\\Concerns\\WithColumnFormatting' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithColumnFormatting.php',
    'Maatwebsite\\Excel\\Concerns\\WithColumnLimit' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithColumnLimit.php',
    'Maatwebsite\\Excel\\Concerns\\WithColumnWidths' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithColumnWidths.php',
    'Maatwebsite\\Excel\\Concerns\\WithConditionalSheets' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithConditionalSheets.php',
    'Maatwebsite\\Excel\\Concerns\\WithCustomChunkSize' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCustomChunkSize.php',
    'Maatwebsite\\Excel\\Concerns\\WithCustomCsvSettings' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCustomCsvSettings.php',
    'Maatwebsite\\Excel\\Concerns\\WithCustomQuerySize' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCustomQuerySize.php',
    'Maatwebsite\\Excel\\Concerns\\WithCustomStartCell' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCustomStartCell.php',
    'Maatwebsite\\Excel\\Concerns\\WithCustomValueBinder' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithCustomValueBinder.php',
    'Maatwebsite\\Excel\\Concerns\\WithDefaultStyles' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithDefaultStyles.php',
    'Maatwebsite\\Excel\\Concerns\\WithDrawings' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithDrawings.php',
    'Maatwebsite\\Excel\\Concerns\\WithEvents' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithEvents.php',
    'Maatwebsite\\Excel\\Concerns\\WithFormatData' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithFormatData.php',
    'Maatwebsite\\Excel\\Concerns\\WithGroupedHeadingRow' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithGroupedHeadingRow.php',
    'Maatwebsite\\Excel\\Concerns\\WithHeadingRow' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithHeadingRow.php',
    'Maatwebsite\\Excel\\Concerns\\WithHeadings' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithHeadings.php',
    'Maatwebsite\\Excel\\Concerns\\WithLimit' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithLimit.php',
    'Maatwebsite\\Excel\\Concerns\\WithMappedCells' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithMappedCells.php',
    'Maatwebsite\\Excel\\Concerns\\WithMapping' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithMapping.php',
    'Maatwebsite\\Excel\\Concerns\\WithMultipleSheets' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithMultipleSheets.php',
    'Maatwebsite\\Excel\\Concerns\\WithPreCalculateFormulas' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithPreCalculateFormulas.php',
    'Maatwebsite\\Excel\\Concerns\\WithProgressBar' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithProgressBar.php',
    'Maatwebsite\\Excel\\Concerns\\WithProperties' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithProperties.php',
    'Maatwebsite\\Excel\\Concerns\\WithReadFilter' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithReadFilter.php',
    'Maatwebsite\\Excel\\Concerns\\WithSkipDuplicates' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithSkipDuplicates.php',
    'Maatwebsite\\Excel\\Concerns\\WithStartRow' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithStartRow.php',
    'Maatwebsite\\Excel\\Concerns\\WithStrictNullComparison' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithStrictNullComparison.php',
    'Maatwebsite\\Excel\\Concerns\\WithStyles' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithStyles.php',
    'Maatwebsite\\Excel\\Concerns\\WithTitle' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithTitle.php',
    'Maatwebsite\\Excel\\Concerns\\WithUpsertColumns' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithUpsertColumns.php',
    'Maatwebsite\\Excel\\Concerns\\WithUpserts' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithUpserts.php',
    'Maatwebsite\\Excel\\Concerns\\WithValidation' => $vendorDir . '/maatwebsite/excel/src/Concerns/WithValidation.php',
    'Maatwebsite\\Excel\\Console\\ExportMakeCommand' => $vendorDir . '/maatwebsite/excel/src/Console/ExportMakeCommand.php',
    'Maatwebsite\\Excel\\Console\\ImportMakeCommand' => $vendorDir . '/maatwebsite/excel/src/Console/ImportMakeCommand.php',
    'Maatwebsite\\Excel\\Console\\WithModelStub' => $vendorDir . '/maatwebsite/excel/src/Console/WithModelStub.php',
    'Maatwebsite\\Excel\\DefaultValueBinder' => $vendorDir . '/maatwebsite/excel/src/DefaultValueBinder.php',
    'Maatwebsite\\Excel\\DelegatedMacroable' => $vendorDir . '/maatwebsite/excel/src/DelegatedMacroable.php',
    'Maatwebsite\\Excel\\Events\\AfterBatch' => $vendorDir . '/maatwebsite/excel/src/Events/AfterBatch.php',
    'Maatwebsite\\Excel\\Events\\AfterChunk' => $vendorDir . '/maatwebsite/excel/src/Events/AfterChunk.php',
    'Maatwebsite\\Excel\\Events\\AfterImport' => $vendorDir . '/maatwebsite/excel/src/Events/AfterImport.php',
    'Maatwebsite\\Excel\\Events\\AfterSheet' => $vendorDir . '/maatwebsite/excel/src/Events/AfterSheet.php',
    'Maatwebsite\\Excel\\Events\\BeforeExport' => $vendorDir . '/maatwebsite/excel/src/Events/BeforeExport.php',
    'Maatwebsite\\Excel\\Events\\BeforeImport' => $vendorDir . '/maatwebsite/excel/src/Events/BeforeImport.php',
    'Maatwebsite\\Excel\\Events\\BeforeSheet' => $vendorDir . '/maatwebsite/excel/src/Events/BeforeSheet.php',
    'Maatwebsite\\Excel\\Events\\BeforeWriting' => $vendorDir . '/maatwebsite/excel/src/Events/BeforeWriting.php',
    'Maatwebsite\\Excel\\Events\\Event' => $vendorDir . '/maatwebsite/excel/src/Events/Event.php',
    'Maatwebsite\\Excel\\Events\\ImportFailed' => $vendorDir . '/maatwebsite/excel/src/Events/ImportFailed.php',
    'Maatwebsite\\Excel\\Excel' => $vendorDir . '/maatwebsite/excel/src/Excel.php',
    'Maatwebsite\\Excel\\ExcelServiceProvider' => $vendorDir . '/maatwebsite/excel/src/ExcelServiceProvider.php',
    'Maatwebsite\\Excel\\Exceptions\\ConcernConflictException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/ConcernConflictException.php',
    'Maatwebsite\\Excel\\Exceptions\\LaravelExcelException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/LaravelExcelException.php',
    'Maatwebsite\\Excel\\Exceptions\\NoFilePathGivenException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/NoFilePathGivenException.php',
    'Maatwebsite\\Excel\\Exceptions\\NoFilenameGivenException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/NoFilenameGivenException.php',
    'Maatwebsite\\Excel\\Exceptions\\NoSheetsFoundException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/NoSheetsFoundException.php',
    'Maatwebsite\\Excel\\Exceptions\\NoTypeDetectedException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/NoTypeDetectedException.php',
    'Maatwebsite\\Excel\\Exceptions\\RowSkippedException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/RowSkippedException.php',
    'Maatwebsite\\Excel\\Exceptions\\SheetNotFoundException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/SheetNotFoundException.php',
    'Maatwebsite\\Excel\\Exceptions\\UnreadableFileException' => $vendorDir . '/maatwebsite/excel/src/Exceptions/UnreadableFileException.php',
    'Maatwebsite\\Excel\\Exporter' => $vendorDir . '/maatwebsite/excel/src/Exporter.php',
    'Maatwebsite\\Excel\\Facades\\Excel' => $vendorDir . '/maatwebsite/excel/src/Facades/Excel.php',
    'Maatwebsite\\Excel\\Factories\\ReaderFactory' => $vendorDir . '/maatwebsite/excel/src/Factories/ReaderFactory.php',
    'Maatwebsite\\Excel\\Factories\\WriterFactory' => $vendorDir . '/maatwebsite/excel/src/Factories/WriterFactory.php',
    'Maatwebsite\\Excel\\Fakes\\ExcelFake' => $vendorDir . '/maatwebsite/excel/src/Fakes/ExcelFake.php',
    'Maatwebsite\\Excel\\Files\\Disk' => $vendorDir . '/maatwebsite/excel/src/Files/Disk.php',
    'Maatwebsite\\Excel\\Files\\Filesystem' => $vendorDir . '/maatwebsite/excel/src/Files/Filesystem.php',
    'Maatwebsite\\Excel\\Files\\LocalTemporaryFile' => $vendorDir . '/maatwebsite/excel/src/Files/LocalTemporaryFile.php',
    'Maatwebsite\\Excel\\Files\\RemoteTemporaryFile' => $vendorDir . '/maatwebsite/excel/src/Files/RemoteTemporaryFile.php',
    'Maatwebsite\\Excel\\Files\\TemporaryFile' => $vendorDir . '/maatwebsite/excel/src/Files/TemporaryFile.php',
    'Maatwebsite\\Excel\\Files\\TemporaryFileFactory' => $vendorDir . '/maatwebsite/excel/src/Files/TemporaryFileFactory.php',
    'Maatwebsite\\Excel\\Filters\\ChunkReadFilter' => $vendorDir . '/maatwebsite/excel/src/Filters/ChunkReadFilter.php',
    'Maatwebsite\\Excel\\Filters\\LimitFilter' => $vendorDir . '/maatwebsite/excel/src/Filters/LimitFilter.php',
    'Maatwebsite\\Excel\\HasEventBus' => $vendorDir . '/maatwebsite/excel/src/HasEventBus.php',
    'Maatwebsite\\Excel\\HeadingRowImport' => $vendorDir . '/maatwebsite/excel/src/HeadingRowImport.php',
    'Maatwebsite\\Excel\\Helpers\\ArrayHelper' => $vendorDir . '/maatwebsite/excel/src/Helpers/ArrayHelper.php',
    'Maatwebsite\\Excel\\Helpers\\CellHelper' => $vendorDir . '/maatwebsite/excel/src/Helpers/CellHelper.php',
    'Maatwebsite\\Excel\\Helpers\\FileTypeDetector' => $vendorDir . '/maatwebsite/excel/src/Helpers/FileTypeDetector.php',
    'Maatwebsite\\Excel\\Importer' => $vendorDir . '/maatwebsite/excel/src/Importer.php',
    'Maatwebsite\\Excel\\Imports\\EndRowFinder' => $vendorDir . '/maatwebsite/excel/src/Imports/EndRowFinder.php',
    'Maatwebsite\\Excel\\Imports\\HeadingRowExtractor' => $vendorDir . '/maatwebsite/excel/src/Imports/HeadingRowExtractor.php',
    'Maatwebsite\\Excel\\Imports\\HeadingRowFormatter' => $vendorDir . '/maatwebsite/excel/src/Imports/HeadingRowFormatter.php',
    'Maatwebsite\\Excel\\Imports\\ModelImporter' => $vendorDir . '/maatwebsite/excel/src/Imports/ModelImporter.php',
    'Maatwebsite\\Excel\\Imports\\ModelManager' => $vendorDir . '/maatwebsite/excel/src/Imports/ModelManager.php',
    'Maatwebsite\\Excel\\Imports\\Persistence\\CascadePersistManager' => $vendorDir . '/maatwebsite/excel/src/Imports/Persistence/CascadePersistManager.php',
    'Maatwebsite\\Excel\\Jobs\\AfterImportJob' => $vendorDir . '/maatwebsite/excel/src/Jobs/AfterImportJob.php',
    'Maatwebsite\\Excel\\Jobs\\AppendDataToSheet' => $vendorDir . '/maatwebsite/excel/src/Jobs/AppendDataToSheet.php',
    'Maatwebsite\\Excel\\Jobs\\AppendPaginatedToSheet' => $vendorDir . '/maatwebsite/excel/src/Jobs/AppendPaginatedToSheet.php',
    'Maatwebsite\\Excel\\Jobs\\AppendQueryToSheet' => $vendorDir . '/maatwebsite/excel/src/Jobs/AppendQueryToSheet.php',
    'Maatwebsite\\Excel\\Jobs\\AppendViewToSheet' => $vendorDir . '/maatwebsite/excel/src/Jobs/AppendViewToSheet.php',
    'Maatwebsite\\Excel\\Jobs\\CloseSheet' => $vendorDir . '/maatwebsite/excel/src/Jobs/CloseSheet.php',
    'Maatwebsite\\Excel\\Jobs\\ExtendedQueueable' => $vendorDir . '/maatwebsite/excel/src/Jobs/ExtendedQueueable.php',
    'Maatwebsite\\Excel\\Jobs\\Middleware\\LocalizeJob' => $vendorDir . '/maatwebsite/excel/src/Jobs/Middleware/LocalizeJob.php',
    'Maatwebsite\\Excel\\Jobs\\ProxyFailures' => $vendorDir . '/maatwebsite/excel/src/Jobs/ProxyFailures.php',
    'Maatwebsite\\Excel\\Jobs\\QueueExport' => $vendorDir . '/maatwebsite/excel/src/Jobs/QueueExport.php',
    'Maatwebsite\\Excel\\Jobs\\QueueImport' => $vendorDir . '/maatwebsite/excel/src/Jobs/QueueImport.php',
    'Maatwebsite\\Excel\\Jobs\\ReadChunk' => $vendorDir . '/maatwebsite/excel/src/Jobs/ReadChunk.php',
    'Maatwebsite\\Excel\\Jobs\\StoreQueuedExport' => $vendorDir . '/maatwebsite/excel/src/Jobs/StoreQueuedExport.php',
    'Maatwebsite\\Excel\\MappedReader' => $vendorDir . '/maatwebsite/excel/src/MappedReader.php',
    'Maatwebsite\\Excel\\Middleware\\CellMiddleware' => $vendorDir . '/maatwebsite/excel/src/Middleware/CellMiddleware.php',
    'Maatwebsite\\Excel\\Middleware\\ConvertEmptyCellValuesToNull' => $vendorDir . '/maatwebsite/excel/src/Middleware/ConvertEmptyCellValuesToNull.php',
    'Maatwebsite\\Excel\\Middleware\\TrimCellValue' => $vendorDir . '/maatwebsite/excel/src/Middleware/TrimCellValue.php',
    'Maatwebsite\\Excel\\Mixins\\DownloadCollectionMixin' => $vendorDir . '/maatwebsite/excel/src/Mixins/DownloadCollectionMixin.php',
    'Maatwebsite\\Excel\\Mixins\\DownloadQueryMacro' => $vendorDir . '/maatwebsite/excel/src/Mixins/DownloadQueryMacro.php',
    'Maatwebsite\\Excel\\Mixins\\ImportAsMacro' => $vendorDir . '/maatwebsite/excel/src/Mixins/ImportAsMacro.php',
    'Maatwebsite\\Excel\\Mixins\\ImportMacro' => $vendorDir . '/maatwebsite/excel/src/Mixins/ImportMacro.php',
    'Maatwebsite\\Excel\\Mixins\\StoreCollectionMixin' => $vendorDir . '/maatwebsite/excel/src/Mixins/StoreCollectionMixin.php',
    'Maatwebsite\\Excel\\Mixins\\StoreQueryMacro' => $vendorDir . '/maatwebsite/excel/src/Mixins/StoreQueryMacro.php',
    'Maatwebsite\\Excel\\QueuedWriter' => $vendorDir . '/maatwebsite/excel/src/QueuedWriter.php',
    'Maatwebsite\\Excel\\Reader' => $vendorDir . '/maatwebsite/excel/src/Reader.php',
    'Maatwebsite\\Excel\\RegistersCustomConcerns' => $vendorDir . '/maatwebsite/excel/src/RegistersCustomConcerns.php',
    'Maatwebsite\\Excel\\Row' => $vendorDir . '/maatwebsite/excel/src/Row.php',
    'Maatwebsite\\Excel\\SettingsProvider' => $vendorDir . '/maatwebsite/excel/src/SettingsProvider.php',
    'Maatwebsite\\Excel\\Sheet' => $vendorDir . '/maatwebsite/excel/src/Sheet.php',
    'Maatwebsite\\Excel\\Transactions\\DbTransactionHandler' => $vendorDir . '/maatwebsite/excel/src/Transactions/DbTransactionHandler.php',
    'Maatwebsite\\Excel\\Transactions\\NullTransactionHandler' => $vendorDir . '/maatwebsite/excel/src/Transactions/NullTransactionHandler.php',
    'Maatwebsite\\Excel\\Transactions\\TransactionHandler' => $vendorDir . '/maatwebsite/excel/src/Transactions/TransactionHandler.php',
    'Maatwebsite\\Excel\\Transactions\\TransactionManager' => $vendorDir . '/maatwebsite/excel/src/Transactions/TransactionManager.php',
    'Maatwebsite\\Excel\\Validators\\Failure' => $vendorDir . '/maatwebsite/excel/src/Validators/Failure.php',
    'Maatwebsite\\Excel\\Validators\\RowValidator' => $vendorDir . '/maatwebsite/excel/src/Validators/RowValidator.php',
    'Maatwebsite\\Excel\\Validators\\ValidationException' => $vendorDir . '/maatwebsite/excel/src/Validators/ValidationException.php',
    'Maatwebsite\\Excel\\Writer' => $vendorDir . '/maatwebsite/excel/src/Writer.php',
    'Matrix\\Builder' => $vendorDir . '/markbaker/matrix/classes/src/Builder.php',
    'Matrix\\Decomposition\\Decomposition' => $vendorDir . '/markbaker/matrix/classes/src/Decomposition/Decomposition.php',
    'Matrix\\Decomposition\\LU' => $vendorDir . '/markbaker/matrix/classes/src/Decomposition/LU.php',
    'Matrix\\Decomposition\\QR' => $vendorDir . '/markbaker/matrix/classes/src/Decomposition/QR.php',
    'Matrix\\Div0Exception' => $vendorDir . '/markbaker/matrix/classes/src/Div0Exception.php',
    'Matrix\\Exception' => $vendorDir . '/markbaker/matrix/classes/src/Exception.php',
    'Matrix\\Functions' => $vendorDir . '/markbaker/matrix/classes/src/Functions.php',
    'Matrix\\Matrix' => $vendorDir . '/markbaker/matrix/classes/src/Matrix.php',
    'Matrix\\Operations' => $vendorDir . '/markbaker/matrix/classes/src/Operations.php',
    'Matrix\\Operators\\Addition' => $vendorDir . '/markbaker/matrix/classes/src/Operators/Addition.php',
    'Matrix\\Operators\\DirectSum' => $vendorDir . '/markbaker/matrix/classes/src/Operators/DirectSum.php',
    'Matrix\\Operators\\Division' => $vendorDir . '/markbaker/matrix/classes/src/Operators/Division.php',
    'Matrix\\Operators\\Multiplication' => $vendorDir . '/markbaker/matrix/classes/src/Operators/Multiplication.php',
    'Matrix\\Operators\\Operator' => $vendorDir . '/markbaker/matrix/classes/src/Operators/Operator.php',
    'Matrix\\Operators\\Subtraction' => $vendorDir . '/markbaker/matrix/classes/src/Operators/Subtraction.php',
    'MercadoPago\\AdvancedPayments\\AdvancedPayment' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/AdvancedPayments/AdvancedPayment.php',
    'MercadoPago\\AdvancedPayments\\DisbursementRefund' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/AdvancedPayments/DisbursementRefund.php',
    'MercadoPago\\AdvancedPayments\\Refund' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/AdvancedPayments/Refund.php',
    'MercadoPago\\Annotation\\Attribute' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Annotation/Attribute.php',
    'MercadoPago\\Annotation\\DenyDynamicAttribute' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Annotation/DenyDynamicAttribute.php',
    'MercadoPago\\Annotation\\RequestParam' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Annotation/RequestParam.php',
    'MercadoPago\\Annotation\\RestMethod' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Annotation/RestMethod.php',
    'MercadoPago\\AuthorizedPayment' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/AuthorizedPayment.php',
    'MercadoPago\\Card' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Card.php',
    'MercadoPago\\CardToken' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/CardToken.php',
    'MercadoPago\\Chargeback' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Chargeback.php',
    'MercadoPago\\Config' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Config.php',
    'MercadoPago\\Config\\AbstractConfig' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Config/AbstractConfig.php',
    'MercadoPago\\Config\\Json' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Config/Json.php',
    'MercadoPago\\Config\\ParserInterface' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Config/ParserInterface.php',
    'MercadoPago\\Config\\Yaml' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Config/Yaml.php',
    'MercadoPago\\Customer' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Customer.php',
    'MercadoPago\\DiscountCampaign' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/DiscountCampaign.php',
    'MercadoPago\\Documentation' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Documentation.php',
    'MercadoPago\\DummyEntity' => $vendorDir . '/mercadopago/dx-php/tests/DummyEntity.php',
    'MercadoPago\\Entity' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entity.php',
    'MercadoPago\\ErrorCause' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Generic/ErrorCause.php',
    'MercadoPago\\FakeApiHub' => $vendorDir . '/mercadopago/dx-php/tests/FakeApiHub.php',
    'MercadoPago\\Http\\CurlRequest' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Http/CurlRequest.php',
    'MercadoPago\\Http\\HttpRequest' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Http/HttpRequest.php',
    'MercadoPago\\InstoreOrder' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/InstoreOrder.php',
    'MercadoPago\\Invoice' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Invoice.php',
    'MercadoPago\\Item' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Item.php',
    'MercadoPago\\Manager' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Manager.php',
    'MercadoPago\\MerchantOrder' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/MerchantOrder.php',
    'MercadoPago\\MetaDataReader' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/MetaDataReader.php',
    'MercadoPago\\OAuth' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/OAuth.php',
    'MercadoPago\\POS' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/POS.php',
    'MercadoPago\\Payer' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Payer.php',
    'MercadoPago\\Payment' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Payment.php',
    'MercadoPago\\PaymentMethod' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/PaymentMethod.php',
    'MercadoPago\\Plan' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Plan.php',
    'MercadoPago\\Preapproval' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Preapproval.php',
    'MercadoPago\\Preference' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Preference.php',
    'MercadoPago\\RecuperableError' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Generic/RecuperableError.php',
    'MercadoPago\\Refund' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Refund.php',
    'MercadoPago\\RestClient' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/RestClient.php',
    'MercadoPago\\SDK' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/SDK.php',
    'MercadoPago\\SearchResultsArray' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Generic/SearchResultsArray.php',
    'MercadoPago\\Shipments' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shipments.php',
    'MercadoPago\\Subscription' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Subscription.php',
    'MercadoPago\\Tax' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Tax.php',
    'MercadoPago\\Track' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/Track.php',
    'MercadoPago\\TrackValues' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Entities/Shared/TrackValues.php',
    'MercadoPago\\Version' => $vendorDir . '/mercadopago/dx-php/src/MercadoPago/Version.php',
    'Midtrans\\ApiRequestor' => $vendorDir . '/midtrans/midtrans-php/Midtrans/ApiRequestor.php',
    'Midtrans\\Config' => $vendorDir . '/midtrans/midtrans-php/Midtrans/Config.php',
    'Midtrans\\CoreApi' => $vendorDir . '/midtrans/midtrans-php/Midtrans/CoreApi.php',
    'Midtrans\\Notification' => $vendorDir . '/midtrans/midtrans-php/Midtrans/Notification.php',
    'Midtrans\\Sanitizer' => $vendorDir . '/midtrans/midtrans-php/Midtrans/Sanitizer.php',
    'Midtrans\\Snap' => $vendorDir . '/midtrans/midtrans-php/Midtrans/Snap.php',
    'Midtrans\\SnapApiRequestor' => $vendorDir . '/midtrans/midtrans-php/Midtrans/SnapApiRequestor.php',
    'Midtrans\\Transaction' => $vendorDir . '/midtrans/midtrans-php/Midtrans/Transaction.php',
    'Milon\\Barcode\\BarcodeServiceProvider' => $vendorDir . '/milon/barcode/src/Milon/Barcode/BarcodeServiceProvider.php',
    'Milon\\Barcode\\DNS1D' => $vendorDir . '/milon/barcode/src/Milon/Barcode/DNS1D.php',
    'Milon\\Barcode\\DNS2D' => $vendorDir . '/milon/barcode/src/Milon/Barcode/DNS2D.php',
    'Milon\\Barcode\\Datamatrix' => $vendorDir . '/milon/barcode/src/Milon/Barcode/Datamatrix.php',
    'Milon\\Barcode\\Facades\\DNS1DFacade' => $vendorDir . '/milon/barcode/src/Milon/Barcode/Facades/DNS1DFacade.php',
    'Milon\\Barcode\\Facades\\DNS2DFacade' => $vendorDir . '/milon/barcode/src/Milon/Barcode/Facades/DNS2DFacade.php',
    'Milon\\Barcode\\GS1_128\\AIData' => $vendorDir . '/milon/barcode/src/Milon/Barcode/GS1_128/AIData.php',
    'Milon\\Barcode\\GS1_128\\GS1128' => $vendorDir . '/milon/barcode/src/Milon/Barcode/GS1_128/GS1128.php',
    'Milon\\Barcode\\GS1_128\\Section' => $vendorDir . '/milon/barcode/src/Milon/Barcode/GS1_128/Section.php',
    'Milon\\Barcode\\GS1_128\\SectionSlicer' => $vendorDir . '/milon/barcode/src/Milon/Barcode/GS1_128/SectionSlicer.php',
    'Milon\\Barcode\\GS1_128\\Subsets' => $vendorDir . '/milon/barcode/src/Milon/Barcode/GS1_128/Subsets.php',
    'Milon\\Barcode\\PDF417' => $vendorDir . '/milon/barcode/src/Milon/Barcode/PDF417.php',
    'Milon\\Barcode\\QRcode' => $vendorDir . '/milon/barcode/src/Milon/Barcode/QRcode.php',
    'Milon\\Barcode\\WrongCheckDigitException' => $vendorDir . '/milon/barcode/src/Milon/Barcode/WrongCheckDigitException.php',
    'Mockery\\Adapter\\Phpunit\\MockeryPHPUnitIntegration' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/MockeryPHPUnitIntegration.php',
    'Mockery\\Adapter\\Phpunit\\MockeryPHPUnitIntegrationAssertPostConditions' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/MockeryPHPUnitIntegrationAssertPostConditions.php',
    'Mockery\\Adapter\\Phpunit\\MockeryTestCase' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/MockeryTestCase.php',
    'Mockery\\Adapter\\Phpunit\\MockeryTestCaseSetUp' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/MockeryTestCaseSetUp.php',
    'Mockery\\Adapter\\Phpunit\\TestListener' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/TestListener.php',
    'Mockery\\Adapter\\Phpunit\\TestListenerTrait' => $vendorDir . '/mockery/mockery/library/Mockery/Adapter/Phpunit/TestListenerTrait.php',
    'Mockery\\ClosureWrapper' => $vendorDir . '/mockery/mockery/library/Mockery/ClosureWrapper.php',
    'Mockery\\CompositeExpectation' => $vendorDir . '/mockery/mockery/library/Mockery/CompositeExpectation.php',
    'Mockery\\Configuration' => $vendorDir . '/mockery/mockery/library/Mockery/Configuration.php',
    'Mockery\\Container' => $vendorDir . '/mockery/mockery/library/Mockery/Container.php',
    'Mockery\\CountValidator\\AtLeast' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/AtLeast.php',
    'Mockery\\CountValidator\\AtMost' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/AtMost.php',
    'Mockery\\CountValidator\\CountValidatorAbstract' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/CountValidatorAbstract.php',
    'Mockery\\CountValidator\\CountValidatorInterface' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/CountValidatorInterface.php',
    'Mockery\\CountValidator\\Exact' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/Exact.php',
    'Mockery\\CountValidator\\Exception' => $vendorDir . '/mockery/mockery/library/Mockery/CountValidator/Exception.php',
    'Mockery\\Exception' => $vendorDir . '/mockery/mockery/library/Mockery/Exception.php',
    'Mockery\\Exception\\BadMethodCallException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/BadMethodCallException.php',
    'Mockery\\Exception\\InvalidArgumentException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/InvalidArgumentException.php',
    'Mockery\\Exception\\InvalidCountException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/InvalidCountException.php',
    'Mockery\\Exception\\InvalidOrderException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/InvalidOrderException.php',
    'Mockery\\Exception\\MockeryExceptionInterface' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/MockeryExceptionInterface.php',
    'Mockery\\Exception\\NoMatchingExpectationException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/NoMatchingExpectationException.php',
    'Mockery\\Exception\\RuntimeException' => $vendorDir . '/mockery/mockery/library/Mockery/Exception/RuntimeException.php',
    'Mockery\\Expectation' => $vendorDir . '/mockery/mockery/library/Mockery/Expectation.php',
    'Mockery\\ExpectationDirector' => $vendorDir . '/mockery/mockery/library/Mockery/ExpectationDirector.php',
    'Mockery\\ExpectationInterface' => $vendorDir . '/mockery/mockery/library/Mockery/ExpectationInterface.php',
    'Mockery\\ExpectsHigherOrderMessage' => $vendorDir . '/mockery/mockery/library/Mockery/ExpectsHigherOrderMessage.php',
    'Mockery\\Generator\\CachingGenerator' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/CachingGenerator.php',
    'Mockery\\Generator\\DefinedTargetClass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/DefinedTargetClass.php',
    'Mockery\\Generator\\Generator' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/Generator.php',
    'Mockery\\Generator\\Method' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/Method.php',
    'Mockery\\Generator\\MockConfiguration' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/MockConfiguration.php',
    'Mockery\\Generator\\MockConfigurationBuilder' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/MockConfigurationBuilder.php',
    'Mockery\\Generator\\MockDefinition' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/MockDefinition.php',
    'Mockery\\Generator\\MockNameBuilder' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/MockNameBuilder.php',
    'Mockery\\Generator\\Parameter' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/Parameter.php',
    'Mockery\\Generator\\StringManipulationGenerator' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulationGenerator.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\AvoidMethodClashPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/AvoidMethodClashPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\CallTypeHintPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/CallTypeHintPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\ClassAttributesPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/ClassAttributesPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\ClassNamePass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/ClassNamePass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\ClassPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/ClassPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\ConstantsPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/ConstantsPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\InstanceMockPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/InstanceMockPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\InterfacePass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/InterfacePass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\MagicMethodTypeHintsPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/MagicMethodTypeHintsPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\MethodDefinitionPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/MethodDefinitionPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\Pass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/Pass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\RemoveBuiltinMethodsThatAreFinalPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/RemoveBuiltinMethodsThatAreFinalPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\RemoveDestructorPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/RemoveDestructorPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\RemoveUnserializeForInternalSerializableClassesPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/RemoveUnserializeForInternalSerializableClassesPass.php',
    'Mockery\\Generator\\StringManipulation\\Pass\\TraitPass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/StringManipulation/Pass/TraitPass.php',
    'Mockery\\Generator\\TargetClassInterface' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/TargetClassInterface.php',
    'Mockery\\Generator\\UndefinedTargetClass' => $vendorDir . '/mockery/mockery/library/Mockery/Generator/UndefinedTargetClass.php',
    'Mockery\\HigherOrderMessage' => $vendorDir . '/mockery/mockery/library/Mockery/HigherOrderMessage.php',
    'Mockery\\Instantiator' => $vendorDir . '/mockery/mockery/library/Mockery/Instantiator.php',
    'Mockery\\LegacyMockInterface' => $vendorDir . '/mockery/mockery/library/Mockery/LegacyMockInterface.php',
    'Mockery\\Loader\\EvalLoader' => $vendorDir . '/mockery/mockery/library/Mockery/Loader/EvalLoader.php',
    'Mockery\\Loader\\Loader' => $vendorDir . '/mockery/mockery/library/Mockery/Loader/Loader.php',
    'Mockery\\Loader\\RequireLoader' => $vendorDir . '/mockery/mockery/library/Mockery/Loader/RequireLoader.php',
    'Mockery\\Matcher\\AndAnyOtherArgs' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/AndAnyOtherArgs.php',
    'Mockery\\Matcher\\Any' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Any.php',
    'Mockery\\Matcher\\AnyArgs' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/AnyArgs.php',
    'Mockery\\Matcher\\AnyOf' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/AnyOf.php',
    'Mockery\\Matcher\\ArgumentListMatcher' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/ArgumentListMatcher.php',
    'Mockery\\Matcher\\Closure' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Closure.php',
    'Mockery\\Matcher\\Contains' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Contains.php',
    'Mockery\\Matcher\\Ducktype' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Ducktype.php',
    'Mockery\\Matcher\\HasKey' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/HasKey.php',
    'Mockery\\Matcher\\HasValue' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/HasValue.php',
    'Mockery\\Matcher\\IsEqual' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/IsEqual.php',
    'Mockery\\Matcher\\IsSame' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/IsSame.php',
    'Mockery\\Matcher\\MatcherAbstract' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/MatcherAbstract.php',
    'Mockery\\Matcher\\MatcherInterface' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/MatcherInterface.php',
    'Mockery\\Matcher\\MultiArgumentClosure' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/MultiArgumentClosure.php',
    'Mockery\\Matcher\\MustBe' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/MustBe.php',
    'Mockery\\Matcher\\NoArgs' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/NoArgs.php',
    'Mockery\\Matcher\\Not' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Not.php',
    'Mockery\\Matcher\\NotAnyOf' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/NotAnyOf.php',
    'Mockery\\Matcher\\Pattern' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Pattern.php',
    'Mockery\\Matcher\\Subset' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Subset.php',
    'Mockery\\Matcher\\Type' => $vendorDir . '/mockery/mockery/library/Mockery/Matcher/Type.php',
    'Mockery\\MethodCall' => $vendorDir . '/mockery/mockery/library/Mockery/MethodCall.php',
    'Mockery\\Mock' => $vendorDir . '/mockery/mockery/library/Mockery/Mock.php',
    'Mockery\\MockInterface' => $vendorDir . '/mockery/mockery/library/Mockery/MockInterface.php',
    'Mockery\\QuickDefinitionsConfiguration' => $vendorDir . '/mockery/mockery/library/Mockery/QuickDefinitionsConfiguration.php',
    'Mockery\\ReceivedMethodCalls' => $vendorDir . '/mockery/mockery/library/Mockery/ReceivedMethodCalls.php',
    'Mockery\\Reflector' => $vendorDir . '/mockery/mockery/library/Mockery/Reflector.php',
    'Mockery\\Undefined' => $vendorDir . '/mockery/mockery/library/Mockery/Undefined.php',
    'Mockery\\VerificationDirector' => $vendorDir . '/mockery/mockery/library/Mockery/VerificationDirector.php',
    'Mockery\\VerificationExpectation' => $vendorDir . '/mockery/mockery/library/Mockery/VerificationExpectation.php',
    'Modules\\LandingPage\\Database\\Seeders\\LandingPageDataTableSeeder' => $baseDir . '/Modules/LandingPage/Database/Seeders/LandingPageDataTableSeeder.php',
    'Modules\\LandingPage\\Database\\Seeders\\LandingPageDatabaseSeeder' => $baseDir . '/Modules/LandingPage/Database/Seeders/LandingPageDatabaseSeeder.php',
    'Modules\\LandingPage\\Entities\\JoinUs' => $baseDir . '/Modules/LandingPage/Entities/JoinUs.php',
    'Modules\\LandingPage\\Entities\\LandingPageSetting' => $baseDir . '/Modules/LandingPage/Entities/LandingPageSetting.php',
    'Modules\\LandingPage\\Http\\Controllers\\CustomPageController' => $baseDir . '/Modules/LandingPage/Http/Controllers/CustomPageController.php',
    'Modules\\LandingPage\\Http\\Controllers\\DiscoverController' => $baseDir . '/Modules/LandingPage/Http/Controllers/DiscoverController.php',
    'Modules\\LandingPage\\Http\\Controllers\\FaqController' => $baseDir . '/Modules/LandingPage/Http/Controllers/FaqController.php',
    'Modules\\LandingPage\\Http\\Controllers\\FeaturesController' => $baseDir . '/Modules/LandingPage/Http/Controllers/FeaturesController.php',
    'Modules\\LandingPage\\Http\\Controllers\\HomeController' => $baseDir . '/Modules/LandingPage/Http/Controllers/HomeController.php',
    'Modules\\LandingPage\\Http\\Controllers\\JoinUsController' => $baseDir . '/Modules/LandingPage/Http/Controllers/JoinUsController.php',
    'Modules\\LandingPage\\Http\\Controllers\\LandingPageController' => $baseDir . '/Modules/LandingPage/Http/Controllers/LandingPageController.php',
    'Modules\\LandingPage\\Http\\Controllers\\PricingPlanController' => $baseDir . '/Modules/LandingPage/Http/Controllers/PricingPlanController.php',
    'Modules\\LandingPage\\Http\\Controllers\\ScreenshotsController' => $baseDir . '/Modules/LandingPage/Http/Controllers/ScreenshotsController.php',
    'Modules\\LandingPage\\Http\\Controllers\\TestimonialsController' => $baseDir . '/Modules/LandingPage/Http/Controllers/TestimonialsController.php',
    'Modules\\LandingPage\\Providers\\AddMenuProvider' => $baseDir . '/Modules/LandingPage/Providers/AddMenuProvider.php',
    'Modules\\LandingPage\\Providers\\LandingPageServiceProvider' => $baseDir . '/Modules/LandingPage/Providers/LandingPageServiceProvider.php',
    'Modules\\LandingPage\\Providers\\RouteServiceProvider' => $baseDir . '/Modules/LandingPage/Providers/RouteServiceProvider.php',
    'Mollie\\Api\\CompatibilityChecker' => $vendorDir . '/mollie/mollie-api-php/src/CompatibilityChecker.php',
    'Mollie\\Api\\Endpoints\\BalanceEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/BalanceEndpoint.php',
    'Mollie\\Api\\Endpoints\\BalanceReportEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/BalanceReportEndpoint.php',
    'Mollie\\Api\\Endpoints\\BalanceTransactionEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/BalanceTransactionEndpoint.php',
    'Mollie\\Api\\Endpoints\\ChargebackEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ChargebackEndpoint.php',
    'Mollie\\Api\\Endpoints\\ClientEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ClientEndpoint.php',
    'Mollie\\Api\\Endpoints\\ClientLinkEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ClientLinkEndpoint.php',
    'Mollie\\Api\\Endpoints\\CollectionEndpointAbstract' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/CollectionEndpointAbstract.php',
    'Mollie\\Api\\Endpoints\\CustomerEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/CustomerEndpoint.php',
    'Mollie\\Api\\Endpoints\\CustomerPaymentsEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/CustomerPaymentsEndpoint.php',
    'Mollie\\Api\\Endpoints\\EndpointAbstract' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/EndpointAbstract.php',
    'Mollie\\Api\\Endpoints\\InvoiceEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/InvoiceEndpoint.php',
    'Mollie\\Api\\Endpoints\\MandateEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/MandateEndpoint.php',
    'Mollie\\Api\\Endpoints\\MethodEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/MethodEndpoint.php',
    'Mollie\\Api\\Endpoints\\MethodIssuerEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/MethodIssuerEndpoint.php',
    'Mollie\\Api\\Endpoints\\OnboardingEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OnboardingEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrderEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrderEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrderLineEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrderLineEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrderPaymentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrderPaymentEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrderRefundEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrderRefundEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrganizationEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrganizationEndpoint.php',
    'Mollie\\Api\\Endpoints\\OrganizationPartnerEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/OrganizationPartnerEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentCaptureEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentCaptureEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentChargebackEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentChargebackEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentLinkEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentLinkEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentLinkPaymentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentLinkPaymentEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentRefundEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentRefundEndpoint.php',
    'Mollie\\Api\\Endpoints\\PaymentRouteEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PaymentRouteEndpoint.php',
    'Mollie\\Api\\Endpoints\\PermissionEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/PermissionEndpoint.php',
    'Mollie\\Api\\Endpoints\\ProfileEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ProfileEndpoint.php',
    'Mollie\\Api\\Endpoints\\ProfileMethodEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ProfileMethodEndpoint.php',
    'Mollie\\Api\\Endpoints\\RefundEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/RefundEndpoint.php',
    'Mollie\\Api\\Endpoints\\SettlementCaptureEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SettlementCaptureEndpoint.php',
    'Mollie\\Api\\Endpoints\\SettlementChargebackEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SettlementChargebackEndpoint.php',
    'Mollie\\Api\\Endpoints\\SettlementPaymentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SettlementPaymentEndpoint.php',
    'Mollie\\Api\\Endpoints\\SettlementRefundEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SettlementRefundEndpoint.php',
    'Mollie\\Api\\Endpoints\\SettlementsEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SettlementsEndpoint.php',
    'Mollie\\Api\\Endpoints\\ShipmentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/ShipmentEndpoint.php',
    'Mollie\\Api\\Endpoints\\SubscriptionEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SubscriptionEndpoint.php',
    'Mollie\\Api\\Endpoints\\SubscriptionPaymentEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/SubscriptionPaymentEndpoint.php',
    'Mollie\\Api\\Endpoints\\TerminalEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/TerminalEndpoint.php',
    'Mollie\\Api\\Endpoints\\WalletEndpoint' => $vendorDir . '/mollie/mollie-api-php/src/Endpoints/WalletEndpoint.php',
    'Mollie\\Api\\Exceptions\\ApiException' => $vendorDir . '/mollie/mollie-api-php/src/Exceptions/ApiException.php',
    'Mollie\\Api\\Exceptions\\CurlConnectTimeoutException' => $vendorDir . '/mollie/mollie-api-php/src/Exceptions/CurlConnectTimeoutException.php',
    'Mollie\\Api\\Exceptions\\HttpAdapterDoesNotSupportDebuggingException' => $vendorDir . '/mollie/mollie-api-php/src/Exceptions/HttpAdapterDoesNotSupportDebuggingException.php',
    'Mollie\\Api\\Exceptions\\IncompatiblePlatform' => $vendorDir . '/mollie/mollie-api-php/src/Exceptions/IncompatiblePlatform.php',
    'Mollie\\Api\\Exceptions\\UnrecognizedClientException' => $vendorDir . '/mollie/mollie-api-php/src/Exceptions/UnrecognizedClientException.php',
    'Mollie\\Api\\HttpAdapter\\CurlMollieHttpAdapter' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/CurlMollieHttpAdapter.php',
    'Mollie\\Api\\HttpAdapter\\Guzzle6And7MollieHttpAdapter' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/Guzzle6And7MollieHttpAdapter.php',
    'Mollie\\Api\\HttpAdapter\\Guzzle6And7RetryMiddlewareFactory' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/Guzzle6And7RetryMiddlewareFactory.php',
    'Mollie\\Api\\HttpAdapter\\MollieHttpAdapterInterface' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/MollieHttpAdapterInterface.php',
    'Mollie\\Api\\HttpAdapter\\MollieHttpAdapterPicker' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/MollieHttpAdapterPicker.php',
    'Mollie\\Api\\HttpAdapter\\MollieHttpAdapterPickerInterface' => $vendorDir . '/mollie/mollie-api-php/src/HttpAdapter/MollieHttpAdapterPickerInterface.php',
    'Mollie\\Api\\Idempotency\\DefaultIdempotencyKeyGenerator' => $vendorDir . '/mollie/mollie-api-php/src/Idempotency/DefaultIdempotencyKeyGenerator.php',
    'Mollie\\Api\\Idempotency\\FakeIdempotencyKeyGenerator' => $vendorDir . '/mollie/mollie-api-php/src/Idempotency/FakeIdempotencyKeyGenerator.php',
    'Mollie\\Api\\Idempotency\\IdempotencyKeyGeneratorContract' => $vendorDir . '/mollie/mollie-api-php/src/Idempotency/IdempotencyKeyGeneratorContract.php',
    'Mollie\\Api\\MollieApiClient' => $vendorDir . '/mollie/mollie-api-php/src/MollieApiClient.php',
    'Mollie\\Api\\Resources\\Balance' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Balance.php',
    'Mollie\\Api\\Resources\\BalanceCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BalanceCollection.php',
    'Mollie\\Api\\Resources\\BalanceReport' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BalanceReport.php',
    'Mollie\\Api\\Resources\\BalanceTransaction' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BalanceTransaction.php',
    'Mollie\\Api\\Resources\\BalanceTransactionCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BalanceTransactionCollection.php',
    'Mollie\\Api\\Resources\\BaseCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BaseCollection.php',
    'Mollie\\Api\\Resources\\BaseResource' => $vendorDir . '/mollie/mollie-api-php/src/Resources/BaseResource.php',
    'Mollie\\Api\\Resources\\Capture' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Capture.php',
    'Mollie\\Api\\Resources\\CaptureCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/CaptureCollection.php',
    'Mollie\\Api\\Resources\\Chargeback' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Chargeback.php',
    'Mollie\\Api\\Resources\\ChargebackCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ChargebackCollection.php',
    'Mollie\\Api\\Resources\\Client' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Client.php',
    'Mollie\\Api\\Resources\\ClientCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ClientCollection.php',
    'Mollie\\Api\\Resources\\ClientLink' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ClientLink.php',
    'Mollie\\Api\\Resources\\CurrentProfile' => $vendorDir . '/mollie/mollie-api-php/src/Resources/CurrentProfile.php',
    'Mollie\\Api\\Resources\\CursorCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/CursorCollection.php',
    'Mollie\\Api\\Resources\\Customer' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Customer.php',
    'Mollie\\Api\\Resources\\CustomerCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/CustomerCollection.php',
    'Mollie\\Api\\Resources\\Invoice' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Invoice.php',
    'Mollie\\Api\\Resources\\InvoiceCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/InvoiceCollection.php',
    'Mollie\\Api\\Resources\\Issuer' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Issuer.php',
    'Mollie\\Api\\Resources\\IssuerCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/IssuerCollection.php',
    'Mollie\\Api\\Resources\\LazyCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/LazyCollection.php',
    'Mollie\\Api\\Resources\\Mandate' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Mandate.php',
    'Mollie\\Api\\Resources\\MandateCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/MandateCollection.php',
    'Mollie\\Api\\Resources\\Method' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Method.php',
    'Mollie\\Api\\Resources\\MethodCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/MethodCollection.php',
    'Mollie\\Api\\Resources\\MethodPrice' => $vendorDir . '/mollie/mollie-api-php/src/Resources/MethodPrice.php',
    'Mollie\\Api\\Resources\\MethodPriceCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/MethodPriceCollection.php',
    'Mollie\\Api\\Resources\\Onboarding' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Onboarding.php',
    'Mollie\\Api\\Resources\\Order' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Order.php',
    'Mollie\\Api\\Resources\\OrderCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/OrderCollection.php',
    'Mollie\\Api\\Resources\\OrderLine' => $vendorDir . '/mollie/mollie-api-php/src/Resources/OrderLine.php',
    'Mollie\\Api\\Resources\\OrderLineCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/OrderLineCollection.php',
    'Mollie\\Api\\Resources\\Organization' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Organization.php',
    'Mollie\\Api\\Resources\\OrganizationCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/OrganizationCollection.php',
    'Mollie\\Api\\Resources\\Partner' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Partner.php',
    'Mollie\\Api\\Resources\\Payment' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Payment.php',
    'Mollie\\Api\\Resources\\PaymentCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/PaymentCollection.php',
    'Mollie\\Api\\Resources\\PaymentLink' => $vendorDir . '/mollie/mollie-api-php/src/Resources/PaymentLink.php',
    'Mollie\\Api\\Resources\\PaymentLinkCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/PaymentLinkCollection.php',
    'Mollie\\Api\\Resources\\Permission' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Permission.php',
    'Mollie\\Api\\Resources\\PermissionCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/PermissionCollection.php',
    'Mollie\\Api\\Resources\\Profile' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Profile.php',
    'Mollie\\Api\\Resources\\ProfileCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ProfileCollection.php',
    'Mollie\\Api\\Resources\\Refund' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Refund.php',
    'Mollie\\Api\\Resources\\RefundCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/RefundCollection.php',
    'Mollie\\Api\\Resources\\ResourceFactory' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ResourceFactory.php',
    'Mollie\\Api\\Resources\\Route' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Route.php',
    'Mollie\\Api\\Resources\\RouteCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/RouteCollection.php',
    'Mollie\\Api\\Resources\\Settlement' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Settlement.php',
    'Mollie\\Api\\Resources\\SettlementCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/SettlementCollection.php',
    'Mollie\\Api\\Resources\\Shipment' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Shipment.php',
    'Mollie\\Api\\Resources\\ShipmentCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/ShipmentCollection.php',
    'Mollie\\Api\\Resources\\Subscription' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Subscription.php',
    'Mollie\\Api\\Resources\\SubscriptionCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/SubscriptionCollection.php',
    'Mollie\\Api\\Resources\\Terminal' => $vendorDir . '/mollie/mollie-api-php/src/Resources/Terminal.php',
    'Mollie\\Api\\Resources\\TerminalCollection' => $vendorDir . '/mollie/mollie-api-php/src/Resources/TerminalCollection.php',
    'Mollie\\Api\\Types\\ApprovalPrompt' => $vendorDir . '/mollie/mollie-api-php/src/Types/ApprovalPrompt.php',
    'Mollie\\Api\\Types\\BalanceTransferFrequency' => $vendorDir . '/mollie/mollie-api-php/src/Types/BalanceTransferFrequency.php',
    'Mollie\\Api\\Types\\InvoiceStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/InvoiceStatus.php',
    'Mollie\\Api\\Types\\MandateMethod' => $vendorDir . '/mollie/mollie-api-php/src/Types/MandateMethod.php',
    'Mollie\\Api\\Types\\MandateStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/MandateStatus.php',
    'Mollie\\Api\\Types\\OnboardingStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/OnboardingStatus.php',
    'Mollie\\Api\\Types\\OrderLineStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/OrderLineStatus.php',
    'Mollie\\Api\\Types\\OrderLineType' => $vendorDir . '/mollie/mollie-api-php/src/Types/OrderLineType.php',
    'Mollie\\Api\\Types\\OrderLineUpdateOperationType' => $vendorDir . '/mollie/mollie-api-php/src/Types/OrderLineUpdateOperationType.php',
    'Mollie\\Api\\Types\\OrderStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/OrderStatus.php',
    'Mollie\\Api\\Types\\PaymentMethod' => $vendorDir . '/mollie/mollie-api-php/src/Types/PaymentMethod.php',
    'Mollie\\Api\\Types\\PaymentMethodStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/PaymentMethodStatus.php',
    'Mollie\\Api\\Types\\PaymentStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/PaymentStatus.php',
    'Mollie\\Api\\Types\\ProfileStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/ProfileStatus.php',
    'Mollie\\Api\\Types\\RefundStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/RefundStatus.php',
    'Mollie\\Api\\Types\\SequenceType' => $vendorDir . '/mollie/mollie-api-php/src/Types/SequenceType.php',
    'Mollie\\Api\\Types\\SettlementStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/SettlementStatus.php',
    'Mollie\\Api\\Types\\SubscriptionStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/SubscriptionStatus.php',
    'Mollie\\Api\\Types\\TerminalStatus' => $vendorDir . '/mollie/mollie-api-php/src/Types/TerminalStatus.php',
    'Monolog\\Attribute\\AsMonologProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Attribute/AsMonologProcessor.php',
    'Monolog\\Attribute\\WithMonologChannel' => $vendorDir . '/monolog/monolog/src/Monolog/Attribute/WithMonologChannel.php',
    'Monolog\\DateTimeImmutable' => $vendorDir . '/monolog/monolog/src/Monolog/DateTimeImmutable.php',
    'Monolog\\ErrorHandler' => $vendorDir . '/monolog/monolog/src/Monolog/ErrorHandler.php',
    'Monolog\\Formatter\\ChromePHPFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/ChromePHPFormatter.php',
    'Monolog\\Formatter\\ElasticaFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/ElasticaFormatter.php',
    'Monolog\\Formatter\\ElasticsearchFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/ElasticsearchFormatter.php',
    'Monolog\\Formatter\\FlowdockFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/FlowdockFormatter.php',
    'Monolog\\Formatter\\FluentdFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/FluentdFormatter.php',
    'Monolog\\Formatter\\FormatterInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/FormatterInterface.php',
    'Monolog\\Formatter\\GelfMessageFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/GelfMessageFormatter.php',
    'Monolog\\Formatter\\GoogleCloudLoggingFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/GoogleCloudLoggingFormatter.php',
    'Monolog\\Formatter\\HtmlFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/HtmlFormatter.php',
    'Monolog\\Formatter\\JsonFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/JsonFormatter.php',
    'Monolog\\Formatter\\LineFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/LineFormatter.php',
    'Monolog\\Formatter\\LogglyFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/LogglyFormatter.php',
    'Monolog\\Formatter\\LogmaticFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/LogmaticFormatter.php',
    'Monolog\\Formatter\\LogstashFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/LogstashFormatter.php',
    'Monolog\\Formatter\\MongoDBFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/MongoDBFormatter.php',
    'Monolog\\Formatter\\NormalizerFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/NormalizerFormatter.php',
    'Monolog\\Formatter\\ScalarFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/ScalarFormatter.php',
    'Monolog\\Formatter\\SyslogFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/SyslogFormatter.php',
    'Monolog\\Formatter\\WildfireFormatter' => $vendorDir . '/monolog/monolog/src/Monolog/Formatter/WildfireFormatter.php',
    'Monolog\\Handler\\AbstractHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/AbstractHandler.php',
    'Monolog\\Handler\\AbstractProcessingHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/AbstractProcessingHandler.php',
    'Monolog\\Handler\\AbstractSyslogHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/AbstractSyslogHandler.php',
    'Monolog\\Handler\\AmqpHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/AmqpHandler.php',
    'Monolog\\Handler\\BrowserConsoleHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/BrowserConsoleHandler.php',
    'Monolog\\Handler\\BufferHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/BufferHandler.php',
    'Monolog\\Handler\\ChromePHPHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ChromePHPHandler.php',
    'Monolog\\Handler\\CouchDBHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/CouchDBHandler.php',
    'Monolog\\Handler\\CubeHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/CubeHandler.php',
    'Monolog\\Handler\\Curl\\Util' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/Curl/Util.php',
    'Monolog\\Handler\\DeduplicationHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/DeduplicationHandler.php',
    'Monolog\\Handler\\DoctrineCouchDBHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/DoctrineCouchDBHandler.php',
    'Monolog\\Handler\\DynamoDbHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/DynamoDbHandler.php',
    'Monolog\\Handler\\ElasticaHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ElasticaHandler.php',
    'Monolog\\Handler\\ElasticsearchHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ElasticsearchHandler.php',
    'Monolog\\Handler\\ErrorLogHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ErrorLogHandler.php',
    'Monolog\\Handler\\FallbackGroupHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FallbackGroupHandler.php',
    'Monolog\\Handler\\FilterHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FilterHandler.php',
    'Monolog\\Handler\\FingersCrossedHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossedHandler.php',
    'Monolog\\Handler\\FingersCrossed\\ActivationStrategyInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ActivationStrategyInterface.php',
    'Monolog\\Handler\\FingersCrossed\\ChannelLevelActivationStrategy' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ChannelLevelActivationStrategy.php',
    'Monolog\\Handler\\FingersCrossed\\ErrorLevelActivationStrategy' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ErrorLevelActivationStrategy.php',
    'Monolog\\Handler\\FirePHPHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FirePHPHandler.php',
    'Monolog\\Handler\\FleepHookHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FleepHookHandler.php',
    'Monolog\\Handler\\FlowdockHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FlowdockHandler.php',
    'Monolog\\Handler\\FormattableHandlerInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FormattableHandlerInterface.php',
    'Monolog\\Handler\\FormattableHandlerTrait' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/FormattableHandlerTrait.php',
    'Monolog\\Handler\\GelfHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/GelfHandler.php',
    'Monolog\\Handler\\GroupHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/GroupHandler.php',
    'Monolog\\Handler\\Handler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/Handler.php',
    'Monolog\\Handler\\HandlerInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/HandlerInterface.php',
    'Monolog\\Handler\\HandlerWrapper' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/HandlerWrapper.php',
    'Monolog\\Handler\\IFTTTHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/IFTTTHandler.php',
    'Monolog\\Handler\\InsightOpsHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/InsightOpsHandler.php',
    'Monolog\\Handler\\LogEntriesHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/LogEntriesHandler.php',
    'Monolog\\Handler\\LogglyHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/LogglyHandler.php',
    'Monolog\\Handler\\LogmaticHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/LogmaticHandler.php',
    'Monolog\\Handler\\MailHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/MailHandler.php',
    'Monolog\\Handler\\MandrillHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/MandrillHandler.php',
    'Monolog\\Handler\\MissingExtensionException' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/MissingExtensionException.php',
    'Monolog\\Handler\\MongoDBHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/MongoDBHandler.php',
    'Monolog\\Handler\\NativeMailerHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/NativeMailerHandler.php',
    'Monolog\\Handler\\NewRelicHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/NewRelicHandler.php',
    'Monolog\\Handler\\NoopHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/NoopHandler.php',
    'Monolog\\Handler\\NullHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/NullHandler.php',
    'Monolog\\Handler\\OverflowHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/OverflowHandler.php',
    'Monolog\\Handler\\PHPConsoleHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/PHPConsoleHandler.php',
    'Monolog\\Handler\\ProcessHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ProcessHandler.php',
    'Monolog\\Handler\\ProcessableHandlerInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ProcessableHandlerInterface.php',
    'Monolog\\Handler\\ProcessableHandlerTrait' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ProcessableHandlerTrait.php',
    'Monolog\\Handler\\PsrHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/PsrHandler.php',
    'Monolog\\Handler\\PushoverHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/PushoverHandler.php',
    'Monolog\\Handler\\RedisHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/RedisHandler.php',
    'Monolog\\Handler\\RedisPubSubHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/RedisPubSubHandler.php',
    'Monolog\\Handler\\RollbarHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/RollbarHandler.php',
    'Monolog\\Handler\\RotatingFileHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/RotatingFileHandler.php',
    'Monolog\\Handler\\SamplingHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SamplingHandler.php',
    'Monolog\\Handler\\SendGridHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SendGridHandler.php',
    'Monolog\\Handler\\SlackHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SlackHandler.php',
    'Monolog\\Handler\\SlackWebhookHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SlackWebhookHandler.php',
    'Monolog\\Handler\\Slack\\SlackRecord' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/Slack/SlackRecord.php',
    'Monolog\\Handler\\SocketHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SocketHandler.php',
    'Monolog\\Handler\\SqsHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SqsHandler.php',
    'Monolog\\Handler\\StreamHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/StreamHandler.php',
    'Monolog\\Handler\\SymfonyMailerHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SymfonyMailerHandler.php',
    'Monolog\\Handler\\SyslogHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SyslogHandler.php',
    'Monolog\\Handler\\SyslogUdpHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SyslogUdpHandler.php',
    'Monolog\\Handler\\SyslogUdp\\UdpSocket' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/SyslogUdp/UdpSocket.php',
    'Monolog\\Handler\\TelegramBotHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/TelegramBotHandler.php',
    'Monolog\\Handler\\TestHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/TestHandler.php',
    'Monolog\\Handler\\WebRequestRecognizerTrait' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/WebRequestRecognizerTrait.php',
    'Monolog\\Handler\\WhatFailureGroupHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/WhatFailureGroupHandler.php',
    'Monolog\\Handler\\ZendMonitorHandler' => $vendorDir . '/monolog/monolog/src/Monolog/Handler/ZendMonitorHandler.php',
    'Monolog\\Level' => $vendorDir . '/monolog/monolog/src/Monolog/Level.php',
    'Monolog\\LogRecord' => $vendorDir . '/monolog/monolog/src/Monolog/LogRecord.php',
    'Monolog\\Logger' => $vendorDir . '/monolog/monolog/src/Monolog/Logger.php',
    'Monolog\\Processor\\ClosureContextProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/ClosureContextProcessor.php',
    'Monolog\\Processor\\GitProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/GitProcessor.php',
    'Monolog\\Processor\\HostnameProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/HostnameProcessor.php',
    'Monolog\\Processor\\IntrospectionProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/IntrospectionProcessor.php',
    'Monolog\\Processor\\LoadAverageProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/LoadAverageProcessor.php',
    'Monolog\\Processor\\MemoryPeakUsageProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/MemoryPeakUsageProcessor.php',
    'Monolog\\Processor\\MemoryProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/MemoryProcessor.php',
    'Monolog\\Processor\\MemoryUsageProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/MemoryUsageProcessor.php',
    'Monolog\\Processor\\MercurialProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/MercurialProcessor.php',
    'Monolog\\Processor\\ProcessIdProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/ProcessIdProcessor.php',
    'Monolog\\Processor\\ProcessorInterface' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/ProcessorInterface.php',
    'Monolog\\Processor\\PsrLogMessageProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/PsrLogMessageProcessor.php',
    'Monolog\\Processor\\TagProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/TagProcessor.php',
    'Monolog\\Processor\\UidProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/UidProcessor.php',
    'Monolog\\Processor\\WebProcessor' => $vendorDir . '/monolog/monolog/src/Monolog/Processor/WebProcessor.php',
    'Monolog\\Registry' => $vendorDir . '/monolog/monolog/src/Monolog/Registry.php',
    'Monolog\\ResettableInterface' => $vendorDir . '/monolog/monolog/src/Monolog/ResettableInterface.php',
    'Monolog\\SignalHandler' => $vendorDir . '/monolog/monolog/src/Monolog/SignalHandler.php',
    'Monolog\\Test\\TestCase' => $vendorDir . '/monolog/monolog/src/Monolog/Test/TestCase.php',
    'Monolog\\Utils' => $vendorDir . '/monolog/monolog/src/Monolog/Utils.php',
    'Nette\\ArgumentOutOfRangeException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\DeprecatedException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\DirectoryNotFoundException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\FileNotFoundException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\HtmlStringable' => $vendorDir . '/nette/utils/src/HtmlStringable.php',
    'Nette\\IOException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\InvalidArgumentException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\InvalidStateException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\Iterators\\CachingIterator' => $vendorDir . '/nette/utils/src/Iterators/CachingIterator.php',
    'Nette\\Iterators\\Mapper' => $vendorDir . '/nette/utils/src/Iterators/Mapper.php',
    'Nette\\Localization\\ITranslator' => $vendorDir . '/nette/utils/src/compatibility.php',
    'Nette\\Localization\\Translator' => $vendorDir . '/nette/utils/src/Translator.php',
    'Nette\\MemberAccessException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\NotImplementedException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\NotSupportedException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\OutOfRangeException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\Schema\\Context' => $vendorDir . '/nette/schema/src/Schema/Context.php',
    'Nette\\Schema\\DynamicParameter' => $vendorDir . '/nette/schema/src/Schema/DynamicParameter.php',
    'Nette\\Schema\\Elements\\AnyOf' => $vendorDir . '/nette/schema/src/Schema/Elements/AnyOf.php',
    'Nette\\Schema\\Elements\\Base' => $vendorDir . '/nette/schema/src/Schema/Elements/Base.php',
    'Nette\\Schema\\Elements\\Structure' => $vendorDir . '/nette/schema/src/Schema/Elements/Structure.php',
    'Nette\\Schema\\Elements\\Type' => $vendorDir . '/nette/schema/src/Schema/Elements/Type.php',
    'Nette\\Schema\\Expect' => $vendorDir . '/nette/schema/src/Schema/Expect.php',
    'Nette\\Schema\\Helpers' => $vendorDir . '/nette/schema/src/Schema/Helpers.php',
    'Nette\\Schema\\Message' => $vendorDir . '/nette/schema/src/Schema/Message.php',
    'Nette\\Schema\\Processor' => $vendorDir . '/nette/schema/src/Schema/Processor.php',
    'Nette\\Schema\\Schema' => $vendorDir . '/nette/schema/src/Schema/Schema.php',
    'Nette\\Schema\\ValidationException' => $vendorDir . '/nette/schema/src/Schema/ValidationException.php',
    'Nette\\SmartObject' => $vendorDir . '/nette/utils/src/SmartObject.php',
    'Nette\\StaticClass' => $vendorDir . '/nette/utils/src/StaticClass.php',
    'Nette\\UnexpectedValueException' => $vendorDir . '/nette/utils/src/exceptions.php',
    'Nette\\Utils\\ArrayHash' => $vendorDir . '/nette/utils/src/Utils/ArrayHash.php',
    'Nette\\Utils\\ArrayList' => $vendorDir . '/nette/utils/src/Utils/ArrayList.php',
    'Nette\\Utils\\Arrays' => $vendorDir . '/nette/utils/src/Utils/Arrays.php',
    'Nette\\Utils\\AssertionException' => $vendorDir . '/nette/utils/src/Utils/exceptions.php',
    'Nette\\Utils\\Callback' => $vendorDir . '/nette/utils/src/Utils/Callback.php',
    'Nette\\Utils\\DateTime' => $vendorDir . '/nette/utils/src/Utils/DateTime.php',
    'Nette\\Utils\\FileInfo' => $vendorDir . '/nette/utils/src/Utils/FileInfo.php',
    'Nette\\Utils\\FileSystem' => $vendorDir . '/nette/utils/src/Utils/FileSystem.php',
    'Nette\\Utils\\Finder' => $vendorDir . '/nette/utils/src/Utils/Finder.php',
    'Nette\\Utils\\Floats' => $vendorDir . '/nette/utils/src/Utils/Floats.php',
    'Nette\\Utils\\Helpers' => $vendorDir . '/nette/utils/src/Utils/Helpers.php',
    'Nette\\Utils\\Html' => $vendorDir . '/nette/utils/src/Utils/Html.php',
    'Nette\\Utils\\IHtmlString' => $vendorDir . '/nette/utils/src/compatibility.php',
    'Nette\\Utils\\Image' => $vendorDir . '/nette/utils/src/Utils/Image.php',
    'Nette\\Utils\\ImageColor' => $vendorDir . '/nette/utils/src/Utils/ImageColor.php',
    'Nette\\Utils\\ImageException' => $vendorDir . '/nette/utils/src/Utils/exceptions.php',
    'Nette\\Utils\\ImageType' => $vendorDir . '/nette/utils/src/Utils/ImageType.php',
    'Nette\\Utils\\Iterables' => $vendorDir . '/nette/utils/src/Utils/Iterables.php',
    'Nette\\Utils\\Json' => $vendorDir . '/nette/utils/src/Utils/Json.php',
    'Nette\\Utils\\JsonException' => $vendorDir . '/nette/utils/src/Utils/exceptions.php',
    'Nette\\Utils\\ObjectHelpers' => $vendorDir . '/nette/utils/src/Utils/ObjectHelpers.php',
    'Nette\\Utils\\Paginator' => $vendorDir . '/nette/utils/src/Utils/Paginator.php',
    'Nette\\Utils\\Random' => $vendorDir . '/nette/utils/src/Utils/Random.php',
    'Nette\\Utils\\Reflection' => $vendorDir . '/nette/utils/src/Utils/Reflection.php',
    'Nette\\Utils\\ReflectionMethod' => $vendorDir . '/nette/utils/src/Utils/ReflectionMethod.php',
    'Nette\\Utils\\RegexpException' => $vendorDir . '/nette/utils/src/Utils/exceptions.php',
    'Nette\\Utils\\Strings' => $vendorDir . '/nette/utils/src/Utils/Strings.php',
    'Nette\\Utils\\Type' => $vendorDir . '/nette/utils/src/Utils/Type.php',
    'Nette\\Utils\\UnknownImageFileException' => $vendorDir . '/nette/utils/src/Utils/exceptions.php',
    'Nette\\Utils\\Validators' => $vendorDir . '/nette/utils/src/Utils/Validators.php',
    'Normalizer' => $vendorDir . '/symfony/polyfill-intl-normalizer/Resources/stubs/Normalizer.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\CollisionServiceProvider' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/CollisionServiceProvider.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\Commands\\TestCommand' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/Commands/TestCommand.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\ExceptionHandler' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/ExceptionHandler.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\Exceptions\\NotSupportedYetException' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/Exceptions/NotSupportedYetException.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\Exceptions\\RequirementsException' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/Exceptions/RequirementsException.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\IgnitionSolutionsRepository' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/IgnitionSolutionsRepository.php',
    'NunoMaduro\\Collision\\Adapters\\Laravel\\Inspector' => $vendorDir . '/nunomaduro/collision/src/Adapters/Laravel/Inspector.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\ConfigureIO' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/ConfigureIO.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Printers\\DefaultPrinter' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Printers/DefaultPrinter.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Printers\\ReportablePrinter' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Printers/ReportablePrinter.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\State' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/State.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Style' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Style.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Subscribers\\EnsurePrinterIsRegisteredSubscriber' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Subscribers/EnsurePrinterIsRegisteredSubscriber.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Subscribers\\Subscriber' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Subscribers/Subscriber.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\Support\\ResultReflection' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/Support/ResultReflection.php',
    'NunoMaduro\\Collision\\Adapters\\Phpunit\\TestResult' => $vendorDir . '/nunomaduro/collision/src/Adapters/Phpunit/TestResult.php',
    'NunoMaduro\\Collision\\ArgumentFormatter' => $vendorDir . '/nunomaduro/collision/src/ArgumentFormatter.php',
    'NunoMaduro\\Collision\\ConsoleColor' => $vendorDir . '/nunomaduro/collision/src/ConsoleColor.php',
    'NunoMaduro\\Collision\\Contracts\\Adapters\\Phpunit\\HasPrintableTestCaseName' => $vendorDir . '/nunomaduro/collision/src/Contracts/Adapters/Phpunit/HasPrintableTestCaseName.php',
    'NunoMaduro\\Collision\\Contracts\\RenderableOnCollisionEditor' => $vendorDir . '/nunomaduro/collision/src/Contracts/RenderableOnCollisionEditor.php',
    'NunoMaduro\\Collision\\Contracts\\RenderlessEditor' => $vendorDir . '/nunomaduro/collision/src/Contracts/RenderlessEditor.php',
    'NunoMaduro\\Collision\\Contracts\\RenderlessTrace' => $vendorDir . '/nunomaduro/collision/src/Contracts/RenderlessTrace.php',
    'NunoMaduro\\Collision\\Contracts\\SolutionsRepository' => $vendorDir . '/nunomaduro/collision/src/Contracts/SolutionsRepository.php',
    'NunoMaduro\\Collision\\Coverage' => $vendorDir . '/nunomaduro/collision/src/Coverage.php',
    'NunoMaduro\\Collision\\Exceptions\\InvalidStyleException' => $vendorDir . '/nunomaduro/collision/src/Exceptions/InvalidStyleException.php',
    'NunoMaduro\\Collision\\Exceptions\\ShouldNotHappen' => $vendorDir . '/nunomaduro/collision/src/Exceptions/ShouldNotHappen.php',
    'NunoMaduro\\Collision\\Exceptions\\TestException' => $vendorDir . '/nunomaduro/collision/src/Exceptions/TestException.php',
    'NunoMaduro\\Collision\\Exceptions\\TestOutcome' => $vendorDir . '/nunomaduro/collision/src/Exceptions/TestOutcome.php',
    'NunoMaduro\\Collision\\Handler' => $vendorDir . '/nunomaduro/collision/src/Handler.php',
    'NunoMaduro\\Collision\\Highlighter' => $vendorDir . '/nunomaduro/collision/src/Highlighter.php',
    'NunoMaduro\\Collision\\Provider' => $vendorDir . '/nunomaduro/collision/src/Provider.php',
    'NunoMaduro\\Collision\\SolutionsRepositories\\NullSolutionsRepository' => $vendorDir . '/nunomaduro/collision/src/SolutionsRepositories/NullSolutionsRepository.php',
    'NunoMaduro\\Collision\\Writer' => $vendorDir . '/nunomaduro/collision/src/Writer.php',
    'Nwidart\\Modules\\Activators\\FileActivator' => $vendorDir . '/nwidart/laravel-modules/src/Activators/FileActivator.php',
    'Nwidart\\Modules\\Collection' => $vendorDir . '/nwidart/laravel-modules/src/Collection.php',
    'Nwidart\\Modules\\Commands\\Actions\\CheckLangCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/CheckLangCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\DisableCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/DisableCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\DumpCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/DumpCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\EnableCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/EnableCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\InstallCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/InstallCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\ListCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/ListCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\ModelPruneCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/ModelPruneCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\ModelShowCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/ModelShowCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\ModuleDeleteCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/ModuleDeleteCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\UnUseCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/UnUseCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\UpdateCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/UpdateCommand.php',
    'Nwidart\\Modules\\Commands\\Actions\\UseCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Actions/UseCommand.php',
    'Nwidart\\Modules\\Commands\\BaseCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/BaseCommand.php',
    'Nwidart\\Modules\\Commands\\ComposerUpdateCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/ComposerUpdateCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateFreshCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateFreshCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateRefreshCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateRefreshCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateResetCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateResetCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateRollbackCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateRollbackCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\MigrateStatusCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/MigrateStatusCommand.php',
    'Nwidart\\Modules\\Commands\\Database\\SeedCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Database/SeedCommand.php',
    'Nwidart\\Modules\\Commands\\LaravelModulesV6Migrator' => $vendorDir . '/nwidart/laravel-modules/src/Commands/LaravelModulesV6Migrator.php',
    'Nwidart\\Modules\\Commands\\Make\\ActionMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ActionMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\CastMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/CastMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ChannelMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ChannelMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ClassMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ClassMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\CommandMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/CommandMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ComponentClassMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ComponentClassMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ComponentViewMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ComponentViewMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ControllerMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ControllerMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\EnumMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/EnumMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\EventMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/EventMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\EventProviderMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/EventProviderMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ExceptionMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ExceptionMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\FactoryMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/FactoryMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\GeneratorCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/GeneratorCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\HelperMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/HelperMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\InterfaceMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/InterfaceMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\JobMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/JobMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ListenerMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ListenerMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\MailMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/MailMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\MiddlewareMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/MiddlewareMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\MigrationMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/MigrationMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ModelMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ModelMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ModuleMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ModuleMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\NotificationMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/NotificationMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ObserverMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ObserverMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\PolicyMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/PolicyMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ProviderMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ProviderMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\RepositoryMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/RepositoryMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\RequestMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/RequestMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ResourceMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ResourceMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\RouteProviderMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/RouteProviderMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\RuleMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/RuleMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ScopeMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ScopeMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\SeedMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/SeedMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ServiceMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ServiceMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\TestMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/TestMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\TraitMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/TraitMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Make\\ViewMakeCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Make/ViewMakeCommand.php',
    'Nwidart\\Modules\\Commands\\Publish\\PublishCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Publish/PublishCommand.php',
    'Nwidart\\Modules\\Commands\\Publish\\PublishConfigurationCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Publish/PublishConfigurationCommand.php',
    'Nwidart\\Modules\\Commands\\Publish\\PublishMigrationCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Publish/PublishMigrationCommand.php',
    'Nwidart\\Modules\\Commands\\Publish\\PublishTranslationCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/Publish/PublishTranslationCommand.php',
    'Nwidart\\Modules\\Commands\\SetupCommand' => $vendorDir . '/nwidart/laravel-modules/src/Commands/SetupCommand.php',
    'Nwidart\\Modules\\Contracts\\ActivatorInterface' => $vendorDir . '/nwidart/laravel-modules/src/Contracts/ActivatorInterface.php',
    'Nwidart\\Modules\\Contracts\\ConfirmableCommand' => $vendorDir . '/nwidart/laravel-modules/src/Contracts/ConfirmableCommand.php',
    'Nwidart\\Modules\\Contracts\\PublisherInterface' => $vendorDir . '/nwidart/laravel-modules/src/Contracts/PublisherInterface.php',
    'Nwidart\\Modules\\Contracts\\RepositoryInterface' => $vendorDir . '/nwidart/laravel-modules/src/Contracts/RepositoryInterface.php',
    'Nwidart\\Modules\\Contracts\\RunableInterface' => $vendorDir . '/nwidart/laravel-modules/src/Contracts/RunableInterface.php',
    'Nwidart\\Modules\\Exceptions\\FileAlreadyExistException' => $vendorDir . '/nwidart/laravel-modules/src/Exceptions/FileAlreadyExistException.php',
    'Nwidart\\Modules\\Exceptions\\InvalidActivatorClass' => $vendorDir . '/nwidart/laravel-modules/src/Exceptions/InvalidActivatorClass.php',
    'Nwidart\\Modules\\Exceptions\\InvalidAssetPath' => $vendorDir . '/nwidart/laravel-modules/src/Exceptions/InvalidAssetPath.php',
    'Nwidart\\Modules\\Exceptions\\InvalidJsonException' => $vendorDir . '/nwidart/laravel-modules/src/Exceptions/InvalidJsonException.php',
    'Nwidart\\Modules\\Exceptions\\ModuleNotFoundException' => $vendorDir . '/nwidart/laravel-modules/src/Exceptions/ModuleNotFoundException.php',
    'Nwidart\\Modules\\Facades\\Module' => $vendorDir . '/nwidart/laravel-modules/src/Facades/Module.php',
    'Nwidart\\Modules\\FileRepository' => $vendorDir . '/nwidart/laravel-modules/src/FileRepository.php',
    'Nwidart\\Modules\\Generators\\FileGenerator' => $vendorDir . '/nwidart/laravel-modules/src/Generators/FileGenerator.php',
    'Nwidart\\Modules\\Generators\\Generator' => $vendorDir . '/nwidart/laravel-modules/src/Generators/Generator.php',
    'Nwidart\\Modules\\Generators\\ModuleGenerator' => $vendorDir . '/nwidart/laravel-modules/src/Generators/ModuleGenerator.php',
    'Nwidart\\Modules\\Json' => $vendorDir . '/nwidart/laravel-modules/src/Json.php',
    'Nwidart\\Modules\\LaravelModulesServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/LaravelModulesServiceProvider.php',
    'Nwidart\\Modules\\Laravel\\LaravelFileRepository' => $vendorDir . '/nwidart/laravel-modules/src/Laravel/LaravelFileRepository.php',
    'Nwidart\\Modules\\Laravel\\Module' => $vendorDir . '/nwidart/laravel-modules/src/Laravel/Module.php',
    'Nwidart\\Modules\\LumenModulesServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/LumenModulesServiceProvider.php',
    'Nwidart\\Modules\\Lumen\\LumenFileRepository' => $vendorDir . '/nwidart/laravel-modules/src/Lumen/LumenFileRepository.php',
    'Nwidart\\Modules\\Lumen\\Module' => $vendorDir . '/nwidart/laravel-modules/src/Lumen/Module.php',
    'Nwidart\\Modules\\Migrations\\Migrator' => $vendorDir . '/nwidart/laravel-modules/src/Migrations/Migrator.php',
    'Nwidart\\Modules\\Module' => $vendorDir . '/nwidart/laravel-modules/src/Module.php',
    'Nwidart\\Modules\\ModulesServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/ModulesServiceProvider.php',
    'Nwidart\\Modules\\Process\\Installer' => $vendorDir . '/nwidart/laravel-modules/src/Process/Installer.php',
    'Nwidart\\Modules\\Process\\Runner' => $vendorDir . '/nwidart/laravel-modules/src/Process/Runner.php',
    'Nwidart\\Modules\\Process\\Updater' => $vendorDir . '/nwidart/laravel-modules/src/Process/Updater.php',
    'Nwidart\\Modules\\Providers\\BootstrapServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/Providers/BootstrapServiceProvider.php',
    'Nwidart\\Modules\\Providers\\ConsoleServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/Providers/ConsoleServiceProvider.php',
    'Nwidart\\Modules\\Providers\\ContractsServiceProvider' => $vendorDir . '/nwidart/laravel-modules/src/Providers/ContractsServiceProvider.php',
    'Nwidart\\Modules\\Publishing\\AssetPublisher' => $vendorDir . '/nwidart/laravel-modules/src/Publishing/AssetPublisher.php',
    'Nwidart\\Modules\\Publishing\\LangPublisher' => $vendorDir . '/nwidart/laravel-modules/src/Publishing/LangPublisher.php',
    'Nwidart\\Modules\\Publishing\\MigrationPublisher' => $vendorDir . '/nwidart/laravel-modules/src/Publishing/MigrationPublisher.php',
    'Nwidart\\Modules\\Publishing\\Publisher' => $vendorDir . '/nwidart/laravel-modules/src/Publishing/Publisher.php',
    'Nwidart\\Modules\\Routing\\Controller' => $vendorDir . '/nwidart/laravel-modules/src/Routing/Controller.php',
    'Nwidart\\Modules\\Support\\Config\\GenerateConfigReader' => $vendorDir . '/nwidart/laravel-modules/src/Support/Config/GenerateConfigReader.php',
    'Nwidart\\Modules\\Support\\Config\\GeneratorPath' => $vendorDir . '/nwidart/laravel-modules/src/Support/Config/GeneratorPath.php',
    'Nwidart\\Modules\\Support\\Migrations\\NameParser' => $vendorDir . '/nwidart/laravel-modules/src/Support/Migrations/NameParser.php',
    'Nwidart\\Modules\\Support\\Migrations\\SchemaParser' => $vendorDir . '/nwidart/laravel-modules/src/Support/Migrations/SchemaParser.php',
    'Nwidart\\Modules\\Support\\Stub' => $vendorDir . '/nwidart/laravel-modules/src/Support/Stub.php',
    'Nwidart\\Modules\\Traits\\CanClearModulesCache' => $vendorDir . '/nwidart/laravel-modules/src/Traits/CanClearModulesCache.php',
    'Nwidart\\Modules\\Traits\\MigrationLoaderTrait' => $vendorDir . '/nwidart/laravel-modules/src/Traits/MigrationLoaderTrait.php',
    'Nwidart\\Modules\\Traits\\ModuleCommandTrait' => $vendorDir . '/nwidart/laravel-modules/src/Traits/ModuleCommandTrait.php',
    'Nwidart\\Modules\\Traits\\PathNamespace' => $vendorDir . '/nwidart/laravel-modules/src/Traits/PathNamespace.php',
    'Obydul\\LaraSkrill\\LaraSkrillServiceProvider' => $vendorDir . '/obydul/laraskrill/src/LaraSkrillServiceProvider.php',
    'Obydul\\LaraSkrill\\SkrillClient' => $vendorDir . '/obydul/laraskrill/src/SkrillClient.php',
    'Obydul\\LaraSkrill\\SkrillRequest' => $vendorDir . '/obydul/laraskrill/src/SkrillRequest.php',
    'Orhanerday\\OpenAi\\OpenAi' => $vendorDir . '/orhanerday/open-ai/src/OpenAi.php',
    'Orhanerday\\OpenAi\\Url' => $vendorDir . '/orhanerday/open-ai/src/Url.php',
    'Override' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/Override.php',
    'PHPUnit\\Event\\Application\\Finished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Application/Finished.php',
    'PHPUnit\\Event\\Application\\FinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Application/FinishedSubscriber.php',
    'PHPUnit\\Event\\Application\\Started' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Application/Started.php',
    'PHPUnit\\Event\\Application\\StartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Application/StartedSubscriber.php',
    'PHPUnit\\Event\\Code\\ClassMethod' => $vendorDir . '/phpunit/phpunit/src/Event/Value/ClassMethod.php',
    'PHPUnit\\Event\\Code\\ComparisonFailure' => $vendorDir . '/phpunit/phpunit/src/Event/Value/ComparisonFailure.php',
    'PHPUnit\\Event\\Code\\ComparisonFailureBuilder' => $vendorDir . '/phpunit/phpunit/src/Event/Value/ComparisonFailureBuilder.php',
    'PHPUnit\\Event\\Code\\IssueTrigger\\DirectTrigger' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Issue/DirectTrigger.php',
    'PHPUnit\\Event\\Code\\IssueTrigger\\IndirectTrigger' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Issue/IndirectTrigger.php',
    'PHPUnit\\Event\\Code\\IssueTrigger\\IssueTrigger' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Issue/IssueTrigger.php',
    'PHPUnit\\Event\\Code\\IssueTrigger\\SelfTrigger' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Issue/SelfTrigger.php',
    'PHPUnit\\Event\\Code\\IssueTrigger\\UnknownTrigger' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Issue/UnknownTrigger.php',
    'PHPUnit\\Event\\Code\\NoTestCaseObjectOnCallStackException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/NoTestCaseObjectOnCallStackException.php',
    'PHPUnit\\Event\\Code\\Phpt' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Phpt.php',
    'PHPUnit\\Event\\Code\\Test' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/Test.php',
    'PHPUnit\\Event\\Code\\TestCollection' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestCollection.php',
    'PHPUnit\\Event\\Code\\TestCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestCollectionIterator.php',
    'PHPUnit\\Event\\Code\\TestDox' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestDox.php',
    'PHPUnit\\Event\\Code\\TestDoxBuilder' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestDoxBuilder.php',
    'PHPUnit\\Event\\Code\\TestMethod' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestMethod.php',
    'PHPUnit\\Event\\Code\\TestMethodBuilder' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestMethodBuilder.php',
    'PHPUnit\\Event\\Code\\Throwable' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Throwable.php',
    'PHPUnit\\Event\\Code\\ThrowableBuilder' => $vendorDir . '/phpunit/phpunit/src/Event/Value/ThrowableBuilder.php',
    'PHPUnit\\Event\\CollectingDispatcher' => $vendorDir . '/phpunit/phpunit/src/Event/Dispatcher/CollectingDispatcher.php',
    'PHPUnit\\Event\\DeferringDispatcher' => $vendorDir . '/phpunit/phpunit/src/Event/Dispatcher/DeferringDispatcher.php',
    'PHPUnit\\Event\\DirectDispatcher' => $vendorDir . '/phpunit/phpunit/src/Event/Dispatcher/DirectDispatcher.php',
    'PHPUnit\\Event\\Dispatcher' => $vendorDir . '/phpunit/phpunit/src/Event/Dispatcher/Dispatcher.php',
    'PHPUnit\\Event\\DispatchingEmitter' => $vendorDir . '/phpunit/phpunit/src/Event/Emitter/DispatchingEmitter.php',
    'PHPUnit\\Event\\Emitter' => $vendorDir . '/phpunit/phpunit/src/Event/Emitter/Emitter.php',
    'PHPUnit\\Event\\Event' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Event.php',
    'PHPUnit\\Event\\EventAlreadyAssignedException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/EventAlreadyAssignedException.php',
    'PHPUnit\\Event\\EventCollection' => $vendorDir . '/phpunit/phpunit/src/Event/Events/EventCollection.php',
    'PHPUnit\\Event\\EventCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/Event/Events/EventCollectionIterator.php',
    'PHPUnit\\Event\\EventFacadeIsSealedException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/EventFacadeIsSealedException.php',
    'PHPUnit\\Event\\Exception' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/Exception.php',
    'PHPUnit\\Event\\Facade' => $vendorDir . '/phpunit/phpunit/src/Event/Facade.php',
    'PHPUnit\\Event\\InvalidArgumentException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/InvalidArgumentException.php',
    'PHPUnit\\Event\\InvalidEventException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/InvalidEventException.php',
    'PHPUnit\\Event\\InvalidSubscriberException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/InvalidSubscriberException.php',
    'PHPUnit\\Event\\MapError' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/MapError.php',
    'PHPUnit\\Event\\NoPreviousThrowableException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/NoPreviousThrowableException.php',
    'PHPUnit\\Event\\RuntimeException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/RuntimeException.php',
    'PHPUnit\\Event\\Runtime\\OperatingSystem' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Runtime/OperatingSystem.php',
    'PHPUnit\\Event\\Runtime\\PHP' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Runtime/PHP.php',
    'PHPUnit\\Event\\Runtime\\PHPUnit' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Runtime/PHPUnit.php',
    'PHPUnit\\Event\\Runtime\\Runtime' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Runtime/Runtime.php',
    'PHPUnit\\Event\\SubscribableDispatcher' => $vendorDir . '/phpunit/phpunit/src/Event/Dispatcher/SubscribableDispatcher.php',
    'PHPUnit\\Event\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Subscriber.php',
    'PHPUnit\\Event\\SubscriberTypeAlreadyRegisteredException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/SubscriberTypeAlreadyRegisteredException.php',
    'PHPUnit\\Event\\Telemetry\\Duration' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/Duration.php',
    'PHPUnit\\Event\\Telemetry\\GarbageCollectorStatus' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/GarbageCollectorStatus.php',
    'PHPUnit\\Event\\Telemetry\\GarbageCollectorStatusProvider' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/GarbageCollectorStatusProvider.php',
    'PHPUnit\\Event\\Telemetry\\HRTime' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/HRTime.php',
    'PHPUnit\\Event\\Telemetry\\Info' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/Info.php',
    'PHPUnit\\Event\\Telemetry\\MemoryMeter' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/MemoryMeter.php',
    'PHPUnit\\Event\\Telemetry\\MemoryUsage' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/MemoryUsage.php',
    'PHPUnit\\Event\\Telemetry\\Php81GarbageCollectorStatusProvider' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/Php81GarbageCollectorStatusProvider.php',
    'PHPUnit\\Event\\Telemetry\\Php83GarbageCollectorStatusProvider' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/Php83GarbageCollectorStatusProvider.php',
    'PHPUnit\\Event\\Telemetry\\Snapshot' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/Snapshot.php',
    'PHPUnit\\Event\\Telemetry\\StopWatch' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/StopWatch.php',
    'PHPUnit\\Event\\Telemetry\\System' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/System.php',
    'PHPUnit\\Event\\Telemetry\\SystemMemoryMeter' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/SystemMemoryMeter.php',
    'PHPUnit\\Event\\Telemetry\\SystemStopWatch' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/SystemStopWatch.php',
    'PHPUnit\\Event\\Telemetry\\SystemStopWatchWithOffset' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Telemetry/SystemStopWatchWithOffset.php',
    'PHPUnit\\Event\\TestData\\DataFromDataProvider' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestData/DataFromDataProvider.php',
    'PHPUnit\\Event\\TestData\\DataFromTestDependency' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestData/DataFromTestDependency.php',
    'PHPUnit\\Event\\TestData\\NoDataSetFromDataProviderException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/NoDataSetFromDataProviderException.php',
    'PHPUnit\\Event\\TestData\\TestData' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestData/TestData.php',
    'PHPUnit\\Event\\TestData\\TestDataCollection' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestData/TestDataCollection.php',
    'PHPUnit\\Event\\TestData\\TestDataCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/Event/Value/Test/TestData/TestDataCollectionIterator.php',
    'PHPUnit\\Event\\TestRunner\\BootstrapFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/BootstrapFinished.php',
    'PHPUnit\\Event\\TestRunner\\BootstrapFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/BootstrapFinishedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\Configured' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/Configured.php',
    'PHPUnit\\Event\\TestRunner\\ConfiguredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ConfiguredSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\DeprecationTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/DeprecationTriggered.php',
    'PHPUnit\\Event\\TestRunner\\DeprecationTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/DeprecationTriggeredSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\EventFacadeSealed' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/EventFacadeSealed.php',
    'PHPUnit\\Event\\TestRunner\\EventFacadeSealedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/EventFacadeSealedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionAborted' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionAborted.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionAbortedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionAbortedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionFinished.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionFinishedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionStarted' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionStarted.php',
    'PHPUnit\\Event\\TestRunner\\ExecutionStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExecutionStartedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\ExtensionBootstrapped' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExtensionBootstrapped.php',
    'PHPUnit\\Event\\TestRunner\\ExtensionBootstrappedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExtensionBootstrappedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\ExtensionLoadedFromPhar' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExtensionLoadedFromPhar.php',
    'PHPUnit\\Event\\TestRunner\\ExtensionLoadedFromPharSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/ExtensionLoadedFromPharSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\Finished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/Finished.php',
    'PHPUnit\\Event\\TestRunner\\FinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/FinishedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionDisabled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionDisabled.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionDisabledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionDisabledSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionEnabled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionEnabled.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionEnabledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionEnabledSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionTriggered.php',
    'PHPUnit\\Event\\TestRunner\\GarbageCollectionTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/GarbageCollectionTriggeredSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\Started' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/Started.php',
    'PHPUnit\\Event\\TestRunner\\StartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/StartedSubscriber.php',
    'PHPUnit\\Event\\TestRunner\\WarningTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/WarningTriggered.php',
    'PHPUnit\\Event\\TestRunner\\WarningTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestRunner/WarningTriggeredSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Filtered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Filtered.php',
    'PHPUnit\\Event\\TestSuite\\FilteredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/FilteredSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Finished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Finished.php',
    'PHPUnit\\Event\\TestSuite\\FinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/FinishedSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Loaded' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Loaded.php',
    'PHPUnit\\Event\\TestSuite\\LoadedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/LoadedSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Skipped' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Skipped.php',
    'PHPUnit\\Event\\TestSuite\\SkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/SkippedSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Sorted' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Sorted.php',
    'PHPUnit\\Event\\TestSuite\\SortedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/SortedSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\Started' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/Started.php',
    'PHPUnit\\Event\\TestSuite\\StartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/TestSuite/StartedSubscriber.php',
    'PHPUnit\\Event\\TestSuite\\TestSuite' => $vendorDir . '/phpunit/phpunit/src/Event/Value/TestSuite/TestSuite.php',
    'PHPUnit\\Event\\TestSuite\\TestSuiteBuilder' => $vendorDir . '/phpunit/phpunit/src/Event/Value/TestSuite/TestSuiteBuilder.php',
    'PHPUnit\\Event\\TestSuite\\TestSuiteForTestClass' => $vendorDir . '/phpunit/phpunit/src/Event/Value/TestSuite/TestSuiteForTestClass.php',
    'PHPUnit\\Event\\TestSuite\\TestSuiteForTestMethodWithDataProvider' => $vendorDir . '/phpunit/phpunit/src/Event/Value/TestSuite/TestSuiteForTestMethodWithDataProvider.php',
    'PHPUnit\\Event\\TestSuite\\TestSuiteWithName' => $vendorDir . '/phpunit/phpunit/src/Event/Value/TestSuite/TestSuiteWithName.php',
    'PHPUnit\\Event\\Test\\AfterLastTestMethodCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterLastTestMethodCalled.php',
    'PHPUnit\\Event\\Test\\AfterLastTestMethodCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterLastTestMethodCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\AfterLastTestMethodFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterLastTestMethodFinished.php',
    'PHPUnit\\Event\\Test\\AfterLastTestMethodFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterLastTestMethodFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\AfterTestMethodCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterTestMethodCalled.php',
    'PHPUnit\\Event\\Test\\AfterTestMethodCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterTestMethodCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\AfterTestMethodFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterTestMethodFinished.php',
    'PHPUnit\\Event\\Test\\AfterTestMethodFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/AfterTestMethodFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodCalled.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodErrored' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodErrored.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodErroredSubscriber.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodFinished.php',
    'PHPUnit\\Event\\Test\\BeforeFirstTestMethodFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeFirstTestMethodFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\BeforeTestMethodCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeTestMethodCalled.php',
    'PHPUnit\\Event\\Test\\BeforeTestMethodCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeTestMethodCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\BeforeTestMethodFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeTestMethodFinished.php',
    'PHPUnit\\Event\\Test\\BeforeTestMethodFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/BeforeTestMethodFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\ComparatorRegistered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/ComparatorRegistered.php',
    'PHPUnit\\Event\\Test\\ComparatorRegisteredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/ComparatorRegisteredSubscriber.php',
    'PHPUnit\\Event\\Test\\ConsideredRisky' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/ConsideredRisky.php',
    'PHPUnit\\Event\\Test\\ConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/ConsideredRiskySubscriber.php',
    'PHPUnit\\Event\\Test\\DataProviderMethodCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/DataProviderMethodCalled.php',
    'PHPUnit\\Event\\Test\\DataProviderMethodCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/DataProviderMethodCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\DataProviderMethodFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/DataProviderMethodFinished.php',
    'PHPUnit\\Event\\Test\\DataProviderMethodFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/DataProviderMethodFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\DeprecationTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/DeprecationTriggered.php',
    'PHPUnit\\Event\\Test\\DeprecationTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/DeprecationTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\ErrorTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/ErrorTriggered.php',
    'PHPUnit\\Event\\Test\\ErrorTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/ErrorTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\Errored' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/Errored.php',
    'PHPUnit\\Event\\Test\\ErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/ErroredSubscriber.php',
    'PHPUnit\\Event\\Test\\Failed' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/Failed.php',
    'PHPUnit\\Event\\Test\\FailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/FailedSubscriber.php',
    'PHPUnit\\Event\\Test\\Finished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/Finished.php',
    'PHPUnit\\Event\\Test\\FinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/FinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\MarkedIncomplete' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/MarkedIncomplete.php',
    'PHPUnit\\Event\\Test\\MarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/MarkedIncompleteSubscriber.php',
    'PHPUnit\\Event\\Test\\MockObjectCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectCreated.php',
    'PHPUnit\\Event\\Test\\MockObjectCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\MockObjectForAbstractClassCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForAbstractClassCreated.php',
    'PHPUnit\\Event\\Test\\MockObjectForAbstractClassCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForAbstractClassCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\MockObjectForIntersectionOfInterfacesCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForIntersectionOfInterfacesCreated.php',
    'PHPUnit\\Event\\Test\\MockObjectForIntersectionOfInterfacesCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForIntersectionOfInterfacesCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\MockObjectForTraitCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForTraitCreated.php',
    'PHPUnit\\Event\\Test\\MockObjectForTraitCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectForTraitCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\MockObjectFromWsdlCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectFromWsdlCreated.php',
    'PHPUnit\\Event\\Test\\MockObjectFromWsdlCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/MockObjectFromWsdlCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\NoComparisonFailureException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/NoComparisonFailureException.php',
    'PHPUnit\\Event\\Test\\NoticeTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/NoticeTriggered.php',
    'PHPUnit\\Event\\Test\\NoticeTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/NoticeTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PartialMockObjectCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/PartialMockObjectCreated.php',
    'PHPUnit\\Event\\Test\\PartialMockObjectCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/PartialMockObjectCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\Passed' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/Passed.php',
    'PHPUnit\\Event\\Test\\PassedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/PassedSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpDeprecationTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpDeprecationTriggered.php',
    'PHPUnit\\Event\\Test\\PhpDeprecationTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpDeprecationTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpNoticeTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpNoticeTriggered.php',
    'PHPUnit\\Event\\Test\\PhpNoticeTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpNoticeTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpWarningTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpWarningTriggered.php',
    'PHPUnit\\Event\\Test\\PhpWarningTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpWarningTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpunitDeprecationTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitDeprecationTriggered.php',
    'PHPUnit\\Event\\Test\\PhpunitDeprecationTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitDeprecationTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpunitErrorTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitErrorTriggered.php',
    'PHPUnit\\Event\\Test\\PhpunitErrorTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitErrorTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PhpunitWarningTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitWarningTriggered.php',
    'PHPUnit\\Event\\Test\\PhpunitWarningTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/PhpunitWarningTriggeredSubscriber.php',
    'PHPUnit\\Event\\Test\\PostConditionCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PostConditionCalled.php',
    'PHPUnit\\Event\\Test\\PostConditionCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PostConditionCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\PostConditionFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PostConditionFinished.php',
    'PHPUnit\\Event\\Test\\PostConditionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PostConditionFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\PreConditionCalled' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PreConditionCalled.php',
    'PHPUnit\\Event\\Test\\PreConditionCalledSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PreConditionCalledSubscriber.php',
    'PHPUnit\\Event\\Test\\PreConditionFinished' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PreConditionFinished.php',
    'PHPUnit\\Event\\Test\\PreConditionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/HookMethod/PreConditionFinishedSubscriber.php',
    'PHPUnit\\Event\\Test\\PreparationFailed' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/PreparationFailed.php',
    'PHPUnit\\Event\\Test\\PreparationFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/PreparationFailedSubscriber.php',
    'PHPUnit\\Event\\Test\\PreparationStarted' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/PreparationStarted.php',
    'PHPUnit\\Event\\Test\\PreparationStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/PreparationStartedSubscriber.php',
    'PHPUnit\\Event\\Test\\Prepared' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/Prepared.php',
    'PHPUnit\\Event\\Test\\PreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Lifecycle/PreparedSubscriber.php',
    'PHPUnit\\Event\\Test\\PrintedUnexpectedOutput' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/PrintedUnexpectedOutput.php',
    'PHPUnit\\Event\\Test\\PrintedUnexpectedOutputSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/PrintedUnexpectedOutputSubscriber.php',
    'PHPUnit\\Event\\Test\\Skipped' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/Skipped.php',
    'PHPUnit\\Event\\Test\\SkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Outcome/SkippedSubscriber.php',
    'PHPUnit\\Event\\Test\\TestProxyCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestProxyCreated.php',
    'PHPUnit\\Event\\Test\\TestProxyCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestProxyCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\TestStubCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestStubCreated.php',
    'PHPUnit\\Event\\Test\\TestStubCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestStubCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\TestStubForIntersectionOfInterfacesCreated' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestStubForIntersectionOfInterfacesCreated.php',
    'PHPUnit\\Event\\Test\\TestStubForIntersectionOfInterfacesCreatedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/TestDouble/TestStubForIntersectionOfInterfacesCreatedSubscriber.php',
    'PHPUnit\\Event\\Test\\WarningTriggered' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/WarningTriggered.php',
    'PHPUnit\\Event\\Test\\WarningTriggeredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Event/Events/Test/Issue/WarningTriggeredSubscriber.php',
    'PHPUnit\\Event\\Tracer\\Tracer' => $vendorDir . '/phpunit/phpunit/src/Event/Tracer.php',
    'PHPUnit\\Event\\TypeMap' => $vendorDir . '/phpunit/phpunit/src/Event/TypeMap.php',
    'PHPUnit\\Event\\UnknownEventException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/UnknownEventException.php',
    'PHPUnit\\Event\\UnknownEventTypeException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/UnknownEventTypeException.php',
    'PHPUnit\\Event\\UnknownSubscriberException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/UnknownSubscriberException.php',
    'PHPUnit\\Event\\UnknownSubscriberTypeException' => $vendorDir . '/phpunit/phpunit/src/Event/Exception/UnknownSubscriberTypeException.php',
    'PHPUnit\\Exception' => $vendorDir . '/phpunit/phpunit/src/Exception.php',
    'PHPUnit\\Framework\\ActualValueIsNotAnObjectException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ActualValueIsNotAnObjectException.php',
    'PHPUnit\\Framework\\Assert' => $vendorDir . '/phpunit/phpunit/src/Framework/Assert.php',
    'PHPUnit\\Framework\\AssertionFailedError' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/AssertionFailedError.php',
    'PHPUnit\\Framework\\Attributes\\After' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/After.php',
    'PHPUnit\\Framework\\Attributes\\AfterClass' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/AfterClass.php',
    'PHPUnit\\Framework\\Attributes\\BackupGlobals' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/BackupGlobals.php',
    'PHPUnit\\Framework\\Attributes\\BackupStaticProperties' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/BackupStaticProperties.php',
    'PHPUnit\\Framework\\Attributes\\Before' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Before.php',
    'PHPUnit\\Framework\\Attributes\\BeforeClass' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/BeforeClass.php',
    'PHPUnit\\Framework\\Attributes\\CoversClass' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/CoversClass.php',
    'PHPUnit\\Framework\\Attributes\\CoversFunction' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/CoversFunction.php',
    'PHPUnit\\Framework\\Attributes\\CoversMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/CoversMethod.php',
    'PHPUnit\\Framework\\Attributes\\CoversNothing' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/CoversNothing.php',
    'PHPUnit\\Framework\\Attributes\\CoversTrait' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/CoversTrait.php',
    'PHPUnit\\Framework\\Attributes\\DataProvider' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DataProvider.php',
    'PHPUnit\\Framework\\Attributes\\DataProviderExternal' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DataProviderExternal.php',
    'PHPUnit\\Framework\\Attributes\\Depends' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Depends.php',
    'PHPUnit\\Framework\\Attributes\\DependsExternal' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsExternal.php',
    'PHPUnit\\Framework\\Attributes\\DependsExternalUsingDeepClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsExternalUsingDeepClone.php',
    'PHPUnit\\Framework\\Attributes\\DependsExternalUsingShallowClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsExternalUsingShallowClone.php',
    'PHPUnit\\Framework\\Attributes\\DependsOnClass' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsOnClass.php',
    'PHPUnit\\Framework\\Attributes\\DependsOnClassUsingDeepClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsOnClassUsingDeepClone.php',
    'PHPUnit\\Framework\\Attributes\\DependsOnClassUsingShallowClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsOnClassUsingShallowClone.php',
    'PHPUnit\\Framework\\Attributes\\DependsUsingDeepClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsUsingDeepClone.php',
    'PHPUnit\\Framework\\Attributes\\DependsUsingShallowClone' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DependsUsingShallowClone.php',
    'PHPUnit\\Framework\\Attributes\\DisableReturnValueGenerationForTestDoubles' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DisableReturnValueGenerationForTestDoubles.php',
    'PHPUnit\\Framework\\Attributes\\DoesNotPerformAssertions' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/DoesNotPerformAssertions.php',
    'PHPUnit\\Framework\\Attributes\\ExcludeGlobalVariableFromBackup' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/ExcludeGlobalVariableFromBackup.php',
    'PHPUnit\\Framework\\Attributes\\ExcludeStaticPropertyFromBackup' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/ExcludeStaticPropertyFromBackup.php',
    'PHPUnit\\Framework\\Attributes\\Group' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Group.php',
    'PHPUnit\\Framework\\Attributes\\IgnoreDeprecations' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/IgnoreDeprecations.php',
    'PHPUnit\\Framework\\Attributes\\IgnorePhpunitDeprecations' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/IgnorePhpunitDeprecations.php',
    'PHPUnit\\Framework\\Attributes\\Large' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Large.php',
    'PHPUnit\\Framework\\Attributes\\Medium' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Medium.php',
    'PHPUnit\\Framework\\Attributes\\PostCondition' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/PostCondition.php',
    'PHPUnit\\Framework\\Attributes\\PreCondition' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/PreCondition.php',
    'PHPUnit\\Framework\\Attributes\\PreserveGlobalState' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/PreserveGlobalState.php',
    'PHPUnit\\Framework\\Attributes\\RequiresFunction' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresFunction.php',
    'PHPUnit\\Framework\\Attributes\\RequiresMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresMethod.php',
    'PHPUnit\\Framework\\Attributes\\RequiresOperatingSystem' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresOperatingSystem.php',
    'PHPUnit\\Framework\\Attributes\\RequiresOperatingSystemFamily' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresOperatingSystemFamily.php',
    'PHPUnit\\Framework\\Attributes\\RequiresPhp' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresPhp.php',
    'PHPUnit\\Framework\\Attributes\\RequiresPhpExtension' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresPhpExtension.php',
    'PHPUnit\\Framework\\Attributes\\RequiresPhpunit' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresPhpunit.php',
    'PHPUnit\\Framework\\Attributes\\RequiresSetting' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RequiresSetting.php',
    'PHPUnit\\Framework\\Attributes\\RunClassInSeparateProcess' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RunClassInSeparateProcess.php',
    'PHPUnit\\Framework\\Attributes\\RunInSeparateProcess' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RunInSeparateProcess.php',
    'PHPUnit\\Framework\\Attributes\\RunTestsInSeparateProcesses' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/RunTestsInSeparateProcesses.php',
    'PHPUnit\\Framework\\Attributes\\Small' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Small.php',
    'PHPUnit\\Framework\\Attributes\\Test' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Test.php',
    'PHPUnit\\Framework\\Attributes\\TestDox' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/TestDox.php',
    'PHPUnit\\Framework\\Attributes\\TestWith' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/TestWith.php',
    'PHPUnit\\Framework\\Attributes\\TestWithJson' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/TestWithJson.php',
    'PHPUnit\\Framework\\Attributes\\Ticket' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/Ticket.php',
    'PHPUnit\\Framework\\Attributes\\UsesClass' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/UsesClass.php',
    'PHPUnit\\Framework\\Attributes\\UsesFunction' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/UsesFunction.php',
    'PHPUnit\\Framework\\Attributes\\UsesMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/UsesMethod.php',
    'PHPUnit\\Framework\\Attributes\\UsesTrait' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/UsesTrait.php',
    'PHPUnit\\Framework\\Attributes\\WithoutErrorHandler' => $vendorDir . '/phpunit/phpunit/src/Framework/Attributes/WithoutErrorHandler.php',
    'PHPUnit\\Framework\\CodeCoverageException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/CodeCoverageException.php',
    'PHPUnit\\Framework\\ComparisonMethodDoesNotAcceptParameterTypeException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ComparisonMethodDoesNotAcceptParameterTypeException.php',
    'PHPUnit\\Framework\\ComparisonMethodDoesNotDeclareBoolReturnTypeException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ComparisonMethodDoesNotDeclareBoolReturnTypeException.php',
    'PHPUnit\\Framework\\ComparisonMethodDoesNotDeclareExactlyOneParameterException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ComparisonMethodDoesNotDeclareExactlyOneParameterException.php',
    'PHPUnit\\Framework\\ComparisonMethodDoesNotDeclareParameterTypeException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ComparisonMethodDoesNotDeclareParameterTypeException.php',
    'PHPUnit\\Framework\\ComparisonMethodDoesNotExistException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ObjectEquals/ComparisonMethodDoesNotExistException.php',
    'PHPUnit\\Framework\\Constraint\\ArrayHasKey' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/ArrayHasKey.php',
    'PHPUnit\\Framework\\Constraint\\BinaryOperator' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/BinaryOperator.php',
    'PHPUnit\\Framework\\Constraint\\Callback' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Callback.php',
    'PHPUnit\\Framework\\Constraint\\Constraint' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Constraint.php',
    'PHPUnit\\Framework\\Constraint\\Count' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Cardinality/Count.php',
    'PHPUnit\\Framework\\Constraint\\DirectoryExists' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Filesystem/DirectoryExists.php',
    'PHPUnit\\Framework\\Constraint\\Exception' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Exception/Exception.php',
    'PHPUnit\\Framework\\Constraint\\ExceptionCode' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Exception/ExceptionCode.php',
    'PHPUnit\\Framework\\Constraint\\ExceptionMessageIsOrContains' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Exception/ExceptionMessageIsOrContains.php',
    'PHPUnit\\Framework\\Constraint\\ExceptionMessageMatchesRegularExpression' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Exception/ExceptionMessageMatchesRegularExpression.php',
    'PHPUnit\\Framework\\Constraint\\FileExists' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Filesystem/FileExists.php',
    'PHPUnit\\Framework\\Constraint\\GreaterThan' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Cardinality/GreaterThan.php',
    'PHPUnit\\Framework\\Constraint\\IsAnything' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/IsAnything.php',
    'PHPUnit\\Framework\\Constraint\\IsEmpty' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Cardinality/IsEmpty.php',
    'PHPUnit\\Framework\\Constraint\\IsEqual' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Equality/IsEqual.php',
    'PHPUnit\\Framework\\Constraint\\IsEqualCanonicalizing' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Equality/IsEqualCanonicalizing.php',
    'PHPUnit\\Framework\\Constraint\\IsEqualIgnoringCase' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Equality/IsEqualIgnoringCase.php',
    'PHPUnit\\Framework\\Constraint\\IsEqualWithDelta' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Equality/IsEqualWithDelta.php',
    'PHPUnit\\Framework\\Constraint\\IsFalse' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Boolean/IsFalse.php',
    'PHPUnit\\Framework\\Constraint\\IsFinite' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Math/IsFinite.php',
    'PHPUnit\\Framework\\Constraint\\IsIdentical' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/IsIdentical.php',
    'PHPUnit\\Framework\\Constraint\\IsInfinite' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Math/IsInfinite.php',
    'PHPUnit\\Framework\\Constraint\\IsInstanceOf' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Type/IsInstanceOf.php',
    'PHPUnit\\Framework\\Constraint\\IsJson' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/IsJson.php',
    'PHPUnit\\Framework\\Constraint\\IsList' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/IsList.php',
    'PHPUnit\\Framework\\Constraint\\IsNan' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Math/IsNan.php',
    'PHPUnit\\Framework\\Constraint\\IsNull' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Type/IsNull.php',
    'PHPUnit\\Framework\\Constraint\\IsReadable' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Filesystem/IsReadable.php',
    'PHPUnit\\Framework\\Constraint\\IsTrue' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Boolean/IsTrue.php',
    'PHPUnit\\Framework\\Constraint\\IsType' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Type/IsType.php',
    'PHPUnit\\Framework\\Constraint\\IsWritable' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Filesystem/IsWritable.php',
    'PHPUnit\\Framework\\Constraint\\JsonMatches' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/JsonMatches.php',
    'PHPUnit\\Framework\\Constraint\\LessThan' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Cardinality/LessThan.php',
    'PHPUnit\\Framework\\Constraint\\LogicalAnd' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/LogicalAnd.php',
    'PHPUnit\\Framework\\Constraint\\LogicalNot' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/LogicalNot.php',
    'PHPUnit\\Framework\\Constraint\\LogicalOr' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/LogicalOr.php',
    'PHPUnit\\Framework\\Constraint\\LogicalXor' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/LogicalXor.php',
    'PHPUnit\\Framework\\Constraint\\ObjectEquals' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Object/ObjectEquals.php',
    'PHPUnit\\Framework\\Constraint\\ObjectHasProperty' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Object/ObjectHasProperty.php',
    'PHPUnit\\Framework\\Constraint\\Operator' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/Operator.php',
    'PHPUnit\\Framework\\Constraint\\RegularExpression' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/RegularExpression.php',
    'PHPUnit\\Framework\\Constraint\\SameSize' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Cardinality/SameSize.php',
    'PHPUnit\\Framework\\Constraint\\StringContains' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/StringContains.php',
    'PHPUnit\\Framework\\Constraint\\StringEndsWith' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/StringEndsWith.php',
    'PHPUnit\\Framework\\Constraint\\StringEqualsStringIgnoringLineEndings' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/StringEqualsStringIgnoringLineEndings.php',
    'PHPUnit\\Framework\\Constraint\\StringMatchesFormatDescription' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/StringMatchesFormatDescription.php',
    'PHPUnit\\Framework\\Constraint\\StringStartsWith' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/String/StringStartsWith.php',
    'PHPUnit\\Framework\\Constraint\\TraversableContains' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/TraversableContains.php',
    'PHPUnit\\Framework\\Constraint\\TraversableContainsEqual' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/TraversableContainsEqual.php',
    'PHPUnit\\Framework\\Constraint\\TraversableContainsIdentical' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/TraversableContainsIdentical.php',
    'PHPUnit\\Framework\\Constraint\\TraversableContainsOnly' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Traversable/TraversableContainsOnly.php',
    'PHPUnit\\Framework\\Constraint\\UnaryOperator' => $vendorDir . '/phpunit/phpunit/src/Framework/Constraint/Operator/UnaryOperator.php',
    'PHPUnit\\Framework\\DataProviderTestSuite' => $vendorDir . '/phpunit/phpunit/src/Framework/DataProviderTestSuite.php',
    'PHPUnit\\Framework\\EmptyStringException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/EmptyStringException.php',
    'PHPUnit\\Framework\\Exception' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Exception.php',
    'PHPUnit\\Framework\\ExecutionOrderDependency' => $vendorDir . '/phpunit/phpunit/src/Framework/ExecutionOrderDependency.php',
    'PHPUnit\\Framework\\ExpectationFailedException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ExpectationFailedException.php',
    'PHPUnit\\Framework\\GeneratorNotSupportedException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/GeneratorNotSupportedException.php',
    'PHPUnit\\Framework\\IncompleteTest' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Incomplete/IncompleteTest.php',
    'PHPUnit\\Framework\\IncompleteTestError' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Incomplete/IncompleteTestError.php',
    'PHPUnit\\Framework\\InvalidArgumentException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/InvalidArgumentException.php',
    'PHPUnit\\Framework\\InvalidCoversTargetException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/InvalidCoversTargetException.php',
    'PHPUnit\\Framework\\InvalidDataProviderException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/InvalidDataProviderException.php',
    'PHPUnit\\Framework\\InvalidDependencyException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/InvalidDependencyException.php',
    'PHPUnit\\Framework\\IsolatedTestRunner' => $vendorDir . '/phpunit/phpunit/src/Framework/TestRunner/IsolatedTestRunner.php',
    'PHPUnit\\Framework\\IsolatedTestRunnerRegistry' => $vendorDir . '/phpunit/phpunit/src/Framework/TestRunner/IsolatedTestRunnerRegistry.php',
    'PHPUnit\\Framework\\MockObject\\BadMethodCallException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/BadMethodCallException.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\Identity' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/Identity.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\InvocationMocker' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/InvocationMocker.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\InvocationStubber' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/InvocationStubber.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\MethodNameMatch' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/MethodNameMatch.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\ParametersMatch' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/ParametersMatch.php',
    'PHPUnit\\Framework\\MockObject\\Builder\\Stub' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Builder/Stub.php',
    'PHPUnit\\Framework\\MockObject\\CannotCloneTestDoubleForReadonlyClassException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/CannotCloneTestDoubleForReadonlyClassException.php',
    'PHPUnit\\Framework\\MockObject\\CannotUseOnlyMethodsException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/CannotUseOnlyMethodsException.php',
    'PHPUnit\\Framework\\MockObject\\ConfigurableMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/ConfigurableMethod.php',
    'PHPUnit\\Framework\\MockObject\\DoubledCloneMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/DoubledCloneMethod.php',
    'PHPUnit\\Framework\\MockObject\\ErrorCloneMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/ErrorCloneMethod.php',
    'PHPUnit\\Framework\\MockObject\\Exception' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/Exception.php',
    'PHPUnit\\Framework\\MockObject\\GeneratedAsMockObject' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/GeneratedAsMockObject.php',
    'PHPUnit\\Framework\\MockObject\\GeneratedAsTestStub' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/GeneratedAsTestStub.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\CannotUseAddMethodsException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/CannotUseAddMethodsException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\ClassIsEnumerationException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/ClassIsEnumerationException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\ClassIsFinalException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/ClassIsFinalException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\DuplicateMethodException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/DuplicateMethodException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\Exception' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/Exception.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\Generator' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Generator.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\InvalidMethodNameException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/InvalidMethodNameException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\MockClass' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/MockClass.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\MockMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/MockMethod.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\MockMethodSet' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/MockMethodSet.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\MockTrait' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/MockTrait.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\MockType' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/MockType.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\NameAlreadyInUseException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/NameAlreadyInUseException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\OriginalConstructorInvocationRequiredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/OriginalConstructorInvocationRequiredException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\ReflectionException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/ReflectionException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\RuntimeException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/RuntimeException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\SoapExtensionNotAvailableException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/SoapExtensionNotAvailableException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\TemplateLoader' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/TemplateLoader.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\UnknownClassException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/UnknownClassException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\UnknownTraitException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/UnknownTraitException.php',
    'PHPUnit\\Framework\\MockObject\\Generator\\UnknownTypeException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Generator/Exception/UnknownTypeException.php',
    'PHPUnit\\Framework\\MockObject\\IncompatibleReturnValueException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/IncompatibleReturnValueException.php',
    'PHPUnit\\Framework\\MockObject\\Invocation' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Invocation.php',
    'PHPUnit\\Framework\\MockObject\\InvocationHandler' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/InvocationHandler.php',
    'PHPUnit\\Framework\\MockObject\\MatchBuilderNotFoundException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MatchBuilderNotFoundException.php',
    'PHPUnit\\Framework\\MockObject\\Matcher' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Matcher.php',
    'PHPUnit\\Framework\\MockObject\\MatcherAlreadyRegisteredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MatcherAlreadyRegisteredException.php',
    'PHPUnit\\Framework\\MockObject\\Method' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/Method.php',
    'PHPUnit\\Framework\\MockObject\\MethodCannotBeConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MethodCannotBeConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\MethodNameAlreadyConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MethodNameAlreadyConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\MethodNameConstraint' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/MethodNameConstraint.php',
    'PHPUnit\\Framework\\MockObject\\MethodNameNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MethodNameNotConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\MethodParametersAlreadyConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/MethodParametersAlreadyConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\MockBuilder' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/MockBuilder.php',
    'PHPUnit\\Framework\\MockObject\\MockObject' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Interface/MockObject.php',
    'PHPUnit\\Framework\\MockObject\\MockObjectApi' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/MockObjectApi.php',
    'PHPUnit\\Framework\\MockObject\\MockObjectInternal' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Interface/MockObjectInternal.php',
    'PHPUnit\\Framework\\MockObject\\MutableStubApi' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/MutableStubApi.php',
    'PHPUnit\\Framework\\MockObject\\NeverReturningMethodException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/NeverReturningMethodException.php',
    'PHPUnit\\Framework\\MockObject\\NoMoreReturnValuesConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/NoMoreReturnValuesConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\ProxiedCloneMethod' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/ProxiedCloneMethod.php',
    'PHPUnit\\Framework\\MockObject\\ReflectionException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/ReflectionException.php',
    'PHPUnit\\Framework\\MockObject\\ReturnValueGenerator' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/ReturnValueGenerator.php',
    'PHPUnit\\Framework\\MockObject\\ReturnValueNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/ReturnValueNotConfiguredException.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\AnyInvokedCount' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/AnyInvokedCount.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\AnyParameters' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/AnyParameters.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\InvocationOrder' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/InvocationOrder.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\InvokedAtLeastCount' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/InvokedAtLeastCount.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\InvokedAtLeastOnce' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/InvokedAtLeastOnce.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\InvokedAtMostCount' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/InvokedAtMostCount.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\InvokedCount' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/InvokedCount.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\MethodName' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/MethodName.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\Parameters' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/Parameters.php',
    'PHPUnit\\Framework\\MockObject\\Rule\\ParametersRule' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Rule/ParametersRule.php',
    'PHPUnit\\Framework\\MockObject\\RuntimeException' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Exception/RuntimeException.php',
    'PHPUnit\\Framework\\MockObject\\Stub' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Interface/Stub.php',
    'PHPUnit\\Framework\\MockObject\\StubApi' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/StubApi.php',
    'PHPUnit\\Framework\\MockObject\\StubInternal' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Interface/StubInternal.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ConsecutiveCalls' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ConsecutiveCalls.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\Exception' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/Exception.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnArgument' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnArgument.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnCallback' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnCallback.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnReference' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnReference.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnSelf' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnSelf.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnStub' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnStub.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\ReturnValueMap' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/ReturnValueMap.php',
    'PHPUnit\\Framework\\MockObject\\Stub\\Stub' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Stub/Stub.php',
    'PHPUnit\\Framework\\MockObject\\TestDoubleState' => $vendorDir . '/phpunit/phpunit/src/Framework/MockObject/Runtime/Api/TestDoubleState.php',
    'PHPUnit\\Framework\\NoChildTestSuiteException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/NoChildTestSuiteException.php',
    'PHPUnit\\Framework\\PhptAssertionFailedError' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/PhptAssertionFailedError.php',
    'PHPUnit\\Framework\\ProcessIsolationException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/ProcessIsolationException.php',
    'PHPUnit\\Framework\\Reorderable' => $vendorDir . '/phpunit/phpunit/src/Framework/Reorderable.php',
    'PHPUnit\\Framework\\SelfDescribing' => $vendorDir . '/phpunit/phpunit/src/Framework/SelfDescribing.php',
    'PHPUnit\\Framework\\SeparateProcessTestRunner' => $vendorDir . '/phpunit/phpunit/src/Framework/TestRunner/SeparateProcessTestRunner.php',
    'PHPUnit\\Framework\\SkippedTest' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Skipped/SkippedTest.php',
    'PHPUnit\\Framework\\SkippedTestSuiteError' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Skipped/SkippedTestSuiteError.php',
    'PHPUnit\\Framework\\SkippedWithMessageException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/Skipped/SkippedWithMessageException.php',
    'PHPUnit\\Framework\\Test' => $vendorDir . '/phpunit/phpunit/src/Framework/Test.php',
    'PHPUnit\\Framework\\TestBuilder' => $vendorDir . '/phpunit/phpunit/src/Framework/TestBuilder.php',
    'PHPUnit\\Framework\\TestCase' => $vendorDir . '/phpunit/phpunit/src/Framework/TestCase.php',
    'PHPUnit\\Framework\\TestRunner' => $vendorDir . '/phpunit/phpunit/src/Framework/TestRunner/TestRunner.php',
    'PHPUnit\\Framework\\TestSize\\Known' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/Known.php',
    'PHPUnit\\Framework\\TestSize\\Large' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/Large.php',
    'PHPUnit\\Framework\\TestSize\\Medium' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/Medium.php',
    'PHPUnit\\Framework\\TestSize\\Small' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/Small.php',
    'PHPUnit\\Framework\\TestSize\\TestSize' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/TestSize.php',
    'PHPUnit\\Framework\\TestSize\\Unknown' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSize/Unknown.php',
    'PHPUnit\\Framework\\TestStatus\\Deprecation' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Deprecation.php',
    'PHPUnit\\Framework\\TestStatus\\Error' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Error.php',
    'PHPUnit\\Framework\\TestStatus\\Failure' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Failure.php',
    'PHPUnit\\Framework\\TestStatus\\Incomplete' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Incomplete.php',
    'PHPUnit\\Framework\\TestStatus\\Known' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Known.php',
    'PHPUnit\\Framework\\TestStatus\\Notice' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Notice.php',
    'PHPUnit\\Framework\\TestStatus\\Risky' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Risky.php',
    'PHPUnit\\Framework\\TestStatus\\Skipped' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Skipped.php',
    'PHPUnit\\Framework\\TestStatus\\Success' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Success.php',
    'PHPUnit\\Framework\\TestStatus\\TestStatus' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/TestStatus.php',
    'PHPUnit\\Framework\\TestStatus\\Unknown' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Unknown.php',
    'PHPUnit\\Framework\\TestStatus\\Warning' => $vendorDir . '/phpunit/phpunit/src/Framework/TestStatus/Warning.php',
    'PHPUnit\\Framework\\TestSuite' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSuite.php',
    'PHPUnit\\Framework\\TestSuiteIterator' => $vendorDir . '/phpunit/phpunit/src/Framework/TestSuiteIterator.php',
    'PHPUnit\\Framework\\UnknownClassOrInterfaceException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/UnknownClassOrInterfaceException.php',
    'PHPUnit\\Framework\\UnknownTypeException' => $vendorDir . '/phpunit/phpunit/src/Framework/Exception/UnknownTypeException.php',
    'PHPUnit\\Logging\\EventLogger' => $vendorDir . '/phpunit/phpunit/src/Logging/EventLogger.php',
    'PHPUnit\\Logging\\Exception' => $vendorDir . '/phpunit/phpunit/src/Logging/Exception.php',
    'PHPUnit\\Logging\\JUnit\\JunitXmlLogger' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/JunitXmlLogger.php',
    'PHPUnit\\Logging\\JUnit\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/Subscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestPreparationFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestPreparationFailedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestPreparationStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestPreparationStartedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestRunnerExecutionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestRunnerExecutionFinishedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestSuiteFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestSuiteFinishedSubscriber.php',
    'PHPUnit\\Logging\\JUnit\\TestSuiteStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/JUnit/Subscriber/TestSuiteStartedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/Subscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TeamCityLogger' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/TeamCityLogger.php',
    'PHPUnit\\Logging\\TeamCity\\TestConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestConsideredRiskySubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestRunnerExecutionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestRunnerExecutionFinishedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestSuiteFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestSuiteFinishedSubscriber.php',
    'PHPUnit\\Logging\\TeamCity\\TestSuiteStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TeamCity/Subscriber/TestSuiteStartedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\HtmlRenderer' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/HtmlRenderer.php',
    'PHPUnit\\Logging\\TestDox\\NamePrettifier' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/NamePrettifier.php',
    'PHPUnit\\Logging\\TestDox\\PlainTextRenderer' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/PlainTextRenderer.php',
    'PHPUnit\\Logging\\TestDox\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/Subscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestConsideredRiskySubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestPassedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestPassedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestResult' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/TestResult.php',
    'PHPUnit\\Logging\\TestDox\\TestResultCollection' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/TestResultCollection.php',
    'PHPUnit\\Logging\\TestDox\\TestResultCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/TestResultCollectionIterator.php',
    'PHPUnit\\Logging\\TestDox\\TestResultCollector' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/TestResultCollector.php',
    'PHPUnit\\Logging\\TestDox\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredDeprecationSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredNoticeSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpDeprecationSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpNoticeSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpWarningSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpunitDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpunitDeprecationSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpunitErrorSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpunitErrorSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredPhpunitWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredPhpunitWarningSubscriber.php',
    'PHPUnit\\Logging\\TestDox\\TestTriggeredWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Logging/TestDox/TestResult/Subscriber/TestTriggeredWarningSubscriber.php',
    'PHPUnit\\Metadata\\After' => $vendorDir . '/phpunit/phpunit/src/Metadata/After.php',
    'PHPUnit\\Metadata\\AfterClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/AfterClass.php',
    'PHPUnit\\Metadata\\Annotation\\Parser\\DocBlock' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/Annotation/DocBlock.php',
    'PHPUnit\\Metadata\\Annotation\\Parser\\Registry' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/Annotation/Registry.php',
    'PHPUnit\\Metadata\\AnnotationsAreNotSupportedForInternalClassesException' => $vendorDir . '/phpunit/phpunit/src/Metadata/Exception/AnnotationsAreNotSupportedForInternalClassesException.php',
    'PHPUnit\\Metadata\\Api\\CodeCoverage' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/CodeCoverage.php',
    'PHPUnit\\Metadata\\Api\\DataProvider' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/DataProvider.php',
    'PHPUnit\\Metadata\\Api\\Dependencies' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/Dependencies.php',
    'PHPUnit\\Metadata\\Api\\Groups' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/Groups.php',
    'PHPUnit\\Metadata\\Api\\HookMethods' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/HookMethods.php',
    'PHPUnit\\Metadata\\Api\\Requirements' => $vendorDir . '/phpunit/phpunit/src/Metadata/Api/Requirements.php',
    'PHPUnit\\Metadata\\BackupGlobals' => $vendorDir . '/phpunit/phpunit/src/Metadata/BackupGlobals.php',
    'PHPUnit\\Metadata\\BackupStaticProperties' => $vendorDir . '/phpunit/phpunit/src/Metadata/BackupStaticProperties.php',
    'PHPUnit\\Metadata\\Before' => $vendorDir . '/phpunit/phpunit/src/Metadata/Before.php',
    'PHPUnit\\Metadata\\BeforeClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/BeforeClass.php',
    'PHPUnit\\Metadata\\Covers' => $vendorDir . '/phpunit/phpunit/src/Metadata/Covers.php',
    'PHPUnit\\Metadata\\CoversClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversClass.php',
    'PHPUnit\\Metadata\\CoversDefaultClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversDefaultClass.php',
    'PHPUnit\\Metadata\\CoversFunction' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversFunction.php',
    'PHPUnit\\Metadata\\CoversMethod' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversMethod.php',
    'PHPUnit\\Metadata\\CoversNothing' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversNothing.php',
    'PHPUnit\\Metadata\\CoversTrait' => $vendorDir . '/phpunit/phpunit/src/Metadata/CoversTrait.php',
    'PHPUnit\\Metadata\\DataProvider' => $vendorDir . '/phpunit/phpunit/src/Metadata/DataProvider.php',
    'PHPUnit\\Metadata\\DependsOnClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/DependsOnClass.php',
    'PHPUnit\\Metadata\\DependsOnMethod' => $vendorDir . '/phpunit/phpunit/src/Metadata/DependsOnMethod.php',
    'PHPUnit\\Metadata\\DisableReturnValueGenerationForTestDoubles' => $vendorDir . '/phpunit/phpunit/src/Metadata/DisableReturnValueGenerationForTestDoubles.php',
    'PHPUnit\\Metadata\\DoesNotPerformAssertions' => $vendorDir . '/phpunit/phpunit/src/Metadata/DoesNotPerformAssertions.php',
    'PHPUnit\\Metadata\\Exception' => $vendorDir . '/phpunit/phpunit/src/Metadata/Exception/Exception.php',
    'PHPUnit\\Metadata\\ExcludeGlobalVariableFromBackup' => $vendorDir . '/phpunit/phpunit/src/Metadata/ExcludeGlobalVariableFromBackup.php',
    'PHPUnit\\Metadata\\ExcludeStaticPropertyFromBackup' => $vendorDir . '/phpunit/phpunit/src/Metadata/ExcludeStaticPropertyFromBackup.php',
    'PHPUnit\\Metadata\\Group' => $vendorDir . '/phpunit/phpunit/src/Metadata/Group.php',
    'PHPUnit\\Metadata\\IgnoreDeprecations' => $vendorDir . '/phpunit/phpunit/src/Metadata/IgnoreDeprecations.php',
    'PHPUnit\\Metadata\\IgnorePhpunitDeprecations' => $vendorDir . '/phpunit/phpunit/src/Metadata/IgnorePhpunitDeprecations.php',
    'PHPUnit\\Metadata\\InvalidVersionRequirementException' => $vendorDir . '/phpunit/phpunit/src/Metadata/Exception/InvalidVersionRequirementException.php',
    'PHPUnit\\Metadata\\Metadata' => $vendorDir . '/phpunit/phpunit/src/Metadata/Metadata.php',
    'PHPUnit\\Metadata\\MetadataCollection' => $vendorDir . '/phpunit/phpunit/src/Metadata/MetadataCollection.php',
    'PHPUnit\\Metadata\\MetadataCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/Metadata/MetadataCollectionIterator.php',
    'PHPUnit\\Metadata\\NoVersionRequirementException' => $vendorDir . '/phpunit/phpunit/src/Metadata/Exception/NoVersionRequirementException.php',
    'PHPUnit\\Metadata\\Parser\\AnnotationParser' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/AnnotationParser.php',
    'PHPUnit\\Metadata\\Parser\\AttributeParser' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/AttributeParser.php',
    'PHPUnit\\Metadata\\Parser\\CachingParser' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/CachingParser.php',
    'PHPUnit\\Metadata\\Parser\\Parser' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/Parser.php',
    'PHPUnit\\Metadata\\Parser\\ParserChain' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/ParserChain.php',
    'PHPUnit\\Metadata\\Parser\\Registry' => $vendorDir . '/phpunit/phpunit/src/Metadata/Parser/Registry.php',
    'PHPUnit\\Metadata\\PostCondition' => $vendorDir . '/phpunit/phpunit/src/Metadata/PostCondition.php',
    'PHPUnit\\Metadata\\PreCondition' => $vendorDir . '/phpunit/phpunit/src/Metadata/PreCondition.php',
    'PHPUnit\\Metadata\\PreserveGlobalState' => $vendorDir . '/phpunit/phpunit/src/Metadata/PreserveGlobalState.php',
    'PHPUnit\\Metadata\\ReflectionException' => $vendorDir . '/phpunit/phpunit/src/Metadata/Exception/ReflectionException.php',
    'PHPUnit\\Metadata\\RequiresFunction' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresFunction.php',
    'PHPUnit\\Metadata\\RequiresMethod' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresMethod.php',
    'PHPUnit\\Metadata\\RequiresOperatingSystem' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresOperatingSystem.php',
    'PHPUnit\\Metadata\\RequiresOperatingSystemFamily' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresOperatingSystemFamily.php',
    'PHPUnit\\Metadata\\RequiresPhp' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresPhp.php',
    'PHPUnit\\Metadata\\RequiresPhpExtension' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresPhpExtension.php',
    'PHPUnit\\Metadata\\RequiresPhpunit' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresPhpunit.php',
    'PHPUnit\\Metadata\\RequiresSetting' => $vendorDir . '/phpunit/phpunit/src/Metadata/RequiresSetting.php',
    'PHPUnit\\Metadata\\RunClassInSeparateProcess' => $vendorDir . '/phpunit/phpunit/src/Metadata/RunClassInSeparateProcess.php',
    'PHPUnit\\Metadata\\RunInSeparateProcess' => $vendorDir . '/phpunit/phpunit/src/Metadata/RunInSeparateProcess.php',
    'PHPUnit\\Metadata\\RunTestsInSeparateProcesses' => $vendorDir . '/phpunit/phpunit/src/Metadata/RunTestsInSeparateProcesses.php',
    'PHPUnit\\Metadata\\Test' => $vendorDir . '/phpunit/phpunit/src/Metadata/Test.php',
    'PHPUnit\\Metadata\\TestDox' => $vendorDir . '/phpunit/phpunit/src/Metadata/TestDox.php',
    'PHPUnit\\Metadata\\TestWith' => $vendorDir . '/phpunit/phpunit/src/Metadata/TestWith.php',
    'PHPUnit\\Metadata\\Uses' => $vendorDir . '/phpunit/phpunit/src/Metadata/Uses.php',
    'PHPUnit\\Metadata\\UsesClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/UsesClass.php',
    'PHPUnit\\Metadata\\UsesDefaultClass' => $vendorDir . '/phpunit/phpunit/src/Metadata/UsesDefaultClass.php',
    'PHPUnit\\Metadata\\UsesFunction' => $vendorDir . '/phpunit/phpunit/src/Metadata/UsesFunction.php',
    'PHPUnit\\Metadata\\UsesMethod' => $vendorDir . '/phpunit/phpunit/src/Metadata/UsesMethod.php',
    'PHPUnit\\Metadata\\UsesTrait' => $vendorDir . '/phpunit/phpunit/src/Metadata/UsesTrait.php',
    'PHPUnit\\Metadata\\Version\\ComparisonRequirement' => $vendorDir . '/phpunit/phpunit/src/Metadata/Version/ComparisonRequirement.php',
    'PHPUnit\\Metadata\\Version\\ConstraintRequirement' => $vendorDir . '/phpunit/phpunit/src/Metadata/Version/ConstraintRequirement.php',
    'PHPUnit\\Metadata\\Version\\Requirement' => $vendorDir . '/phpunit/phpunit/src/Metadata/Version/Requirement.php',
    'PHPUnit\\Metadata\\WithoutErrorHandler' => $vendorDir . '/phpunit/phpunit/src/Metadata/WithoutErrorHandler.php',
    'PHPUnit\\Runner\\Baseline\\Baseline' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Baseline.php',
    'PHPUnit\\Runner\\Baseline\\CannotLoadBaselineException' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Exception/CannotLoadBaselineException.php',
    'PHPUnit\\Runner\\Baseline\\FileDoesNotHaveLineException' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Exception/FileDoesNotHaveLineException.php',
    'PHPUnit\\Runner\\Baseline\\Generator' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Generator.php',
    'PHPUnit\\Runner\\Baseline\\Issue' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Issue.php',
    'PHPUnit\\Runner\\Baseline\\Reader' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Reader.php',
    'PHPUnit\\Runner\\Baseline\\RelativePathCalculator' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/RelativePathCalculator.php',
    'PHPUnit\\Runner\\Baseline\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/Subscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredDeprecationSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredNoticeSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredPhpDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredPhpDeprecationSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredPhpNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredPhpNoticeSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredPhpWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredPhpWarningSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\TestTriggeredWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Subscriber/TestTriggeredWarningSubscriber.php',
    'PHPUnit\\Runner\\Baseline\\Writer' => $vendorDir . '/phpunit/phpunit/src/Runner/Baseline/Writer.php',
    'PHPUnit\\Runner\\ClassCannotBeFoundException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ClassCannotBeFoundException.php',
    'PHPUnit\\Runner\\ClassDoesNotExtendTestCaseException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ClassDoesNotExtendTestCaseException.php',
    'PHPUnit\\Runner\\ClassIsAbstractException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ClassIsAbstractException.php',
    'PHPUnit\\Runner\\CodeCoverage' => $vendorDir . '/phpunit/phpunit/src/Runner/CodeCoverage.php',
    'PHPUnit\\Runner\\DeprecationCollector\\Collector' => $vendorDir . '/phpunit/phpunit/src/Runner/DeprecationCollector/Collector.php',
    'PHPUnit\\Runner\\DeprecationCollector\\Facade' => $vendorDir . '/phpunit/phpunit/src/Runner/DeprecationCollector/Facade.php',
    'PHPUnit\\Runner\\DeprecationCollector\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/DeprecationCollector/Subscriber/Subscriber.php',
    'PHPUnit\\Runner\\DeprecationCollector\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/DeprecationCollector/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\Runner\\DeprecationCollector\\TestTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/DeprecationCollector/Subscriber/TestTriggeredDeprecationSubscriber.php',
    'PHPUnit\\Runner\\DirectoryDoesNotExistException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/DirectoryDoesNotExistException.php',
    'PHPUnit\\Runner\\ErrorException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ErrorException.php',
    'PHPUnit\\Runner\\ErrorHandler' => $vendorDir . '/phpunit/phpunit/src/Runner/ErrorHandler.php',
    'PHPUnit\\Runner\\Exception' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/Exception.php',
    'PHPUnit\\Runner\\Extension\\Extension' => $vendorDir . '/phpunit/phpunit/src/Runner/Extension/Extension.php',
    'PHPUnit\\Runner\\Extension\\ExtensionBootstrapper' => $vendorDir . '/phpunit/phpunit/src/Runner/Extension/ExtensionBootstrapper.php',
    'PHPUnit\\Runner\\Extension\\Facade' => $vendorDir . '/phpunit/phpunit/src/Runner/Extension/Facade.php',
    'PHPUnit\\Runner\\Extension\\ParameterCollection' => $vendorDir . '/phpunit/phpunit/src/Runner/Extension/ParameterCollection.php',
    'PHPUnit\\Runner\\Extension\\PharLoader' => $vendorDir . '/phpunit/phpunit/src/Runner/Extension/PharLoader.php',
    'PHPUnit\\Runner\\FileDoesNotExistException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/FileDoesNotExistException.php',
    'PHPUnit\\Runner\\Filter\\ExcludeGroupFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/ExcludeGroupFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\ExcludeNameFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/ExcludeNameFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\Factory' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/Factory.php',
    'PHPUnit\\Runner\\Filter\\GroupFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/GroupFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\IncludeGroupFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/IncludeGroupFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\IncludeNameFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/IncludeNameFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\NameFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/NameFilterIterator.php',
    'PHPUnit\\Runner\\Filter\\TestIdFilterIterator' => $vendorDir . '/phpunit/phpunit/src/Runner/Filter/TestIdFilterIterator.php',
    'PHPUnit\\Runner\\GarbageCollection\\ExecutionFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/GarbageCollection/Subscriber/ExecutionFinishedSubscriber.php',
    'PHPUnit\\Runner\\GarbageCollection\\ExecutionStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/GarbageCollection/Subscriber/ExecutionStartedSubscriber.php',
    'PHPUnit\\Runner\\GarbageCollection\\GarbageCollectionHandler' => $vendorDir . '/phpunit/phpunit/src/Runner/GarbageCollection/GarbageCollectionHandler.php',
    'PHPUnit\\Runner\\GarbageCollection\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/GarbageCollection/Subscriber/Subscriber.php',
    'PHPUnit\\Runner\\GarbageCollection\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/GarbageCollection/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\Runner\\HookMethod' => $vendorDir . '/phpunit/phpunit/src/Runner/HookMethod/HookMethod.php',
    'PHPUnit\\Runner\\HookMethodCollection' => $vendorDir . '/phpunit/phpunit/src/Runner/HookMethod/HookMethodCollection.php',
    'PHPUnit\\Runner\\InvalidOrderException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/InvalidOrderException.php',
    'PHPUnit\\Runner\\InvalidPhptFileException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/InvalidPhptFileException.php',
    'PHPUnit\\Runner\\NoIgnoredEventException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/NoIgnoredEventException.php',
    'PHPUnit\\Runner\\ParameterDoesNotExistException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ParameterDoesNotExistException.php',
    'PHPUnit\\Runner\\PhptExternalFileCannotBeLoadedException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/PhptExternalFileCannotBeLoadedException.php',
    'PHPUnit\\Runner\\PhptTestCase' => $vendorDir . '/phpunit/phpunit/src/Runner/PHPT/PhptTestCase.php',
    'PHPUnit\\Runner\\ReflectionException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/ReflectionException.php',
    'PHPUnit\\Runner\\ResultCache\\DefaultResultCache' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/DefaultResultCache.php',
    'PHPUnit\\Runner\\ResultCache\\NullResultCache' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/NullResultCache.php',
    'PHPUnit\\Runner\\ResultCache\\ResultCache' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/ResultCache.php',
    'PHPUnit\\Runner\\ResultCache\\ResultCacheHandler' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/ResultCacheHandler.php',
    'PHPUnit\\Runner\\ResultCache\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/Subscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestConsideredRiskySubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestSuiteFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestSuiteFinishedSubscriber.php',
    'PHPUnit\\Runner\\ResultCache\\TestSuiteStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/ResultCache/Subscriber/TestSuiteStartedSubscriber.php',
    'PHPUnit\\Runner\\TestSuiteLoader' => $vendorDir . '/phpunit/phpunit/src/Runner/TestSuiteLoader.php',
    'PHPUnit\\Runner\\TestSuiteSorter' => $vendorDir . '/phpunit/phpunit/src/Runner/TestSuiteSorter.php',
    'PHPUnit\\Runner\\UnsupportedPhptSectionException' => $vendorDir . '/phpunit/phpunit/src/Runner/Exception/UnsupportedPhptSectionException.php',
    'PHPUnit\\Runner\\Version' => $vendorDir . '/phpunit/phpunit/src/Runner/Version.php',
    'PHPUnit\\TestRunner\\TestResult\\BeforeTestClassMethodErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/BeforeTestClassMethodErroredSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\Collector' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Collector.php',
    'PHPUnit\\TestRunner\\TestResult\\ExecutionStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/ExecutionStartedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\Facade' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Facade.php',
    'PHPUnit\\TestRunner\\TestResult\\Issues\\Issue' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Issue.php',
    'PHPUnit\\TestRunner\\TestResult\\PassedTests' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/PassedTests.php',
    'PHPUnit\\TestRunner\\TestResult\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/Subscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestConsideredRiskySubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestResult' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/TestResult.php',
    'PHPUnit\\TestRunner\\TestResult\\TestRunnerTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestRunnerTriggeredDeprecationSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestRunnerTriggeredWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestRunnerTriggeredWarningSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestSuiteFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestSuiteFinishedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestSuiteSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestSuiteSkippedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestSuiteStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestSuiteStartedSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredDeprecationSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredErrorSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredErrorSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredNoticeSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpDeprecationSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpNoticeSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpWarningSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpunitDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpunitDeprecationSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpunitErrorSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpunitErrorSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredPhpunitWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredPhpunitWarningSubscriber.php',
    'PHPUnit\\TestRunner\\TestResult\\TestTriggeredWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/Runner/TestResult/Subscriber/TestTriggeredWarningSubscriber.php',
    'PHPUnit\\TextUI\\Application' => $vendorDir . '/phpunit/phpunit/src/TextUI/Application.php',
    'PHPUnit\\TextUI\\CannotOpenSocketException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/CannotOpenSocketException.php',
    'PHPUnit\\TextUI\\CliArguments\\Builder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Cli/Builder.php',
    'PHPUnit\\TextUI\\CliArguments\\Configuration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Cli/Configuration.php',
    'PHPUnit\\TextUI\\CliArguments\\Exception' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Cli/Exception.php',
    'PHPUnit\\TextUI\\CliArguments\\XmlConfigurationFileFinder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Cli/XmlConfigurationFileFinder.php',
    'PHPUnit\\TextUI\\Command\\AtLeastVersionCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/AtLeastVersionCommand.php',
    'PHPUnit\\TextUI\\Command\\Command' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Command.php',
    'PHPUnit\\TextUI\\Command\\GenerateConfigurationCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/GenerateConfigurationCommand.php',
    'PHPUnit\\TextUI\\Command\\ListGroupsCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ListGroupsCommand.php',
    'PHPUnit\\TextUI\\Command\\ListTestFilesCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ListTestFilesCommand.php',
    'PHPUnit\\TextUI\\Command\\ListTestSuitesCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ListTestSuitesCommand.php',
    'PHPUnit\\TextUI\\Command\\ListTestsAsTextCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ListTestsAsTextCommand.php',
    'PHPUnit\\TextUI\\Command\\ListTestsAsXmlCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ListTestsAsXmlCommand.php',
    'PHPUnit\\TextUI\\Command\\MigrateConfigurationCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/MigrateConfigurationCommand.php',
    'PHPUnit\\TextUI\\Command\\Result' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Result.php',
    'PHPUnit\\TextUI\\Command\\ShowHelpCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ShowHelpCommand.php',
    'PHPUnit\\TextUI\\Command\\ShowVersionCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/ShowVersionCommand.php',
    'PHPUnit\\TextUI\\Command\\VersionCheckCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/VersionCheckCommand.php',
    'PHPUnit\\TextUI\\Command\\WarmCodeCoverageCacheCommand' => $vendorDir . '/phpunit/phpunit/src/TextUI/Command/Commands/WarmCodeCoverageCacheCommand.php',
    'PHPUnit\\TextUI\\Configuration\\Builder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Builder.php',
    'PHPUnit\\TextUI\\Configuration\\CodeCoverageFilterRegistry' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/CodeCoverageFilterRegistry.php',
    'PHPUnit\\TextUI\\Configuration\\CodeCoverageReportNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/CodeCoverageReportNotConfiguredException.php',
    'PHPUnit\\TextUI\\Configuration\\Configuration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Configuration.php',
    'PHPUnit\\TextUI\\Configuration\\ConfigurationCannotBeBuiltException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/ConfigurationCannotBeBuiltException.php',
    'PHPUnit\\TextUI\\Configuration\\Constant' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Constant.php',
    'PHPUnit\\TextUI\\Configuration\\ConstantCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/ConstantCollection.php',
    'PHPUnit\\TextUI\\Configuration\\ConstantCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/ConstantCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\Directory' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Directory.php',
    'PHPUnit\\TextUI\\Configuration\\DirectoryCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/DirectoryCollection.php',
    'PHPUnit\\TextUI\\Configuration\\DirectoryCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/DirectoryCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\Exception' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/Exception.php',
    'PHPUnit\\TextUI\\Configuration\\ExtensionBootstrap' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/ExtensionBootstrap.php',
    'PHPUnit\\TextUI\\Configuration\\ExtensionBootstrapCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/ExtensionBootstrapCollection.php',
    'PHPUnit\\TextUI\\Configuration\\ExtensionBootstrapCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/ExtensionBootstrapCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\File' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/File.php',
    'PHPUnit\\TextUI\\Configuration\\FileCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/FileCollection.php',
    'PHPUnit\\TextUI\\Configuration\\FileCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/FileCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\FilterDirectory' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/FilterDirectory.php',
    'PHPUnit\\TextUI\\Configuration\\FilterDirectoryCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/FilterDirectoryCollection.php',
    'PHPUnit\\TextUI\\Configuration\\FilterDirectoryCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/FilterDirectoryCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\FilterNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/FilterNotConfiguredException.php',
    'PHPUnit\\TextUI\\Configuration\\Group' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Group.php',
    'PHPUnit\\TextUI\\Configuration\\GroupCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/GroupCollection.php',
    'PHPUnit\\TextUI\\Configuration\\GroupCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/GroupCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\IncludePathNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/IncludePathNotConfiguredException.php',
    'PHPUnit\\TextUI\\Configuration\\IniSetting' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/IniSetting.php',
    'PHPUnit\\TextUI\\Configuration\\IniSettingCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/IniSettingCollection.php',
    'PHPUnit\\TextUI\\Configuration\\IniSettingCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/IniSettingCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\LoggingNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/LoggingNotConfiguredException.php',
    'PHPUnit\\TextUI\\Configuration\\Merger' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Merger.php',
    'PHPUnit\\TextUI\\Configuration\\NoBaselineException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoBaselineException.php',
    'PHPUnit\\TextUI\\Configuration\\NoBootstrapException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoBootstrapException.php',
    'PHPUnit\\TextUI\\Configuration\\NoCacheDirectoryException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoCacheDirectoryException.php',
    'PHPUnit\\TextUI\\Configuration\\NoCliArgumentException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoCliArgumentException.php',
    'PHPUnit\\TextUI\\Configuration\\NoConfigurationFileException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoConfigurationFileException.php',
    'PHPUnit\\TextUI\\Configuration\\NoCoverageCacheDirectoryException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoCoverageCacheDirectoryException.php',
    'PHPUnit\\TextUI\\Configuration\\NoCustomCssFileException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoCustomCssFileException.php',
    'PHPUnit\\TextUI\\Configuration\\NoDefaultTestSuiteException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoDefaultTestSuiteException.php',
    'PHPUnit\\TextUI\\Configuration\\NoPharExtensionDirectoryException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/NoPharExtensionDirectoryException.php',
    'PHPUnit\\TextUI\\Configuration\\Php' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Php.php',
    'PHPUnit\\TextUI\\Configuration\\PhpHandler' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/PhpHandler.php',
    'PHPUnit\\TextUI\\Configuration\\Registry' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Registry.php',
    'PHPUnit\\TextUI\\Configuration\\Source' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Source.php',
    'PHPUnit\\TextUI\\Configuration\\SourceFilter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/SourceFilter.php',
    'PHPUnit\\TextUI\\Configuration\\SourceMapper' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/SourceMapper.php',
    'PHPUnit\\TextUI\\Configuration\\TestDirectory' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestDirectory.php',
    'PHPUnit\\TextUI\\Configuration\\TestDirectoryCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestDirectoryCollection.php',
    'PHPUnit\\TextUI\\Configuration\\TestDirectoryCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestDirectoryCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\TestFile' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestFile.php',
    'PHPUnit\\TextUI\\Configuration\\TestFileCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestFileCollection.php',
    'PHPUnit\\TextUI\\Configuration\\TestFileCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestFileCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\TestSuite' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestSuite.php',
    'PHPUnit\\TextUI\\Configuration\\TestSuiteBuilder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/TestSuiteBuilder.php',
    'PHPUnit\\TextUI\\Configuration\\TestSuiteCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestSuiteCollection.php',
    'PHPUnit\\TextUI\\Configuration\\TestSuiteCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/TestSuiteCollectionIterator.php',
    'PHPUnit\\TextUI\\Configuration\\Variable' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/Variable.php',
    'PHPUnit\\TextUI\\Configuration\\VariableCollection' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/VariableCollection.php',
    'PHPUnit\\TextUI\\Configuration\\VariableCollectionIterator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Value/VariableCollectionIterator.php',
    'PHPUnit\\TextUI\\Exception' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/Exception.php',
    'PHPUnit\\TextUI\\ExtensionsNotConfiguredException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/ExtensionsNotConfiguredException.php',
    'PHPUnit\\TextUI\\Help' => $vendorDir . '/phpunit/phpunit/src/TextUI/Help.php',
    'PHPUnit\\TextUI\\InvalidSocketException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/InvalidSocketException.php',
    'PHPUnit\\TextUI\\Output\\DefaultPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Printer/DefaultPrinter.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\BeforeTestClassMethodErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/BeforeTestClassMethodErroredSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\ProgressPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/ProgressPrinter.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\Subscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/Subscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestConsideredRiskySubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestConsideredRiskySubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestErroredSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestErroredSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestFailedSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestFailedSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestFinishedSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestFinishedSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestMarkedIncompleteSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestMarkedIncompleteSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestPreparedSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestPreparedSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestRunnerExecutionStartedSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestRunnerExecutionStartedSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestSkippedSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestSkippedSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredDeprecationSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredErrorSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredErrorSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredNoticeSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredPhpDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredPhpDeprecationSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredPhpNoticeSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredPhpNoticeSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredPhpWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredPhpWarningSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredPhpunitDeprecationSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredPhpunitDeprecationSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredPhpunitWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredPhpunitWarningSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ProgressPrinter\\TestTriggeredWarningSubscriber' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ProgressPrinter/Subscriber/TestTriggeredWarningSubscriber.php',
    'PHPUnit\\TextUI\\Output\\Default\\ResultPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/ResultPrinter.php',
    'PHPUnit\\TextUI\\Output\\Default\\UnexpectedOutputPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Default/UnexpectedOutputPrinter.php',
    'PHPUnit\\TextUI\\Output\\Facade' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Facade.php',
    'PHPUnit\\TextUI\\Output\\NullPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Printer/NullPrinter.php',
    'PHPUnit\\TextUI\\Output\\Printer' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/Printer/Printer.php',
    'PHPUnit\\TextUI\\Output\\SummaryPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/SummaryPrinter.php',
    'PHPUnit\\TextUI\\Output\\TestDox\\ResultPrinter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Output/TestDox/ResultPrinter.php',
    'PHPUnit\\TextUI\\ReflectionException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/ReflectionException.php',
    'PHPUnit\\TextUI\\RuntimeException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/RuntimeException.php',
    'PHPUnit\\TextUI\\ShellExitCodeCalculator' => $vendorDir . '/phpunit/phpunit/src/TextUI/ShellExitCodeCalculator.php',
    'PHPUnit\\TextUI\\TestDirectoryNotFoundException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/TestDirectoryNotFoundException.php',
    'PHPUnit\\TextUI\\TestFileNotFoundException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Exception/TestFileNotFoundException.php',
    'PHPUnit\\TextUI\\TestRunner' => $vendorDir . '/phpunit/phpunit/src/TextUI/TestRunner.php',
    'PHPUnit\\TextUI\\TestSuiteFilterProcessor' => $vendorDir . '/phpunit/phpunit/src/TextUI/TestSuiteFilterProcessor.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CannotFindSchemaException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Exception/CannotFindSchemaException.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\CodeCoverage' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/CodeCoverage.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Clover' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Clover.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Cobertura' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Cobertura.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Crap4j' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Crap4j.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Html' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Html.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Php' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Php.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Text' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Text.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CodeCoverage\\Report\\Xml' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/CodeCoverage/Report/Xml.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Configuration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Configuration.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\ConvertLogTypes' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/ConvertLogTypes.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoverageCloverToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoverageCloverToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoverageCrap4jToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoverageCrap4jToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoverageHtmlToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoverageHtmlToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoveragePhpToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoveragePhpToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoverageTextToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoverageTextToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\CoverageXmlToReport' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/CoverageXmlToReport.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\DefaultConfiguration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/DefaultConfiguration.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Exception' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Exception.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\FailedSchemaDetectionResult' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/SchemaDetector/FailedSchemaDetectionResult.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Generator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Generator.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Groups' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Groups.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\IntroduceCacheDirectoryAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/IntroduceCacheDirectoryAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\IntroduceCoverageElement' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/IntroduceCoverageElement.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\LoadedFromFileConfiguration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/LoadedFromFileConfiguration.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Loader' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Loader.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\LogToReportMigration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/LogToReportMigration.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Logging\\Junit' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Logging/Junit.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Logging\\Logging' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Logging/Logging.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Logging\\TeamCity' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Logging/TeamCity.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Logging\\TestDox\\Html' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Logging/TestDox/Html.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Logging\\TestDox\\Text' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Logging/TestDox/Text.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Migration' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/Migration.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MigrationBuilder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/MigrationBuilder.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MigrationBuilderException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/MigrationBuilderException.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MigrationException' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/MigrationException.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Migrator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrator.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MoveAttributesFromFilterWhitelistToCoverage' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/MoveAttributesFromFilterWhitelistToCoverage.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MoveAttributesFromRootToCoverage' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/MoveAttributesFromRootToCoverage.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MoveCoverageDirectoriesToSource' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/MoveCoverageDirectoriesToSource.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MoveWhitelistExcludesToCoverage' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/MoveWhitelistExcludesToCoverage.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\MoveWhitelistIncludesToCoverage' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/MoveWhitelistIncludesToCoverage.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\PHPUnit' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/PHPUnit.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveBeStrictAboutResourceUsageDuringSmallTestsAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveBeStrictAboutResourceUsageDuringSmallTestsAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveBeStrictAboutTodoAnnotatedTestsAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveBeStrictAboutTodoAnnotatedTestsAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveCacheResultFileAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveCacheResultFileAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveCacheTokensAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveCacheTokensAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveConversionToExceptionsAttributes' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveConversionToExceptionsAttributes.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveCoverageElementCacheDirectoryAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveCoverageElementCacheDirectoryAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveCoverageElementProcessUncoveredFilesAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveCoverageElementProcessUncoveredFilesAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveEmptyFilter' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveEmptyFilter.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveListeners' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveListeners.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveLogTypes' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveLogTypes.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveLoggingElements' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveLoggingElements.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveNoInteractionAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveNoInteractionAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemovePrinterAttributes' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemovePrinterAttributes.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveRegisterMockObjectsFromTestArgumentsRecursivelyAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveRegisterMockObjectsFromTestArgumentsRecursivelyAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveTestDoxGroupsElement' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveTestDoxGroupsElement.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveTestSuiteLoaderAttributes' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveTestSuiteLoaderAttributes.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RemoveVerboseAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RemoveVerboseAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RenameBackupStaticAttributesAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RenameBackupStaticAttributesAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RenameBeStrictAboutCoversAnnotationAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RenameBeStrictAboutCoversAnnotationAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\RenameForceCoversAnnotationAttribute' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/RenameForceCoversAnnotationAttribute.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\ReplaceRestrictDeprecationsWithIgnoreDeprecations' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/ReplaceRestrictDeprecationsWithIgnoreDeprecations.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\SchemaDetectionResult' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/SchemaDetector/SchemaDetectionResult.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\SchemaDetector' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/SchemaDetector/SchemaDetector.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\SchemaFinder' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/SchemaFinder.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\SnapshotNodeList' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/SnapshotNodeList.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\SuccessfulSchemaDetectionResult' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/SchemaDetector/SuccessfulSchemaDetectionResult.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\TestSuiteMapper' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/TestSuiteMapper.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\UpdateSchemaLocation' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Migration/Migrations/UpdateSchemaLocation.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\ValidationResult' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Validator/ValidationResult.php',
    'PHPUnit\\TextUI\\XmlConfiguration\\Validator' => $vendorDir . '/phpunit/phpunit/src/TextUI/Configuration/Xml/Validator/Validator.php',
    'PHPUnit\\Util\\Cloner' => $vendorDir . '/phpunit/phpunit/src/Util/Cloner.php',
    'PHPUnit\\Util\\Color' => $vendorDir . '/phpunit/phpunit/src/Util/Color.php',
    'PHPUnit\\Util\\Exception' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/Exception.php',
    'PHPUnit\\Util\\ExcludeList' => $vendorDir . '/phpunit/phpunit/src/Util/ExcludeList.php',
    'PHPUnit\\Util\\Exporter' => $vendorDir . '/phpunit/phpunit/src/Util/Exporter.php',
    'PHPUnit\\Util\\Filesystem' => $vendorDir . '/phpunit/phpunit/src/Util/Filesystem.php',
    'PHPUnit\\Util\\Filter' => $vendorDir . '/phpunit/phpunit/src/Util/Filter.php',
    'PHPUnit\\Util\\GlobalState' => $vendorDir . '/phpunit/phpunit/src/Util/GlobalState.php',
    'PHPUnit\\Util\\InvalidDirectoryException' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/InvalidDirectoryException.php',
    'PHPUnit\\Util\\InvalidJsonException' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/InvalidJsonException.php',
    'PHPUnit\\Util\\InvalidVersionOperatorException' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/InvalidVersionOperatorException.php',
    'PHPUnit\\Util\\Json' => $vendorDir . '/phpunit/phpunit/src/Util/Json.php',
    'PHPUnit\\Util\\PHP\\DefaultJobRunner' => $vendorDir . '/phpunit/phpunit/src/Util/PHP/DefaultJobRunner.php',
    'PHPUnit\\Util\\PHP\\Job' => $vendorDir . '/phpunit/phpunit/src/Util/PHP/Job.php',
    'PHPUnit\\Util\\PHP\\JobRunner' => $vendorDir . '/phpunit/phpunit/src/Util/PHP/JobRunner.php',
    'PHPUnit\\Util\\PHP\\JobRunnerRegistry' => $vendorDir . '/phpunit/phpunit/src/Util/PHP/JobRunnerRegistry.php',
    'PHPUnit\\Util\\PHP\\PhpProcessException' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/PhpProcessException.php',
    'PHPUnit\\Util\\PHP\\Result' => $vendorDir . '/phpunit/phpunit/src/Util/PHP/Result.php',
    'PHPUnit\\Util\\Reflection' => $vendorDir . '/phpunit/phpunit/src/Util/Reflection.php',
    'PHPUnit\\Util\\Test' => $vendorDir . '/phpunit/phpunit/src/Util/Test.php',
    'PHPUnit\\Util\\ThrowableToStringMapper' => $vendorDir . '/phpunit/phpunit/src/Util/ThrowableToStringMapper.php',
    'PHPUnit\\Util\\VersionComparisonOperator' => $vendorDir . '/phpunit/phpunit/src/Util/VersionComparisonOperator.php',
    'PHPUnit\\Util\\Xml' => $vendorDir . '/phpunit/phpunit/src/Util/Xml/Xml.php',
    'PHPUnit\\Util\\Xml\\Loader' => $vendorDir . '/phpunit/phpunit/src/Util/Xml/Loader.php',
    'PHPUnit\\Util\\Xml\\XmlException' => $vendorDir . '/phpunit/phpunit/src/Util/Exception/XmlException.php',
    'ParagonIE\\ConstantTime\\Base32' => $vendorDir . '/paragonie/constant_time_encoding/src/Base32.php',
    'ParagonIE\\ConstantTime\\Base32Hex' => $vendorDir . '/paragonie/constant_time_encoding/src/Base32Hex.php',
    'ParagonIE\\ConstantTime\\Base64' => $vendorDir . '/paragonie/constant_time_encoding/src/Base64.php',
    'ParagonIE\\ConstantTime\\Base64DotSlash' => $vendorDir . '/paragonie/constant_time_encoding/src/Base64DotSlash.php',
    'ParagonIE\\ConstantTime\\Base64DotSlashOrdered' => $vendorDir . '/paragonie/constant_time_encoding/src/Base64DotSlashOrdered.php',
    'ParagonIE\\ConstantTime\\Base64UrlSafe' => $vendorDir . '/paragonie/constant_time_encoding/src/Base64UrlSafe.php',
    'ParagonIE\\ConstantTime\\Binary' => $vendorDir . '/paragonie/constant_time_encoding/src/Binary.php',
    'ParagonIE\\ConstantTime\\EncoderInterface' => $vendorDir . '/paragonie/constant_time_encoding/src/EncoderInterface.php',
    'ParagonIE\\ConstantTime\\Encoding' => $vendorDir . '/paragonie/constant_time_encoding/src/Encoding.php',
    'ParagonIE\\ConstantTime\\Hex' => $vendorDir . '/paragonie/constant_time_encoding/src/Hex.php',
    'ParagonIE\\ConstantTime\\RFC4648' => $vendorDir . '/paragonie/constant_time_encoding/src/RFC4648.php',
    'Paymentwall_ApiObject' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/ApiObject.php',
    'Paymentwall_ApiObjectInterface' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/ApiObjectInterface.php',
    'Paymentwall_Base' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Base.php',
    'Paymentwall_Card' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Card.php',
    'Paymentwall_Charge' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Charge.php',
    'Paymentwall_Config' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Config.php',
    'Paymentwall_GenerericApiObject' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/GenerericApiObject.php',
    'Paymentwall_HttpAction' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/HttpAction.php',
    'Paymentwall_Instance' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Instance.php',
    'Paymentwall_Mobiamo' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Mobiamo.php',
    'Paymentwall_OneTimeToken' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/OneTimeToken.php',
    'Paymentwall_Pingback' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Pingback.php',
    'Paymentwall_Product' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Product.php',
    'Paymentwall_Response_Abstract' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Response/Abstract.php',
    'Paymentwall_Response_Error' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Response/Error.php',
    'Paymentwall_Response_Factory' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Response/Factory.php',
    'Paymentwall_Response_Interface' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Response/Interface.php',
    'Paymentwall_Response_Success' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Response/Success.php',
    'Paymentwall_Signature_Abstract' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Signature/Abstract.php',
    'Paymentwall_Signature_Pingback' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Signature/Pingback.php',
    'Paymentwall_Signature_Widget' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Signature/Widget.php',
    'Paymentwall_Subscription' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Subscription.php',
    'Paymentwall_Widget' => $vendorDir . '/paymentwall/paymentwall-php/lib/Paymentwall/Widget.php',
    'PharIo\\Manifest\\Application' => $vendorDir . '/phar-io/manifest/src/values/Application.php',
    'PharIo\\Manifest\\ApplicationName' => $vendorDir . '/phar-io/manifest/src/values/ApplicationName.php',
    'PharIo\\Manifest\\Author' => $vendorDir . '/phar-io/manifest/src/values/Author.php',
    'PharIo\\Manifest\\AuthorCollection' => $vendorDir . '/phar-io/manifest/src/values/AuthorCollection.php',
    'PharIo\\Manifest\\AuthorCollectionIterator' => $vendorDir . '/phar-io/manifest/src/values/AuthorCollectionIterator.php',
    'PharIo\\Manifest\\AuthorElement' => $vendorDir . '/phar-io/manifest/src/xml/AuthorElement.php',
    'PharIo\\Manifest\\AuthorElementCollection' => $vendorDir . '/phar-io/manifest/src/xml/AuthorElementCollection.php',
    'PharIo\\Manifest\\BundledComponent' => $vendorDir . '/phar-io/manifest/src/values/BundledComponent.php',
    'PharIo\\Manifest\\BundledComponentCollection' => $vendorDir . '/phar-io/manifest/src/values/BundledComponentCollection.php',
    'PharIo\\Manifest\\BundledComponentCollectionIterator' => $vendorDir . '/phar-io/manifest/src/values/BundledComponentCollectionIterator.php',
    'PharIo\\Manifest\\BundlesElement' => $vendorDir . '/phar-io/manifest/src/xml/BundlesElement.php',
    'PharIo\\Manifest\\ComponentElement' => $vendorDir . '/phar-io/manifest/src/xml/ComponentElement.php',
    'PharIo\\Manifest\\ComponentElementCollection' => $vendorDir . '/phar-io/manifest/src/xml/ComponentElementCollection.php',
    'PharIo\\Manifest\\ContainsElement' => $vendorDir . '/phar-io/manifest/src/xml/ContainsElement.php',
    'PharIo\\Manifest\\CopyrightElement' => $vendorDir . '/phar-io/manifest/src/xml/CopyrightElement.php',
    'PharIo\\Manifest\\CopyrightInformation' => $vendorDir . '/phar-io/manifest/src/values/CopyrightInformation.php',
    'PharIo\\Manifest\\ElementCollection' => $vendorDir . '/phar-io/manifest/src/xml/ElementCollection.php',
    'PharIo\\Manifest\\ElementCollectionException' => $vendorDir . '/phar-io/manifest/src/exceptions/ElementCollectionException.php',
    'PharIo\\Manifest\\Email' => $vendorDir . '/phar-io/manifest/src/values/Email.php',
    'PharIo\\Manifest\\Exception' => $vendorDir . '/phar-io/manifest/src/exceptions/Exception.php',
    'PharIo\\Manifest\\ExtElement' => $vendorDir . '/phar-io/manifest/src/xml/ExtElement.php',
    'PharIo\\Manifest\\ExtElementCollection' => $vendorDir . '/phar-io/manifest/src/xml/ExtElementCollection.php',
    'PharIo\\Manifest\\Extension' => $vendorDir . '/phar-io/manifest/src/values/Extension.php',
    'PharIo\\Manifest\\ExtensionElement' => $vendorDir . '/phar-io/manifest/src/xml/ExtensionElement.php',
    'PharIo\\Manifest\\InvalidApplicationNameException' => $vendorDir . '/phar-io/manifest/src/exceptions/InvalidApplicationNameException.php',
    'PharIo\\Manifest\\InvalidEmailException' => $vendorDir . '/phar-io/manifest/src/exceptions/InvalidEmailException.php',
    'PharIo\\Manifest\\InvalidUrlException' => $vendorDir . '/phar-io/manifest/src/exceptions/InvalidUrlException.php',
    'PharIo\\Manifest\\Library' => $vendorDir . '/phar-io/manifest/src/values/Library.php',
    'PharIo\\Manifest\\License' => $vendorDir . '/phar-io/manifest/src/values/License.php',
    'PharIo\\Manifest\\LicenseElement' => $vendorDir . '/phar-io/manifest/src/xml/LicenseElement.php',
    'PharIo\\Manifest\\Manifest' => $vendorDir . '/phar-io/manifest/src/values/Manifest.php',
    'PharIo\\Manifest\\ManifestDocument' => $vendorDir . '/phar-io/manifest/src/xml/ManifestDocument.php',
    'PharIo\\Manifest\\ManifestDocumentException' => $vendorDir . '/phar-io/manifest/src/exceptions/ManifestDocumentException.php',
    'PharIo\\Manifest\\ManifestDocumentLoadingException' => $vendorDir . '/phar-io/manifest/src/exceptions/ManifestDocumentLoadingException.php',
    'PharIo\\Manifest\\ManifestDocumentMapper' => $vendorDir . '/phar-io/manifest/src/ManifestDocumentMapper.php',
    'PharIo\\Manifest\\ManifestDocumentMapperException' => $vendorDir . '/phar-io/manifest/src/exceptions/ManifestDocumentMapperException.php',
    'PharIo\\Manifest\\ManifestElement' => $vendorDir . '/phar-io/manifest/src/xml/ManifestElement.php',
    'PharIo\\Manifest\\ManifestElementException' => $vendorDir . '/phar-io/manifest/src/exceptions/ManifestElementException.php',
    'PharIo\\Manifest\\ManifestLoader' => $vendorDir . '/phar-io/manifest/src/ManifestLoader.php',
    'PharIo\\Manifest\\ManifestLoaderException' => $vendorDir . '/phar-io/manifest/src/exceptions/ManifestLoaderException.php',
    'PharIo\\Manifest\\ManifestSerializer' => $vendorDir . '/phar-io/manifest/src/ManifestSerializer.php',
    'PharIo\\Manifest\\NoEmailAddressException' => $vendorDir . '/phar-io/manifest/src/exceptions/NoEmailAddressException.php',
    'PharIo\\Manifest\\PhpElement' => $vendorDir . '/phar-io/manifest/src/xml/PhpElement.php',
    'PharIo\\Manifest\\PhpExtensionRequirement' => $vendorDir . '/phar-io/manifest/src/values/PhpExtensionRequirement.php',
    'PharIo\\Manifest\\PhpVersionRequirement' => $vendorDir . '/phar-io/manifest/src/values/PhpVersionRequirement.php',
    'PharIo\\Manifest\\Requirement' => $vendorDir . '/phar-io/manifest/src/values/Requirement.php',
    'PharIo\\Manifest\\RequirementCollection' => $vendorDir . '/phar-io/manifest/src/values/RequirementCollection.php',
    'PharIo\\Manifest\\RequirementCollectionIterator' => $vendorDir . '/phar-io/manifest/src/values/RequirementCollectionIterator.php',
    'PharIo\\Manifest\\RequiresElement' => $vendorDir . '/phar-io/manifest/src/xml/RequiresElement.php',
    'PharIo\\Manifest\\Type' => $vendorDir . '/phar-io/manifest/src/values/Type.php',
    'PharIo\\Manifest\\Url' => $vendorDir . '/phar-io/manifest/src/values/Url.php',
    'PharIo\\Version\\AbstractVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/AbstractVersionConstraint.php',
    'PharIo\\Version\\AndVersionConstraintGroup' => $vendorDir . '/phar-io/version/src/constraints/AndVersionConstraintGroup.php',
    'PharIo\\Version\\AnyVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/AnyVersionConstraint.php',
    'PharIo\\Version\\BuildMetaData' => $vendorDir . '/phar-io/version/src/BuildMetaData.php',
    'PharIo\\Version\\ExactVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/ExactVersionConstraint.php',
    'PharIo\\Version\\Exception' => $vendorDir . '/phar-io/version/src/exceptions/Exception.php',
    'PharIo\\Version\\GreaterThanOrEqualToVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/GreaterThanOrEqualToVersionConstraint.php',
    'PharIo\\Version\\InvalidPreReleaseSuffixException' => $vendorDir . '/phar-io/version/src/exceptions/InvalidPreReleaseSuffixException.php',
    'PharIo\\Version\\InvalidVersionException' => $vendorDir . '/phar-io/version/src/exceptions/InvalidVersionException.php',
    'PharIo\\Version\\NoBuildMetaDataException' => $vendorDir . '/phar-io/version/src/exceptions/NoBuildMetaDataException.php',
    'PharIo\\Version\\NoPreReleaseSuffixException' => $vendorDir . '/phar-io/version/src/exceptions/NoPreReleaseSuffixException.php',
    'PharIo\\Version\\OrVersionConstraintGroup' => $vendorDir . '/phar-io/version/src/constraints/OrVersionConstraintGroup.php',
    'PharIo\\Version\\PreReleaseSuffix' => $vendorDir . '/phar-io/version/src/PreReleaseSuffix.php',
    'PharIo\\Version\\SpecificMajorAndMinorVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/SpecificMajorAndMinorVersionConstraint.php',
    'PharIo\\Version\\SpecificMajorVersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/SpecificMajorVersionConstraint.php',
    'PharIo\\Version\\UnsupportedVersionConstraintException' => $vendorDir . '/phar-io/version/src/exceptions/UnsupportedVersionConstraintException.php',
    'PharIo\\Version\\Version' => $vendorDir . '/phar-io/version/src/Version.php',
    'PharIo\\Version\\VersionConstraint' => $vendorDir . '/phar-io/version/src/constraints/VersionConstraint.php',
    'PharIo\\Version\\VersionConstraintParser' => $vendorDir . '/phar-io/version/src/VersionConstraintParser.php',
    'PharIo\\Version\\VersionConstraintValue' => $vendorDir . '/phar-io/version/src/VersionConstraintValue.php',
    'PharIo\\Version\\VersionNumber' => $vendorDir . '/phar-io/version/src/VersionNumber.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\ArrayEnabled' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/ArrayEnabled.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\BinaryComparison' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/BinaryComparison.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Calculation' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Calculation.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Category' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Category.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DAverage' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DAverage.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DCount' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DCount.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DCountA' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DCountA.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DGet' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DGet.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DMax' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DMax.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DMin' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DMin.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DProduct' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DProduct.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DStDev' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DStDev.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DStDevP' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DStDevP.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DSum' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DSum.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DVar' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DVar.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DVarP' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DVarP.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Database\\DatabaseAbstract' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Database/DatabaseAbstract.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTime' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTime.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Constants' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Constants.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Current' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Current.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Date' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Date.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\DateParts' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/DateParts.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\DateValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/DateValue.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Days' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Days.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Days360' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Days360.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Difference' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Difference.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Helpers' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Helpers.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Month' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Month.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\NetworkDays' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/NetworkDays.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Time' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Time.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\TimeParts' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/TimeParts.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\TimeValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/TimeValue.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\Week' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/Week.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\WorkDay' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/WorkDay.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\DateTimeExcel\\YearFrac' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/DateTimeExcel/YearFrac.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\ArrayArgumentHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/ArrayArgumentHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\ArrayArgumentProcessor' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/ArrayArgumentProcessor.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\BranchPruner' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/BranchPruner.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\CyclicReferenceStack' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/CyclicReferenceStack.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\FormattedNumber' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/FormattedNumber.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\Logger' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/Logger.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\Operands\\Operand' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/Operands/Operand.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engine\\Operands\\StructuredReference' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engine/Operands/StructuredReference.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\BesselI' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/BesselI.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\BesselJ' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/BesselJ.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\BesselK' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/BesselK.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\BesselY' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/BesselY.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\BitWise' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/BitWise.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\Compare' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/Compare.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\Complex' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/Complex.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ComplexFunctions' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ComplexFunctions.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ComplexOperations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ComplexOperations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\Constants' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/Constants.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertBinary' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertBinary.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertDecimal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertDecimal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertHex' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertHex.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertOctal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertOctal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ConvertUOM' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ConvertUOM.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\EngineeringValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/EngineeringValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\Erf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/Erf.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Engineering\\ErfC' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Engineering/ErfC.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Exception' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Exception.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\ExceptionHandler' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/ExceptionHandler.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Amortization' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Amortization.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\CashFlowValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/CashFlowValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Constant\\Periodic' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Constant/Periodic.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Constant\\Periodic\\Cumulative' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Constant/Periodic/Cumulative.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Constant\\Periodic\\Interest' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Constant/Periodic/Interest.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Constant\\Periodic\\InterestAndPrincipal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Constant/Periodic/InterestAndPrincipal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Constant\\Periodic\\Payments' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Constant/Periodic/Payments.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Single' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Single.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Variable\\NonPeriodic' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Variable/NonPeriodic.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\CashFlow\\Variable\\Periodic' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/CashFlow/Variable/Periodic.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Constants' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Constants.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Coupons' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Coupons.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Depreciation' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Depreciation.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Dollar' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Dollar.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\FinancialValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/FinancialValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Helpers' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Helpers.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\InterestRate' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/InterestRate.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Securities\\AccruedInterest' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Securities/AccruedInterest.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Securities\\Price' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Securities/Price.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Securities\\Rates' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Securities/Rates.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Securities\\SecurityValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Securities/SecurityValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\Securities\\Yields' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/Securities/Yields.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Financial\\TreasuryBill' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Financial/TreasuryBill.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\FormulaParser' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/FormulaParser.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\FormulaToken' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/FormulaToken.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Functions' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Functions.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Information\\ErrorValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Information/ErrorValue.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Information\\ExcelError' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Information/ExcelError.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Information\\Value' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Information/Value.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Internal\\MakeMatrix' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Internal/MakeMatrix.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Internal\\WildcardMatch' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Internal/WildcardMatch.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Logical' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Logical.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Logical\\Boolean' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Logical/Boolean.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Logical\\Conditional' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Logical/Conditional.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Logical\\Operations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Logical/Operations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Address' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Address.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\ExcelMatch' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/ExcelMatch.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Filter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Filter.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Formula' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Formula.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\HLookup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/HLookup.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Helpers' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Helpers.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Hyperlink' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Hyperlink.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Indirect' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Indirect.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Lookup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Lookup.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\LookupBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/LookupBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\LookupRefValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/LookupRefValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Matrix' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Matrix.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Offset' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Offset.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\RowColumnInformation' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/RowColumnInformation.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Selection' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Selection.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Sort' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Sort.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\Unique' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/Unique.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\LookupRef\\VLookup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/LookupRef/VLookup.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Absolute' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Absolute.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Angle' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Angle.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Arabic' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Arabic.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Base' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Base.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Ceiling' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Ceiling.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Combinations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Combinations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Exp' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Exp.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Factorial' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Factorial.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Floor' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Floor.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Gcd' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Gcd.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Helpers' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Helpers.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\IntClass' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/IntClass.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Lcm' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Lcm.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Logarithms' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Logarithms.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\MatrixFunctions' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/MatrixFunctions.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Operations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Operations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Random' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Random.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Roman' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Roman.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Round' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Round.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\SeriesSum' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/SeriesSum.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Sign' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Sign.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Sqrt' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Sqrt.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Subtotal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Subtotal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Sum' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Sum.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\SumSquares' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/SumSquares.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Cosecant' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Cosecant.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Cosine' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Cosine.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Cotangent' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Cotangent.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Secant' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Secant.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Sine' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Sine.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trig\\Tangent' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trig/Tangent.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\MathTrig\\Trunc' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/MathTrig/Trunc.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\AggregateBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/AggregateBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Averages' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Averages.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Averages\\Mean' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Averages/Mean.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Conditional' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Conditional.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Confidence' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Confidence.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Counts' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Counts.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Deviations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Deviations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Beta' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Beta.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Binomial' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Binomial.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\ChiSquared' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/ChiSquared.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\DistributionValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/DistributionValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Exponential' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Exponential.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\F' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/F.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Fisher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Fisher.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Gamma' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Gamma.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\GammaBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/GammaBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\HyperGeometric' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/HyperGeometric.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\LogNormal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/LogNormal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\NewtonRaphson' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/NewtonRaphson.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Normal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Normal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Poisson' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Poisson.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\StandardNormal' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/StandardNormal.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\StudentT' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/StudentT.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Distributions\\Weibull' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Distributions/Weibull.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\MaxMinBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/MaxMinBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Maximum' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Maximum.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Minimum' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Minimum.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Percentiles' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Percentiles.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Permutations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Permutations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Size' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Size.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\StandardDeviations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/StandardDeviations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Standardize' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Standardize.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\StatisticalValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/StatisticalValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Trends' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Trends.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\VarianceBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/VarianceBase.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Statistical\\Variances' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Statistical/Variances.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\CaseConvert' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/CaseConvert.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\CharacterConvert' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/CharacterConvert.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Concatenate' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Concatenate.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Extract' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Extract.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Format' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Format.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Helpers' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Helpers.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Replace' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Replace.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Search' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Search.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Text' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Text.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\TextData\\Trim' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/TextData/Trim.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Token\\Stack' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Token/Stack.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Web' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Web.php',
    'PhpOffice\\PhpSpreadsheet\\Calculation\\Web\\Service' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Calculation/Web/Service.php',
    'PhpOffice\\PhpSpreadsheet\\CellReferenceHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/CellReferenceHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\AddressHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/AddressHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\AddressRange' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/AddressRange.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\AdvancedValueBinder' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/AdvancedValueBinder.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\Cell' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/Cell.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\CellAddress' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/CellAddress.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\CellRange' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/CellRange.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\ColumnRange' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/ColumnRange.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\Coordinate' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/Coordinate.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\DataType' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/DataType.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\DataValidation' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/DataValidation.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\DataValidator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/DataValidator.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\DefaultValueBinder' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/DefaultValueBinder.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\Hyperlink' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/Hyperlink.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\IValueBinder' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/IValueBinder.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\IgnoredErrors' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/IgnoredErrors.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\RowRange' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/RowRange.php',
    'PhpOffice\\PhpSpreadsheet\\Cell\\StringValueBinder' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Cell/StringValueBinder.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Axis' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Axis.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\AxisText' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/AxisText.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Chart' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Chart.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\ChartColor' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/ChartColor.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\DataSeries' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/DataSeries.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\DataSeriesValues' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/DataSeriesValues.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Exception' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Exception.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\GridLines' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/GridLines.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Layout' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Layout.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Legend' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Legend.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\PlotArea' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/PlotArea.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Renderer\\IRenderer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Renderer/IRenderer.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Renderer\\JpGraph' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Renderer/JpGraph.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Renderer\\JpGraphRendererBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Renderer/JpGraphRendererBase.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Renderer\\MtJpGraphRenderer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Renderer/MtJpGraphRenderer.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\Title' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/Title.php',
    'PhpOffice\\PhpSpreadsheet\\Chart\\TrendLine' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Chart/TrendLine.php',
    'PhpOffice\\PhpSpreadsheet\\Collection\\Cells' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Collection/Cells.php',
    'PhpOffice\\PhpSpreadsheet\\Collection\\CellsFactory' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Collection/CellsFactory.php',
    'PhpOffice\\PhpSpreadsheet\\Collection\\Memory\\SimpleCache1' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Collection/Memory/SimpleCache1.php',
    'PhpOffice\\PhpSpreadsheet\\Collection\\Memory\\SimpleCache3' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Collection/Memory/SimpleCache3.php',
    'PhpOffice\\PhpSpreadsheet\\Comment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Comment.php',
    'PhpOffice\\PhpSpreadsheet\\DefinedName' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/DefinedName.php',
    'PhpOffice\\PhpSpreadsheet\\Document\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Document/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Document\\Security' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Document/Security.php',
    'PhpOffice\\PhpSpreadsheet\\Exception' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Exception.php',
    'PhpOffice\\PhpSpreadsheet\\HashTable' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/HashTable.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Dimension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Dimension.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Downloader' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Downloader.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Handler' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Handler.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Html' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Html.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Sample' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Sample.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\Size' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/Size.php',
    'PhpOffice\\PhpSpreadsheet\\Helper\\TextGrid' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Helper/TextGrid.php',
    'PhpOffice\\PhpSpreadsheet\\IComparable' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/IComparable.php',
    'PhpOffice\\PhpSpreadsheet\\IOFactory' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/IOFactory.php',
    'PhpOffice\\PhpSpreadsheet\\NamedFormula' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/NamedFormula.php',
    'PhpOffice\\PhpSpreadsheet\\NamedRange' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/NamedRange.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\BaseReader' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/BaseReader.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Csv' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Csv.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Csv\\Delimiter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Csv/Delimiter.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\DefaultReadFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/DefaultReadFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Exception' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Exception.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Gnumeric' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Gnumeric.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Gnumeric\\PageSetup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Gnumeric/PageSetup.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Gnumeric\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Gnumeric/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Gnumeric\\Styles' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Gnumeric/Styles.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Html' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Html.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\IReadFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/IReadFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\IReader' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/IReader.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\AutoFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/AutoFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\BaseLoader' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/BaseLoader.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\DefinedNames' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/DefinedNames.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\FormulaTranslator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/FormulaTranslator.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\PageSettings' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/PageSettings.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Ods\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Ods/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Security\\XmlScanner' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Security/XmlScanner.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Slk' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Slk.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Color' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Color.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Color\\BIFF5' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Color/BIFF5.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Color\\BIFF8' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Color/BIFF8.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Color\\BuiltIn' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Color/BuiltIn.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\ConditionalFormatting' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/ConditionalFormatting.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\DataValidationHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/DataValidationHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\ErrorCode' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/ErrorCode.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Escher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Escher.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\MD5' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/MD5.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\RC4' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/RC4.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Style\\Border' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Style/Border.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Style\\CellAlignment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Style/CellAlignment.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Style\\CellFont' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Style/CellFont.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xls\\Style\\FillPattern' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xls/Style/FillPattern.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\AutoFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/AutoFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\BaseParserClass' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/BaseParserClass.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Chart' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Chart.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\ColumnAndRowAttributes' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/ColumnAndRowAttributes.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\ConditionalStyles' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/ConditionalStyles.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\DataValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/DataValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Hyperlinks' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Hyperlinks.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Namespaces' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Namespaces.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\PageSetup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/PageSetup.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\SharedFormula' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/SharedFormula.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\SheetViewOptions' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/SheetViewOptions.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\SheetViews' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/SheetViews.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Styles' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Styles.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\TableReader' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/TableReader.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\Theme' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/Theme.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xlsx\\WorkbookView' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xlsx/WorkbookView.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\DataValidations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/DataValidations.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\PageSettings' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/PageSettings.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Properties' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Properties.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\Alignment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/Alignment.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\Border' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/Border.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\Fill' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/Fill.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\Font' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/Font.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\NumberFormat' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/NumberFormat.php',
    'PhpOffice\\PhpSpreadsheet\\Reader\\Xml\\Style\\StyleBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Reader/Xml/Style/StyleBase.php',
    'PhpOffice\\PhpSpreadsheet\\ReferenceHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/ReferenceHelper.php',
    'PhpOffice\\PhpSpreadsheet\\RichText\\ITextElement' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/RichText/ITextElement.php',
    'PhpOffice\\PhpSpreadsheet\\RichText\\RichText' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/RichText/RichText.php',
    'PhpOffice\\PhpSpreadsheet\\RichText\\Run' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/RichText/Run.php',
    'PhpOffice\\PhpSpreadsheet\\RichText\\TextElement' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/RichText/TextElement.php',
    'PhpOffice\\PhpSpreadsheet\\Settings' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Settings.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\CodePage' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/CodePage.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Date' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Date.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Drawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Drawing.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DgContainer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DgContainer.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DgContainer\\SpgrContainer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DgContainer/SpgrContainer.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DgContainer\\SpgrContainer\\SpContainer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DgContainer/SpgrContainer/SpContainer.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DggContainer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DggContainer.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DggContainer\\BstoreContainer' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DggContainer/BstoreContainer.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DggContainer\\BstoreContainer\\BSE' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DggContainer/BstoreContainer/BSE.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Escher\\DggContainer\\BstoreContainer\\BSE\\Blip' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Escher/DggContainer/BstoreContainer/BSE/Blip.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\File' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/File.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Font' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Font.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\IntOrFloat' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/IntOrFloat.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLE' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLE.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLERead' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLERead.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLE\\ChainedBlockStream' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLE/ChainedBlockStream.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLE\\PPS' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLE/PPS.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLE\\PPS\\File' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLE/PPS/File.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\OLE\\PPS\\Root' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/OLE/PPS/Root.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\PasswordHasher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/PasswordHasher.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\StringHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/StringHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\TimeZone' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/TimeZone.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\BestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/BestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\ExponentialBestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/ExponentialBestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\LinearBestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/LinearBestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\LogarithmicBestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/LogarithmicBestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\PolynomialBestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/PolynomialBestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\PowerBestFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/PowerBestFit.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Trend\\Trend' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Trend/Trend.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\XMLWriter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/XMLWriter.php',
    'PhpOffice\\PhpSpreadsheet\\Shared\\Xls' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Shared/Xls.php',
    'PhpOffice\\PhpSpreadsheet\\Spreadsheet' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Spreadsheet.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Alignment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Alignment.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Border' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Border.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Borders' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Borders.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Color' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Color.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Conditional' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Conditional.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\CellMatcher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/CellMatcher.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\CellStyleAssessor' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/CellStyleAssessor.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\ConditionalDataBar' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/ConditionalDataBar.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\ConditionalDataBarExtension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/ConditionalDataBarExtension.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\ConditionalFormatValueObject' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/ConditionalFormatValueObject.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\ConditionalFormattingRuleExtension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/ConditionalFormattingRuleExtension.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\StyleMerger' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/StyleMerger.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\Blanks' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/Blanks.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\CellValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/CellValue.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\DateValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/DateValue.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\Duplicates' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/Duplicates.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\Errors' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/Errors.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\Expression' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/Expression.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\TextValue' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/TextValue.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\WizardAbstract' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/WizardAbstract.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\ConditionalFormatting\\Wizard\\WizardInterface' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/ConditionalFormatting/Wizard/WizardInterface.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Fill' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Fill.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Font' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Font.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\BaseFormatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/BaseFormatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\DateFormatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/DateFormatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Formatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Formatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\FractionFormatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/FractionFormatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\NumberFormatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/NumberFormatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\PercentageFormatter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/PercentageFormatter.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Accounting' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Accounting.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Currency' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Currency.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Date' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Date.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\DateTime' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/DateTime.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\DateTimeWizard' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/DateTimeWizard.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Duration' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Duration.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Locale' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Locale.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Number' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Number.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\NumberBase' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/NumberBase.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Percentage' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Percentage.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Scientific' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Scientific.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Time' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Time.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\NumberFormat\\Wizard\\Wizard' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/NumberFormat/Wizard/Wizard.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Protection' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Protection.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\RgbTint' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/RgbTint.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Style' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Style.php',
    'PhpOffice\\PhpSpreadsheet\\Style\\Supervisor' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Style/Supervisor.php',
    'PhpOffice\\PhpSpreadsheet\\Theme' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Theme.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\AutoFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/AutoFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\AutoFilter\\Column' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/AutoFilter/Column.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\AutoFilter\\Column\\Rule' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/AutoFilter/Column/Rule.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\AutoFit' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/AutoFit.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\BaseDrawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/BaseDrawing.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\CellIterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/CellIterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Column' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Column.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\ColumnCellIterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/ColumnCellIterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\ColumnDimension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/ColumnDimension.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\ColumnIterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/ColumnIterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Dimension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Dimension.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Drawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Drawing.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Drawing\\Shadow' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Drawing/Shadow.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\HeaderFooter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/HeaderFooter.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\HeaderFooterDrawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/HeaderFooterDrawing.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Iterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Iterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\MemoryDrawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/MemoryDrawing.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\PageBreak' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/PageBreak.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\PageMargins' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/PageMargins.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\PageSetup' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/PageSetup.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Protection' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Protection.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Row' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Row.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\RowCellIterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/RowCellIterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\RowDimension' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/RowDimension.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\RowIterator' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/RowIterator.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\SheetView' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/SheetView.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Table' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Table.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Table\\Column' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Table/Column.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Table\\TableStyle' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Table/TableStyle.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Validations' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Validations.php',
    'PhpOffice\\PhpSpreadsheet\\Worksheet\\Worksheet' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Worksheet/Worksheet.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\BaseWriter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/BaseWriter.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Csv' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Csv.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Exception' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Exception.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Html' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Html.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\IWriter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/IWriter.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\AutoFilters' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/AutoFilters.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Cell\\Comment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Cell/Comment.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Cell\\Style' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Cell/Style.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Content' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Content.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Formula' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Formula.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Meta' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Meta.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\MetaInf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/MetaInf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Mimetype' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Mimetype.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\NamedExpressions' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/NamedExpressions.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Settings' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Settings.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Styles' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Styles.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\Thumbnails' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/Thumbnails.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Ods\\WriterPart' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Ods/WriterPart.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Pdf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Pdf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Pdf\\Dompdf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Pdf/Dompdf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Pdf\\Mpdf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Pdf/Mpdf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Pdf\\Tcpdf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Pdf/Tcpdf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\BIFFwriter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/BIFFwriter.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\CellDataValidation' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/CellDataValidation.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\ConditionalHelper' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/ConditionalHelper.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\ErrorCode' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/ErrorCode.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Escher' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Escher.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Font' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Font.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Parser' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Parser.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Style\\CellAlignment' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Style/CellAlignment.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Style\\CellBorder' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Style/CellBorder.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Style\\CellFill' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Style/CellFill.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Style\\ColorMap' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Style/ColorMap.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Workbook' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Workbook.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Worksheet' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Worksheet.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xls\\Xf' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xls/Xf.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\AutoFilter' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/AutoFilter.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Chart' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Chart.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Comments' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Comments.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\ContentTypes' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/ContentTypes.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\DefinedNames' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/DefinedNames.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\DocProps' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/DocProps.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Drawing' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Drawing.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\FunctionPrefix' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/FunctionPrefix.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Rels' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Rels.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\RelsRibbon' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/RelsRibbon.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\RelsVBA' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/RelsVBA.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\StringTable' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/StringTable.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Style' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Style.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Table' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Table.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Theme' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Theme.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Workbook' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Workbook.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\Worksheet' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/Worksheet.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\Xlsx\\WriterPart' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/Xlsx/WriterPart.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\ZipStream0' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/ZipStream0.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\ZipStream2' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/ZipStream2.php',
    'PhpOffice\\PhpSpreadsheet\\Writer\\ZipStream3' => $vendorDir . '/phpoffice/phpspreadsheet/src/PhpSpreadsheet/Writer/ZipStream3.php',
    'PhpOption\\LazyOption' => $vendorDir . '/phpoption/phpoption/src/PhpOption/LazyOption.php',
    'PhpOption\\None' => $vendorDir . '/phpoption/phpoption/src/PhpOption/None.php',
    'PhpOption\\Option' => $vendorDir . '/phpoption/phpoption/src/PhpOption/Option.php',
    'PhpOption\\Some' => $vendorDir . '/phpoption/phpoption/src/PhpOption/Some.php',
    'PhpParser\\Builder' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder.php',
    'PhpParser\\BuilderFactory' => $vendorDir . '/nikic/php-parser/lib/PhpParser/BuilderFactory.php',
    'PhpParser\\BuilderHelpers' => $vendorDir . '/nikic/php-parser/lib/PhpParser/BuilderHelpers.php',
    'PhpParser\\Builder\\ClassConst' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/ClassConst.php',
    'PhpParser\\Builder\\Class_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Class_.php',
    'PhpParser\\Builder\\Declaration' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Declaration.php',
    'PhpParser\\Builder\\EnumCase' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/EnumCase.php',
    'PhpParser\\Builder\\Enum_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Enum_.php',
    'PhpParser\\Builder\\FunctionLike' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/FunctionLike.php',
    'PhpParser\\Builder\\Function_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Function_.php',
    'PhpParser\\Builder\\Interface_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Interface_.php',
    'PhpParser\\Builder\\Method' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Method.php',
    'PhpParser\\Builder\\Namespace_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Namespace_.php',
    'PhpParser\\Builder\\Param' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Param.php',
    'PhpParser\\Builder\\Property' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Property.php',
    'PhpParser\\Builder\\TraitUse' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/TraitUse.php',
    'PhpParser\\Builder\\TraitUseAdaptation' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/TraitUseAdaptation.php',
    'PhpParser\\Builder\\Trait_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Trait_.php',
    'PhpParser\\Builder\\Use_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Builder/Use_.php',
    'PhpParser\\Comment' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Comment.php',
    'PhpParser\\Comment\\Doc' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Comment/Doc.php',
    'PhpParser\\ConstExprEvaluationException' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ConstExprEvaluationException.php',
    'PhpParser\\ConstExprEvaluator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ConstExprEvaluator.php',
    'PhpParser\\Error' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Error.php',
    'PhpParser\\ErrorHandler' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ErrorHandler.php',
    'PhpParser\\ErrorHandler\\Collecting' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ErrorHandler/Collecting.php',
    'PhpParser\\ErrorHandler\\Throwing' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ErrorHandler/Throwing.php',
    'PhpParser\\Internal\\DiffElem' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Internal/DiffElem.php',
    'PhpParser\\Internal\\Differ' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Internal/Differ.php',
    'PhpParser\\Internal\\PrintableNewAnonClassNode' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Internal/PrintableNewAnonClassNode.php',
    'PhpParser\\Internal\\TokenPolyfill' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Internal/TokenPolyfill.php',
    'PhpParser\\Internal\\TokenStream' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Internal/TokenStream.php',
    'PhpParser\\JsonDecoder' => $vendorDir . '/nikic/php-parser/lib/PhpParser/JsonDecoder.php',
    'PhpParser\\Lexer' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer.php',
    'PhpParser\\Lexer\\Emulative' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/Emulative.php',
    'PhpParser\\Lexer\\TokenEmulator\\AttributeEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/AttributeEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\EnumTokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/EnumTokenEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\ExplicitOctalEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/ExplicitOctalEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\KeywordEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/KeywordEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\MatchTokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/MatchTokenEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\NullsafeTokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/NullsafeTokenEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\ReadonlyFunctionTokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/ReadonlyFunctionTokenEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\ReadonlyTokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/ReadonlyTokenEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\ReverseEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/ReverseEmulator.php',
    'PhpParser\\Lexer\\TokenEmulator\\TokenEmulator' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Lexer/TokenEmulator/TokenEmulator.php',
    'PhpParser\\Modifiers' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Modifiers.php',
    'PhpParser\\NameContext' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NameContext.php',
    'PhpParser\\Node' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node.php',
    'PhpParser\\NodeAbstract' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeAbstract.php',
    'PhpParser\\NodeDumper' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeDumper.php',
    'PhpParser\\NodeFinder' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeFinder.php',
    'PhpParser\\NodeTraverser' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeTraverser.php',
    'PhpParser\\NodeTraverserInterface' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeTraverserInterface.php',
    'PhpParser\\NodeVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor.php',
    'PhpParser\\NodeVisitorAbstract' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitorAbstract.php',
    'PhpParser\\NodeVisitor\\CloningVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/CloningVisitor.php',
    'PhpParser\\NodeVisitor\\CommentAnnotatingVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/CommentAnnotatingVisitor.php',
    'PhpParser\\NodeVisitor\\FindingVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/FindingVisitor.php',
    'PhpParser\\NodeVisitor\\FirstFindingVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/FirstFindingVisitor.php',
    'PhpParser\\NodeVisitor\\NameResolver' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/NameResolver.php',
    'PhpParser\\NodeVisitor\\NodeConnectingVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/NodeConnectingVisitor.php',
    'PhpParser\\NodeVisitor\\ParentConnectingVisitor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/NodeVisitor/ParentConnectingVisitor.php',
    'PhpParser\\Node\\Arg' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Arg.php',
    'PhpParser\\Node\\ArrayItem' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/ArrayItem.php',
    'PhpParser\\Node\\Attribute' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Attribute.php',
    'PhpParser\\Node\\AttributeGroup' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/AttributeGroup.php',
    'PhpParser\\Node\\ClosureUse' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/ClosureUse.php',
    'PhpParser\\Node\\ComplexType' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/ComplexType.php',
    'PhpParser\\Node\\Const_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Const_.php',
    'PhpParser\\Node\\DeclareItem' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/DeclareItem.php',
    'PhpParser\\Node\\Expr' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr.php',
    'PhpParser\\Node\\Expr\\ArrayDimFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ArrayDimFetch.php',
    'PhpParser\\Node\\Expr\\Array_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Array_.php',
    'PhpParser\\Node\\Expr\\ArrowFunction' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ArrowFunction.php',
    'PhpParser\\Node\\Expr\\Assign' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Assign.php',
    'PhpParser\\Node\\Expr\\AssignOp' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp.php',
    'PhpParser\\Node\\Expr\\AssignOp\\BitwiseAnd' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/BitwiseAnd.php',
    'PhpParser\\Node\\Expr\\AssignOp\\BitwiseOr' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/BitwiseOr.php',
    'PhpParser\\Node\\Expr\\AssignOp\\BitwiseXor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/BitwiseXor.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Coalesce' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Coalesce.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Concat' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Concat.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Div' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Div.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Minus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Minus.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Mod' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Mod.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Mul' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Mul.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Plus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Plus.php',
    'PhpParser\\Node\\Expr\\AssignOp\\Pow' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/Pow.php',
    'PhpParser\\Node\\Expr\\AssignOp\\ShiftLeft' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/ShiftLeft.php',
    'PhpParser\\Node\\Expr\\AssignOp\\ShiftRight' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignOp/ShiftRight.php',
    'PhpParser\\Node\\Expr\\AssignRef' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/AssignRef.php',
    'PhpParser\\Node\\Expr\\BinaryOp' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\BitwiseAnd' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/BitwiseAnd.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\BitwiseOr' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/BitwiseOr.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\BitwiseXor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/BitwiseXor.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\BooleanAnd' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/BooleanAnd.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\BooleanOr' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/BooleanOr.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Coalesce' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Coalesce.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Concat' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Concat.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Div' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Div.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Equal' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Equal.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Greater' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Greater.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\GreaterOrEqual' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/GreaterOrEqual.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Identical' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Identical.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\LogicalAnd' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/LogicalAnd.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\LogicalOr' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/LogicalOr.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\LogicalXor' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/LogicalXor.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Minus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Minus.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Mod' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Mod.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Mul' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Mul.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\NotEqual' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/NotEqual.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\NotIdentical' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/NotIdentical.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Plus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Plus.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Pow' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Pow.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\ShiftLeft' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/ShiftLeft.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\ShiftRight' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/ShiftRight.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Smaller' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Smaller.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\SmallerOrEqual' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/SmallerOrEqual.php',
    'PhpParser\\Node\\Expr\\BinaryOp\\Spaceship' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BinaryOp/Spaceship.php',
    'PhpParser\\Node\\Expr\\BitwiseNot' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BitwiseNot.php',
    'PhpParser\\Node\\Expr\\BooleanNot' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/BooleanNot.php',
    'PhpParser\\Node\\Expr\\CallLike' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/CallLike.php',
    'PhpParser\\Node\\Expr\\Cast' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast.php',
    'PhpParser\\Node\\Expr\\Cast\\Array_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Array_.php',
    'PhpParser\\Node\\Expr\\Cast\\Bool_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Bool_.php',
    'PhpParser\\Node\\Expr\\Cast\\Double' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Double.php',
    'PhpParser\\Node\\Expr\\Cast\\Int_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Int_.php',
    'PhpParser\\Node\\Expr\\Cast\\Object_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Object_.php',
    'PhpParser\\Node\\Expr\\Cast\\String_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/String_.php',
    'PhpParser\\Node\\Expr\\Cast\\Unset_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Cast/Unset_.php',
    'PhpParser\\Node\\Expr\\ClassConstFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ClassConstFetch.php',
    'PhpParser\\Node\\Expr\\Clone_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Clone_.php',
    'PhpParser\\Node\\Expr\\Closure' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Closure.php',
    'PhpParser\\Node\\Expr\\ConstFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ConstFetch.php',
    'PhpParser\\Node\\Expr\\Empty_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Empty_.php',
    'PhpParser\\Node\\Expr\\Error' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Error.php',
    'PhpParser\\Node\\Expr\\ErrorSuppress' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ErrorSuppress.php',
    'PhpParser\\Node\\Expr\\Eval_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Eval_.php',
    'PhpParser\\Node\\Expr\\Exit_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Exit_.php',
    'PhpParser\\Node\\Expr\\FuncCall' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/FuncCall.php',
    'PhpParser\\Node\\Expr\\Include_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Include_.php',
    'PhpParser\\Node\\Expr\\Instanceof_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Instanceof_.php',
    'PhpParser\\Node\\Expr\\Isset_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Isset_.php',
    'PhpParser\\Node\\Expr\\List_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/List_.php',
    'PhpParser\\Node\\Expr\\Match_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Match_.php',
    'PhpParser\\Node\\Expr\\MethodCall' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/MethodCall.php',
    'PhpParser\\Node\\Expr\\New_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/New_.php',
    'PhpParser\\Node\\Expr\\NullsafeMethodCall' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/NullsafeMethodCall.php',
    'PhpParser\\Node\\Expr\\NullsafePropertyFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/NullsafePropertyFetch.php',
    'PhpParser\\Node\\Expr\\PostDec' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/PostDec.php',
    'PhpParser\\Node\\Expr\\PostInc' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/PostInc.php',
    'PhpParser\\Node\\Expr\\PreDec' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/PreDec.php',
    'PhpParser\\Node\\Expr\\PreInc' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/PreInc.php',
    'PhpParser\\Node\\Expr\\Print_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Print_.php',
    'PhpParser\\Node\\Expr\\PropertyFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/PropertyFetch.php',
    'PhpParser\\Node\\Expr\\ShellExec' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/ShellExec.php',
    'PhpParser\\Node\\Expr\\StaticCall' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/StaticCall.php',
    'PhpParser\\Node\\Expr\\StaticPropertyFetch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/StaticPropertyFetch.php',
    'PhpParser\\Node\\Expr\\Ternary' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Ternary.php',
    'PhpParser\\Node\\Expr\\Throw_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Throw_.php',
    'PhpParser\\Node\\Expr\\UnaryMinus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/UnaryMinus.php',
    'PhpParser\\Node\\Expr\\UnaryPlus' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/UnaryPlus.php',
    'PhpParser\\Node\\Expr\\Variable' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Variable.php',
    'PhpParser\\Node\\Expr\\YieldFrom' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/YieldFrom.php',
    'PhpParser\\Node\\Expr\\Yield_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Expr/Yield_.php',
    'PhpParser\\Node\\FunctionLike' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/FunctionLike.php',
    'PhpParser\\Node\\Identifier' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Identifier.php',
    'PhpParser\\Node\\InterpolatedStringPart' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/InterpolatedStringPart.php',
    'PhpParser\\Node\\IntersectionType' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/IntersectionType.php',
    'PhpParser\\Node\\MatchArm' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/MatchArm.php',
    'PhpParser\\Node\\Name' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Name.php',
    'PhpParser\\Node\\Name\\FullyQualified' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Name/FullyQualified.php',
    'PhpParser\\Node\\Name\\Relative' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Name/Relative.php',
    'PhpParser\\Node\\NullableType' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/NullableType.php',
    'PhpParser\\Node\\Param' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Param.php',
    'PhpParser\\Node\\PropertyItem' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/PropertyItem.php',
    'PhpParser\\Node\\Scalar' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar.php',
    'PhpParser\\Node\\Scalar\\Float_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/Float_.php',
    'PhpParser\\Node\\Scalar\\Int_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/Int_.php',
    'PhpParser\\Node\\Scalar\\InterpolatedString' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/InterpolatedString.php',
    'PhpParser\\Node\\Scalar\\MagicConst' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Class_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Class_.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Dir' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Dir.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\File' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/File.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Function_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Function_.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Line' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Line.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Method' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Method.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Namespace_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Namespace_.php',
    'PhpParser\\Node\\Scalar\\MagicConst\\Trait_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/MagicConst/Trait_.php',
    'PhpParser\\Node\\Scalar\\String_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Scalar/String_.php',
    'PhpParser\\Node\\StaticVar' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/StaticVar.php',
    'PhpParser\\Node\\Stmt' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt.php',
    'PhpParser\\Node\\Stmt\\Block' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Block.php',
    'PhpParser\\Node\\Stmt\\Break_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Break_.php',
    'PhpParser\\Node\\Stmt\\Case_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Case_.php',
    'PhpParser\\Node\\Stmt\\Catch_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Catch_.php',
    'PhpParser\\Node\\Stmt\\ClassConst' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/ClassConst.php',
    'PhpParser\\Node\\Stmt\\ClassLike' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/ClassLike.php',
    'PhpParser\\Node\\Stmt\\ClassMethod' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/ClassMethod.php',
    'PhpParser\\Node\\Stmt\\Class_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Class_.php',
    'PhpParser\\Node\\Stmt\\Const_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Const_.php',
    'PhpParser\\Node\\Stmt\\Continue_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Continue_.php',
    'PhpParser\\Node\\Stmt\\Declare_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Declare_.php',
    'PhpParser\\Node\\Stmt\\Do_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Do_.php',
    'PhpParser\\Node\\Stmt\\Echo_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Echo_.php',
    'PhpParser\\Node\\Stmt\\ElseIf_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/ElseIf_.php',
    'PhpParser\\Node\\Stmt\\Else_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Else_.php',
    'PhpParser\\Node\\Stmt\\EnumCase' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/EnumCase.php',
    'PhpParser\\Node\\Stmt\\Enum_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Enum_.php',
    'PhpParser\\Node\\Stmt\\Expression' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Expression.php',
    'PhpParser\\Node\\Stmt\\Finally_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Finally_.php',
    'PhpParser\\Node\\Stmt\\For_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/For_.php',
    'PhpParser\\Node\\Stmt\\Foreach_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Foreach_.php',
    'PhpParser\\Node\\Stmt\\Function_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Function_.php',
    'PhpParser\\Node\\Stmt\\Global_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Global_.php',
    'PhpParser\\Node\\Stmt\\Goto_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Goto_.php',
    'PhpParser\\Node\\Stmt\\GroupUse' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/GroupUse.php',
    'PhpParser\\Node\\Stmt\\HaltCompiler' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/HaltCompiler.php',
    'PhpParser\\Node\\Stmt\\If_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/If_.php',
    'PhpParser\\Node\\Stmt\\InlineHTML' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/InlineHTML.php',
    'PhpParser\\Node\\Stmt\\Interface_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Interface_.php',
    'PhpParser\\Node\\Stmt\\Label' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Label.php',
    'PhpParser\\Node\\Stmt\\Namespace_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Namespace_.php',
    'PhpParser\\Node\\Stmt\\Nop' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Nop.php',
    'PhpParser\\Node\\Stmt\\Property' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Property.php',
    'PhpParser\\Node\\Stmt\\Return_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Return_.php',
    'PhpParser\\Node\\Stmt\\Static_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Static_.php',
    'PhpParser\\Node\\Stmt\\Switch_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Switch_.php',
    'PhpParser\\Node\\Stmt\\TraitUse' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/TraitUse.php',
    'PhpParser\\Node\\Stmt\\TraitUseAdaptation' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/TraitUseAdaptation.php',
    'PhpParser\\Node\\Stmt\\TraitUseAdaptation\\Alias' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/TraitUseAdaptation/Alias.php',
    'PhpParser\\Node\\Stmt\\TraitUseAdaptation\\Precedence' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/TraitUseAdaptation/Precedence.php',
    'PhpParser\\Node\\Stmt\\Trait_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Trait_.php',
    'PhpParser\\Node\\Stmt\\TryCatch' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/TryCatch.php',
    'PhpParser\\Node\\Stmt\\Unset_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Unset_.php',
    'PhpParser\\Node\\Stmt\\Use_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/Use_.php',
    'PhpParser\\Node\\Stmt\\While_' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/Stmt/While_.php',
    'PhpParser\\Node\\UnionType' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/UnionType.php',
    'PhpParser\\Node\\UseItem' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/UseItem.php',
    'PhpParser\\Node\\VarLikeIdentifier' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/VarLikeIdentifier.php',
    'PhpParser\\Node\\VariadicPlaceholder' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Node/VariadicPlaceholder.php',
    'PhpParser\\Parser' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Parser.php',
    'PhpParser\\ParserAbstract' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ParserAbstract.php',
    'PhpParser\\ParserFactory' => $vendorDir . '/nikic/php-parser/lib/PhpParser/ParserFactory.php',
    'PhpParser\\Parser\\Php7' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Parser/Php7.php',
    'PhpParser\\Parser\\Php8' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Parser/Php8.php',
    'PhpParser\\PhpVersion' => $vendorDir . '/nikic/php-parser/lib/PhpParser/PhpVersion.php',
    'PhpParser\\PrettyPrinter' => $vendorDir . '/nikic/php-parser/lib/PhpParser/PrettyPrinter.php',
    'PhpParser\\PrettyPrinterAbstract' => $vendorDir . '/nikic/php-parser/lib/PhpParser/PrettyPrinterAbstract.php',
    'PhpParser\\PrettyPrinter\\Standard' => $vendorDir . '/nikic/php-parser/lib/PhpParser/PrettyPrinter/Standard.php',
    'PhpParser\\Token' => $vendorDir . '/nikic/php-parser/lib/PhpParser/Token.php',
    'PhpToken' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
    'Psr\\Cache\\CacheException' => $vendorDir . '/psr/cache/src/CacheException.php',
    'Psr\\Cache\\CacheItemInterface' => $vendorDir . '/psr/cache/src/CacheItemInterface.php',
    'Psr\\Cache\\CacheItemPoolInterface' => $vendorDir . '/psr/cache/src/CacheItemPoolInterface.php',
    'Psr\\Cache\\InvalidArgumentException' => $vendorDir . '/psr/cache/src/InvalidArgumentException.php',
    'Psr\\Clock\\ClockInterface' => $vendorDir . '/psr/clock/src/ClockInterface.php',
    'Psr\\Container\\ContainerExceptionInterface' => $vendorDir . '/psr/container/src/ContainerExceptionInterface.php',
    'Psr\\Container\\ContainerInterface' => $vendorDir . '/psr/container/src/ContainerInterface.php',
    'Psr\\Container\\NotFoundExceptionInterface' => $vendorDir . '/psr/container/src/NotFoundExceptionInterface.php',
    'Psr\\EventDispatcher\\EventDispatcherInterface' => $vendorDir . '/psr/event-dispatcher/src/EventDispatcherInterface.php',
    'Psr\\EventDispatcher\\ListenerProviderInterface' => $vendorDir . '/psr/event-dispatcher/src/ListenerProviderInterface.php',
    'Psr\\EventDispatcher\\StoppableEventInterface' => $vendorDir . '/psr/event-dispatcher/src/StoppableEventInterface.php',
    'Psr\\Http\\Client\\ClientExceptionInterface' => $vendorDir . '/psr/http-client/src/ClientExceptionInterface.php',
    'Psr\\Http\\Client\\ClientInterface' => $vendorDir . '/psr/http-client/src/ClientInterface.php',
    'Psr\\Http\\Client\\NetworkExceptionInterface' => $vendorDir . '/psr/http-client/src/NetworkExceptionInterface.php',
    'Psr\\Http\\Client\\RequestExceptionInterface' => $vendorDir . '/psr/http-client/src/RequestExceptionInterface.php',
    'Psr\\Http\\Message\\MessageInterface' => $vendorDir . '/psr/http-message/src/MessageInterface.php',
    'Psr\\Http\\Message\\RequestFactoryInterface' => $vendorDir . '/psr/http-factory/src/RequestFactoryInterface.php',
    'Psr\\Http\\Message\\RequestInterface' => $vendorDir . '/psr/http-message/src/RequestInterface.php',
    'Psr\\Http\\Message\\ResponseFactoryInterface' => $vendorDir . '/psr/http-factory/src/ResponseFactoryInterface.php',
    'Psr\\Http\\Message\\ResponseInterface' => $vendorDir . '/psr/http-message/src/ResponseInterface.php',
    'Psr\\Http\\Message\\ServerRequestFactoryInterface' => $vendorDir . '/psr/http-factory/src/ServerRequestFactoryInterface.php',
    'Psr\\Http\\Message\\ServerRequestInterface' => $vendorDir . '/psr/http-message/src/ServerRequestInterface.php',
    'Psr\\Http\\Message\\StreamFactoryInterface' => $vendorDir . '/psr/http-factory/src/StreamFactoryInterface.php',
    'Psr\\Http\\Message\\StreamInterface' => $vendorDir . '/psr/http-message/src/StreamInterface.php',
    'Psr\\Http\\Message\\UploadedFileFactoryInterface' => $vendorDir . '/psr/http-factory/src/UploadedFileFactoryInterface.php',
    'Psr\\Http\\Message\\UploadedFileInterface' => $vendorDir . '/psr/http-message/src/UploadedFileInterface.php',
    'Psr\\Http\\Message\\UriFactoryInterface' => $vendorDir . '/psr/http-factory/src/UriFactoryInterface.php',
    'Psr\\Http\\Message\\UriInterface' => $vendorDir . '/psr/http-message/src/UriInterface.php',
    'Psr\\Log\\AbstractLogger' => $vendorDir . '/psr/log/src/AbstractLogger.php',
    'Psr\\Log\\InvalidArgumentException' => $vendorDir . '/psr/log/src/InvalidArgumentException.php',
    'Psr\\Log\\LogLevel' => $vendorDir . '/psr/log/src/LogLevel.php',
    'Psr\\Log\\LoggerAwareInterface' => $vendorDir . '/psr/log/src/LoggerAwareInterface.php',
    'Psr\\Log\\LoggerAwareTrait' => $vendorDir . '/psr/log/src/LoggerAwareTrait.php',
    'Psr\\Log\\LoggerInterface' => $vendorDir . '/psr/log/src/LoggerInterface.php',
    'Psr\\Log\\LoggerTrait' => $vendorDir . '/psr/log/src/LoggerTrait.php',
    'Psr\\Log\\NullLogger' => $vendorDir . '/psr/log/src/NullLogger.php',
    'Psr\\SimpleCache\\CacheException' => $vendorDir . '/psr/simple-cache/src/CacheException.php',
    'Psr\\SimpleCache\\CacheInterface' => $vendorDir . '/psr/simple-cache/src/CacheInterface.php',
    'Psr\\SimpleCache\\InvalidArgumentException' => $vendorDir . '/psr/simple-cache/src/InvalidArgumentException.php',
    'Psy\\CodeCleaner' => $vendorDir . '/psy/psysh/src/CodeCleaner.php',
    'Psy\\CodeCleaner\\AbstractClassPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/AbstractClassPass.php',
    'Psy\\CodeCleaner\\AssignThisVariablePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/AssignThisVariablePass.php',
    'Psy\\CodeCleaner\\CallTimePassByReferencePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/CallTimePassByReferencePass.php',
    'Psy\\CodeCleaner\\CalledClassPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/CalledClassPass.php',
    'Psy\\CodeCleaner\\CodeCleanerPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/CodeCleanerPass.php',
    'Psy\\CodeCleaner\\EmptyArrayDimFetchPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/EmptyArrayDimFetchPass.php',
    'Psy\\CodeCleaner\\ExitPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ExitPass.php',
    'Psy\\CodeCleaner\\FinalClassPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/FinalClassPass.php',
    'Psy\\CodeCleaner\\FunctionContextPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/FunctionContextPass.php',
    'Psy\\CodeCleaner\\FunctionReturnInWriteContextPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/FunctionReturnInWriteContextPass.php',
    'Psy\\CodeCleaner\\ImplicitReturnPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ImplicitReturnPass.php',
    'Psy\\CodeCleaner\\IssetPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/IssetPass.php',
    'Psy\\CodeCleaner\\LabelContextPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/LabelContextPass.php',
    'Psy\\CodeCleaner\\LeavePsyshAlonePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/LeavePsyshAlonePass.php',
    'Psy\\CodeCleaner\\ListPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ListPass.php',
    'Psy\\CodeCleaner\\LoopContextPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/LoopContextPass.php',
    'Psy\\CodeCleaner\\MagicConstantsPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/MagicConstantsPass.php',
    'Psy\\CodeCleaner\\NamespaceAwarePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/NamespaceAwarePass.php',
    'Psy\\CodeCleaner\\NamespacePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/NamespacePass.php',
    'Psy\\CodeCleaner\\NoReturnValue' => $vendorDir . '/psy/psysh/src/CodeCleaner/NoReturnValue.php',
    'Psy\\CodeCleaner\\PassableByReferencePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/PassableByReferencePass.php',
    'Psy\\CodeCleaner\\RequirePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/RequirePass.php',
    'Psy\\CodeCleaner\\ReturnTypePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ReturnTypePass.php',
    'Psy\\CodeCleaner\\StrictTypesPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/StrictTypesPass.php',
    'Psy\\CodeCleaner\\UseStatementPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/UseStatementPass.php',
    'Psy\\CodeCleaner\\ValidClassNamePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ValidClassNamePass.php',
    'Psy\\CodeCleaner\\ValidConstructorPass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ValidConstructorPass.php',
    'Psy\\CodeCleaner\\ValidFunctionNamePass' => $vendorDir . '/psy/psysh/src/CodeCleaner/ValidFunctionNamePass.php',
    'Psy\\Command\\BufferCommand' => $vendorDir . '/psy/psysh/src/Command/BufferCommand.php',
    'Psy\\Command\\ClearCommand' => $vendorDir . '/psy/psysh/src/Command/ClearCommand.php',
    'Psy\\Command\\CodeArgumentParser' => $vendorDir . '/psy/psysh/src/Command/CodeArgumentParser.php',
    'Psy\\Command\\Command' => $vendorDir . '/psy/psysh/src/Command/Command.php',
    'Psy\\Command\\DocCommand' => $vendorDir . '/psy/psysh/src/Command/DocCommand.php',
    'Psy\\Command\\DumpCommand' => $vendorDir . '/psy/psysh/src/Command/DumpCommand.php',
    'Psy\\Command\\EditCommand' => $vendorDir . '/psy/psysh/src/Command/EditCommand.php',
    'Psy\\Command\\ExitCommand' => $vendorDir . '/psy/psysh/src/Command/ExitCommand.php',
    'Psy\\Command\\HelpCommand' => $vendorDir . '/psy/psysh/src/Command/HelpCommand.php',
    'Psy\\Command\\HistoryCommand' => $vendorDir . '/psy/psysh/src/Command/HistoryCommand.php',
    'Psy\\Command\\ListCommand' => $vendorDir . '/psy/psysh/src/Command/ListCommand.php',
    'Psy\\Command\\ListCommand\\ClassConstantEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/ClassConstantEnumerator.php',
    'Psy\\Command\\ListCommand\\ClassEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/ClassEnumerator.php',
    'Psy\\Command\\ListCommand\\ConstantEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/ConstantEnumerator.php',
    'Psy\\Command\\ListCommand\\Enumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/Enumerator.php',
    'Psy\\Command\\ListCommand\\FunctionEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/FunctionEnumerator.php',
    'Psy\\Command\\ListCommand\\GlobalVariableEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/GlobalVariableEnumerator.php',
    'Psy\\Command\\ListCommand\\MethodEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/MethodEnumerator.php',
    'Psy\\Command\\ListCommand\\PropertyEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/PropertyEnumerator.php',
    'Psy\\Command\\ListCommand\\VariableEnumerator' => $vendorDir . '/psy/psysh/src/Command/ListCommand/VariableEnumerator.php',
    'Psy\\Command\\ParseCommand' => $vendorDir . '/psy/psysh/src/Command/ParseCommand.php',
    'Psy\\Command\\PsyVersionCommand' => $vendorDir . '/psy/psysh/src/Command/PsyVersionCommand.php',
    'Psy\\Command\\ReflectingCommand' => $vendorDir . '/psy/psysh/src/Command/ReflectingCommand.php',
    'Psy\\Command\\ShowCommand' => $vendorDir . '/psy/psysh/src/Command/ShowCommand.php',
    'Psy\\Command\\SudoCommand' => $vendorDir . '/psy/psysh/src/Command/SudoCommand.php',
    'Psy\\Command\\ThrowUpCommand' => $vendorDir . '/psy/psysh/src/Command/ThrowUpCommand.php',
    'Psy\\Command\\TimeitCommand' => $vendorDir . '/psy/psysh/src/Command/TimeitCommand.php',
    'Psy\\Command\\TimeitCommand\\TimeitVisitor' => $vendorDir . '/psy/psysh/src/Command/TimeitCommand/TimeitVisitor.php',
    'Psy\\Command\\TraceCommand' => $vendorDir . '/psy/psysh/src/Command/TraceCommand.php',
    'Psy\\Command\\WhereamiCommand' => $vendorDir . '/psy/psysh/src/Command/WhereamiCommand.php',
    'Psy\\Command\\WtfCommand' => $vendorDir . '/psy/psysh/src/Command/WtfCommand.php',
    'Psy\\ConfigPaths' => $vendorDir . '/psy/psysh/src/ConfigPaths.php',
    'Psy\\Configuration' => $vendorDir . '/psy/psysh/src/Configuration.php',
    'Psy\\Context' => $vendorDir . '/psy/psysh/src/Context.php',
    'Psy\\ContextAware' => $vendorDir . '/psy/psysh/src/ContextAware.php',
    'Psy\\EnvInterface' => $vendorDir . '/psy/psysh/src/EnvInterface.php',
    'Psy\\Exception\\BreakException' => $vendorDir . '/psy/psysh/src/Exception/BreakException.php',
    'Psy\\Exception\\DeprecatedException' => $vendorDir . '/psy/psysh/src/Exception/DeprecatedException.php',
    'Psy\\Exception\\ErrorException' => $vendorDir . '/psy/psysh/src/Exception/ErrorException.php',
    'Psy\\Exception\\Exception' => $vendorDir . '/psy/psysh/src/Exception/Exception.php',
    'Psy\\Exception\\FatalErrorException' => $vendorDir . '/psy/psysh/src/Exception/FatalErrorException.php',
    'Psy\\Exception\\ParseErrorException' => $vendorDir . '/psy/psysh/src/Exception/ParseErrorException.php',
    'Psy\\Exception\\RuntimeException' => $vendorDir . '/psy/psysh/src/Exception/RuntimeException.php',
    'Psy\\Exception\\ThrowUpException' => $vendorDir . '/psy/psysh/src/Exception/ThrowUpException.php',
    'Psy\\Exception\\UnexpectedTargetException' => $vendorDir . '/psy/psysh/src/Exception/UnexpectedTargetException.php',
    'Psy\\ExecutionClosure' => $vendorDir . '/psy/psysh/src/ExecutionClosure.php',
    'Psy\\ExecutionLoopClosure' => $vendorDir . '/psy/psysh/src/ExecutionLoopClosure.php',
    'Psy\\ExecutionLoop\\AbstractListener' => $vendorDir . '/psy/psysh/src/ExecutionLoop/AbstractListener.php',
    'Psy\\ExecutionLoop\\Listener' => $vendorDir . '/psy/psysh/src/ExecutionLoop/Listener.php',
    'Psy\\ExecutionLoop\\ProcessForker' => $vendorDir . '/psy/psysh/src/ExecutionLoop/ProcessForker.php',
    'Psy\\ExecutionLoop\\RunkitReloader' => $vendorDir . '/psy/psysh/src/ExecutionLoop/RunkitReloader.php',
    'Psy\\Formatter\\CodeFormatter' => $vendorDir . '/psy/psysh/src/Formatter/CodeFormatter.php',
    'Psy\\Formatter\\DocblockFormatter' => $vendorDir . '/psy/psysh/src/Formatter/DocblockFormatter.php',
    'Psy\\Formatter\\ReflectorFormatter' => $vendorDir . '/psy/psysh/src/Formatter/ReflectorFormatter.php',
    'Psy\\Formatter\\SignatureFormatter' => $vendorDir . '/psy/psysh/src/Formatter/SignatureFormatter.php',
    'Psy\\Formatter\\TraceFormatter' => $vendorDir . '/psy/psysh/src/Formatter/TraceFormatter.php',
    'Psy\\Input\\CodeArgument' => $vendorDir . '/psy/psysh/src/Input/CodeArgument.php',
    'Psy\\Input\\FilterOptions' => $vendorDir . '/psy/psysh/src/Input/FilterOptions.php',
    'Psy\\Input\\ShellInput' => $vendorDir . '/psy/psysh/src/Input/ShellInput.php',
    'Psy\\Input\\SilentInput' => $vendorDir . '/psy/psysh/src/Input/SilentInput.php',
    'Psy\\Output\\OutputPager' => $vendorDir . '/psy/psysh/src/Output/OutputPager.php',
    'Psy\\Output\\PassthruPager' => $vendorDir . '/psy/psysh/src/Output/PassthruPager.php',
    'Psy\\Output\\ProcOutputPager' => $vendorDir . '/psy/psysh/src/Output/ProcOutputPager.php',
    'Psy\\Output\\ShellOutput' => $vendorDir . '/psy/psysh/src/Output/ShellOutput.php',
    'Psy\\Output\\Theme' => $vendorDir . '/psy/psysh/src/Output/Theme.php',
    'Psy\\ParserFactory' => $vendorDir . '/psy/psysh/src/ParserFactory.php',
    'Psy\\Readline\\GNUReadline' => $vendorDir . '/psy/psysh/src/Readline/GNUReadline.php',
    'Psy\\Readline\\Hoa\\Autocompleter' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Autocompleter.php',
    'Psy\\Readline\\Hoa\\AutocompleterAggregate' => $vendorDir . '/psy/psysh/src/Readline/Hoa/AutocompleterAggregate.php',
    'Psy\\Readline\\Hoa\\AutocompleterPath' => $vendorDir . '/psy/psysh/src/Readline/Hoa/AutocompleterPath.php',
    'Psy\\Readline\\Hoa\\AutocompleterWord' => $vendorDir . '/psy/psysh/src/Readline/Hoa/AutocompleterWord.php',
    'Psy\\Readline\\Hoa\\Console' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Console.php',
    'Psy\\Readline\\Hoa\\ConsoleCursor' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleCursor.php',
    'Psy\\Readline\\Hoa\\ConsoleException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleException.php',
    'Psy\\Readline\\Hoa\\ConsoleInput' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleInput.php',
    'Psy\\Readline\\Hoa\\ConsoleOutput' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleOutput.php',
    'Psy\\Readline\\Hoa\\ConsoleProcessus' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleProcessus.php',
    'Psy\\Readline\\Hoa\\ConsoleTput' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleTput.php',
    'Psy\\Readline\\Hoa\\ConsoleWindow' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ConsoleWindow.php',
    'Psy\\Readline\\Hoa\\Event' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Event.php',
    'Psy\\Readline\\Hoa\\EventBucket' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventBucket.php',
    'Psy\\Readline\\Hoa\\EventException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventException.php',
    'Psy\\Readline\\Hoa\\EventListenable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventListenable.php',
    'Psy\\Readline\\Hoa\\EventListener' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventListener.php',
    'Psy\\Readline\\Hoa\\EventListens' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventListens.php',
    'Psy\\Readline\\Hoa\\EventSource' => $vendorDir . '/psy/psysh/src/Readline/Hoa/EventSource.php',
    'Psy\\Readline\\Hoa\\Exception' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Exception.php',
    'Psy\\Readline\\Hoa\\ExceptionIdle' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ExceptionIdle.php',
    'Psy\\Readline\\Hoa\\File' => $vendorDir . '/psy/psysh/src/Readline/Hoa/File.php',
    'Psy\\Readline\\Hoa\\FileDirectory' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileDirectory.php',
    'Psy\\Readline\\Hoa\\FileDoesNotExistException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileDoesNotExistException.php',
    'Psy\\Readline\\Hoa\\FileException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileException.php',
    'Psy\\Readline\\Hoa\\FileFinder' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileFinder.php',
    'Psy\\Readline\\Hoa\\FileGeneric' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileGeneric.php',
    'Psy\\Readline\\Hoa\\FileLink' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileLink.php',
    'Psy\\Readline\\Hoa\\FileLinkRead' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileLinkRead.php',
    'Psy\\Readline\\Hoa\\FileLinkReadWrite' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileLinkReadWrite.php',
    'Psy\\Readline\\Hoa\\FileRead' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileRead.php',
    'Psy\\Readline\\Hoa\\FileReadWrite' => $vendorDir . '/psy/psysh/src/Readline/Hoa/FileReadWrite.php',
    'Psy\\Readline\\Hoa\\IStream' => $vendorDir . '/psy/psysh/src/Readline/Hoa/IStream.php',
    'Psy\\Readline\\Hoa\\IteratorFileSystem' => $vendorDir . '/psy/psysh/src/Readline/Hoa/IteratorFileSystem.php',
    'Psy\\Readline\\Hoa\\IteratorRecursiveDirectory' => $vendorDir . '/psy/psysh/src/Readline/Hoa/IteratorRecursiveDirectory.php',
    'Psy\\Readline\\Hoa\\IteratorSplFileInfo' => $vendorDir . '/psy/psysh/src/Readline/Hoa/IteratorSplFileInfo.php',
    'Psy\\Readline\\Hoa\\Protocol' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Protocol.php',
    'Psy\\Readline\\Hoa\\ProtocolException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ProtocolException.php',
    'Psy\\Readline\\Hoa\\ProtocolNode' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ProtocolNode.php',
    'Psy\\Readline\\Hoa\\ProtocolNodeLibrary' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ProtocolNodeLibrary.php',
    'Psy\\Readline\\Hoa\\ProtocolWrapper' => $vendorDir . '/psy/psysh/src/Readline/Hoa/ProtocolWrapper.php',
    'Psy\\Readline\\Hoa\\Readline' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Readline.php',
    'Psy\\Readline\\Hoa\\Stream' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Stream.php',
    'Psy\\Readline\\Hoa\\StreamBufferable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamBufferable.php',
    'Psy\\Readline\\Hoa\\StreamContext' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamContext.php',
    'Psy\\Readline\\Hoa\\StreamException' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamException.php',
    'Psy\\Readline\\Hoa\\StreamIn' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamIn.php',
    'Psy\\Readline\\Hoa\\StreamLockable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamLockable.php',
    'Psy\\Readline\\Hoa\\StreamOut' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamOut.php',
    'Psy\\Readline\\Hoa\\StreamPathable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamPathable.php',
    'Psy\\Readline\\Hoa\\StreamPointable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamPointable.php',
    'Psy\\Readline\\Hoa\\StreamStatable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamStatable.php',
    'Psy\\Readline\\Hoa\\StreamTouchable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/StreamTouchable.php',
    'Psy\\Readline\\Hoa\\Ustring' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Ustring.php',
    'Psy\\Readline\\Hoa\\Xcallable' => $vendorDir . '/psy/psysh/src/Readline/Hoa/Xcallable.php',
    'Psy\\Readline\\Libedit' => $vendorDir . '/psy/psysh/src/Readline/Libedit.php',
    'Psy\\Readline\\Readline' => $vendorDir . '/psy/psysh/src/Readline/Readline.php',
    'Psy\\Readline\\Transient' => $vendorDir . '/psy/psysh/src/Readline/Transient.php',
    'Psy\\Readline\\Userland' => $vendorDir . '/psy/psysh/src/Readline/Userland.php',
    'Psy\\Reflection\\ReflectionConstant' => $vendorDir . '/psy/psysh/src/Reflection/ReflectionConstant.php',
    'Psy\\Reflection\\ReflectionLanguageConstruct' => $vendorDir . '/psy/psysh/src/Reflection/ReflectionLanguageConstruct.php',
    'Psy\\Reflection\\ReflectionLanguageConstructParameter' => $vendorDir . '/psy/psysh/src/Reflection/ReflectionLanguageConstructParameter.php',
    'Psy\\Reflection\\ReflectionNamespace' => $vendorDir . '/psy/psysh/src/Reflection/ReflectionNamespace.php',
    'Psy\\Shell' => $vendorDir . '/psy/psysh/src/Shell.php',
    'Psy\\Sudo' => $vendorDir . '/psy/psysh/src/Sudo.php',
    'Psy\\Sudo\\SudoVisitor' => $vendorDir . '/psy/psysh/src/Sudo/SudoVisitor.php',
    'Psy\\SuperglobalsEnv' => $vendorDir . '/psy/psysh/src/SuperglobalsEnv.php',
    'Psy\\SystemEnv' => $vendorDir . '/psy/psysh/src/SystemEnv.php',
    'Psy\\TabCompletion\\AutoCompleter' => $vendorDir . '/psy/psysh/src/TabCompletion/AutoCompleter.php',
    'Psy\\TabCompletion\\Matcher\\AbstractContextAwareMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/AbstractContextAwareMatcher.php',
    'Psy\\TabCompletion\\Matcher\\AbstractDefaultParametersMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/AbstractDefaultParametersMatcher.php',
    'Psy\\TabCompletion\\Matcher\\AbstractMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/AbstractMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ClassAttributesMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ClassAttributesMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ClassMethodDefaultParametersMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ClassMethodDefaultParametersMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ClassMethodsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ClassMethodsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ClassNamesMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ClassNamesMatcher.php',
    'Psy\\TabCompletion\\Matcher\\CommandsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/CommandsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ConstantsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ConstantsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\FunctionDefaultParametersMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/FunctionDefaultParametersMatcher.php',
    'Psy\\TabCompletion\\Matcher\\FunctionsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/FunctionsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\KeywordsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/KeywordsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\MongoClientMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/MongoClientMatcher.php',
    'Psy\\TabCompletion\\Matcher\\MongoDatabaseMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/MongoDatabaseMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ObjectAttributesMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ObjectAttributesMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ObjectMethodDefaultParametersMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ObjectMethodDefaultParametersMatcher.php',
    'Psy\\TabCompletion\\Matcher\\ObjectMethodsMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/ObjectMethodsMatcher.php',
    'Psy\\TabCompletion\\Matcher\\VariablesMatcher' => $vendorDir . '/psy/psysh/src/TabCompletion/Matcher/VariablesMatcher.php',
    'Psy\\Util\\Docblock' => $vendorDir . '/psy/psysh/src/Util/Docblock.php',
    'Psy\\Util\\Json' => $vendorDir . '/psy/psysh/src/Util/Json.php',
    'Psy\\Util\\Mirror' => $vendorDir . '/psy/psysh/src/Util/Mirror.php',
    'Psy\\Util\\Str' => $vendorDir . '/psy/psysh/src/Util/Str.php',
    'Psy\\VarDumper\\Cloner' => $vendorDir . '/psy/psysh/src/VarDumper/Cloner.php',
    'Psy\\VarDumper\\Dumper' => $vendorDir . '/psy/psysh/src/VarDumper/Dumper.php',
    'Psy\\VarDumper\\Presenter' => $vendorDir . '/psy/psysh/src/VarDumper/Presenter.php',
    'Psy\\VarDumper\\PresenterAware' => $vendorDir . '/psy/psysh/src/VarDumper/PresenterAware.php',
    'Psy\\VersionUpdater\\Checker' => $vendorDir . '/psy/psysh/src/VersionUpdater/Checker.php',
    'Psy\\VersionUpdater\\Downloader' => $vendorDir . '/psy/psysh/src/VersionUpdater/Downloader.php',
    'Psy\\VersionUpdater\\Downloader\\CurlDownloader' => $vendorDir . '/psy/psysh/src/VersionUpdater/Downloader/CurlDownloader.php',
    'Psy\\VersionUpdater\\Downloader\\Factory' => $vendorDir . '/psy/psysh/src/VersionUpdater/Downloader/Factory.php',
    'Psy\\VersionUpdater\\Downloader\\FileDownloader' => $vendorDir . '/psy/psysh/src/VersionUpdater/Downloader/FileDownloader.php',
    'Psy\\VersionUpdater\\GitHubChecker' => $vendorDir . '/psy/psysh/src/VersionUpdater/GitHubChecker.php',
    'Psy\\VersionUpdater\\Installer' => $vendorDir . '/psy/psysh/src/VersionUpdater/Installer.php',
    'Psy\\VersionUpdater\\IntervalChecker' => $vendorDir . '/psy/psysh/src/VersionUpdater/IntervalChecker.php',
    'Psy\\VersionUpdater\\NoopChecker' => $vendorDir . '/psy/psysh/src/VersionUpdater/NoopChecker.php',
    'Psy\\VersionUpdater\\SelfUpdate' => $vendorDir . '/psy/psysh/src/VersionUpdater/SelfUpdate.php',
    'Pusher\\ApiErrorException' => $vendorDir . '/pusher/pusher-php-server/src/ApiErrorException.php',
    'Pusher\\Pusher' => $vendorDir . '/pusher/pusher-php-server/src/Pusher.php',
    'Pusher\\PusherCrypto' => $vendorDir . '/pusher/pusher-php-server/src/PusherCrypto.php',
    'Pusher\\PusherException' => $vendorDir . '/pusher/pusher-php-server/src/PusherException.php',
    'Pusher\\PusherInstance' => $vendorDir . '/pusher/pusher-php-server/src/PusherInstance.php',
    'Pusher\\PusherInterface' => $vendorDir . '/pusher/pusher-php-server/src/PusherInterface.php',
    'Pusher\\Webhook' => $vendorDir . '/pusher/pusher-php-server/src/Webhook.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\DatabaseController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/DatabaseController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\EnvironmentController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/EnvironmentController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\FinalController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/FinalController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\PermissionsController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/PermissionsController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\RequirementsController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/RequirementsController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\UpdateController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/UpdateController.php',
    'RachidLaasri\\LaravelInstaller\\Controllers\\WelcomeController' => $vendorDir . '/rachidlaasri/laravel-installer/src/Controllers/WelcomeController.php',
    'RachidLaasri\\LaravelInstaller\\Events\\EnvironmentSaved' => $vendorDir . '/rachidlaasri/laravel-installer/src/Events/EnvironmentSaved.php',
    'RachidLaasri\\LaravelInstaller\\Events\\LaravelInstallerFinished' => $vendorDir . '/rachidlaasri/laravel-installer/src/Events/LaravelInstallerFinished.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\DatabaseManager' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/DatabaseManager.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\EnvironmentManager' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/EnvironmentManager.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\FinalInstallManager' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/FinalInstallManager.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\InstalledFileManager' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/InstalledFileManager.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\MigrationsHelper' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/MigrationsHelper.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\PermissionsChecker' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/PermissionsChecker.php',
    'RachidLaasri\\LaravelInstaller\\Helpers\\RequirementsChecker' => $vendorDir . '/rachidlaasri/laravel-installer/src/Helpers/RequirementsChecker.php',
    'RachidLaasri\\LaravelInstaller\\Middleware\\canInstall' => $vendorDir . '/rachidlaasri/laravel-installer/src/Middleware/canInstall.php',
    'RachidLaasri\\LaravelInstaller\\Middleware\\canUpdate' => $vendorDir . '/rachidlaasri/laravel-installer/src/Middleware/canUpdate.php',
    'RachidLaasri\\LaravelInstaller\\Providers\\LaravelInstallerServiceProvider' => $vendorDir . '/rachidlaasri/laravel-installer/src/Providers/LaravelInstallerServiceProvider.php',
    'Ramsey\\Collection\\AbstractArray' => $vendorDir . '/ramsey/collection/src/AbstractArray.php',
    'Ramsey\\Collection\\AbstractCollection' => $vendorDir . '/ramsey/collection/src/AbstractCollection.php',
    'Ramsey\\Collection\\AbstractSet' => $vendorDir . '/ramsey/collection/src/AbstractSet.php',
    'Ramsey\\Collection\\ArrayInterface' => $vendorDir . '/ramsey/collection/src/ArrayInterface.php',
    'Ramsey\\Collection\\Collection' => $vendorDir . '/ramsey/collection/src/Collection.php',
    'Ramsey\\Collection\\CollectionInterface' => $vendorDir . '/ramsey/collection/src/CollectionInterface.php',
    'Ramsey\\Collection\\DoubleEndedQueue' => $vendorDir . '/ramsey/collection/src/DoubleEndedQueue.php',
    'Ramsey\\Collection\\DoubleEndedQueueInterface' => $vendorDir . '/ramsey/collection/src/DoubleEndedQueueInterface.php',
    'Ramsey\\Collection\\Exception\\CollectionException' => $vendorDir . '/ramsey/collection/src/Exception/CollectionException.php',
    'Ramsey\\Collection\\Exception\\CollectionMismatchException' => $vendorDir . '/ramsey/collection/src/Exception/CollectionMismatchException.php',
    'Ramsey\\Collection\\Exception\\InvalidArgumentException' => $vendorDir . '/ramsey/collection/src/Exception/InvalidArgumentException.php',
    'Ramsey\\Collection\\Exception\\InvalidPropertyOrMethod' => $vendorDir . '/ramsey/collection/src/Exception/InvalidPropertyOrMethod.php',
    'Ramsey\\Collection\\Exception\\NoSuchElementException' => $vendorDir . '/ramsey/collection/src/Exception/NoSuchElementException.php',
    'Ramsey\\Collection\\Exception\\OutOfBoundsException' => $vendorDir . '/ramsey/collection/src/Exception/OutOfBoundsException.php',
    'Ramsey\\Collection\\Exception\\UnsupportedOperationException' => $vendorDir . '/ramsey/collection/src/Exception/UnsupportedOperationException.php',
    'Ramsey\\Collection\\GenericArray' => $vendorDir . '/ramsey/collection/src/GenericArray.php',
    'Ramsey\\Collection\\Map\\AbstractMap' => $vendorDir . '/ramsey/collection/src/Map/AbstractMap.php',
    'Ramsey\\Collection\\Map\\AbstractTypedMap' => $vendorDir . '/ramsey/collection/src/Map/AbstractTypedMap.php',
    'Ramsey\\Collection\\Map\\AssociativeArrayMap' => $vendorDir . '/ramsey/collection/src/Map/AssociativeArrayMap.php',
    'Ramsey\\Collection\\Map\\MapInterface' => $vendorDir . '/ramsey/collection/src/Map/MapInterface.php',
    'Ramsey\\Collection\\Map\\NamedParameterMap' => $vendorDir . '/ramsey/collection/src/Map/NamedParameterMap.php',
    'Ramsey\\Collection\\Map\\TypedMap' => $vendorDir . '/ramsey/collection/src/Map/TypedMap.php',
    'Ramsey\\Collection\\Map\\TypedMapInterface' => $vendorDir . '/ramsey/collection/src/Map/TypedMapInterface.php',
    'Ramsey\\Collection\\Queue' => $vendorDir . '/ramsey/collection/src/Queue.php',
    'Ramsey\\Collection\\QueueInterface' => $vendorDir . '/ramsey/collection/src/QueueInterface.php',
    'Ramsey\\Collection\\Set' => $vendorDir . '/ramsey/collection/src/Set.php',
    'Ramsey\\Collection\\Sort' => $vendorDir . '/ramsey/collection/src/Sort.php',
    'Ramsey\\Collection\\Tool\\TypeTrait' => $vendorDir . '/ramsey/collection/src/Tool/TypeTrait.php',
    'Ramsey\\Collection\\Tool\\ValueExtractorTrait' => $vendorDir . '/ramsey/collection/src/Tool/ValueExtractorTrait.php',
    'Ramsey\\Collection\\Tool\\ValueToStringTrait' => $vendorDir . '/ramsey/collection/src/Tool/ValueToStringTrait.php',
    'Ramsey\\Uuid\\BinaryUtils' => $vendorDir . '/ramsey/uuid/src/BinaryUtils.php',
    'Ramsey\\Uuid\\Builder\\BuilderCollection' => $vendorDir . '/ramsey/uuid/src/Builder/BuilderCollection.php',
    'Ramsey\\Uuid\\Builder\\DefaultUuidBuilder' => $vendorDir . '/ramsey/uuid/src/Builder/DefaultUuidBuilder.php',
    'Ramsey\\Uuid\\Builder\\DegradedUuidBuilder' => $vendorDir . '/ramsey/uuid/src/Builder/DegradedUuidBuilder.php',
    'Ramsey\\Uuid\\Builder\\FallbackBuilder' => $vendorDir . '/ramsey/uuid/src/Builder/FallbackBuilder.php',
    'Ramsey\\Uuid\\Builder\\UuidBuilderInterface' => $vendorDir . '/ramsey/uuid/src/Builder/UuidBuilderInterface.php',
    'Ramsey\\Uuid\\Codec\\CodecInterface' => $vendorDir . '/ramsey/uuid/src/Codec/CodecInterface.php',
    'Ramsey\\Uuid\\Codec\\GuidStringCodec' => $vendorDir . '/ramsey/uuid/src/Codec/GuidStringCodec.php',
    'Ramsey\\Uuid\\Codec\\OrderedTimeCodec' => $vendorDir . '/ramsey/uuid/src/Codec/OrderedTimeCodec.php',
    'Ramsey\\Uuid\\Codec\\StringCodec' => $vendorDir . '/ramsey/uuid/src/Codec/StringCodec.php',
    'Ramsey\\Uuid\\Codec\\TimestampFirstCombCodec' => $vendorDir . '/ramsey/uuid/src/Codec/TimestampFirstCombCodec.php',
    'Ramsey\\Uuid\\Codec\\TimestampLastCombCodec' => $vendorDir . '/ramsey/uuid/src/Codec/TimestampLastCombCodec.php',
    'Ramsey\\Uuid\\Converter\\NumberConverterInterface' => $vendorDir . '/ramsey/uuid/src/Converter/NumberConverterInterface.php',
    'Ramsey\\Uuid\\Converter\\Number\\BigNumberConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Number/BigNumberConverter.php',
    'Ramsey\\Uuid\\Converter\\Number\\DegradedNumberConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Number/DegradedNumberConverter.php',
    'Ramsey\\Uuid\\Converter\\Number\\GenericNumberConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Number/GenericNumberConverter.php',
    'Ramsey\\Uuid\\Converter\\TimeConverterInterface' => $vendorDir . '/ramsey/uuid/src/Converter/TimeConverterInterface.php',
    'Ramsey\\Uuid\\Converter\\Time\\BigNumberTimeConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Time/BigNumberTimeConverter.php',
    'Ramsey\\Uuid\\Converter\\Time\\DegradedTimeConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Time/DegradedTimeConverter.php',
    'Ramsey\\Uuid\\Converter\\Time\\GenericTimeConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Time/GenericTimeConverter.php',
    'Ramsey\\Uuid\\Converter\\Time\\PhpTimeConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Time/PhpTimeConverter.php',
    'Ramsey\\Uuid\\Converter\\Time\\UnixTimeConverter' => $vendorDir . '/ramsey/uuid/src/Converter/Time/UnixTimeConverter.php',
    'Ramsey\\Uuid\\DegradedUuid' => $vendorDir . '/ramsey/uuid/src/DegradedUuid.php',
    'Ramsey\\Uuid\\DeprecatedUuidInterface' => $vendorDir . '/ramsey/uuid/src/DeprecatedUuidInterface.php',
    'Ramsey\\Uuid\\DeprecatedUuidMethodsTrait' => $vendorDir . '/ramsey/uuid/src/DeprecatedUuidMethodsTrait.php',
    'Ramsey\\Uuid\\Exception\\BuilderNotFoundException' => $vendorDir . '/ramsey/uuid/src/Exception/BuilderNotFoundException.php',
    'Ramsey\\Uuid\\Exception\\DateTimeException' => $vendorDir . '/ramsey/uuid/src/Exception/DateTimeException.php',
    'Ramsey\\Uuid\\Exception\\DceSecurityException' => $vendorDir . '/ramsey/uuid/src/Exception/DceSecurityException.php',
    'Ramsey\\Uuid\\Exception\\InvalidArgumentException' => $vendorDir . '/ramsey/uuid/src/Exception/InvalidArgumentException.php',
    'Ramsey\\Uuid\\Exception\\InvalidBytesException' => $vendorDir . '/ramsey/uuid/src/Exception/InvalidBytesException.php',
    'Ramsey\\Uuid\\Exception\\InvalidUuidStringException' => $vendorDir . '/ramsey/uuid/src/Exception/InvalidUuidStringException.php',
    'Ramsey\\Uuid\\Exception\\NameException' => $vendorDir . '/ramsey/uuid/src/Exception/NameException.php',
    'Ramsey\\Uuid\\Exception\\NodeException' => $vendorDir . '/ramsey/uuid/src/Exception/NodeException.php',
    'Ramsey\\Uuid\\Exception\\RandomSourceException' => $vendorDir . '/ramsey/uuid/src/Exception/RandomSourceException.php',
    'Ramsey\\Uuid\\Exception\\TimeSourceException' => $vendorDir . '/ramsey/uuid/src/Exception/TimeSourceException.php',
    'Ramsey\\Uuid\\Exception\\UnableToBuildUuidException' => $vendorDir . '/ramsey/uuid/src/Exception/UnableToBuildUuidException.php',
    'Ramsey\\Uuid\\Exception\\UnsupportedOperationException' => $vendorDir . '/ramsey/uuid/src/Exception/UnsupportedOperationException.php',
    'Ramsey\\Uuid\\Exception\\UuidExceptionInterface' => $vendorDir . '/ramsey/uuid/src/Exception/UuidExceptionInterface.php',
    'Ramsey\\Uuid\\FeatureSet' => $vendorDir . '/ramsey/uuid/src/FeatureSet.php',
    'Ramsey\\Uuid\\Fields\\FieldsInterface' => $vendorDir . '/ramsey/uuid/src/Fields/FieldsInterface.php',
    'Ramsey\\Uuid\\Fields\\SerializableFieldsTrait' => $vendorDir . '/ramsey/uuid/src/Fields/SerializableFieldsTrait.php',
    'Ramsey\\Uuid\\Generator\\CombGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/CombGenerator.php',
    'Ramsey\\Uuid\\Generator\\DceSecurityGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/DceSecurityGenerator.php',
    'Ramsey\\Uuid\\Generator\\DceSecurityGeneratorInterface' => $vendorDir . '/ramsey/uuid/src/Generator/DceSecurityGeneratorInterface.php',
    'Ramsey\\Uuid\\Generator\\DefaultNameGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/DefaultNameGenerator.php',
    'Ramsey\\Uuid\\Generator\\DefaultTimeGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/DefaultTimeGenerator.php',
    'Ramsey\\Uuid\\Generator\\NameGeneratorFactory' => $vendorDir . '/ramsey/uuid/src/Generator/NameGeneratorFactory.php',
    'Ramsey\\Uuid\\Generator\\NameGeneratorInterface' => $vendorDir . '/ramsey/uuid/src/Generator/NameGeneratorInterface.php',
    'Ramsey\\Uuid\\Generator\\PeclUuidNameGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/PeclUuidNameGenerator.php',
    'Ramsey\\Uuid\\Generator\\PeclUuidRandomGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/PeclUuidRandomGenerator.php',
    'Ramsey\\Uuid\\Generator\\PeclUuidTimeGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/PeclUuidTimeGenerator.php',
    'Ramsey\\Uuid\\Generator\\RandomBytesGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/RandomBytesGenerator.php',
    'Ramsey\\Uuid\\Generator\\RandomGeneratorFactory' => $vendorDir . '/ramsey/uuid/src/Generator/RandomGeneratorFactory.php',
    'Ramsey\\Uuid\\Generator\\RandomGeneratorInterface' => $vendorDir . '/ramsey/uuid/src/Generator/RandomGeneratorInterface.php',
    'Ramsey\\Uuid\\Generator\\RandomLibAdapter' => $vendorDir . '/ramsey/uuid/src/Generator/RandomLibAdapter.php',
    'Ramsey\\Uuid\\Generator\\TimeGeneratorFactory' => $vendorDir . '/ramsey/uuid/src/Generator/TimeGeneratorFactory.php',
    'Ramsey\\Uuid\\Generator\\TimeGeneratorInterface' => $vendorDir . '/ramsey/uuid/src/Generator/TimeGeneratorInterface.php',
    'Ramsey\\Uuid\\Generator\\UnixTimeGenerator' => $vendorDir . '/ramsey/uuid/src/Generator/UnixTimeGenerator.php',
    'Ramsey\\Uuid\\Guid\\Fields' => $vendorDir . '/ramsey/uuid/src/Guid/Fields.php',
    'Ramsey\\Uuid\\Guid\\Guid' => $vendorDir . '/ramsey/uuid/src/Guid/Guid.php',
    'Ramsey\\Uuid\\Guid\\GuidBuilder' => $vendorDir . '/ramsey/uuid/src/Guid/GuidBuilder.php',
    'Ramsey\\Uuid\\Lazy\\LazyUuidFromString' => $vendorDir . '/ramsey/uuid/src/Lazy/LazyUuidFromString.php',
    'Ramsey\\Uuid\\Math\\BrickMathCalculator' => $vendorDir . '/ramsey/uuid/src/Math/BrickMathCalculator.php',
    'Ramsey\\Uuid\\Math\\CalculatorInterface' => $vendorDir . '/ramsey/uuid/src/Math/CalculatorInterface.php',
    'Ramsey\\Uuid\\Math\\RoundingMode' => $vendorDir . '/ramsey/uuid/src/Math/RoundingMode.php',
    'Ramsey\\Uuid\\Nonstandard\\Fields' => $vendorDir . '/ramsey/uuid/src/Nonstandard/Fields.php',
    'Ramsey\\Uuid\\Nonstandard\\Uuid' => $vendorDir . '/ramsey/uuid/src/Nonstandard/Uuid.php',
    'Ramsey\\Uuid\\Nonstandard\\UuidBuilder' => $vendorDir . '/ramsey/uuid/src/Nonstandard/UuidBuilder.php',
    'Ramsey\\Uuid\\Nonstandard\\UuidV6' => $vendorDir . '/ramsey/uuid/src/Nonstandard/UuidV6.php',
    'Ramsey\\Uuid\\Provider\\DceSecurityProviderInterface' => $vendorDir . '/ramsey/uuid/src/Provider/DceSecurityProviderInterface.php',
    'Ramsey\\Uuid\\Provider\\Dce\\SystemDceSecurityProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Dce/SystemDceSecurityProvider.php',
    'Ramsey\\Uuid\\Provider\\NodeProviderInterface' => $vendorDir . '/ramsey/uuid/src/Provider/NodeProviderInterface.php',
    'Ramsey\\Uuid\\Provider\\Node\\FallbackNodeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Node/FallbackNodeProvider.php',
    'Ramsey\\Uuid\\Provider\\Node\\NodeProviderCollection' => $vendorDir . '/ramsey/uuid/src/Provider/Node/NodeProviderCollection.php',
    'Ramsey\\Uuid\\Provider\\Node\\RandomNodeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Node/RandomNodeProvider.php',
    'Ramsey\\Uuid\\Provider\\Node\\StaticNodeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Node/StaticNodeProvider.php',
    'Ramsey\\Uuid\\Provider\\Node\\SystemNodeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Node/SystemNodeProvider.php',
    'Ramsey\\Uuid\\Provider\\TimeProviderInterface' => $vendorDir . '/ramsey/uuid/src/Provider/TimeProviderInterface.php',
    'Ramsey\\Uuid\\Provider\\Time\\FixedTimeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Time/FixedTimeProvider.php',
    'Ramsey\\Uuid\\Provider\\Time\\SystemTimeProvider' => $vendorDir . '/ramsey/uuid/src/Provider/Time/SystemTimeProvider.php',
    'Ramsey\\Uuid\\Rfc4122\\Fields' => $vendorDir . '/ramsey/uuid/src/Rfc4122/Fields.php',
    'Ramsey\\Uuid\\Rfc4122\\FieldsInterface' => $vendorDir . '/ramsey/uuid/src/Rfc4122/FieldsInterface.php',
    'Ramsey\\Uuid\\Rfc4122\\MaxTrait' => $vendorDir . '/ramsey/uuid/src/Rfc4122/MaxTrait.php',
    'Ramsey\\Uuid\\Rfc4122\\MaxUuid' => $vendorDir . '/ramsey/uuid/src/Rfc4122/MaxUuid.php',
    'Ramsey\\Uuid\\Rfc4122\\NilTrait' => $vendorDir . '/ramsey/uuid/src/Rfc4122/NilTrait.php',
    'Ramsey\\Uuid\\Rfc4122\\NilUuid' => $vendorDir . '/ramsey/uuid/src/Rfc4122/NilUuid.php',
    'Ramsey\\Uuid\\Rfc4122\\TimeTrait' => $vendorDir . '/ramsey/uuid/src/Rfc4122/TimeTrait.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidBuilder' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidBuilder.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidInterface' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidInterface.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV1' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV1.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV2' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV2.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV3' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV3.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV4' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV4.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV5' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV5.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV6' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV6.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV7' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV7.php',
    'Ramsey\\Uuid\\Rfc4122\\UuidV8' => $vendorDir . '/ramsey/uuid/src/Rfc4122/UuidV8.php',
    'Ramsey\\Uuid\\Rfc4122\\Validator' => $vendorDir . '/ramsey/uuid/src/Rfc4122/Validator.php',
    'Ramsey\\Uuid\\Rfc4122\\VariantTrait' => $vendorDir . '/ramsey/uuid/src/Rfc4122/VariantTrait.php',
    'Ramsey\\Uuid\\Rfc4122\\VersionTrait' => $vendorDir . '/ramsey/uuid/src/Rfc4122/VersionTrait.php',
    'Ramsey\\Uuid\\Type\\Decimal' => $vendorDir . '/ramsey/uuid/src/Type/Decimal.php',
    'Ramsey\\Uuid\\Type\\Hexadecimal' => $vendorDir . '/ramsey/uuid/src/Type/Hexadecimal.php',
    'Ramsey\\Uuid\\Type\\Integer' => $vendorDir . '/ramsey/uuid/src/Type/Integer.php',
    'Ramsey\\Uuid\\Type\\NumberInterface' => $vendorDir . '/ramsey/uuid/src/Type/NumberInterface.php',
    'Ramsey\\Uuid\\Type\\Time' => $vendorDir . '/ramsey/uuid/src/Type/Time.php',
    'Ramsey\\Uuid\\Type\\TypeInterface' => $vendorDir . '/ramsey/uuid/src/Type/TypeInterface.php',
    'Ramsey\\Uuid\\Uuid' => $vendorDir . '/ramsey/uuid/src/Uuid.php',
    'Ramsey\\Uuid\\UuidFactory' => $vendorDir . '/ramsey/uuid/src/UuidFactory.php',
    'Ramsey\\Uuid\\UuidFactoryInterface' => $vendorDir . '/ramsey/uuid/src/UuidFactoryInterface.php',
    'Ramsey\\Uuid\\UuidInterface' => $vendorDir . '/ramsey/uuid/src/UuidInterface.php',
    'Ramsey\\Uuid\\Validator\\GenericValidator' => $vendorDir . '/ramsey/uuid/src/Validator/GenericValidator.php',
    'Ramsey\\Uuid\\Validator\\ValidatorInterface' => $vendorDir . '/ramsey/uuid/src/Validator/ValidatorInterface.php',
    'SQLite3Exception' => $vendorDir . '/symfony/polyfill-php83/Resources/stubs/SQLite3Exception.php',
    'SebastianBergmann\\CliParser\\AmbiguousOptionException' => $vendorDir . '/sebastian/cli-parser/src/exceptions/AmbiguousOptionException.php',
    'SebastianBergmann\\CliParser\\Exception' => $vendorDir . '/sebastian/cli-parser/src/exceptions/Exception.php',
    'SebastianBergmann\\CliParser\\OptionDoesNotAllowArgumentException' => $vendorDir . '/sebastian/cli-parser/src/exceptions/OptionDoesNotAllowArgumentException.php',
    'SebastianBergmann\\CliParser\\Parser' => $vendorDir . '/sebastian/cli-parser/src/Parser.php',
    'SebastianBergmann\\CliParser\\RequiredOptionArgumentMissingException' => $vendorDir . '/sebastian/cli-parser/src/exceptions/RequiredOptionArgumentMissingException.php',
    'SebastianBergmann\\CliParser\\UnknownOptionException' => $vendorDir . '/sebastian/cli-parser/src/exceptions/UnknownOptionException.php',
    'SebastianBergmann\\CodeCoverage\\BranchAndPathCoverageNotSupportedException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/BranchAndPathCoverageNotSupportedException.php',
    'SebastianBergmann\\CodeCoverage\\CodeCoverage' => $vendorDir . '/phpunit/php-code-coverage/src/CodeCoverage.php',
    'SebastianBergmann\\CodeCoverage\\Data\\ProcessedCodeCoverageData' => $vendorDir . '/phpunit/php-code-coverage/src/Data/ProcessedCodeCoverageData.php',
    'SebastianBergmann\\CodeCoverage\\Data\\RawCodeCoverageData' => $vendorDir . '/phpunit/php-code-coverage/src/Data/RawCodeCoverageData.php',
    'SebastianBergmann\\CodeCoverage\\DeadCodeDetectionNotSupportedException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/DeadCodeDetectionNotSupportedException.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\Driver' => $vendorDir . '/phpunit/php-code-coverage/src/Driver/Driver.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\PathExistsButIsNotDirectoryException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/PathExistsButIsNotDirectoryException.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\PcovDriver' => $vendorDir . '/phpunit/php-code-coverage/src/Driver/PcovDriver.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\PcovNotAvailableException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/PcovNotAvailableException.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\Selector' => $vendorDir . '/phpunit/php-code-coverage/src/Driver/Selector.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\WriteOperationFailedException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/WriteOperationFailedException.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\XdebugDriver' => $vendorDir . '/phpunit/php-code-coverage/src/Driver/XdebugDriver.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\XdebugNotAvailableException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/XdebugNotAvailableException.php',
    'SebastianBergmann\\CodeCoverage\\Driver\\XdebugNotEnabledException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/XdebugNotEnabledException.php',
    'SebastianBergmann\\CodeCoverage\\Exception' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/Exception.php',
    'SebastianBergmann\\CodeCoverage\\FileCouldNotBeWrittenException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/FileCouldNotBeWrittenException.php',
    'SebastianBergmann\\CodeCoverage\\Filter' => $vendorDir . '/phpunit/php-code-coverage/src/Filter.php',
    'SebastianBergmann\\CodeCoverage\\InvalidArgumentException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/InvalidArgumentException.php',
    'SebastianBergmann\\CodeCoverage\\NoCodeCoverageDriverAvailableException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/NoCodeCoverageDriverAvailableException.php',
    'SebastianBergmann\\CodeCoverage\\NoCodeCoverageDriverWithPathCoverageSupportAvailableException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/NoCodeCoverageDriverWithPathCoverageSupportAvailableException.php',
    'SebastianBergmann\\CodeCoverage\\Node\\AbstractNode' => $vendorDir . '/phpunit/php-code-coverage/src/Node/AbstractNode.php',
    'SebastianBergmann\\CodeCoverage\\Node\\Builder' => $vendorDir . '/phpunit/php-code-coverage/src/Node/Builder.php',
    'SebastianBergmann\\CodeCoverage\\Node\\CrapIndex' => $vendorDir . '/phpunit/php-code-coverage/src/Node/CrapIndex.php',
    'SebastianBergmann\\CodeCoverage\\Node\\Directory' => $vendorDir . '/phpunit/php-code-coverage/src/Node/Directory.php',
    'SebastianBergmann\\CodeCoverage\\Node\\File' => $vendorDir . '/phpunit/php-code-coverage/src/Node/File.php',
    'SebastianBergmann\\CodeCoverage\\Node\\Iterator' => $vendorDir . '/phpunit/php-code-coverage/src/Node/Iterator.php',
    'SebastianBergmann\\CodeCoverage\\ParserException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/ParserException.php',
    'SebastianBergmann\\CodeCoverage\\ReflectionException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/ReflectionException.php',
    'SebastianBergmann\\CodeCoverage\\ReportAlreadyFinalizedException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/ReportAlreadyFinalizedException.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Clover' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Clover.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Cobertura' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Cobertura.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Crap4j' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Crap4j.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\Colors' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Colors.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\CustomCssFile' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/CustomCssFile.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\Dashboard' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Renderer/Dashboard.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\Directory' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Renderer/Directory.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\Facade' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Facade.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\File' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Renderer/File.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Html\\Renderer' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Html/Renderer.php',
    'SebastianBergmann\\CodeCoverage\\Report\\PHP' => $vendorDir . '/phpunit/php-code-coverage/src/Report/PHP.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Text' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Text.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Thresholds' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Thresholds.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\BuildInformation' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/BuildInformation.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Coverage' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Coverage.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Directory' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Directory.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Facade' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Facade.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\File' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/File.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Method' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Method.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Node' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Node.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Project' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Project.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Report' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Report.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Source' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Source.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Tests' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Tests.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Totals' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Totals.php',
    'SebastianBergmann\\CodeCoverage\\Report\\Xml\\Unit' => $vendorDir . '/phpunit/php-code-coverage/src/Report/Xml/Unit.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysisCacheNotConfiguredException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/StaticAnalysisCacheNotConfiguredException.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\CacheWarmer' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/CacheWarmer.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\CachingFileAnalyser' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/CachingFileAnalyser.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\CodeUnitFindingVisitor' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/CodeUnitFindingVisitor.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\ExecutableLinesFindingVisitor' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/ExecutableLinesFindingVisitor.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\FileAnalyser' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/FileAnalyser.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\IgnoredLinesFindingVisitor' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/IgnoredLinesFindingVisitor.php',
    'SebastianBergmann\\CodeCoverage\\StaticAnalysis\\ParsingFileAnalyser' => $vendorDir . '/phpunit/php-code-coverage/src/StaticAnalysis/ParsingFileAnalyser.php',
    'SebastianBergmann\\CodeCoverage\\TestIdMissingException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/TestIdMissingException.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\Known' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/Known.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\Large' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/Large.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\Medium' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/Medium.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\Small' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/Small.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\TestSize' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/TestSize.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestSize\\Unknown' => $vendorDir . '/phpunit/php-code-coverage/src/TestSize/Unknown.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestStatus\\Failure' => $vendorDir . '/phpunit/php-code-coverage/src/TestStatus/Failure.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestStatus\\Known' => $vendorDir . '/phpunit/php-code-coverage/src/TestStatus/Known.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestStatus\\Success' => $vendorDir . '/phpunit/php-code-coverage/src/TestStatus/Success.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestStatus\\TestStatus' => $vendorDir . '/phpunit/php-code-coverage/src/TestStatus/TestStatus.php',
    'SebastianBergmann\\CodeCoverage\\Test\\TestStatus\\Unknown' => $vendorDir . '/phpunit/php-code-coverage/src/TestStatus/Unknown.php',
    'SebastianBergmann\\CodeCoverage\\UnintentionallyCoveredCodeException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/UnintentionallyCoveredCodeException.php',
    'SebastianBergmann\\CodeCoverage\\Util\\DirectoryCouldNotBeCreatedException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/DirectoryCouldNotBeCreatedException.php',
    'SebastianBergmann\\CodeCoverage\\Util\\Filesystem' => $vendorDir . '/phpunit/php-code-coverage/src/Util/Filesystem.php',
    'SebastianBergmann\\CodeCoverage\\Util\\Percentage' => $vendorDir . '/phpunit/php-code-coverage/src/Util/Percentage.php',
    'SebastianBergmann\\CodeCoverage\\Version' => $vendorDir . '/phpunit/php-code-coverage/src/Version.php',
    'SebastianBergmann\\CodeCoverage\\XmlException' => $vendorDir . '/phpunit/php-code-coverage/src/Exception/XmlException.php',
    'SebastianBergmann\\CodeUnitReverseLookup\\Wizard' => $vendorDir . '/sebastian/code-unit-reverse-lookup/src/Wizard.php',
    'SebastianBergmann\\CodeUnit\\ClassMethodUnit' => $vendorDir . '/sebastian/code-unit/src/ClassMethodUnit.php',
    'SebastianBergmann\\CodeUnit\\ClassUnit' => $vendorDir . '/sebastian/code-unit/src/ClassUnit.php',
    'SebastianBergmann\\CodeUnit\\CodeUnit' => $vendorDir . '/sebastian/code-unit/src/CodeUnit.php',
    'SebastianBergmann\\CodeUnit\\CodeUnitCollection' => $vendorDir . '/sebastian/code-unit/src/CodeUnitCollection.php',
    'SebastianBergmann\\CodeUnit\\CodeUnitCollectionIterator' => $vendorDir . '/sebastian/code-unit/src/CodeUnitCollectionIterator.php',
    'SebastianBergmann\\CodeUnit\\Exception' => $vendorDir . '/sebastian/code-unit/src/exceptions/Exception.php',
    'SebastianBergmann\\CodeUnit\\FileUnit' => $vendorDir . '/sebastian/code-unit/src/FileUnit.php',
    'SebastianBergmann\\CodeUnit\\FunctionUnit' => $vendorDir . '/sebastian/code-unit/src/FunctionUnit.php',
    'SebastianBergmann\\CodeUnit\\InterfaceMethodUnit' => $vendorDir . '/sebastian/code-unit/src/InterfaceMethodUnit.php',
    'SebastianBergmann\\CodeUnit\\InterfaceUnit' => $vendorDir . '/sebastian/code-unit/src/InterfaceUnit.php',
    'SebastianBergmann\\CodeUnit\\InvalidCodeUnitException' => $vendorDir . '/sebastian/code-unit/src/exceptions/InvalidCodeUnitException.php',
    'SebastianBergmann\\CodeUnit\\Mapper' => $vendorDir . '/sebastian/code-unit/src/Mapper.php',
    'SebastianBergmann\\CodeUnit\\NoTraitException' => $vendorDir . '/sebastian/code-unit/src/exceptions/NoTraitException.php',
    'SebastianBergmann\\CodeUnit\\ReflectionException' => $vendorDir . '/sebastian/code-unit/src/exceptions/ReflectionException.php',
    'SebastianBergmann\\CodeUnit\\TraitMethodUnit' => $vendorDir . '/sebastian/code-unit/src/TraitMethodUnit.php',
    'SebastianBergmann\\CodeUnit\\TraitUnit' => $vendorDir . '/sebastian/code-unit/src/TraitUnit.php',
    'SebastianBergmann\\Comparator\\ArrayComparator' => $vendorDir . '/sebastian/comparator/src/ArrayComparator.php',
    'SebastianBergmann\\Comparator\\Comparator' => $vendorDir . '/sebastian/comparator/src/Comparator.php',
    'SebastianBergmann\\Comparator\\ComparisonFailure' => $vendorDir . '/sebastian/comparator/src/ComparisonFailure.php',
    'SebastianBergmann\\Comparator\\DOMNodeComparator' => $vendorDir . '/sebastian/comparator/src/DOMNodeComparator.php',
    'SebastianBergmann\\Comparator\\DateTimeComparator' => $vendorDir . '/sebastian/comparator/src/DateTimeComparator.php',
    'SebastianBergmann\\Comparator\\Exception' => $vendorDir . '/sebastian/comparator/src/exceptions/Exception.php',
    'SebastianBergmann\\Comparator\\ExceptionComparator' => $vendorDir . '/sebastian/comparator/src/ExceptionComparator.php',
    'SebastianBergmann\\Comparator\\Factory' => $vendorDir . '/sebastian/comparator/src/Factory.php',
    'SebastianBergmann\\Comparator\\MockObjectComparator' => $vendorDir . '/sebastian/comparator/src/MockObjectComparator.php',
    'SebastianBergmann\\Comparator\\NumericComparator' => $vendorDir . '/sebastian/comparator/src/NumericComparator.php',
    'SebastianBergmann\\Comparator\\ObjectComparator' => $vendorDir . '/sebastian/comparator/src/ObjectComparator.php',
    'SebastianBergmann\\Comparator\\ResourceComparator' => $vendorDir . '/sebastian/comparator/src/ResourceComparator.php',
    'SebastianBergmann\\Comparator\\RuntimeException' => $vendorDir . '/sebastian/comparator/src/exceptions/RuntimeException.php',
    'SebastianBergmann\\Comparator\\ScalarComparator' => $vendorDir . '/sebastian/comparator/src/ScalarComparator.php',
    'SebastianBergmann\\Comparator\\SplObjectStorageComparator' => $vendorDir . '/sebastian/comparator/src/SplObjectStorageComparator.php',
    'SebastianBergmann\\Comparator\\TypeComparator' => $vendorDir . '/sebastian/comparator/src/TypeComparator.php',
    'SebastianBergmann\\Complexity\\Calculator' => $vendorDir . '/sebastian/complexity/src/Calculator.php',
    'SebastianBergmann\\Complexity\\Complexity' => $vendorDir . '/sebastian/complexity/src/Complexity/Complexity.php',
    'SebastianBergmann\\Complexity\\ComplexityCalculatingVisitor' => $vendorDir . '/sebastian/complexity/src/Visitor/ComplexityCalculatingVisitor.php',
    'SebastianBergmann\\Complexity\\ComplexityCollection' => $vendorDir . '/sebastian/complexity/src/Complexity/ComplexityCollection.php',
    'SebastianBergmann\\Complexity\\ComplexityCollectionIterator' => $vendorDir . '/sebastian/complexity/src/Complexity/ComplexityCollectionIterator.php',
    'SebastianBergmann\\Complexity\\CyclomaticComplexityCalculatingVisitor' => $vendorDir . '/sebastian/complexity/src/Visitor/CyclomaticComplexityCalculatingVisitor.php',
    'SebastianBergmann\\Complexity\\Exception' => $vendorDir . '/sebastian/complexity/src/Exception/Exception.php',
    'SebastianBergmann\\Complexity\\RuntimeException' => $vendorDir . '/sebastian/complexity/src/Exception/RuntimeException.php',
    'SebastianBergmann\\Diff\\Chunk' => $vendorDir . '/sebastian/diff/src/Chunk.php',
    'SebastianBergmann\\Diff\\ConfigurationException' => $vendorDir . '/sebastian/diff/src/Exception/ConfigurationException.php',
    'SebastianBergmann\\Diff\\Diff' => $vendorDir . '/sebastian/diff/src/Diff.php',
    'SebastianBergmann\\Diff\\Differ' => $vendorDir . '/sebastian/diff/src/Differ.php',
    'SebastianBergmann\\Diff\\Exception' => $vendorDir . '/sebastian/diff/src/Exception/Exception.php',
    'SebastianBergmann\\Diff\\InvalidArgumentException' => $vendorDir . '/sebastian/diff/src/Exception/InvalidArgumentException.php',
    'SebastianBergmann\\Diff\\Line' => $vendorDir . '/sebastian/diff/src/Line.php',
    'SebastianBergmann\\Diff\\LongestCommonSubsequenceCalculator' => $vendorDir . '/sebastian/diff/src/LongestCommonSubsequenceCalculator.php',
    'SebastianBergmann\\Diff\\MemoryEfficientLongestCommonSubsequenceCalculator' => $vendorDir . '/sebastian/diff/src/MemoryEfficientLongestCommonSubsequenceCalculator.php',
    'SebastianBergmann\\Diff\\Output\\AbstractChunkOutputBuilder' => $vendorDir . '/sebastian/diff/src/Output/AbstractChunkOutputBuilder.php',
    'SebastianBergmann\\Diff\\Output\\DiffOnlyOutputBuilder' => $vendorDir . '/sebastian/diff/src/Output/DiffOnlyOutputBuilder.php',
    'SebastianBergmann\\Diff\\Output\\DiffOutputBuilderInterface' => $vendorDir . '/sebastian/diff/src/Output/DiffOutputBuilderInterface.php',
    'SebastianBergmann\\Diff\\Output\\StrictUnifiedDiffOutputBuilder' => $vendorDir . '/sebastian/diff/src/Output/StrictUnifiedDiffOutputBuilder.php',
    'SebastianBergmann\\Diff\\Output\\UnifiedDiffOutputBuilder' => $vendorDir . '/sebastian/diff/src/Output/UnifiedDiffOutputBuilder.php',
    'SebastianBergmann\\Diff\\Parser' => $vendorDir . '/sebastian/diff/src/Parser.php',
    'SebastianBergmann\\Diff\\TimeEfficientLongestCommonSubsequenceCalculator' => $vendorDir . '/sebastian/diff/src/TimeEfficientLongestCommonSubsequenceCalculator.php',
    'SebastianBergmann\\Environment\\Console' => $vendorDir . '/sebastian/environment/src/Console.php',
    'SebastianBergmann\\Environment\\Runtime' => $vendorDir . '/sebastian/environment/src/Runtime.php',
    'SebastianBergmann\\Exporter\\Exporter' => $vendorDir . '/sebastian/exporter/src/Exporter.php',
    'SebastianBergmann\\FileIterator\\ExcludeIterator' => $vendorDir . '/phpunit/php-file-iterator/src/ExcludeIterator.php',
    'SebastianBergmann\\FileIterator\\Facade' => $vendorDir . '/phpunit/php-file-iterator/src/Facade.php',
    'SebastianBergmann\\FileIterator\\Factory' => $vendorDir . '/phpunit/php-file-iterator/src/Factory.php',
    'SebastianBergmann\\FileIterator\\Iterator' => $vendorDir . '/phpunit/php-file-iterator/src/Iterator.php',
    'SebastianBergmann\\GlobalState\\CodeExporter' => $vendorDir . '/sebastian/global-state/src/CodeExporter.php',
    'SebastianBergmann\\GlobalState\\Exception' => $vendorDir . '/sebastian/global-state/src/exceptions/Exception.php',
    'SebastianBergmann\\GlobalState\\ExcludeList' => $vendorDir . '/sebastian/global-state/src/ExcludeList.php',
    'SebastianBergmann\\GlobalState\\Restorer' => $vendorDir . '/sebastian/global-state/src/Restorer.php',
    'SebastianBergmann\\GlobalState\\RuntimeException' => $vendorDir . '/sebastian/global-state/src/exceptions/RuntimeException.php',
    'SebastianBergmann\\GlobalState\\Snapshot' => $vendorDir . '/sebastian/global-state/src/Snapshot.php',
    'SebastianBergmann\\Invoker\\Exception' => $vendorDir . '/phpunit/php-invoker/src/exceptions/Exception.php',
    'SebastianBergmann\\Invoker\\Invoker' => $vendorDir . '/phpunit/php-invoker/src/Invoker.php',
    'SebastianBergmann\\Invoker\\ProcessControlExtensionNotLoadedException' => $vendorDir . '/phpunit/php-invoker/src/exceptions/ProcessControlExtensionNotLoadedException.php',
    'SebastianBergmann\\Invoker\\TimeoutException' => $vendorDir . '/phpunit/php-invoker/src/exceptions/TimeoutException.php',
    'SebastianBergmann\\LinesOfCode\\Counter' => $vendorDir . '/sebastian/lines-of-code/src/Counter.php',
    'SebastianBergmann\\LinesOfCode\\Exception' => $vendorDir . '/sebastian/lines-of-code/src/Exception/Exception.php',
    'SebastianBergmann\\LinesOfCode\\IllogicalValuesException' => $vendorDir . '/sebastian/lines-of-code/src/Exception/IllogicalValuesException.php',
    'SebastianBergmann\\LinesOfCode\\LineCountingVisitor' => $vendorDir . '/sebastian/lines-of-code/src/LineCountingVisitor.php',
    'SebastianBergmann\\LinesOfCode\\LinesOfCode' => $vendorDir . '/sebastian/lines-of-code/src/LinesOfCode.php',
    'SebastianBergmann\\LinesOfCode\\NegativeValueException' => $vendorDir . '/sebastian/lines-of-code/src/Exception/NegativeValueException.php',
    'SebastianBergmann\\LinesOfCode\\RuntimeException' => $vendorDir . '/sebastian/lines-of-code/src/Exception/RuntimeException.php',
    'SebastianBergmann\\ObjectEnumerator\\Enumerator' => $vendorDir . '/sebastian/object-enumerator/src/Enumerator.php',
    'SebastianBergmann\\ObjectReflector\\ObjectReflector' => $vendorDir . '/sebastian/object-reflector/src/ObjectReflector.php',
    'SebastianBergmann\\RecursionContext\\Context' => $vendorDir . '/sebastian/recursion-context/src/Context.php',
    'SebastianBergmann\\Template\\Exception' => $vendorDir . '/phpunit/php-text-template/src/exceptions/Exception.php',
    'SebastianBergmann\\Template\\InvalidArgumentException' => $vendorDir . '/phpunit/php-text-template/src/exceptions/InvalidArgumentException.php',
    'SebastianBergmann\\Template\\RuntimeException' => $vendorDir . '/phpunit/php-text-template/src/exceptions/RuntimeException.php',
    'SebastianBergmann\\Template\\Template' => $vendorDir . '/phpunit/php-text-template/src/Template.php',
    'SebastianBergmann\\Timer\\Duration' => $vendorDir . '/phpunit/php-timer/src/Duration.php',
    'SebastianBergmann\\Timer\\Exception' => $vendorDir . '/phpunit/php-timer/src/exceptions/Exception.php',
    'SebastianBergmann\\Timer\\NoActiveTimerException' => $vendorDir . '/phpunit/php-timer/src/exceptions/NoActiveTimerException.php',
    'SebastianBergmann\\Timer\\ResourceUsageFormatter' => $vendorDir . '/phpunit/php-timer/src/ResourceUsageFormatter.php',
    'SebastianBergmann\\Timer\\TimeSinceStartOfRequestNotAvailableException' => $vendorDir . '/phpunit/php-timer/src/exceptions/TimeSinceStartOfRequestNotAvailableException.php',
    'SebastianBergmann\\Timer\\Timer' => $vendorDir . '/phpunit/php-timer/src/Timer.php',
    'SebastianBergmann\\Type\\CallableType' => $vendorDir . '/sebastian/type/src/type/CallableType.php',
    'SebastianBergmann\\Type\\Exception' => $vendorDir . '/sebastian/type/src/exception/Exception.php',
    'SebastianBergmann\\Type\\FalseType' => $vendorDir . '/sebastian/type/src/type/FalseType.php',
    'SebastianBergmann\\Type\\GenericObjectType' => $vendorDir . '/sebastian/type/src/type/GenericObjectType.php',
    'SebastianBergmann\\Type\\IntersectionType' => $vendorDir . '/sebastian/type/src/type/IntersectionType.php',
    'SebastianBergmann\\Type\\IterableType' => $vendorDir . '/sebastian/type/src/type/IterableType.php',
    'SebastianBergmann\\Type\\MixedType' => $vendorDir . '/sebastian/type/src/type/MixedType.php',
    'SebastianBergmann\\Type\\NeverType' => $vendorDir . '/sebastian/type/src/type/NeverType.php',
    'SebastianBergmann\\Type\\NullType' => $vendorDir . '/sebastian/type/src/type/NullType.php',
    'SebastianBergmann\\Type\\ObjectType' => $vendorDir . '/sebastian/type/src/type/ObjectType.php',
    'SebastianBergmann\\Type\\Parameter' => $vendorDir . '/sebastian/type/src/Parameter.php',
    'SebastianBergmann\\Type\\ReflectionMapper' => $vendorDir . '/sebastian/type/src/ReflectionMapper.php',
    'SebastianBergmann\\Type\\RuntimeException' => $vendorDir . '/sebastian/type/src/exception/RuntimeException.php',
    'SebastianBergmann\\Type\\SimpleType' => $vendorDir . '/sebastian/type/src/type/SimpleType.php',
    'SebastianBergmann\\Type\\StaticType' => $vendorDir . '/sebastian/type/src/type/StaticType.php',
    'SebastianBergmann\\Type\\TrueType' => $vendorDir . '/sebastian/type/src/type/TrueType.php',
    'SebastianBergmann\\Type\\Type' => $vendorDir . '/sebastian/type/src/type/Type.php',
    'SebastianBergmann\\Type\\TypeName' => $vendorDir . '/sebastian/type/src/TypeName.php',
    'SebastianBergmann\\Type\\UnionType' => $vendorDir . '/sebastian/type/src/type/UnionType.php',
    'SebastianBergmann\\Type\\UnknownType' => $vendorDir . '/sebastian/type/src/type/UnknownType.php',
    'SebastianBergmann\\Type\\VoidType' => $vendorDir . '/sebastian/type/src/type/VoidType.php',
    'SebastianBergmann\\Version' => $vendorDir . '/sebastian/version/src/Version.php',
    'Spatie\\Backtrace\\Arguments\\ArgumentReducers' => $vendorDir . '/spatie/backtrace/src/Arguments/ArgumentReducers.php',
    'Spatie\\Backtrace\\Arguments\\ProvidedArgument' => $vendorDir . '/spatie/backtrace/src/Arguments/ProvidedArgument.php',
    'Spatie\\Backtrace\\Arguments\\ReduceArgumentPayloadAction' => $vendorDir . '/spatie/backtrace/src/Arguments/ReduceArgumentPayloadAction.php',
    'Spatie\\Backtrace\\Arguments\\ReduceArgumentsAction' => $vendorDir . '/spatie/backtrace/src/Arguments/ReduceArgumentsAction.php',
    'Spatie\\Backtrace\\Arguments\\ReducedArgument\\ReducedArgument' => $vendorDir . '/spatie/backtrace/src/Arguments/ReducedArgument/ReducedArgument.php',
    'Spatie\\Backtrace\\Arguments\\ReducedArgument\\ReducedArgumentContract' => $vendorDir . '/spatie/backtrace/src/Arguments/ReducedArgument/ReducedArgumentContract.php',
    'Spatie\\Backtrace\\Arguments\\ReducedArgument\\TruncatedReducedArgument' => $vendorDir . '/spatie/backtrace/src/Arguments/ReducedArgument/TruncatedReducedArgument.php',
    'Spatie\\Backtrace\\Arguments\\ReducedArgument\\UnReducedArgument' => $vendorDir . '/spatie/backtrace/src/Arguments/ReducedArgument/UnReducedArgument.php',
    'Spatie\\Backtrace\\Arguments\\ReducedArgument\\VariadicReducedArgument' => $vendorDir . '/spatie/backtrace/src/Arguments/ReducedArgument/VariadicReducedArgument.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\ArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/ArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\ArrayArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/ArrayArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\BaseTypeArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/BaseTypeArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\ClosureArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/ClosureArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\DateTimeArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/DateTimeArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\DateTimeZoneArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/DateTimeZoneArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\EnumArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/EnumArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\MinimalArrayArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/MinimalArrayArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\SensitiveParameterArrayReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/SensitiveParameterArrayReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\StdClassArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/StdClassArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\StringableArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/StringableArgumentReducer.php',
    'Spatie\\Backtrace\\Arguments\\Reducers\\SymphonyRequestArgumentReducer' => $vendorDir . '/spatie/backtrace/src/Arguments/Reducers/SymphonyRequestArgumentReducer.php',
    'Spatie\\Backtrace\\Backtrace' => $vendorDir . '/spatie/backtrace/src/Backtrace.php',
    'Spatie\\Backtrace\\CodeSnippets\\CodeSnippet' => $vendorDir . '/spatie/backtrace/src/CodeSnippets/CodeSnippet.php',
    'Spatie\\Backtrace\\CodeSnippets\\FileSnippetProvider' => $vendorDir . '/spatie/backtrace/src/CodeSnippets/FileSnippetProvider.php',
    'Spatie\\Backtrace\\CodeSnippets\\LaravelSerializableClosureSnippetProvider' => $vendorDir . '/spatie/backtrace/src/CodeSnippets/LaravelSerializableClosureSnippetProvider.php',
    'Spatie\\Backtrace\\CodeSnippets\\NullSnippetProvider' => $vendorDir . '/spatie/backtrace/src/CodeSnippets/NullSnippetProvider.php',
    'Spatie\\Backtrace\\CodeSnippets\\SnippetProvider' => $vendorDir . '/spatie/backtrace/src/CodeSnippets/SnippetProvider.php',
    'Spatie\\Backtrace\\Frame' => $vendorDir . '/spatie/backtrace/src/Frame.php',
    'Spatie\\ErrorSolutions\\Contracts\\BaseSolution' => $vendorDir . '/spatie/error-solutions/src/Contracts/BaseSolution.php',
    'Spatie\\ErrorSolutions\\Contracts\\HasSolutionsForThrowable' => $vendorDir . '/spatie/error-solutions/src/Contracts/HasSolutionsForThrowable.php',
    'Spatie\\ErrorSolutions\\Contracts\\ProvidesSolution' => $vendorDir . '/spatie/error-solutions/src/Contracts/ProvidesSolution.php',
    'Spatie\\ErrorSolutions\\Contracts\\RunnableSolution' => $vendorDir . '/spatie/error-solutions/src/Contracts/RunnableSolution.php',
    'Spatie\\ErrorSolutions\\Contracts\\Solution' => $vendorDir . '/spatie/error-solutions/src/Contracts/Solution.php',
    'Spatie\\ErrorSolutions\\Contracts\\SolutionProviderRepository' => $vendorDir . '/spatie/error-solutions/src/Contracts/SolutionProviderRepository.php',
    'Spatie\\ErrorSolutions\\DiscoverSolutionProviders' => $vendorDir . '/spatie/error-solutions/src/DiscoverSolutionProviders.php',
    'Spatie\\ErrorSolutions\\SolutionProviderRepository' => $vendorDir . '/spatie/error-solutions/src/SolutionProviderRepository.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\BadMethodCallSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/BadMethodCallSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\DefaultDbNameSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/DefaultDbNameSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\GenericLaravelExceptionSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/GenericLaravelExceptionSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\IncorrectValetDbCredentialsSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/IncorrectValetDbCredentialsSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\InvalidRouteActionSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/InvalidRouteActionSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\LazyLoadingViolationSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/LazyLoadingViolationSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingAppKeySolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingAppKeySolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingColumnSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingColumnSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingImportSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingImportSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingLivewireComponentSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingLivewireComponentSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingMixManifestSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingMixManifestSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\MissingViteManifestSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/MissingViteManifestSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\OpenAiSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/OpenAiSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\RouteNotDefinedSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/RouteNotDefinedSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\RunningLaravelDuskInProductionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/RunningLaravelDuskInProductionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\SailNetworkSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/SailNetworkSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\TableNotFoundSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/TableNotFoundSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UndefinedLivewireMethodSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UndefinedLivewireMethodSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UndefinedLivewirePropertySolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UndefinedLivewirePropertySolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UndefinedViewVariableSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UndefinedViewVariableSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UnknownMariadbCollationSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UnknownMariadbCollationSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UnknownMysql8CollationSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UnknownMysql8CollationSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\UnknownValidationSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/UnknownValidationSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\Laravel\\ViewNotFoundSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/Laravel/ViewNotFoundSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\MergeConflictSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/MergeConflictSolutionProvider.php',
    'Spatie\\ErrorSolutions\\SolutionProviders\\UndefinedPropertySolutionProvider' => $vendorDir . '/spatie/error-solutions/src/SolutionProviders/UndefinedPropertySolutionProvider.php',
    'Spatie\\ErrorSolutions\\Solutions\\Concerns\\IsProvidedByFlare' => $vendorDir . '/spatie/error-solutions/src/Solutions/Concerns/IsProvidedByFlare.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\GenerateAppKeySolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/GenerateAppKeySolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\LivewireDiscoverSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/LivewireDiscoverSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\MakeViewVariableOptionalSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/MakeViewVariableOptionalSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\RunMigrationsSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/RunMigrationsSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\SuggestLivewireMethodNameSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/SuggestLivewireMethodNameSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\SuggestLivewirePropertyNameSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/SuggestLivewirePropertyNameSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\SuggestUsingCorrectDbNameSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/SuggestUsingCorrectDbNameSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\SuggestUsingMariadbDatabaseSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/SuggestUsingMariadbDatabaseSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\SuggestUsingMysql8DatabaseSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/SuggestUsingMysql8DatabaseSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\Laravel\\UseDefaultValetDbCredentialsSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/Laravel/UseDefaultValetDbCredentialsSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\OpenAi\\DummyCache' => $vendorDir . '/spatie/error-solutions/src/Solutions/OpenAi/DummyCache.php',
    'Spatie\\ErrorSolutions\\Solutions\\OpenAi\\OpenAiPromptViewModel' => $vendorDir . '/spatie/error-solutions/src/Solutions/OpenAi/OpenAiPromptViewModel.php',
    'Spatie\\ErrorSolutions\\Solutions\\OpenAi\\OpenAiSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/OpenAi/OpenAiSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\OpenAi\\OpenAiSolutionProvider' => $vendorDir . '/spatie/error-solutions/src/Solutions/OpenAi/OpenAiSolutionProvider.php',
    'Spatie\\ErrorSolutions\\Solutions\\OpenAi\\OpenAiSolutionResponse' => $vendorDir . '/spatie/error-solutions/src/Solutions/OpenAi/OpenAiSolutionResponse.php',
    'Spatie\\ErrorSolutions\\Solutions\\SolutionTransformer' => $vendorDir . '/spatie/error-solutions/src/Solutions/SolutionTransformer.php',
    'Spatie\\ErrorSolutions\\Solutions\\SuggestCorrectVariableNameSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/SuggestCorrectVariableNameSolution.php',
    'Spatie\\ErrorSolutions\\Solutions\\SuggestImportSolution' => $vendorDir . '/spatie/error-solutions/src/Solutions/SuggestImportSolution.php',
    'Spatie\\ErrorSolutions\\Support\\AiPromptRenderer' => $vendorDir . '/spatie/error-solutions/src/Support/AiPromptRenderer.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\Composer\\Composer' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/Composer/Composer.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\Composer\\ComposerClassMap' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/Composer/ComposerClassMap.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\Composer\\FakeComposer' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/Composer/FakeComposer.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\LaravelVersion' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/LaravelVersion.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\LivewireComponentParser' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/LivewireComponentParser.php',
    'Spatie\\ErrorSolutions\\Support\\Laravel\\StringComparator' => $vendorDir . '/spatie/error-solutions/src/Support/Laravel/StringComparator.php',
    'Spatie\\FlareClient\\Api' => $vendorDir . '/spatie/flare-client-php/src/Api.php',
    'Spatie\\FlareClient\\Concerns\\HasContext' => $vendorDir . '/spatie/flare-client-php/src/Concerns/HasContext.php',
    'Spatie\\FlareClient\\Concerns\\UsesTime' => $vendorDir . '/spatie/flare-client-php/src/Concerns/UsesTime.php',
    'Spatie\\FlareClient\\Context\\BaseContextProviderDetector' => $vendorDir . '/spatie/flare-client-php/src/Context/BaseContextProviderDetector.php',
    'Spatie\\FlareClient\\Context\\ConsoleContextProvider' => $vendorDir . '/spatie/flare-client-php/src/Context/ConsoleContextProvider.php',
    'Spatie\\FlareClient\\Context\\ContextProvider' => $vendorDir . '/spatie/flare-client-php/src/Context/ContextProvider.php',
    'Spatie\\FlareClient\\Context\\ContextProviderDetector' => $vendorDir . '/spatie/flare-client-php/src/Context/ContextProviderDetector.php',
    'Spatie\\FlareClient\\Context\\RequestContextProvider' => $vendorDir . '/spatie/flare-client-php/src/Context/RequestContextProvider.php',
    'Spatie\\FlareClient\\Contracts\\ProvidesFlareContext' => $vendorDir . '/spatie/flare-client-php/src/Contracts/ProvidesFlareContext.php',
    'Spatie\\FlareClient\\Enums\\MessageLevels' => $vendorDir . '/spatie/flare-client-php/src/Enums/MessageLevels.php',
    'Spatie\\FlareClient\\Flare' => $vendorDir . '/spatie/flare-client-php/src/Flare.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddDocumentationLinks' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddDocumentationLinks.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddEnvironmentInformation' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddEnvironmentInformation.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddGitInformation' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddGitInformation.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddGlows' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddGlows.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddNotifierName' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddNotifierName.php',
    'Spatie\\FlareClient\\FlareMiddleware\\AddSolutions' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/AddSolutions.php',
    'Spatie\\FlareClient\\FlareMiddleware\\CensorRequestBodyFields' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/CensorRequestBodyFields.php',
    'Spatie\\FlareClient\\FlareMiddleware\\CensorRequestHeaders' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/CensorRequestHeaders.php',
    'Spatie\\FlareClient\\FlareMiddleware\\FlareMiddleware' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/FlareMiddleware.php',
    'Spatie\\FlareClient\\FlareMiddleware\\RemoveRequestIp' => $vendorDir . '/spatie/flare-client-php/src/FlareMiddleware/RemoveRequestIp.php',
    'Spatie\\FlareClient\\Frame' => $vendorDir . '/spatie/flare-client-php/src/Frame.php',
    'Spatie\\FlareClient\\Glows\\Glow' => $vendorDir . '/spatie/flare-client-php/src/Glows/Glow.php',
    'Spatie\\FlareClient\\Glows\\GlowRecorder' => $vendorDir . '/spatie/flare-client-php/src/Glows/GlowRecorder.php',
    'Spatie\\FlareClient\\Http\\Client' => $vendorDir . '/spatie/flare-client-php/src/Http/Client.php',
    'Spatie\\FlareClient\\Http\\Exceptions\\BadResponse' => $vendorDir . '/spatie/flare-client-php/src/Http/Exceptions/BadResponse.php',
    'Spatie\\FlareClient\\Http\\Exceptions\\BadResponseCode' => $vendorDir . '/spatie/flare-client-php/src/Http/Exceptions/BadResponseCode.php',
    'Spatie\\FlareClient\\Http\\Exceptions\\InvalidData' => $vendorDir . '/spatie/flare-client-php/src/Http/Exceptions/InvalidData.php',
    'Spatie\\FlareClient\\Http\\Exceptions\\MissingParameter' => $vendorDir . '/spatie/flare-client-php/src/Http/Exceptions/MissingParameter.php',
    'Spatie\\FlareClient\\Http\\Exceptions\\NotFound' => $vendorDir . '/spatie/flare-client-php/src/Http/Exceptions/NotFound.php',
    'Spatie\\FlareClient\\Http\\Response' => $vendorDir . '/spatie/flare-client-php/src/Http/Response.php',
    'Spatie\\FlareClient\\Report' => $vendorDir . '/spatie/flare-client-php/src/Report.php',
    'Spatie\\FlareClient\\Solutions\\ReportSolution' => $vendorDir . '/spatie/flare-client-php/src/Solutions/ReportSolution.php',
    'Spatie\\FlareClient\\Support\\PhpStackFrameArgumentsFixer' => $vendorDir . '/spatie/flare-client-php/src/Support/PhpStackFrameArgumentsFixer.php',
    'Spatie\\FlareClient\\Time\\SystemTime' => $vendorDir . '/spatie/flare-client-php/src/Time/SystemTime.php',
    'Spatie\\FlareClient\\Time\\Time' => $vendorDir . '/spatie/flare-client-php/src/Time/Time.php',
    'Spatie\\FlareClient\\Truncation\\AbstractTruncationStrategy' => $vendorDir . '/spatie/flare-client-php/src/Truncation/AbstractTruncationStrategy.php',
    'Spatie\\FlareClient\\Truncation\\ReportTrimmer' => $vendorDir . '/spatie/flare-client-php/src/Truncation/ReportTrimmer.php',
    'Spatie\\FlareClient\\Truncation\\TrimContextItemsStrategy' => $vendorDir . '/spatie/flare-client-php/src/Truncation/TrimContextItemsStrategy.php',
    'Spatie\\FlareClient\\Truncation\\TrimStackFrameArgumentsStrategy' => $vendorDir . '/spatie/flare-client-php/src/Truncation/TrimStackFrameArgumentsStrategy.php',
    'Spatie\\FlareClient\\Truncation\\TrimStringsStrategy' => $vendorDir . '/spatie/flare-client-php/src/Truncation/TrimStringsStrategy.php',
    'Spatie\\FlareClient\\Truncation\\TruncationStrategy' => $vendorDir . '/spatie/flare-client-php/src/Truncation/TruncationStrategy.php',
    'Spatie\\FlareClient\\View' => $vendorDir . '/spatie/flare-client-php/src/View.php',
    'Spatie\\GoogleCalendar\\Event' => $vendorDir . '/spatie/laravel-google-calendar/src/Event.php',
    'Spatie\\GoogleCalendar\\Exceptions\\InvalidConfiguration' => $vendorDir . '/spatie/laravel-google-calendar/src/Exceptions/InvalidConfiguration.php',
    'Spatie\\GoogleCalendar\\GoogleCalendar' => $vendorDir . '/spatie/laravel-google-calendar/src/GoogleCalendar.php',
    'Spatie\\GoogleCalendar\\GoogleCalendarFacade' => $vendorDir . '/spatie/laravel-google-calendar/src/GoogleCalendarFacade.php',
    'Spatie\\GoogleCalendar\\GoogleCalendarFactory' => $vendorDir . '/spatie/laravel-google-calendar/src/GoogleCalendarFactory.php',
    'Spatie\\GoogleCalendar\\GoogleCalendarServiceProvider' => $vendorDir . '/spatie/laravel-google-calendar/src/GoogleCalendarServiceProvider.php',
    'Spatie\\Ignition\\Config\\FileConfigManager' => $vendorDir . '/spatie/ignition/src/Config/FileConfigManager.php',
    'Spatie\\Ignition\\Config\\IgnitionConfig' => $vendorDir . '/spatie/ignition/src/Config/IgnitionConfig.php',
    'Spatie\\Ignition\\Contracts\\BaseSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/BaseSolution.php',
    'Spatie\\Ignition\\Contracts\\ConfigManager' => $vendorDir . '/spatie/ignition/src/Contracts/ConfigManager.php',
    'Spatie\\Ignition\\Contracts\\HasSolutionsForThrowable' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/HasSolutionsForThrowable.php',
    'Spatie\\Ignition\\Contracts\\ProvidesSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/ProvidesSolution.php',
    'Spatie\\Ignition\\Contracts\\RunnableSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/RunnableSolution.php',
    'Spatie\\Ignition\\Contracts\\Solution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/Solution.php',
    'Spatie\\Ignition\\Contracts\\SolutionProviderRepository' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Contracts/SolutionProviderRepository.php',
    'Spatie\\Ignition\\ErrorPage\\ErrorPageViewModel' => $vendorDir . '/spatie/ignition/src/ErrorPage/ErrorPageViewModel.php',
    'Spatie\\Ignition\\ErrorPage\\Renderer' => $vendorDir . '/spatie/ignition/src/ErrorPage/Renderer.php',
    'Spatie\\Ignition\\Ignition' => $vendorDir . '/spatie/ignition/src/Ignition.php',
    'Spatie\\Ignition\\Solutions\\OpenAi\\DummyCache' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/OpenAi/DummyCache.php',
    'Spatie\\Ignition\\Solutions\\OpenAi\\OpenAiPromptViewModel' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/OpenAi/OpenAiPromptViewModel.php',
    'Spatie\\Ignition\\Solutions\\OpenAi\\OpenAiSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/OpenAi/OpenAiSolution.php',
    'Spatie\\Ignition\\Solutions\\OpenAi\\OpenAiSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/OpenAi/OpenAiSolutionProvider.php',
    'Spatie\\Ignition\\Solutions\\OpenAi\\OpenAiSolutionResponse' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/OpenAi/OpenAiSolutionResponse.php',
    'Spatie\\Ignition\\Solutions\\SolutionProviders\\BadMethodCallSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SolutionProviders/BadMethodCallSolutionProvider.php',
    'Spatie\\Ignition\\Solutions\\SolutionProviders\\MergeConflictSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SolutionProviders/MergeConflictSolutionProvider.php',
    'Spatie\\Ignition\\Solutions\\SolutionProviders\\SolutionProviderRepository' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SolutionProviders/SolutionProviderRepository.php',
    'Spatie\\Ignition\\Solutions\\SolutionProviders\\UndefinedPropertySolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SolutionProviders/UndefinedPropertySolutionProvider.php',
    'Spatie\\Ignition\\Solutions\\SolutionTransformer' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SolutionTransformer.php',
    'Spatie\\Ignition\\Solutions\\SuggestCorrectVariableNameSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SuggestCorrectVariableNameSolution.php',
    'Spatie\\Ignition\\Solutions\\SuggestImportSolution' => $vendorDir . '/spatie/error-solutions/legacy/ignition/Solutions/SuggestImportSolution.php',
    'Spatie\\LaravelIgnition\\ArgumentReducers\\CollectionArgumentReducer' => $vendorDir . '/spatie/laravel-ignition/src/ArgumentReducers/CollectionArgumentReducer.php',
    'Spatie\\LaravelIgnition\\ArgumentReducers\\ModelArgumentReducer' => $vendorDir . '/spatie/laravel-ignition/src/ArgumentReducers/ModelArgumentReducer.php',
    'Spatie\\LaravelIgnition\\Commands\\SolutionMakeCommand' => $vendorDir . '/spatie/laravel-ignition/src/Commands/SolutionMakeCommand.php',
    'Spatie\\LaravelIgnition\\Commands\\SolutionProviderMakeCommand' => $vendorDir . '/spatie/laravel-ignition/src/Commands/SolutionProviderMakeCommand.php',
    'Spatie\\LaravelIgnition\\Commands\\TestCommand' => $vendorDir . '/spatie/laravel-ignition/src/Commands/TestCommand.php',
    'Spatie\\LaravelIgnition\\ContextProviders\\LaravelConsoleContextProvider' => $vendorDir . '/spatie/laravel-ignition/src/ContextProviders/LaravelConsoleContextProvider.php',
    'Spatie\\LaravelIgnition\\ContextProviders\\LaravelContextProviderDetector' => $vendorDir . '/spatie/laravel-ignition/src/ContextProviders/LaravelContextProviderDetector.php',
    'Spatie\\LaravelIgnition\\ContextProviders\\LaravelLivewireRequestContextProvider' => $vendorDir . '/spatie/laravel-ignition/src/ContextProviders/LaravelLivewireRequestContextProvider.php',
    'Spatie\\LaravelIgnition\\ContextProviders\\LaravelRequestContextProvider' => $vendorDir . '/spatie/laravel-ignition/src/ContextProviders/LaravelRequestContextProvider.php',
    'Spatie\\LaravelIgnition\\Exceptions\\CannotExecuteSolutionForNonLocalIp' => $vendorDir . '/spatie/laravel-ignition/src/Exceptions/CannotExecuteSolutionForNonLocalIp.php',
    'Spatie\\LaravelIgnition\\Exceptions\\InvalidConfig' => $vendorDir . '/spatie/laravel-ignition/src/Exceptions/InvalidConfig.php',
    'Spatie\\LaravelIgnition\\Exceptions\\ViewException' => $vendorDir . '/spatie/laravel-ignition/src/Exceptions/ViewException.php',
    'Spatie\\LaravelIgnition\\Exceptions\\ViewExceptionWithSolution' => $vendorDir . '/spatie/laravel-ignition/src/Exceptions/ViewExceptionWithSolution.php',
    'Spatie\\LaravelIgnition\\Facades\\Flare' => $vendorDir . '/spatie/laravel-ignition/src/Facades/Flare.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddContext' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddContext.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddDumps' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddDumps.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddEnvironmentInformation' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddEnvironmentInformation.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddExceptionHandledStatus' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddExceptionHandledStatus.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddExceptionInformation' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddExceptionInformation.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddJobs' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddJobs.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddLogs' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddLogs.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddNotifierName' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddNotifierName.php',
    'Spatie\\LaravelIgnition\\FlareMiddleware\\AddQueries' => $vendorDir . '/spatie/laravel-ignition/src/FlareMiddleware/AddQueries.php',
    'Spatie\\LaravelIgnition\\Http\\Controllers\\ExecuteSolutionController' => $vendorDir . '/spatie/laravel-ignition/src/Http/Controllers/ExecuteSolutionController.php',
    'Spatie\\LaravelIgnition\\Http\\Controllers\\HealthCheckController' => $vendorDir . '/spatie/laravel-ignition/src/Http/Controllers/HealthCheckController.php',
    'Spatie\\LaravelIgnition\\Http\\Controllers\\UpdateConfigController' => $vendorDir . '/spatie/laravel-ignition/src/Http/Controllers/UpdateConfigController.php',
    'Spatie\\LaravelIgnition\\Http\\Middleware\\RunnableSolutionsEnabled' => $vendorDir . '/spatie/laravel-ignition/src/Http/Middleware/RunnableSolutionsEnabled.php',
    'Spatie\\LaravelIgnition\\Http\\Requests\\ExecuteSolutionRequest' => $vendorDir . '/spatie/laravel-ignition/src/Http/Requests/ExecuteSolutionRequest.php',
    'Spatie\\LaravelIgnition\\Http\\Requests\\UpdateConfigRequest' => $vendorDir . '/spatie/laravel-ignition/src/Http/Requests/UpdateConfigRequest.php',
    'Spatie\\LaravelIgnition\\IgnitionServiceProvider' => $vendorDir . '/spatie/laravel-ignition/src/IgnitionServiceProvider.php',
    'Spatie\\LaravelIgnition\\Recorders\\DumpRecorder\\Dump' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/DumpRecorder/Dump.php',
    'Spatie\\LaravelIgnition\\Recorders\\DumpRecorder\\DumpHandler' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/DumpRecorder/DumpHandler.php',
    'Spatie\\LaravelIgnition\\Recorders\\DumpRecorder\\DumpRecorder' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/DumpRecorder/DumpRecorder.php',
    'Spatie\\LaravelIgnition\\Recorders\\DumpRecorder\\HtmlDumper' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/DumpRecorder/HtmlDumper.php',
    'Spatie\\LaravelIgnition\\Recorders\\DumpRecorder\\MultiDumpHandler' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/DumpRecorder/MultiDumpHandler.php',
    'Spatie\\LaravelIgnition\\Recorders\\JobRecorder\\JobRecorder' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/JobRecorder/JobRecorder.php',
    'Spatie\\LaravelIgnition\\Recorders\\LogRecorder\\LogMessage' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/LogRecorder/LogMessage.php',
    'Spatie\\LaravelIgnition\\Recorders\\LogRecorder\\LogRecorder' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/LogRecorder/LogRecorder.php',
    'Spatie\\LaravelIgnition\\Recorders\\QueryRecorder\\Query' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/QueryRecorder/Query.php',
    'Spatie\\LaravelIgnition\\Recorders\\QueryRecorder\\QueryRecorder' => $vendorDir . '/spatie/laravel-ignition/src/Recorders/QueryRecorder/QueryRecorder.php',
    'Spatie\\LaravelIgnition\\Renderers\\ErrorPageRenderer' => $vendorDir . '/spatie/laravel-ignition/src/Renderers/ErrorPageRenderer.php',
    'Spatie\\LaravelIgnition\\Renderers\\IgnitionExceptionRenderer' => $vendorDir . '/spatie/laravel-ignition/src/Renderers/IgnitionExceptionRenderer.php',
    'Spatie\\LaravelIgnition\\Solutions\\GenerateAppKeySolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/GenerateAppKeySolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\LivewireDiscoverSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/LivewireDiscoverSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\MakeViewVariableOptionalSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/MakeViewVariableOptionalSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\RunMigrationsSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/RunMigrationsSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\DefaultDbNameSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/DefaultDbNameSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\GenericLaravelExceptionSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/GenericLaravelExceptionSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\IncorrectValetDbCredentialsSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/IncorrectValetDbCredentialsSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\InvalidRouteActionSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/InvalidRouteActionSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\LazyLoadingViolationSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/LazyLoadingViolationSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingAppKeySolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingAppKeySolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingColumnSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingColumnSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingImportSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingImportSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingLivewireComponentSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingLivewireComponentSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingMixManifestSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingMixManifestSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\MissingViteManifestSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/MissingViteManifestSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\OpenAiSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/OpenAiSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\RouteNotDefinedSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/RouteNotDefinedSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\RunningLaravelDuskInProductionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/RunningLaravelDuskInProductionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\SailNetworkSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/SailNetworkSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\SolutionProviderRepository' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/SolutionProviderRepository.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\TableNotFoundSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/TableNotFoundSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UndefinedLivewireMethodSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UndefinedLivewireMethodSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UndefinedLivewirePropertySolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UndefinedLivewirePropertySolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UndefinedViewVariableSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UndefinedViewVariableSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UnknownMariadbCollationSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UnknownMariadbCollationSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UnknownMysql8CollationSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UnknownMysql8CollationSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\UnknownValidationSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/UnknownValidationSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionProviders\\ViewNotFoundSolutionProvider' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SolutionProviders/ViewNotFoundSolutionProvider.php',
    'Spatie\\LaravelIgnition\\Solutions\\SolutionTransformers\\LaravelSolutionTransformer' => $vendorDir . '/spatie/laravel-ignition/src/Solutions/SolutionTransformers/LaravelSolutionTransformer.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestCorrectVariableNameSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestCorrectVariableNameSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestImportSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestImportSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestLivewireMethodNameSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestLivewireMethodNameSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestLivewirePropertyNameSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestLivewirePropertyNameSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestUsingCorrectDbNameSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestUsingCorrectDbNameSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestUsingMariadbDatabaseSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestUsingMariadbDatabaseSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\SuggestUsingMysql8DatabaseSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/SuggestUsingMysql8DatabaseSolution.php',
    'Spatie\\LaravelIgnition\\Solutions\\UseDefaultValetDbCredentialsSolution' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Solutions/UseDefaultValetDbCredentialsSolution.php',
    'Spatie\\LaravelIgnition\\Support\\FlareLogHandler' => $vendorDir . '/spatie/laravel-ignition/src/Support/FlareLogHandler.php',
    'Spatie\\LaravelIgnition\\Support\\LaravelDocumentationLinkFinder' => $vendorDir . '/spatie/laravel-ignition/src/Support/LaravelDocumentationLinkFinder.php',
    'Spatie\\LaravelIgnition\\Support\\LaravelVersion' => $vendorDir . '/spatie/laravel-ignition/src/Support/LaravelVersion.php',
    'Spatie\\LaravelIgnition\\Support\\RunnableSolutionsGuard' => $vendorDir . '/spatie/laravel-ignition/src/Support/RunnableSolutionsGuard.php',
    'Spatie\\LaravelIgnition\\Support\\SentReports' => $vendorDir . '/spatie/laravel-ignition/src/Support/SentReports.php',
    'Spatie\\LaravelIgnition\\Support\\StringComparator' => $vendorDir . '/spatie/error-solutions/legacy/laravel-ignition/Support/StringComparator.php',
    'Spatie\\LaravelIgnition\\Views\\BladeSourceMapCompiler' => $vendorDir . '/spatie/laravel-ignition/src/Views/BladeSourceMapCompiler.php',
    'Spatie\\LaravelIgnition\\Views\\ViewExceptionMapper' => $vendorDir . '/spatie/laravel-ignition/src/Views/ViewExceptionMapper.php',
    'Spatie\\LaravelPackageTools\\Commands\\InstallCommand' => $vendorDir . '/spatie/laravel-package-tools/src/Commands/InstallCommand.php',
    'Spatie\\LaravelPackageTools\\Exceptions\\InvalidPackage' => $vendorDir . '/spatie/laravel-package-tools/src/Exceptions/InvalidPackage.php',
    'Spatie\\LaravelPackageTools\\Package' => $vendorDir . '/spatie/laravel-package-tools/src/Package.php',
    'Spatie\\LaravelPackageTools\\PackageServiceProvider' => $vendorDir . '/spatie/laravel-package-tools/src/PackageServiceProvider.php',
    'Spatie\\Permission\\Commands\\CacheReset' => $vendorDir . '/spatie/laravel-permission/src/Commands/CacheReset.php',
    'Spatie\\Permission\\Commands\\CreatePermission' => $vendorDir . '/spatie/laravel-permission/src/Commands/CreatePermission.php',
    'Spatie\\Permission\\Commands\\CreateRole' => $vendorDir . '/spatie/laravel-permission/src/Commands/CreateRole.php',
    'Spatie\\Permission\\Commands\\Show' => $vendorDir . '/spatie/laravel-permission/src/Commands/Show.php',
    'Spatie\\Permission\\Commands\\UpgradeForTeams' => $vendorDir . '/spatie/laravel-permission/src/Commands/UpgradeForTeams.php',
    'Spatie\\Permission\\Contracts\\Permission' => $vendorDir . '/spatie/laravel-permission/src/Contracts/Permission.php',
    'Spatie\\Permission\\Contracts\\Role' => $vendorDir . '/spatie/laravel-permission/src/Contracts/Role.php',
    'Spatie\\Permission\\Contracts\\Wildcard' => $vendorDir . '/spatie/laravel-permission/src/Contracts/Wildcard.php',
    'Spatie\\Permission\\Exceptions\\GuardDoesNotMatch' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/GuardDoesNotMatch.php',
    'Spatie\\Permission\\Exceptions\\PermissionAlreadyExists' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/PermissionAlreadyExists.php',
    'Spatie\\Permission\\Exceptions\\PermissionDoesNotExist' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/PermissionDoesNotExist.php',
    'Spatie\\Permission\\Exceptions\\RoleAlreadyExists' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/RoleAlreadyExists.php',
    'Spatie\\Permission\\Exceptions\\RoleDoesNotExist' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/RoleDoesNotExist.php',
    'Spatie\\Permission\\Exceptions\\UnauthorizedException' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/UnauthorizedException.php',
    'Spatie\\Permission\\Exceptions\\WildcardPermissionInvalidArgument' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/WildcardPermissionInvalidArgument.php',
    'Spatie\\Permission\\Exceptions\\WildcardPermissionNotImplementsContract' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/WildcardPermissionNotImplementsContract.php',
    'Spatie\\Permission\\Exceptions\\WildcardPermissionNotProperlyFormatted' => $vendorDir . '/spatie/laravel-permission/src/Exceptions/WildcardPermissionNotProperlyFormatted.php',
    'Spatie\\Permission\\Guard' => $vendorDir . '/spatie/laravel-permission/src/Guard.php',
    'Spatie\\Permission\\Middleware\\PermissionMiddleware' => $vendorDir . '/spatie/laravel-permission/src/Middleware/PermissionMiddleware.php',
    'Spatie\\Permission\\Middleware\\RoleMiddleware' => $vendorDir . '/spatie/laravel-permission/src/Middleware/RoleMiddleware.php',
    'Spatie\\Permission\\Middleware\\RoleOrPermissionMiddleware' => $vendorDir . '/spatie/laravel-permission/src/Middleware/RoleOrPermissionMiddleware.php',
    'Spatie\\Permission\\Models\\Permission' => $vendorDir . '/spatie/laravel-permission/src/Models/Permission.php',
    'Spatie\\Permission\\Models\\Role' => $vendorDir . '/spatie/laravel-permission/src/Models/Role.php',
    'Spatie\\Permission\\PermissionRegistrar' => $vendorDir . '/spatie/laravel-permission/src/PermissionRegistrar.php',
    'Spatie\\Permission\\PermissionServiceProvider' => $vendorDir . '/spatie/laravel-permission/src/PermissionServiceProvider.php',
    'Spatie\\Permission\\Traits\\HasPermissions' => $vendorDir . '/spatie/laravel-permission/src/Traits/HasPermissions.php',
    'Spatie\\Permission\\Traits\\HasRoles' => $vendorDir . '/spatie/laravel-permission/src/Traits/HasRoles.php',
    'Spatie\\Permission\\Traits\\RefreshesPermissionCache' => $vendorDir . '/spatie/laravel-permission/src/Traits/RefreshesPermissionCache.php',
    'Spatie\\Permission\\WildcardPermission' => $vendorDir . '/spatie/laravel-permission/src/WildcardPermission.php',
    'Srmklive\\PayPal\\Facades\\PayPal' => $vendorDir . '/srmklive/paypal/src/Facades/PayPal.php',
    'Srmklive\\PayPal\\PayPalFacadeAccessor' => $vendorDir . '/srmklive/paypal/src/PayPalFacadeAccessor.php',
    'Srmklive\\PayPal\\Providers\\PayPalServiceProvider' => $vendorDir . '/srmklive/paypal/src/Providers/PayPalServiceProvider.php',
    'Srmklive\\PayPal\\Services\\PayPal' => $vendorDir . '/srmklive/paypal/src/Services/PayPal.php',
    'Srmklive\\PayPal\\Services\\Str' => $vendorDir . '/srmklive/paypal/src/Services/Str.php',
    'Srmklive\\PayPal\\Services\\VerifyDocuments' => $vendorDir . '/srmklive/paypal/src/Services/VerifyDocuments.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\BillingPlans' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/BillingPlans.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\BillingPlans\\PricingSchemes' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/BillingPlans/PricingSchemes.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\CatalogProducts' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/CatalogProducts.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Disputes' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Disputes.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\DisputesActions' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/DisputesActions.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Identity' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Identity.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\InvoiceSearch\\Filters' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/InvoiceSearch/Filters.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Invoices' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Invoices.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\InvoicesSearch' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/InvoicesSearch.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\InvoicesTemplates' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/InvoicesTemplates.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Orders' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Orders.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Orders\\Helpers' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Orders/Helpers.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PartnerReferrals' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PartnerReferrals.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentAuthorizations' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentAuthorizations.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentCaptures' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentCaptures.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentExperienceWebProfiles' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentExperienceWebProfiles.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentMethodsTokens' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentMethodsTokens.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentMethodsTokens\\Helpers' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentMethodsTokens/Helpers.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\PaymentRefunds' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/PaymentRefunds.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Payouts' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Payouts.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\ReferencedPayouts' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/ReferencedPayouts.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Reporting' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Reporting.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Subscriptions' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Subscriptions.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Subscriptions\\Helpers' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Subscriptions/Helpers.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\Trackers' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/Trackers.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\WebHooks' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/WebHooks.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\WebHooksEvents' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/WebHooksEvents.php',
    'Srmklive\\PayPal\\Traits\\PayPalAPI\\WebHooksVerification' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalAPI/WebHooksVerification.php',
    'Srmklive\\PayPal\\Traits\\PayPalExperienceContext' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalExperienceContext.php',
    'Srmklive\\PayPal\\Traits\\PayPalHttpClient' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalHttpClient.php',
    'Srmklive\\PayPal\\Traits\\PayPalRequest' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalRequest.php',
    'Srmklive\\PayPal\\Traits\\PayPalVerifyIPN' => $vendorDir . '/srmklive/paypal/src/Traits/PayPalVerifyIPN.php',
    'Stringable' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/Stringable.php',
    'Stripe\\Account' => $vendorDir . '/stripe/stripe-php/lib/Account.php',
    'Stripe\\AccountLink' => $vendorDir . '/stripe/stripe-php/lib/AccountLink.php',
    'Stripe\\AccountSession' => $vendorDir . '/stripe/stripe-php/lib/AccountSession.php',
    'Stripe\\ApiOperations\\All' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/All.php',
    'Stripe\\ApiOperations\\Create' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Create.php',
    'Stripe\\ApiOperations\\Delete' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Delete.php',
    'Stripe\\ApiOperations\\NestedResource' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/NestedResource.php',
    'Stripe\\ApiOperations\\Request' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Request.php',
    'Stripe\\ApiOperations\\Retrieve' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Retrieve.php',
    'Stripe\\ApiOperations\\Search' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Search.php',
    'Stripe\\ApiOperations\\SingletonRetrieve' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/SingletonRetrieve.php',
    'Stripe\\ApiOperations\\Update' => $vendorDir . '/stripe/stripe-php/lib/ApiOperations/Update.php',
    'Stripe\\ApiRequestor' => $vendorDir . '/stripe/stripe-php/lib/ApiRequestor.php',
    'Stripe\\ApiResource' => $vendorDir . '/stripe/stripe-php/lib/ApiResource.php',
    'Stripe\\ApiResponse' => $vendorDir . '/stripe/stripe-php/lib/ApiResponse.php',
    'Stripe\\ApplePayDomain' => $vendorDir . '/stripe/stripe-php/lib/ApplePayDomain.php',
    'Stripe\\Application' => $vendorDir . '/stripe/stripe-php/lib/Application.php',
    'Stripe\\ApplicationFee' => $vendorDir . '/stripe/stripe-php/lib/ApplicationFee.php',
    'Stripe\\ApplicationFeeRefund' => $vendorDir . '/stripe/stripe-php/lib/ApplicationFeeRefund.php',
    'Stripe\\Apps\\Secret' => $vendorDir . '/stripe/stripe-php/lib/Apps/Secret.php',
    'Stripe\\Balance' => $vendorDir . '/stripe/stripe-php/lib/Balance.php',
    'Stripe\\BalanceTransaction' => $vendorDir . '/stripe/stripe-php/lib/BalanceTransaction.php',
    'Stripe\\BankAccount' => $vendorDir . '/stripe/stripe-php/lib/BankAccount.php',
    'Stripe\\BaseStripeClient' => $vendorDir . '/stripe/stripe-php/lib/BaseStripeClient.php',
    'Stripe\\BaseStripeClientInterface' => $vendorDir . '/stripe/stripe-php/lib/BaseStripeClientInterface.php',
    'Stripe\\BillingPortal\\Configuration' => $vendorDir . '/stripe/stripe-php/lib/BillingPortal/Configuration.php',
    'Stripe\\BillingPortal\\Session' => $vendorDir . '/stripe/stripe-php/lib/BillingPortal/Session.php',
    'Stripe\\Billing\\Alert' => $vendorDir . '/stripe/stripe-php/lib/Billing/Alert.php',
    'Stripe\\Billing\\AlertTriggered' => $vendorDir . '/stripe/stripe-php/lib/Billing/AlertTriggered.php',
    'Stripe\\Billing\\Meter' => $vendorDir . '/stripe/stripe-php/lib/Billing/Meter.php',
    'Stripe\\Billing\\MeterEvent' => $vendorDir . '/stripe/stripe-php/lib/Billing/MeterEvent.php',
    'Stripe\\Billing\\MeterEventAdjustment' => $vendorDir . '/stripe/stripe-php/lib/Billing/MeterEventAdjustment.php',
    'Stripe\\Billing\\MeterEventSummary' => $vendorDir . '/stripe/stripe-php/lib/Billing/MeterEventSummary.php',
    'Stripe\\Capability' => $vendorDir . '/stripe/stripe-php/lib/Capability.php',
    'Stripe\\Card' => $vendorDir . '/stripe/stripe-php/lib/Card.php',
    'Stripe\\CashBalance' => $vendorDir . '/stripe/stripe-php/lib/CashBalance.php',
    'Stripe\\Charge' => $vendorDir . '/stripe/stripe-php/lib/Charge.php',
    'Stripe\\Checkout\\Session' => $vendorDir . '/stripe/stripe-php/lib/Checkout/Session.php',
    'Stripe\\Climate\\Order' => $vendorDir . '/stripe/stripe-php/lib/Climate/Order.php',
    'Stripe\\Climate\\Product' => $vendorDir . '/stripe/stripe-php/lib/Climate/Product.php',
    'Stripe\\Climate\\Supplier' => $vendorDir . '/stripe/stripe-php/lib/Climate/Supplier.php',
    'Stripe\\Collection' => $vendorDir . '/stripe/stripe-php/lib/Collection.php',
    'Stripe\\ConfirmationToken' => $vendorDir . '/stripe/stripe-php/lib/ConfirmationToken.php',
    'Stripe\\ConnectCollectionTransfer' => $vendorDir . '/stripe/stripe-php/lib/ConnectCollectionTransfer.php',
    'Stripe\\CountrySpec' => $vendorDir . '/stripe/stripe-php/lib/CountrySpec.php',
    'Stripe\\Coupon' => $vendorDir . '/stripe/stripe-php/lib/Coupon.php',
    'Stripe\\CreditNote' => $vendorDir . '/stripe/stripe-php/lib/CreditNote.php',
    'Stripe\\CreditNoteLineItem' => $vendorDir . '/stripe/stripe-php/lib/CreditNoteLineItem.php',
    'Stripe\\Customer' => $vendorDir . '/stripe/stripe-php/lib/Customer.php',
    'Stripe\\CustomerBalanceTransaction' => $vendorDir . '/stripe/stripe-php/lib/CustomerBalanceTransaction.php',
    'Stripe\\CustomerCashBalanceTransaction' => $vendorDir . '/stripe/stripe-php/lib/CustomerCashBalanceTransaction.php',
    'Stripe\\CustomerSession' => $vendorDir . '/stripe/stripe-php/lib/CustomerSession.php',
    'Stripe\\Discount' => $vendorDir . '/stripe/stripe-php/lib/Discount.php',
    'Stripe\\Dispute' => $vendorDir . '/stripe/stripe-php/lib/Dispute.php',
    'Stripe\\Entitlements\\ActiveEntitlement' => $vendorDir . '/stripe/stripe-php/lib/Entitlements/ActiveEntitlement.php',
    'Stripe\\Entitlements\\ActiveEntitlementSummary' => $vendorDir . '/stripe/stripe-php/lib/Entitlements/ActiveEntitlementSummary.php',
    'Stripe\\Entitlements\\Feature' => $vendorDir . '/stripe/stripe-php/lib/Entitlements/Feature.php',
    'Stripe\\EphemeralKey' => $vendorDir . '/stripe/stripe-php/lib/EphemeralKey.php',
    'Stripe\\ErrorObject' => $vendorDir . '/stripe/stripe-php/lib/ErrorObject.php',
    'Stripe\\Event' => $vendorDir . '/stripe/stripe-php/lib/Event.php',
    'Stripe\\Exception\\ApiConnectionException' => $vendorDir . '/stripe/stripe-php/lib/Exception/ApiConnectionException.php',
    'Stripe\\Exception\\ApiErrorException' => $vendorDir . '/stripe/stripe-php/lib/Exception/ApiErrorException.php',
    'Stripe\\Exception\\AuthenticationException' => $vendorDir . '/stripe/stripe-php/lib/Exception/AuthenticationException.php',
    'Stripe\\Exception\\BadMethodCallException' => $vendorDir . '/stripe/stripe-php/lib/Exception/BadMethodCallException.php',
    'Stripe\\Exception\\CardException' => $vendorDir . '/stripe/stripe-php/lib/Exception/CardException.php',
    'Stripe\\Exception\\ExceptionInterface' => $vendorDir . '/stripe/stripe-php/lib/Exception/ExceptionInterface.php',
    'Stripe\\Exception\\IdempotencyException' => $vendorDir . '/stripe/stripe-php/lib/Exception/IdempotencyException.php',
    'Stripe\\Exception\\InvalidArgumentException' => $vendorDir . '/stripe/stripe-php/lib/Exception/InvalidArgumentException.php',
    'Stripe\\Exception\\InvalidRequestException' => $vendorDir . '/stripe/stripe-php/lib/Exception/InvalidRequestException.php',
    'Stripe\\Exception\\OAuth\\ExceptionInterface' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/ExceptionInterface.php',
    'Stripe\\Exception\\OAuth\\InvalidClientException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/InvalidClientException.php',
    'Stripe\\Exception\\OAuth\\InvalidGrantException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/InvalidGrantException.php',
    'Stripe\\Exception\\OAuth\\InvalidRequestException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/InvalidRequestException.php',
    'Stripe\\Exception\\OAuth\\InvalidScopeException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/InvalidScopeException.php',
    'Stripe\\Exception\\OAuth\\OAuthErrorException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/OAuthErrorException.php',
    'Stripe\\Exception\\OAuth\\UnknownOAuthErrorException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/UnknownOAuthErrorException.php',
    'Stripe\\Exception\\OAuth\\UnsupportedGrantTypeException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/UnsupportedGrantTypeException.php',
    'Stripe\\Exception\\OAuth\\UnsupportedResponseTypeException' => $vendorDir . '/stripe/stripe-php/lib/Exception/OAuth/UnsupportedResponseTypeException.php',
    'Stripe\\Exception\\PermissionException' => $vendorDir . '/stripe/stripe-php/lib/Exception/PermissionException.php',
    'Stripe\\Exception\\RateLimitException' => $vendorDir . '/stripe/stripe-php/lib/Exception/RateLimitException.php',
    'Stripe\\Exception\\SignatureVerificationException' => $vendorDir . '/stripe/stripe-php/lib/Exception/SignatureVerificationException.php',
    'Stripe\\Exception\\UnexpectedValueException' => $vendorDir . '/stripe/stripe-php/lib/Exception/UnexpectedValueException.php',
    'Stripe\\Exception\\UnknownApiErrorException' => $vendorDir . '/stripe/stripe-php/lib/Exception/UnknownApiErrorException.php',
    'Stripe\\ExchangeRate' => $vendorDir . '/stripe/stripe-php/lib/ExchangeRate.php',
    'Stripe\\File' => $vendorDir . '/stripe/stripe-php/lib/File.php',
    'Stripe\\FileLink' => $vendorDir . '/stripe/stripe-php/lib/FileLink.php',
    'Stripe\\FinancialConnections\\Account' => $vendorDir . '/stripe/stripe-php/lib/FinancialConnections/Account.php',
    'Stripe\\FinancialConnections\\AccountOwner' => $vendorDir . '/stripe/stripe-php/lib/FinancialConnections/AccountOwner.php',
    'Stripe\\FinancialConnections\\AccountOwnership' => $vendorDir . '/stripe/stripe-php/lib/FinancialConnections/AccountOwnership.php',
    'Stripe\\FinancialConnections\\Session' => $vendorDir . '/stripe/stripe-php/lib/FinancialConnections/Session.php',
    'Stripe\\FinancialConnections\\Transaction' => $vendorDir . '/stripe/stripe-php/lib/FinancialConnections/Transaction.php',
    'Stripe\\Forwarding\\Request' => $vendorDir . '/stripe/stripe-php/lib/Forwarding/Request.php',
    'Stripe\\FundingInstructions' => $vendorDir . '/stripe/stripe-php/lib/FundingInstructions.php',
    'Stripe\\HttpClient\\ClientInterface' => $vendorDir . '/stripe/stripe-php/lib/HttpClient/ClientInterface.php',
    'Stripe\\HttpClient\\CurlClient' => $vendorDir . '/stripe/stripe-php/lib/HttpClient/CurlClient.php',
    'Stripe\\HttpClient\\StreamingClientInterface' => $vendorDir . '/stripe/stripe-php/lib/HttpClient/StreamingClientInterface.php',
    'Stripe\\Identity\\VerificationReport' => $vendorDir . '/stripe/stripe-php/lib/Identity/VerificationReport.php',
    'Stripe\\Identity\\VerificationSession' => $vendorDir . '/stripe/stripe-php/lib/Identity/VerificationSession.php',
    'Stripe\\Invoice' => $vendorDir . '/stripe/stripe-php/lib/Invoice.php',
    'Stripe\\InvoiceItem' => $vendorDir . '/stripe/stripe-php/lib/InvoiceItem.php',
    'Stripe\\InvoiceLineItem' => $vendorDir . '/stripe/stripe-php/lib/InvoiceLineItem.php',
    'Stripe\\Issuing\\Authorization' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Authorization.php',
    'Stripe\\Issuing\\Card' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Card.php',
    'Stripe\\Issuing\\CardDetails' => $vendorDir . '/stripe/stripe-php/lib/Issuing/CardDetails.php',
    'Stripe\\Issuing\\Cardholder' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Cardholder.php',
    'Stripe\\Issuing\\Dispute' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Dispute.php',
    'Stripe\\Issuing\\PersonalizationDesign' => $vendorDir . '/stripe/stripe-php/lib/Issuing/PersonalizationDesign.php',
    'Stripe\\Issuing\\PhysicalBundle' => $vendorDir . '/stripe/stripe-php/lib/Issuing/PhysicalBundle.php',
    'Stripe\\Issuing\\Token' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Token.php',
    'Stripe\\Issuing\\Transaction' => $vendorDir . '/stripe/stripe-php/lib/Issuing/Transaction.php',
    'Stripe\\LineItem' => $vendorDir . '/stripe/stripe-php/lib/LineItem.php',
    'Stripe\\LoginLink' => $vendorDir . '/stripe/stripe-php/lib/LoginLink.php',
    'Stripe\\Mandate' => $vendorDir . '/stripe/stripe-php/lib/Mandate.php',
    'Stripe\\OAuth' => $vendorDir . '/stripe/stripe-php/lib/OAuth.php',
    'Stripe\\OAuthErrorObject' => $vendorDir . '/stripe/stripe-php/lib/OAuthErrorObject.php',
    'Stripe\\PaymentIntent' => $vendorDir . '/stripe/stripe-php/lib/PaymentIntent.php',
    'Stripe\\PaymentLink' => $vendorDir . '/stripe/stripe-php/lib/PaymentLink.php',
    'Stripe\\PaymentMethod' => $vendorDir . '/stripe/stripe-php/lib/PaymentMethod.php',
    'Stripe\\PaymentMethodConfiguration' => $vendorDir . '/stripe/stripe-php/lib/PaymentMethodConfiguration.php',
    'Stripe\\PaymentMethodDomain' => $vendorDir . '/stripe/stripe-php/lib/PaymentMethodDomain.php',
    'Stripe\\Payout' => $vendorDir . '/stripe/stripe-php/lib/Payout.php',
    'Stripe\\Person' => $vendorDir . '/stripe/stripe-php/lib/Person.php',
    'Stripe\\Plan' => $vendorDir . '/stripe/stripe-php/lib/Plan.php',
    'Stripe\\Price' => $vendorDir . '/stripe/stripe-php/lib/Price.php',
    'Stripe\\Product' => $vendorDir . '/stripe/stripe-php/lib/Product.php',
    'Stripe\\ProductFeature' => $vendorDir . '/stripe/stripe-php/lib/ProductFeature.php',
    'Stripe\\PromotionCode' => $vendorDir . '/stripe/stripe-php/lib/PromotionCode.php',
    'Stripe\\Quote' => $vendorDir . '/stripe/stripe-php/lib/Quote.php',
    'Stripe\\Radar\\EarlyFraudWarning' => $vendorDir . '/stripe/stripe-php/lib/Radar/EarlyFraudWarning.php',
    'Stripe\\Radar\\ValueList' => $vendorDir . '/stripe/stripe-php/lib/Radar/ValueList.php',
    'Stripe\\Radar\\ValueListItem' => $vendorDir . '/stripe/stripe-php/lib/Radar/ValueListItem.php',
    'Stripe\\RecipientTransfer' => $vendorDir . '/stripe/stripe-php/lib/RecipientTransfer.php',
    'Stripe\\Refund' => $vendorDir . '/stripe/stripe-php/lib/Refund.php',
    'Stripe\\Reporting\\ReportRun' => $vendorDir . '/stripe/stripe-php/lib/Reporting/ReportRun.php',
    'Stripe\\Reporting\\ReportType' => $vendorDir . '/stripe/stripe-php/lib/Reporting/ReportType.php',
    'Stripe\\RequestTelemetry' => $vendorDir . '/stripe/stripe-php/lib/RequestTelemetry.php',
    'Stripe\\ReserveTransaction' => $vendorDir . '/stripe/stripe-php/lib/ReserveTransaction.php',
    'Stripe\\Review' => $vendorDir . '/stripe/stripe-php/lib/Review.php',
    'Stripe\\SearchResult' => $vendorDir . '/stripe/stripe-php/lib/SearchResult.php',
    'Stripe\\Service\\AbstractService' => $vendorDir . '/stripe/stripe-php/lib/Service/AbstractService.php',
    'Stripe\\Service\\AbstractServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/AbstractServiceFactory.php',
    'Stripe\\Service\\AccountLinkService' => $vendorDir . '/stripe/stripe-php/lib/Service/AccountLinkService.php',
    'Stripe\\Service\\AccountService' => $vendorDir . '/stripe/stripe-php/lib/Service/AccountService.php',
    'Stripe\\Service\\AccountSessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/AccountSessionService.php',
    'Stripe\\Service\\ApplePayDomainService' => $vendorDir . '/stripe/stripe-php/lib/Service/ApplePayDomainService.php',
    'Stripe\\Service\\ApplicationFeeService' => $vendorDir . '/stripe/stripe-php/lib/Service/ApplicationFeeService.php',
    'Stripe\\Service\\Apps\\AppsServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Apps/AppsServiceFactory.php',
    'Stripe\\Service\\Apps\\SecretService' => $vendorDir . '/stripe/stripe-php/lib/Service/Apps/SecretService.php',
    'Stripe\\Service\\BalanceService' => $vendorDir . '/stripe/stripe-php/lib/Service/BalanceService.php',
    'Stripe\\Service\\BalanceTransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/BalanceTransactionService.php',
    'Stripe\\Service\\BillingPortal\\BillingPortalServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/BillingPortal/BillingPortalServiceFactory.php',
    'Stripe\\Service\\BillingPortal\\ConfigurationService' => $vendorDir . '/stripe/stripe-php/lib/Service/BillingPortal/ConfigurationService.php',
    'Stripe\\Service\\BillingPortal\\SessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/BillingPortal/SessionService.php',
    'Stripe\\Service\\Billing\\AlertService' => $vendorDir . '/stripe/stripe-php/lib/Service/Billing/AlertService.php',
    'Stripe\\Service\\Billing\\BillingServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Billing/BillingServiceFactory.php',
    'Stripe\\Service\\Billing\\MeterEventAdjustmentService' => $vendorDir . '/stripe/stripe-php/lib/Service/Billing/MeterEventAdjustmentService.php',
    'Stripe\\Service\\Billing\\MeterEventService' => $vendorDir . '/stripe/stripe-php/lib/Service/Billing/MeterEventService.php',
    'Stripe\\Service\\Billing\\MeterService' => $vendorDir . '/stripe/stripe-php/lib/Service/Billing/MeterService.php',
    'Stripe\\Service\\ChargeService' => $vendorDir . '/stripe/stripe-php/lib/Service/ChargeService.php',
    'Stripe\\Service\\Checkout\\CheckoutServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Checkout/CheckoutServiceFactory.php',
    'Stripe\\Service\\Checkout\\SessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/Checkout/SessionService.php',
    'Stripe\\Service\\Climate\\ClimateServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Climate/ClimateServiceFactory.php',
    'Stripe\\Service\\Climate\\OrderService' => $vendorDir . '/stripe/stripe-php/lib/Service/Climate/OrderService.php',
    'Stripe\\Service\\Climate\\ProductService' => $vendorDir . '/stripe/stripe-php/lib/Service/Climate/ProductService.php',
    'Stripe\\Service\\Climate\\SupplierService' => $vendorDir . '/stripe/stripe-php/lib/Service/Climate/SupplierService.php',
    'Stripe\\Service\\ConfirmationTokenService' => $vendorDir . '/stripe/stripe-php/lib/Service/ConfirmationTokenService.php',
    'Stripe\\Service\\CoreServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/CoreServiceFactory.php',
    'Stripe\\Service\\CountrySpecService' => $vendorDir . '/stripe/stripe-php/lib/Service/CountrySpecService.php',
    'Stripe\\Service\\CouponService' => $vendorDir . '/stripe/stripe-php/lib/Service/CouponService.php',
    'Stripe\\Service\\CreditNoteService' => $vendorDir . '/stripe/stripe-php/lib/Service/CreditNoteService.php',
    'Stripe\\Service\\CustomerService' => $vendorDir . '/stripe/stripe-php/lib/Service/CustomerService.php',
    'Stripe\\Service\\CustomerSessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/CustomerSessionService.php',
    'Stripe\\Service\\DisputeService' => $vendorDir . '/stripe/stripe-php/lib/Service/DisputeService.php',
    'Stripe\\Service\\Entitlements\\ActiveEntitlementService' => $vendorDir . '/stripe/stripe-php/lib/Service/Entitlements/ActiveEntitlementService.php',
    'Stripe\\Service\\Entitlements\\EntitlementsServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Entitlements/EntitlementsServiceFactory.php',
    'Stripe\\Service\\Entitlements\\FeatureService' => $vendorDir . '/stripe/stripe-php/lib/Service/Entitlements/FeatureService.php',
    'Stripe\\Service\\EphemeralKeyService' => $vendorDir . '/stripe/stripe-php/lib/Service/EphemeralKeyService.php',
    'Stripe\\Service\\EventService' => $vendorDir . '/stripe/stripe-php/lib/Service/EventService.php',
    'Stripe\\Service\\ExchangeRateService' => $vendorDir . '/stripe/stripe-php/lib/Service/ExchangeRateService.php',
    'Stripe\\Service\\FileLinkService' => $vendorDir . '/stripe/stripe-php/lib/Service/FileLinkService.php',
    'Stripe\\Service\\FileService' => $vendorDir . '/stripe/stripe-php/lib/Service/FileService.php',
    'Stripe\\Service\\FinancialConnections\\AccountService' => $vendorDir . '/stripe/stripe-php/lib/Service/FinancialConnections/AccountService.php',
    'Stripe\\Service\\FinancialConnections\\FinancialConnectionsServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/FinancialConnections/FinancialConnectionsServiceFactory.php',
    'Stripe\\Service\\FinancialConnections\\SessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/FinancialConnections/SessionService.php',
    'Stripe\\Service\\FinancialConnections\\TransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/FinancialConnections/TransactionService.php',
    'Stripe\\Service\\Forwarding\\ForwardingServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Forwarding/ForwardingServiceFactory.php',
    'Stripe\\Service\\Forwarding\\RequestService' => $vendorDir . '/stripe/stripe-php/lib/Service/Forwarding/RequestService.php',
    'Stripe\\Service\\Identity\\IdentityServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Identity/IdentityServiceFactory.php',
    'Stripe\\Service\\Identity\\VerificationReportService' => $vendorDir . '/stripe/stripe-php/lib/Service/Identity/VerificationReportService.php',
    'Stripe\\Service\\Identity\\VerificationSessionService' => $vendorDir . '/stripe/stripe-php/lib/Service/Identity/VerificationSessionService.php',
    'Stripe\\Service\\InvoiceItemService' => $vendorDir . '/stripe/stripe-php/lib/Service/InvoiceItemService.php',
    'Stripe\\Service\\InvoiceService' => $vendorDir . '/stripe/stripe-php/lib/Service/InvoiceService.php',
    'Stripe\\Service\\Issuing\\AuthorizationService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/AuthorizationService.php',
    'Stripe\\Service\\Issuing\\CardService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/CardService.php',
    'Stripe\\Service\\Issuing\\CardholderService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/CardholderService.php',
    'Stripe\\Service\\Issuing\\DisputeService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/DisputeService.php',
    'Stripe\\Service\\Issuing\\IssuingServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/IssuingServiceFactory.php',
    'Stripe\\Service\\Issuing\\PersonalizationDesignService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/PersonalizationDesignService.php',
    'Stripe\\Service\\Issuing\\PhysicalBundleService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/PhysicalBundleService.php',
    'Stripe\\Service\\Issuing\\TokenService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/TokenService.php',
    'Stripe\\Service\\Issuing\\TransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/Issuing/TransactionService.php',
    'Stripe\\Service\\MandateService' => $vendorDir . '/stripe/stripe-php/lib/Service/MandateService.php',
    'Stripe\\Service\\OAuthService' => $vendorDir . '/stripe/stripe-php/lib/Service/OAuthService.php',
    'Stripe\\Service\\PaymentIntentService' => $vendorDir . '/stripe/stripe-php/lib/Service/PaymentIntentService.php',
    'Stripe\\Service\\PaymentLinkService' => $vendorDir . '/stripe/stripe-php/lib/Service/PaymentLinkService.php',
    'Stripe\\Service\\PaymentMethodConfigurationService' => $vendorDir . '/stripe/stripe-php/lib/Service/PaymentMethodConfigurationService.php',
    'Stripe\\Service\\PaymentMethodDomainService' => $vendorDir . '/stripe/stripe-php/lib/Service/PaymentMethodDomainService.php',
    'Stripe\\Service\\PaymentMethodService' => $vendorDir . '/stripe/stripe-php/lib/Service/PaymentMethodService.php',
    'Stripe\\Service\\PayoutService' => $vendorDir . '/stripe/stripe-php/lib/Service/PayoutService.php',
    'Stripe\\Service\\PlanService' => $vendorDir . '/stripe/stripe-php/lib/Service/PlanService.php',
    'Stripe\\Service\\PriceService' => $vendorDir . '/stripe/stripe-php/lib/Service/PriceService.php',
    'Stripe\\Service\\ProductService' => $vendorDir . '/stripe/stripe-php/lib/Service/ProductService.php',
    'Stripe\\Service\\PromotionCodeService' => $vendorDir . '/stripe/stripe-php/lib/Service/PromotionCodeService.php',
    'Stripe\\Service\\QuoteService' => $vendorDir . '/stripe/stripe-php/lib/Service/QuoteService.php',
    'Stripe\\Service\\Radar\\EarlyFraudWarningService' => $vendorDir . '/stripe/stripe-php/lib/Service/Radar/EarlyFraudWarningService.php',
    'Stripe\\Service\\Radar\\RadarServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Radar/RadarServiceFactory.php',
    'Stripe\\Service\\Radar\\ValueListItemService' => $vendorDir . '/stripe/stripe-php/lib/Service/Radar/ValueListItemService.php',
    'Stripe\\Service\\Radar\\ValueListService' => $vendorDir . '/stripe/stripe-php/lib/Service/Radar/ValueListService.php',
    'Stripe\\Service\\RefundService' => $vendorDir . '/stripe/stripe-php/lib/Service/RefundService.php',
    'Stripe\\Service\\Reporting\\ReportRunService' => $vendorDir . '/stripe/stripe-php/lib/Service/Reporting/ReportRunService.php',
    'Stripe\\Service\\Reporting\\ReportTypeService' => $vendorDir . '/stripe/stripe-php/lib/Service/Reporting/ReportTypeService.php',
    'Stripe\\Service\\Reporting\\ReportingServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Reporting/ReportingServiceFactory.php',
    'Stripe\\Service\\ReviewService' => $vendorDir . '/stripe/stripe-php/lib/Service/ReviewService.php',
    'Stripe\\Service\\SetupAttemptService' => $vendorDir . '/stripe/stripe-php/lib/Service/SetupAttemptService.php',
    'Stripe\\Service\\SetupIntentService' => $vendorDir . '/stripe/stripe-php/lib/Service/SetupIntentService.php',
    'Stripe\\Service\\ShippingRateService' => $vendorDir . '/stripe/stripe-php/lib/Service/ShippingRateService.php',
    'Stripe\\Service\\Sigma\\ScheduledQueryRunService' => $vendorDir . '/stripe/stripe-php/lib/Service/Sigma/ScheduledQueryRunService.php',
    'Stripe\\Service\\Sigma\\SigmaServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Sigma/SigmaServiceFactory.php',
    'Stripe\\Service\\SourceService' => $vendorDir . '/stripe/stripe-php/lib/Service/SourceService.php',
    'Stripe\\Service\\SubscriptionItemService' => $vendorDir . '/stripe/stripe-php/lib/Service/SubscriptionItemService.php',
    'Stripe\\Service\\SubscriptionScheduleService' => $vendorDir . '/stripe/stripe-php/lib/Service/SubscriptionScheduleService.php',
    'Stripe\\Service\\SubscriptionService' => $vendorDir . '/stripe/stripe-php/lib/Service/SubscriptionService.php',
    'Stripe\\Service\\TaxCodeService' => $vendorDir . '/stripe/stripe-php/lib/Service/TaxCodeService.php',
    'Stripe\\Service\\TaxIdService' => $vendorDir . '/stripe/stripe-php/lib/Service/TaxIdService.php',
    'Stripe\\Service\\TaxRateService' => $vendorDir . '/stripe/stripe-php/lib/Service/TaxRateService.php',
    'Stripe\\Service\\Tax\\CalculationService' => $vendorDir . '/stripe/stripe-php/lib/Service/Tax/CalculationService.php',
    'Stripe\\Service\\Tax\\RegistrationService' => $vendorDir . '/stripe/stripe-php/lib/Service/Tax/RegistrationService.php',
    'Stripe\\Service\\Tax\\SettingsService' => $vendorDir . '/stripe/stripe-php/lib/Service/Tax/SettingsService.php',
    'Stripe\\Service\\Tax\\TaxServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Tax/TaxServiceFactory.php',
    'Stripe\\Service\\Tax\\TransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/Tax/TransactionService.php',
    'Stripe\\Service\\Terminal\\ConfigurationService' => $vendorDir . '/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php',
    'Stripe\\Service\\Terminal\\ConnectionTokenService' => $vendorDir . '/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php',
    'Stripe\\Service\\Terminal\\LocationService' => $vendorDir . '/stripe/stripe-php/lib/Service/Terminal/LocationService.php',
    'Stripe\\Service\\Terminal\\ReaderService' => $vendorDir . '/stripe/stripe-php/lib/Service/Terminal/ReaderService.php',
    'Stripe\\Service\\Terminal\\TerminalServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php',
    'Stripe\\Service\\TestHelpers\\ConfirmationTokenService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/ConfirmationTokenService.php',
    'Stripe\\Service\\TestHelpers\\CustomerService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/CustomerService.php',
    'Stripe\\Service\\TestHelpers\\Issuing\\AuthorizationService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Issuing/AuthorizationService.php',
    'Stripe\\Service\\TestHelpers\\Issuing\\CardService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Issuing/CardService.php',
    'Stripe\\Service\\TestHelpers\\Issuing\\IssuingServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Issuing/IssuingServiceFactory.php',
    'Stripe\\Service\\TestHelpers\\Issuing\\PersonalizationDesignService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Issuing/PersonalizationDesignService.php',
    'Stripe\\Service\\TestHelpers\\Issuing\\TransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Issuing/TransactionService.php',
    'Stripe\\Service\\TestHelpers\\RefundService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/RefundService.php',
    'Stripe\\Service\\TestHelpers\\Terminal\\ReaderService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Terminal/ReaderService.php',
    'Stripe\\Service\\TestHelpers\\Terminal\\TerminalServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Terminal/TerminalServiceFactory.php',
    'Stripe\\Service\\TestHelpers\\TestClockService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/TestClockService.php',
    'Stripe\\Service\\TestHelpers\\TestHelpersServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/TestHelpersServiceFactory.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\InboundTransferService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/InboundTransferService.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\OutboundPaymentService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/OutboundPaymentService.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\OutboundTransferService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/OutboundTransferService.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\ReceivedCreditService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/ReceivedCreditService.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\ReceivedDebitService' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/ReceivedDebitService.php',
    'Stripe\\Service\\TestHelpers\\Treasury\\TreasuryServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/TestHelpers/Treasury/TreasuryServiceFactory.php',
    'Stripe\\Service\\TokenService' => $vendorDir . '/stripe/stripe-php/lib/Service/TokenService.php',
    'Stripe\\Service\\TopupService' => $vendorDir . '/stripe/stripe-php/lib/Service/TopupService.php',
    'Stripe\\Service\\TransferService' => $vendorDir . '/stripe/stripe-php/lib/Service/TransferService.php',
    'Stripe\\Service\\Treasury\\CreditReversalService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/CreditReversalService.php',
    'Stripe\\Service\\Treasury\\DebitReversalService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/DebitReversalService.php',
    'Stripe\\Service\\Treasury\\FinancialAccountService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/FinancialAccountService.php',
    'Stripe\\Service\\Treasury\\InboundTransferService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/InboundTransferService.php',
    'Stripe\\Service\\Treasury\\OutboundPaymentService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/OutboundPaymentService.php',
    'Stripe\\Service\\Treasury\\OutboundTransferService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/OutboundTransferService.php',
    'Stripe\\Service\\Treasury\\ReceivedCreditService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/ReceivedCreditService.php',
    'Stripe\\Service\\Treasury\\ReceivedDebitService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/ReceivedDebitService.php',
    'Stripe\\Service\\Treasury\\TransactionEntryService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/TransactionEntryService.php',
    'Stripe\\Service\\Treasury\\TransactionService' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/TransactionService.php',
    'Stripe\\Service\\Treasury\\TreasuryServiceFactory' => $vendorDir . '/stripe/stripe-php/lib/Service/Treasury/TreasuryServiceFactory.php',
    'Stripe\\Service\\WebhookEndpointService' => $vendorDir . '/stripe/stripe-php/lib/Service/WebhookEndpointService.php',
    'Stripe\\SetupAttempt' => $vendorDir . '/stripe/stripe-php/lib/SetupAttempt.php',
    'Stripe\\SetupIntent' => $vendorDir . '/stripe/stripe-php/lib/SetupIntent.php',
    'Stripe\\ShippingRate' => $vendorDir . '/stripe/stripe-php/lib/ShippingRate.php',
    'Stripe\\Sigma\\ScheduledQueryRun' => $vendorDir . '/stripe/stripe-php/lib/Sigma/ScheduledQueryRun.php',
    'Stripe\\SingletonApiResource' => $vendorDir . '/stripe/stripe-php/lib/SingletonApiResource.php',
    'Stripe\\Source' => $vendorDir . '/stripe/stripe-php/lib/Source.php',
    'Stripe\\SourceMandateNotification' => $vendorDir . '/stripe/stripe-php/lib/SourceMandateNotification.php',
    'Stripe\\SourceTransaction' => $vendorDir . '/stripe/stripe-php/lib/SourceTransaction.php',
    'Stripe\\Stripe' => $vendorDir . '/stripe/stripe-php/lib/Stripe.php',
    'Stripe\\StripeClient' => $vendorDir . '/stripe/stripe-php/lib/StripeClient.php',
    'Stripe\\StripeClientInterface' => $vendorDir . '/stripe/stripe-php/lib/StripeClientInterface.php',
    'Stripe\\StripeObject' => $vendorDir . '/stripe/stripe-php/lib/StripeObject.php',
    'Stripe\\StripeStreamingClientInterface' => $vendorDir . '/stripe/stripe-php/lib/StripeStreamingClientInterface.php',
    'Stripe\\Subscription' => $vendorDir . '/stripe/stripe-php/lib/Subscription.php',
    'Stripe\\SubscriptionItem' => $vendorDir . '/stripe/stripe-php/lib/SubscriptionItem.php',
    'Stripe\\SubscriptionSchedule' => $vendorDir . '/stripe/stripe-php/lib/SubscriptionSchedule.php',
    'Stripe\\TaxCode' => $vendorDir . '/stripe/stripe-php/lib/TaxCode.php',
    'Stripe\\TaxDeductedAtSource' => $vendorDir . '/stripe/stripe-php/lib/TaxDeductedAtSource.php',
    'Stripe\\TaxId' => $vendorDir . '/stripe/stripe-php/lib/TaxId.php',
    'Stripe\\TaxRate' => $vendorDir . '/stripe/stripe-php/lib/TaxRate.php',
    'Stripe\\Tax\\Calculation' => $vendorDir . '/stripe/stripe-php/lib/Tax/Calculation.php',
    'Stripe\\Tax\\CalculationLineItem' => $vendorDir . '/stripe/stripe-php/lib/Tax/CalculationLineItem.php',
    'Stripe\\Tax\\Registration' => $vendorDir . '/stripe/stripe-php/lib/Tax/Registration.php',
    'Stripe\\Tax\\Settings' => $vendorDir . '/stripe/stripe-php/lib/Tax/Settings.php',
    'Stripe\\Tax\\Transaction' => $vendorDir . '/stripe/stripe-php/lib/Tax/Transaction.php',
    'Stripe\\Tax\\TransactionLineItem' => $vendorDir . '/stripe/stripe-php/lib/Tax/TransactionLineItem.php',
    'Stripe\\Terminal\\Configuration' => $vendorDir . '/stripe/stripe-php/lib/Terminal/Configuration.php',
    'Stripe\\Terminal\\ConnectionToken' => $vendorDir . '/stripe/stripe-php/lib/Terminal/ConnectionToken.php',
    'Stripe\\Terminal\\Location' => $vendorDir . '/stripe/stripe-php/lib/Terminal/Location.php',
    'Stripe\\Terminal\\Reader' => $vendorDir . '/stripe/stripe-php/lib/Terminal/Reader.php',
    'Stripe\\TestHelpers\\TestClock' => $vendorDir . '/stripe/stripe-php/lib/TestHelpers/TestClock.php',
    'Stripe\\Token' => $vendorDir . '/stripe/stripe-php/lib/Token.php',
    'Stripe\\Topup' => $vendorDir . '/stripe/stripe-php/lib/Topup.php',
    'Stripe\\Transfer' => $vendorDir . '/stripe/stripe-php/lib/Transfer.php',
    'Stripe\\TransferReversal' => $vendorDir . '/stripe/stripe-php/lib/TransferReversal.php',
    'Stripe\\Treasury\\CreditReversal' => $vendorDir . '/stripe/stripe-php/lib/Treasury/CreditReversal.php',
    'Stripe\\Treasury\\DebitReversal' => $vendorDir . '/stripe/stripe-php/lib/Treasury/DebitReversal.php',
    'Stripe\\Treasury\\FinancialAccount' => $vendorDir . '/stripe/stripe-php/lib/Treasury/FinancialAccount.php',
    'Stripe\\Treasury\\FinancialAccountFeatures' => $vendorDir . '/stripe/stripe-php/lib/Treasury/FinancialAccountFeatures.php',
    'Stripe\\Treasury\\InboundTransfer' => $vendorDir . '/stripe/stripe-php/lib/Treasury/InboundTransfer.php',
    'Stripe\\Treasury\\OutboundPayment' => $vendorDir . '/stripe/stripe-php/lib/Treasury/OutboundPayment.php',
    'Stripe\\Treasury\\OutboundTransfer' => $vendorDir . '/stripe/stripe-php/lib/Treasury/OutboundTransfer.php',
    'Stripe\\Treasury\\ReceivedCredit' => $vendorDir . '/stripe/stripe-php/lib/Treasury/ReceivedCredit.php',
    'Stripe\\Treasury\\ReceivedDebit' => $vendorDir . '/stripe/stripe-php/lib/Treasury/ReceivedDebit.php',
    'Stripe\\Treasury\\Transaction' => $vendorDir . '/stripe/stripe-php/lib/Treasury/Transaction.php',
    'Stripe\\Treasury\\TransactionEntry' => $vendorDir . '/stripe/stripe-php/lib/Treasury/TransactionEntry.php',
    'Stripe\\UsageRecord' => $vendorDir . '/stripe/stripe-php/lib/UsageRecord.php',
    'Stripe\\UsageRecordSummary' => $vendorDir . '/stripe/stripe-php/lib/UsageRecordSummary.php',
    'Stripe\\Util\\ApiVersion' => $vendorDir . '/stripe/stripe-php/lib/Util/ApiVersion.php',
    'Stripe\\Util\\CaseInsensitiveArray' => $vendorDir . '/stripe/stripe-php/lib/Util/CaseInsensitiveArray.php',
    'Stripe\\Util\\DefaultLogger' => $vendorDir . '/stripe/stripe-php/lib/Util/DefaultLogger.php',
    'Stripe\\Util\\LoggerInterface' => $vendorDir . '/stripe/stripe-php/lib/Util/LoggerInterface.php',
    'Stripe\\Util\\ObjectTypes' => $vendorDir . '/stripe/stripe-php/lib/Util/ObjectTypes.php',
    'Stripe\\Util\\RandomGenerator' => $vendorDir . '/stripe/stripe-php/lib/Util/RandomGenerator.php',
    'Stripe\\Util\\RequestOptions' => $vendorDir . '/stripe/stripe-php/lib/Util/RequestOptions.php',
    'Stripe\\Util\\Set' => $vendorDir . '/stripe/stripe-php/lib/Util/Set.php',
    'Stripe\\Util\\Util' => $vendorDir . '/stripe/stripe-php/lib/Util/Util.php',
    'Stripe\\Webhook' => $vendorDir . '/stripe/stripe-php/lib/Webhook.php',
    'Stripe\\WebhookEndpoint' => $vendorDir . '/stripe/stripe-php/lib/WebhookEndpoint.php',
    'Stripe\\WebhookSignature' => $vendorDir . '/stripe/stripe-php/lib/WebhookSignature.php',
    'Symfony\\Component\\Clock\\Clock' => $vendorDir . '/symfony/clock/Clock.php',
    'Symfony\\Component\\Clock\\ClockAwareTrait' => $vendorDir . '/symfony/clock/ClockAwareTrait.php',
    'Symfony\\Component\\Clock\\ClockInterface' => $vendorDir . '/symfony/clock/ClockInterface.php',
    'Symfony\\Component\\Clock\\DatePoint' => $vendorDir . '/symfony/clock/DatePoint.php',
    'Symfony\\Component\\Clock\\MockClock' => $vendorDir . '/symfony/clock/MockClock.php',
    'Symfony\\Component\\Clock\\MonotonicClock' => $vendorDir . '/symfony/clock/MonotonicClock.php',
    'Symfony\\Component\\Clock\\NativeClock' => $vendorDir . '/symfony/clock/NativeClock.php',
    'Symfony\\Component\\Clock\\Test\\ClockSensitiveTrait' => $vendorDir . '/symfony/clock/Test/ClockSensitiveTrait.php',
    'Symfony\\Component\\Console\\Application' => $vendorDir . '/symfony/console/Application.php',
    'Symfony\\Component\\Console\\Attribute\\AsCommand' => $vendorDir . '/symfony/console/Attribute/AsCommand.php',
    'Symfony\\Component\\Console\\CI\\GithubActionReporter' => $vendorDir . '/symfony/console/CI/GithubActionReporter.php',
    'Symfony\\Component\\Console\\Color' => $vendorDir . '/symfony/console/Color.php',
    'Symfony\\Component\\Console\\CommandLoader\\CommandLoaderInterface' => $vendorDir . '/symfony/console/CommandLoader/CommandLoaderInterface.php',
    'Symfony\\Component\\Console\\CommandLoader\\ContainerCommandLoader' => $vendorDir . '/symfony/console/CommandLoader/ContainerCommandLoader.php',
    'Symfony\\Component\\Console\\CommandLoader\\FactoryCommandLoader' => $vendorDir . '/symfony/console/CommandLoader/FactoryCommandLoader.php',
    'Symfony\\Component\\Console\\Command\\Command' => $vendorDir . '/symfony/console/Command/Command.php',
    'Symfony\\Component\\Console\\Command\\CompleteCommand' => $vendorDir . '/symfony/console/Command/CompleteCommand.php',
    'Symfony\\Component\\Console\\Command\\DumpCompletionCommand' => $vendorDir . '/symfony/console/Command/DumpCompletionCommand.php',
    'Symfony\\Component\\Console\\Command\\HelpCommand' => $vendorDir . '/symfony/console/Command/HelpCommand.php',
    'Symfony\\Component\\Console\\Command\\LazyCommand' => $vendorDir . '/symfony/console/Command/LazyCommand.php',
    'Symfony\\Component\\Console\\Command\\ListCommand' => $vendorDir . '/symfony/console/Command/ListCommand.php',
    'Symfony\\Component\\Console\\Command\\LockableTrait' => $vendorDir . '/symfony/console/Command/LockableTrait.php',
    'Symfony\\Component\\Console\\Command\\SignalableCommandInterface' => $vendorDir . '/symfony/console/Command/SignalableCommandInterface.php',
    'Symfony\\Component\\Console\\Command\\TraceableCommand' => $vendorDir . '/symfony/console/Command/TraceableCommand.php',
    'Symfony\\Component\\Console\\Completion\\CompletionInput' => $vendorDir . '/symfony/console/Completion/CompletionInput.php',
    'Symfony\\Component\\Console\\Completion\\CompletionSuggestions' => $vendorDir . '/symfony/console/Completion/CompletionSuggestions.php',
    'Symfony\\Component\\Console\\Completion\\Output\\BashCompletionOutput' => $vendorDir . '/symfony/console/Completion/Output/BashCompletionOutput.php',
    'Symfony\\Component\\Console\\Completion\\Output\\CompletionOutputInterface' => $vendorDir . '/symfony/console/Completion/Output/CompletionOutputInterface.php',
    'Symfony\\Component\\Console\\Completion\\Output\\FishCompletionOutput' => $vendorDir . '/symfony/console/Completion/Output/FishCompletionOutput.php',
    'Symfony\\Component\\Console\\Completion\\Output\\ZshCompletionOutput' => $vendorDir . '/symfony/console/Completion/Output/ZshCompletionOutput.php',
    'Symfony\\Component\\Console\\Completion\\Suggestion' => $vendorDir . '/symfony/console/Completion/Suggestion.php',
    'Symfony\\Component\\Console\\ConsoleEvents' => $vendorDir . '/symfony/console/ConsoleEvents.php',
    'Symfony\\Component\\Console\\Cursor' => $vendorDir . '/symfony/console/Cursor.php',
    'Symfony\\Component\\Console\\DataCollector\\CommandDataCollector' => $vendorDir . '/symfony/console/DataCollector/CommandDataCollector.php',
    'Symfony\\Component\\Console\\Debug\\CliRequest' => $vendorDir . '/symfony/console/Debug/CliRequest.php',
    'Symfony\\Component\\Console\\DependencyInjection\\AddConsoleCommandPass' => $vendorDir . '/symfony/console/DependencyInjection/AddConsoleCommandPass.php',
    'Symfony\\Component\\Console\\Descriptor\\ApplicationDescription' => $vendorDir . '/symfony/console/Descriptor/ApplicationDescription.php',
    'Symfony\\Component\\Console\\Descriptor\\Descriptor' => $vendorDir . '/symfony/console/Descriptor/Descriptor.php',
    'Symfony\\Component\\Console\\Descriptor\\DescriptorInterface' => $vendorDir . '/symfony/console/Descriptor/DescriptorInterface.php',
    'Symfony\\Component\\Console\\Descriptor\\JsonDescriptor' => $vendorDir . '/symfony/console/Descriptor/JsonDescriptor.php',
    'Symfony\\Component\\Console\\Descriptor\\MarkdownDescriptor' => $vendorDir . '/symfony/console/Descriptor/MarkdownDescriptor.php',
    'Symfony\\Component\\Console\\Descriptor\\ReStructuredTextDescriptor' => $vendorDir . '/symfony/console/Descriptor/ReStructuredTextDescriptor.php',
    'Symfony\\Component\\Console\\Descriptor\\TextDescriptor' => $vendorDir . '/symfony/console/Descriptor/TextDescriptor.php',
    'Symfony\\Component\\Console\\Descriptor\\XmlDescriptor' => $vendorDir . '/symfony/console/Descriptor/XmlDescriptor.php',
    'Symfony\\Component\\Console\\EventListener\\ErrorListener' => $vendorDir . '/symfony/console/EventListener/ErrorListener.php',
    'Symfony\\Component\\Console\\Event\\ConsoleCommandEvent' => $vendorDir . '/symfony/console/Event/ConsoleCommandEvent.php',
    'Symfony\\Component\\Console\\Event\\ConsoleErrorEvent' => $vendorDir . '/symfony/console/Event/ConsoleErrorEvent.php',
    'Symfony\\Component\\Console\\Event\\ConsoleEvent' => $vendorDir . '/symfony/console/Event/ConsoleEvent.php',
    'Symfony\\Component\\Console\\Event\\ConsoleSignalEvent' => $vendorDir . '/symfony/console/Event/ConsoleSignalEvent.php',
    'Symfony\\Component\\Console\\Event\\ConsoleTerminateEvent' => $vendorDir . '/symfony/console/Event/ConsoleTerminateEvent.php',
    'Symfony\\Component\\Console\\Exception\\CommandNotFoundException' => $vendorDir . '/symfony/console/Exception/CommandNotFoundException.php',
    'Symfony\\Component\\Console\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/console/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Console\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/console/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Console\\Exception\\InvalidOptionException' => $vendorDir . '/symfony/console/Exception/InvalidOptionException.php',
    'Symfony\\Component\\Console\\Exception\\LogicException' => $vendorDir . '/symfony/console/Exception/LogicException.php',
    'Symfony\\Component\\Console\\Exception\\MissingInputException' => $vendorDir . '/symfony/console/Exception/MissingInputException.php',
    'Symfony\\Component\\Console\\Exception\\NamespaceNotFoundException' => $vendorDir . '/symfony/console/Exception/NamespaceNotFoundException.php',
    'Symfony\\Component\\Console\\Exception\\RunCommandFailedException' => $vendorDir . '/symfony/console/Exception/RunCommandFailedException.php',
    'Symfony\\Component\\Console\\Exception\\RuntimeException' => $vendorDir . '/symfony/console/Exception/RuntimeException.php',
    'Symfony\\Component\\Console\\Formatter\\NullOutputFormatter' => $vendorDir . '/symfony/console/Formatter/NullOutputFormatter.php',
    'Symfony\\Component\\Console\\Formatter\\NullOutputFormatterStyle' => $vendorDir . '/symfony/console/Formatter/NullOutputFormatterStyle.php',
    'Symfony\\Component\\Console\\Formatter\\OutputFormatter' => $vendorDir . '/symfony/console/Formatter/OutputFormatter.php',
    'Symfony\\Component\\Console\\Formatter\\OutputFormatterInterface' => $vendorDir . '/symfony/console/Formatter/OutputFormatterInterface.php',
    'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyle' => $vendorDir . '/symfony/console/Formatter/OutputFormatterStyle.php',
    'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyleInterface' => $vendorDir . '/symfony/console/Formatter/OutputFormatterStyleInterface.php',
    'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyleStack' => $vendorDir . '/symfony/console/Formatter/OutputFormatterStyleStack.php',
    'Symfony\\Component\\Console\\Formatter\\WrappableOutputFormatterInterface' => $vendorDir . '/symfony/console/Formatter/WrappableOutputFormatterInterface.php',
    'Symfony\\Component\\Console\\Helper\\DebugFormatterHelper' => $vendorDir . '/symfony/console/Helper/DebugFormatterHelper.php',
    'Symfony\\Component\\Console\\Helper\\DescriptorHelper' => $vendorDir . '/symfony/console/Helper/DescriptorHelper.php',
    'Symfony\\Component\\Console\\Helper\\Dumper' => $vendorDir . '/symfony/console/Helper/Dumper.php',
    'Symfony\\Component\\Console\\Helper\\FormatterHelper' => $vendorDir . '/symfony/console/Helper/FormatterHelper.php',
    'Symfony\\Component\\Console\\Helper\\Helper' => $vendorDir . '/symfony/console/Helper/Helper.php',
    'Symfony\\Component\\Console\\Helper\\HelperInterface' => $vendorDir . '/symfony/console/Helper/HelperInterface.php',
    'Symfony\\Component\\Console\\Helper\\HelperSet' => $vendorDir . '/symfony/console/Helper/HelperSet.php',
    'Symfony\\Component\\Console\\Helper\\InputAwareHelper' => $vendorDir . '/symfony/console/Helper/InputAwareHelper.php',
    'Symfony\\Component\\Console\\Helper\\OutputWrapper' => $vendorDir . '/symfony/console/Helper/OutputWrapper.php',
    'Symfony\\Component\\Console\\Helper\\ProcessHelper' => $vendorDir . '/symfony/console/Helper/ProcessHelper.php',
    'Symfony\\Component\\Console\\Helper\\ProgressBar' => $vendorDir . '/symfony/console/Helper/ProgressBar.php',
    'Symfony\\Component\\Console\\Helper\\ProgressIndicator' => $vendorDir . '/symfony/console/Helper/ProgressIndicator.php',
    'Symfony\\Component\\Console\\Helper\\QuestionHelper' => $vendorDir . '/symfony/console/Helper/QuestionHelper.php',
    'Symfony\\Component\\Console\\Helper\\SymfonyQuestionHelper' => $vendorDir . '/symfony/console/Helper/SymfonyQuestionHelper.php',
    'Symfony\\Component\\Console\\Helper\\Table' => $vendorDir . '/symfony/console/Helper/Table.php',
    'Symfony\\Component\\Console\\Helper\\TableCell' => $vendorDir . '/symfony/console/Helper/TableCell.php',
    'Symfony\\Component\\Console\\Helper\\TableCellStyle' => $vendorDir . '/symfony/console/Helper/TableCellStyle.php',
    'Symfony\\Component\\Console\\Helper\\TableRows' => $vendorDir . '/symfony/console/Helper/TableRows.php',
    'Symfony\\Component\\Console\\Helper\\TableSeparator' => $vendorDir . '/symfony/console/Helper/TableSeparator.php',
    'Symfony\\Component\\Console\\Helper\\TableStyle' => $vendorDir . '/symfony/console/Helper/TableStyle.php',
    'Symfony\\Component\\Console\\Input\\ArgvInput' => $vendorDir . '/symfony/console/Input/ArgvInput.php',
    'Symfony\\Component\\Console\\Input\\ArrayInput' => $vendorDir . '/symfony/console/Input/ArrayInput.php',
    'Symfony\\Component\\Console\\Input\\Input' => $vendorDir . '/symfony/console/Input/Input.php',
    'Symfony\\Component\\Console\\Input\\InputArgument' => $vendorDir . '/symfony/console/Input/InputArgument.php',
    'Symfony\\Component\\Console\\Input\\InputAwareInterface' => $vendorDir . '/symfony/console/Input/InputAwareInterface.php',
    'Symfony\\Component\\Console\\Input\\InputDefinition' => $vendorDir . '/symfony/console/Input/InputDefinition.php',
    'Symfony\\Component\\Console\\Input\\InputInterface' => $vendorDir . '/symfony/console/Input/InputInterface.php',
    'Symfony\\Component\\Console\\Input\\InputOption' => $vendorDir . '/symfony/console/Input/InputOption.php',
    'Symfony\\Component\\Console\\Input\\StreamableInputInterface' => $vendorDir . '/symfony/console/Input/StreamableInputInterface.php',
    'Symfony\\Component\\Console\\Input\\StringInput' => $vendorDir . '/symfony/console/Input/StringInput.php',
    'Symfony\\Component\\Console\\Logger\\ConsoleLogger' => $vendorDir . '/symfony/console/Logger/ConsoleLogger.php',
    'Symfony\\Component\\Console\\Messenger\\RunCommandContext' => $vendorDir . '/symfony/console/Messenger/RunCommandContext.php',
    'Symfony\\Component\\Console\\Messenger\\RunCommandMessage' => $vendorDir . '/symfony/console/Messenger/RunCommandMessage.php',
    'Symfony\\Component\\Console\\Messenger\\RunCommandMessageHandler' => $vendorDir . '/symfony/console/Messenger/RunCommandMessageHandler.php',
    'Symfony\\Component\\Console\\Output\\AnsiColorMode' => $vendorDir . '/symfony/console/Output/AnsiColorMode.php',
    'Symfony\\Component\\Console\\Output\\BufferedOutput' => $vendorDir . '/symfony/console/Output/BufferedOutput.php',
    'Symfony\\Component\\Console\\Output\\ConsoleOutput' => $vendorDir . '/symfony/console/Output/ConsoleOutput.php',
    'Symfony\\Component\\Console\\Output\\ConsoleOutputInterface' => $vendorDir . '/symfony/console/Output/ConsoleOutputInterface.php',
    'Symfony\\Component\\Console\\Output\\ConsoleSectionOutput' => $vendorDir . '/symfony/console/Output/ConsoleSectionOutput.php',
    'Symfony\\Component\\Console\\Output\\NullOutput' => $vendorDir . '/symfony/console/Output/NullOutput.php',
    'Symfony\\Component\\Console\\Output\\Output' => $vendorDir . '/symfony/console/Output/Output.php',
    'Symfony\\Component\\Console\\Output\\OutputInterface' => $vendorDir . '/symfony/console/Output/OutputInterface.php',
    'Symfony\\Component\\Console\\Output\\StreamOutput' => $vendorDir . '/symfony/console/Output/StreamOutput.php',
    'Symfony\\Component\\Console\\Output\\TrimmedBufferOutput' => $vendorDir . '/symfony/console/Output/TrimmedBufferOutput.php',
    'Symfony\\Component\\Console\\Question\\ChoiceQuestion' => $vendorDir . '/symfony/console/Question/ChoiceQuestion.php',
    'Symfony\\Component\\Console\\Question\\ConfirmationQuestion' => $vendorDir . '/symfony/console/Question/ConfirmationQuestion.php',
    'Symfony\\Component\\Console\\Question\\Question' => $vendorDir . '/symfony/console/Question/Question.php',
    'Symfony\\Component\\Console\\SignalRegistry\\SignalMap' => $vendorDir . '/symfony/console/SignalRegistry/SignalMap.php',
    'Symfony\\Component\\Console\\SignalRegistry\\SignalRegistry' => $vendorDir . '/symfony/console/SignalRegistry/SignalRegistry.php',
    'Symfony\\Component\\Console\\SingleCommandApplication' => $vendorDir . '/symfony/console/SingleCommandApplication.php',
    'Symfony\\Component\\Console\\Style\\OutputStyle' => $vendorDir . '/symfony/console/Style/OutputStyle.php',
    'Symfony\\Component\\Console\\Style\\StyleInterface' => $vendorDir . '/symfony/console/Style/StyleInterface.php',
    'Symfony\\Component\\Console\\Style\\SymfonyStyle' => $vendorDir . '/symfony/console/Style/SymfonyStyle.php',
    'Symfony\\Component\\Console\\Terminal' => $vendorDir . '/symfony/console/Terminal.php',
    'Symfony\\Component\\Console\\Tester\\ApplicationTester' => $vendorDir . '/symfony/console/Tester/ApplicationTester.php',
    'Symfony\\Component\\Console\\Tester\\CommandCompletionTester' => $vendorDir . '/symfony/console/Tester/CommandCompletionTester.php',
    'Symfony\\Component\\Console\\Tester\\CommandTester' => $vendorDir . '/symfony/console/Tester/CommandTester.php',
    'Symfony\\Component\\Console\\Tester\\Constraint\\CommandIsSuccessful' => $vendorDir . '/symfony/console/Tester/Constraint/CommandIsSuccessful.php',
    'Symfony\\Component\\Console\\Tester\\TesterTrait' => $vendorDir . '/symfony/console/Tester/TesterTrait.php',
    'Symfony\\Component\\CssSelector\\CssSelectorConverter' => $vendorDir . '/symfony/css-selector/CssSelectorConverter.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/css-selector/Exception/ExceptionInterface.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExpressionErrorException' => $vendorDir . '/symfony/css-selector/Exception/ExpressionErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\InternalErrorException' => $vendorDir . '/symfony/css-selector/Exception/InternalErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\ParseException' => $vendorDir . '/symfony/css-selector/Exception/ParseException.php',
    'Symfony\\Component\\CssSelector\\Exception\\SyntaxErrorException' => $vendorDir . '/symfony/css-selector/Exception/SyntaxErrorException.php',
    'Symfony\\Component\\CssSelector\\Node\\AbstractNode' => $vendorDir . '/symfony/css-selector/Node/AbstractNode.php',
    'Symfony\\Component\\CssSelector\\Node\\AttributeNode' => $vendorDir . '/symfony/css-selector/Node/AttributeNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ClassNode' => $vendorDir . '/symfony/css-selector/Node/ClassNode.php',
    'Symfony\\Component\\CssSelector\\Node\\CombinedSelectorNode' => $vendorDir . '/symfony/css-selector/Node/CombinedSelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ElementNode' => $vendorDir . '/symfony/css-selector/Node/ElementNode.php',
    'Symfony\\Component\\CssSelector\\Node\\FunctionNode' => $vendorDir . '/symfony/css-selector/Node/FunctionNode.php',
    'Symfony\\Component\\CssSelector\\Node\\HashNode' => $vendorDir . '/symfony/css-selector/Node/HashNode.php',
    'Symfony\\Component\\CssSelector\\Node\\MatchingNode' => $vendorDir . '/symfony/css-selector/Node/MatchingNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NegationNode' => $vendorDir . '/symfony/css-selector/Node/NegationNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NodeInterface' => $vendorDir . '/symfony/css-selector/Node/NodeInterface.php',
    'Symfony\\Component\\CssSelector\\Node\\PseudoNode' => $vendorDir . '/symfony/css-selector/Node/PseudoNode.php',
    'Symfony\\Component\\CssSelector\\Node\\SelectorNode' => $vendorDir . '/symfony/css-selector/Node/SelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\Specificity' => $vendorDir . '/symfony/css-selector/Node/Specificity.php',
    'Symfony\\Component\\CssSelector\\Node\\SpecificityAdjustmentNode' => $vendorDir . '/symfony/css-selector/Node/SpecificityAdjustmentNode.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\CommentHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/CommentHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HandlerInterface' => $vendorDir . '/symfony/css-selector/Parser/Handler/HandlerInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HashHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/HashHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\IdentifierHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/IdentifierHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\NumberHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/NumberHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\StringHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/StringHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\WhitespaceHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/WhitespaceHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Parser' => $vendorDir . '/symfony/css-selector/Parser/Parser.php',
    'Symfony\\Component\\CssSelector\\Parser\\ParserInterface' => $vendorDir . '/symfony/css-selector/Parser/ParserInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Reader' => $vendorDir . '/symfony/css-selector/Parser/Reader.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ClassParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ClassParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ElementParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ElementParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\EmptyStringParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/EmptyStringParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\HashParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/HashParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Token' => $vendorDir . '/symfony/css-selector/Parser/Token.php',
    'Symfony\\Component\\CssSelector\\Parser\\TokenStream' => $vendorDir . '/symfony/css-selector/Parser/TokenStream.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\Tokenizer' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/Tokenizer.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerEscaping' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerEscaping.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerPatterns' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerPatterns.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AbstractExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AbstractExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AttributeMatchingExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AttributeMatchingExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\CombinationExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/CombinationExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\ExtensionInterface' => $vendorDir . '/symfony/css-selector/XPath/Extension/ExtensionInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\FunctionExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/FunctionExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\HtmlExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/HtmlExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\NodeExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/NodeExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\PseudoClassExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/PseudoClassExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Translator' => $vendorDir . '/symfony/css-selector/XPath/Translator.php',
    'Symfony\\Component\\CssSelector\\XPath\\TranslatorInterface' => $vendorDir . '/symfony/css-selector/XPath/TranslatorInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\XPathExpr' => $vendorDir . '/symfony/css-selector/XPath/XPathExpr.php',
    'Symfony\\Component\\ErrorHandler\\BufferingLogger' => $vendorDir . '/symfony/error-handler/BufferingLogger.php',
    'Symfony\\Component\\ErrorHandler\\Debug' => $vendorDir . '/symfony/error-handler/Debug.php',
    'Symfony\\Component\\ErrorHandler\\DebugClassLoader' => $vendorDir . '/symfony/error-handler/DebugClassLoader.php',
    'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\ClassNotFoundErrorEnhancer' => $vendorDir . '/symfony/error-handler/ErrorEnhancer/ClassNotFoundErrorEnhancer.php',
    'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\ErrorEnhancerInterface' => $vendorDir . '/symfony/error-handler/ErrorEnhancer/ErrorEnhancerInterface.php',
    'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\UndefinedFunctionErrorEnhancer' => $vendorDir . '/symfony/error-handler/ErrorEnhancer/UndefinedFunctionErrorEnhancer.php',
    'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\UndefinedMethodErrorEnhancer' => $vendorDir . '/symfony/error-handler/ErrorEnhancer/UndefinedMethodErrorEnhancer.php',
    'Symfony\\Component\\ErrorHandler\\ErrorHandler' => $vendorDir . '/symfony/error-handler/ErrorHandler.php',
    'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\CliErrorRenderer' => $vendorDir . '/symfony/error-handler/ErrorRenderer/CliErrorRenderer.php',
    'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\ErrorRendererInterface' => $vendorDir . '/symfony/error-handler/ErrorRenderer/ErrorRendererInterface.php',
    'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\FileLinkFormatter' => $vendorDir . '/symfony/error-handler/ErrorRenderer/FileLinkFormatter.php',
    'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\HtmlErrorRenderer' => $vendorDir . '/symfony/error-handler/ErrorRenderer/HtmlErrorRenderer.php',
    'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\SerializerErrorRenderer' => $vendorDir . '/symfony/error-handler/ErrorRenderer/SerializerErrorRenderer.php',
    'Symfony\\Component\\ErrorHandler\\Error\\ClassNotFoundError' => $vendorDir . '/symfony/error-handler/Error/ClassNotFoundError.php',
    'Symfony\\Component\\ErrorHandler\\Error\\FatalError' => $vendorDir . '/symfony/error-handler/Error/FatalError.php',
    'Symfony\\Component\\ErrorHandler\\Error\\OutOfMemoryError' => $vendorDir . '/symfony/error-handler/Error/OutOfMemoryError.php',
    'Symfony\\Component\\ErrorHandler\\Error\\UndefinedFunctionError' => $vendorDir . '/symfony/error-handler/Error/UndefinedFunctionError.php',
    'Symfony\\Component\\ErrorHandler\\Error\\UndefinedMethodError' => $vendorDir . '/symfony/error-handler/Error/UndefinedMethodError.php',
    'Symfony\\Component\\ErrorHandler\\Exception\\FlattenException' => $vendorDir . '/symfony/error-handler/Exception/FlattenException.php',
    'Symfony\\Component\\ErrorHandler\\Exception\\SilencedErrorContext' => $vendorDir . '/symfony/error-handler/Exception/SilencedErrorContext.php',
    'Symfony\\Component\\ErrorHandler\\Internal\\TentativeTypes' => $vendorDir . '/symfony/error-handler/Internal/TentativeTypes.php',
    'Symfony\\Component\\ErrorHandler\\ThrowableUtils' => $vendorDir . '/symfony/error-handler/ThrowableUtils.php',
    'Symfony\\Component\\EventDispatcher\\Attribute\\AsEventListener' => $vendorDir . '/symfony/event-dispatcher/Attribute/AsEventListener.php',
    'Symfony\\Component\\EventDispatcher\\Debug\\TraceableEventDispatcher' => $vendorDir . '/symfony/event-dispatcher/Debug/TraceableEventDispatcher.php',
    'Symfony\\Component\\EventDispatcher\\Debug\\WrappedListener' => $vendorDir . '/symfony/event-dispatcher/Debug/WrappedListener.php',
    'Symfony\\Component\\EventDispatcher\\DependencyInjection\\AddEventAliasesPass' => $vendorDir . '/symfony/event-dispatcher/DependencyInjection/AddEventAliasesPass.php',
    'Symfony\\Component\\EventDispatcher\\DependencyInjection\\RegisterListenersPass' => $vendorDir . '/symfony/event-dispatcher/DependencyInjection/RegisterListenersPass.php',
    'Symfony\\Component\\EventDispatcher\\EventDispatcher' => $vendorDir . '/symfony/event-dispatcher/EventDispatcher.php',
    'Symfony\\Component\\EventDispatcher\\EventDispatcherInterface' => $vendorDir . '/symfony/event-dispatcher/EventDispatcherInterface.php',
    'Symfony\\Component\\EventDispatcher\\EventSubscriberInterface' => $vendorDir . '/symfony/event-dispatcher/EventSubscriberInterface.php',
    'Symfony\\Component\\EventDispatcher\\GenericEvent' => $vendorDir . '/symfony/event-dispatcher/GenericEvent.php',
    'Symfony\\Component\\EventDispatcher\\ImmutableEventDispatcher' => $vendorDir . '/symfony/event-dispatcher/ImmutableEventDispatcher.php',
    'Symfony\\Component\\Finder\\Comparator\\Comparator' => $vendorDir . '/symfony/finder/Comparator/Comparator.php',
    'Symfony\\Component\\Finder\\Comparator\\DateComparator' => $vendorDir . '/symfony/finder/Comparator/DateComparator.php',
    'Symfony\\Component\\Finder\\Comparator\\NumberComparator' => $vendorDir . '/symfony/finder/Comparator/NumberComparator.php',
    'Symfony\\Component\\Finder\\Exception\\AccessDeniedException' => $vendorDir . '/symfony/finder/Exception/AccessDeniedException.php',
    'Symfony\\Component\\Finder\\Exception\\DirectoryNotFoundException' => $vendorDir . '/symfony/finder/Exception/DirectoryNotFoundException.php',
    'Symfony\\Component\\Finder\\Finder' => $vendorDir . '/symfony/finder/Finder.php',
    'Symfony\\Component\\Finder\\Gitignore' => $vendorDir . '/symfony/finder/Gitignore.php',
    'Symfony\\Component\\Finder\\Glob' => $vendorDir . '/symfony/finder/Glob.php',
    'Symfony\\Component\\Finder\\Iterator\\CustomFilterIterator' => $vendorDir . '/symfony/finder/Iterator/CustomFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\DateRangeFilterIterator' => $vendorDir . '/symfony/finder/Iterator/DateRangeFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\DepthRangeFilterIterator' => $vendorDir . '/symfony/finder/Iterator/DepthRangeFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\ExcludeDirectoryFilterIterator' => $vendorDir . '/symfony/finder/Iterator/ExcludeDirectoryFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\FileTypeFilterIterator' => $vendorDir . '/symfony/finder/Iterator/FileTypeFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\FilecontentFilterIterator' => $vendorDir . '/symfony/finder/Iterator/FilecontentFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\FilenameFilterIterator' => $vendorDir . '/symfony/finder/Iterator/FilenameFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\LazyIterator' => $vendorDir . '/symfony/finder/Iterator/LazyIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\MultiplePcreFilterIterator' => $vendorDir . '/symfony/finder/Iterator/MultiplePcreFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\PathFilterIterator' => $vendorDir . '/symfony/finder/Iterator/PathFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\RecursiveDirectoryIterator' => $vendorDir . '/symfony/finder/Iterator/RecursiveDirectoryIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\SizeRangeFilterIterator' => $vendorDir . '/symfony/finder/Iterator/SizeRangeFilterIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\SortableIterator' => $vendorDir . '/symfony/finder/Iterator/SortableIterator.php',
    'Symfony\\Component\\Finder\\Iterator\\VcsIgnoredFilterIterator' => $vendorDir . '/symfony/finder/Iterator/VcsIgnoredFilterIterator.php',
    'Symfony\\Component\\Finder\\SplFileInfo' => $vendorDir . '/symfony/finder/SplFileInfo.php',
    'Symfony\\Component\\HttpFoundation\\AcceptHeader' => $vendorDir . '/symfony/http-foundation/AcceptHeader.php',
    'Symfony\\Component\\HttpFoundation\\AcceptHeaderItem' => $vendorDir . '/symfony/http-foundation/AcceptHeaderItem.php',
    'Symfony\\Component\\HttpFoundation\\BinaryFileResponse' => $vendorDir . '/symfony/http-foundation/BinaryFileResponse.php',
    'Symfony\\Component\\HttpFoundation\\ChainRequestMatcher' => $vendorDir . '/symfony/http-foundation/ChainRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\Cookie' => $vendorDir . '/symfony/http-foundation/Cookie.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\BadRequestException' => $vendorDir . '/symfony/http-foundation/Exception/BadRequestException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\ConflictingHeadersException' => $vendorDir . '/symfony/http-foundation/Exception/ConflictingHeadersException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/http-foundation/Exception/ExceptionInterface.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\JsonException' => $vendorDir . '/symfony/http-foundation/Exception/JsonException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\LogicException' => $vendorDir . '/symfony/http-foundation/Exception/LogicException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\RequestExceptionInterface' => $vendorDir . '/symfony/http-foundation/Exception/RequestExceptionInterface.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\SessionNotFoundException' => $vendorDir . '/symfony/http-foundation/Exception/SessionNotFoundException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\SuspiciousOperationException' => $vendorDir . '/symfony/http-foundation/Exception/SuspiciousOperationException.php',
    'Symfony\\Component\\HttpFoundation\\Exception\\UnexpectedValueException' => $vendorDir . '/symfony/http-foundation/Exception/UnexpectedValueException.php',
    'Symfony\\Component\\HttpFoundation\\FileBag' => $vendorDir . '/symfony/http-foundation/FileBag.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\AccessDeniedException' => $vendorDir . '/symfony/http-foundation/File/Exception/AccessDeniedException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\CannotWriteFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/CannotWriteFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\ExtensionFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/ExtensionFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\FileException' => $vendorDir . '/symfony/http-foundation/File/Exception/FileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\FileNotFoundException' => $vendorDir . '/symfony/http-foundation/File/Exception/FileNotFoundException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\FormSizeFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/FormSizeFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\IniSizeFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/IniSizeFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\NoFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/NoFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\NoTmpDirFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/NoTmpDirFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\PartialFileException' => $vendorDir . '/symfony/http-foundation/File/Exception/PartialFileException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\UnexpectedTypeException' => $vendorDir . '/symfony/http-foundation/File/Exception/UnexpectedTypeException.php',
    'Symfony\\Component\\HttpFoundation\\File\\Exception\\UploadException' => $vendorDir . '/symfony/http-foundation/File/Exception/UploadException.php',
    'Symfony\\Component\\HttpFoundation\\File\\File' => $vendorDir . '/symfony/http-foundation/File/File.php',
    'Symfony\\Component\\HttpFoundation\\File\\Stream' => $vendorDir . '/symfony/http-foundation/File/Stream.php',
    'Symfony\\Component\\HttpFoundation\\File\\UploadedFile' => $vendorDir . '/symfony/http-foundation/File/UploadedFile.php',
    'Symfony\\Component\\HttpFoundation\\HeaderBag' => $vendorDir . '/symfony/http-foundation/HeaderBag.php',
    'Symfony\\Component\\HttpFoundation\\HeaderUtils' => $vendorDir . '/symfony/http-foundation/HeaderUtils.php',
    'Symfony\\Component\\HttpFoundation\\InputBag' => $vendorDir . '/symfony/http-foundation/InputBag.php',
    'Symfony\\Component\\HttpFoundation\\IpUtils' => $vendorDir . '/symfony/http-foundation/IpUtils.php',
    'Symfony\\Component\\HttpFoundation\\JsonResponse' => $vendorDir . '/symfony/http-foundation/JsonResponse.php',
    'Symfony\\Component\\HttpFoundation\\ParameterBag' => $vendorDir . '/symfony/http-foundation/ParameterBag.php',
    'Symfony\\Component\\HttpFoundation\\RateLimiter\\AbstractRequestRateLimiter' => $vendorDir . '/symfony/http-foundation/RateLimiter/AbstractRequestRateLimiter.php',
    'Symfony\\Component\\HttpFoundation\\RateLimiter\\PeekableRequestRateLimiterInterface' => $vendorDir . '/symfony/http-foundation/RateLimiter/PeekableRequestRateLimiterInterface.php',
    'Symfony\\Component\\HttpFoundation\\RateLimiter\\RequestRateLimiterInterface' => $vendorDir . '/symfony/http-foundation/RateLimiter/RequestRateLimiterInterface.php',
    'Symfony\\Component\\HttpFoundation\\RedirectResponse' => $vendorDir . '/symfony/http-foundation/RedirectResponse.php',
    'Symfony\\Component\\HttpFoundation\\Request' => $vendorDir . '/symfony/http-foundation/Request.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcherInterface' => $vendorDir . '/symfony/http-foundation/RequestMatcherInterface.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\AttributesRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/AttributesRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\ExpressionRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/ExpressionRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\HeaderRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/HeaderRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\HostRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/HostRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\IpsRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/IpsRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\IsJsonRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/IsJsonRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\MethodRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/MethodRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\PathRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/PathRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\PortRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/PortRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\QueryParameterRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/QueryParameterRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestMatcher\\SchemeRequestMatcher' => $vendorDir . '/symfony/http-foundation/RequestMatcher/SchemeRequestMatcher.php',
    'Symfony\\Component\\HttpFoundation\\RequestStack' => $vendorDir . '/symfony/http-foundation/RequestStack.php',
    'Symfony\\Component\\HttpFoundation\\Response' => $vendorDir . '/symfony/http-foundation/Response.php',
    'Symfony\\Component\\HttpFoundation\\ResponseHeaderBag' => $vendorDir . '/symfony/http-foundation/ResponseHeaderBag.php',
    'Symfony\\Component\\HttpFoundation\\ServerBag' => $vendorDir . '/symfony/http-foundation/ServerBag.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Attribute\\AttributeBag' => $vendorDir . '/symfony/http-foundation/Session/Attribute/AttributeBag.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Attribute\\AttributeBagInterface' => $vendorDir . '/symfony/http-foundation/Session/Attribute/AttributeBagInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\FlashBagAwareSessionInterface' => $vendorDir . '/symfony/http-foundation/Session/FlashBagAwareSessionInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Flash\\AutoExpireFlashBag' => $vendorDir . '/symfony/http-foundation/Session/Flash/AutoExpireFlashBag.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Flash\\FlashBag' => $vendorDir . '/symfony/http-foundation/Session/Flash/FlashBag.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Flash\\FlashBagInterface' => $vendorDir . '/symfony/http-foundation/Session/Flash/FlashBagInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Session' => $vendorDir . '/symfony/http-foundation/Session/Session.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionBagInterface' => $vendorDir . '/symfony/http-foundation/Session/SessionBagInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionBagProxy' => $vendorDir . '/symfony/http-foundation/Session/SessionBagProxy.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionFactory' => $vendorDir . '/symfony/http-foundation/Session/SessionFactory.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionFactoryInterface' => $vendorDir . '/symfony/http-foundation/Session/SessionFactoryInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionInterface' => $vendorDir . '/symfony/http-foundation/Session/SessionInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\SessionUtils' => $vendorDir . '/symfony/http-foundation/Session/SessionUtils.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\AbstractSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/AbstractSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\IdentityMarshaller' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/IdentityMarshaller.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MarshallingSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/MarshallingSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MemcachedSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/MemcachedSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MigratingSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/MigratingSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MongoDbSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/MongoDbSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\NativeFileSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/NativeFileSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\NullSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/NullSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\PdoSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/PdoSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\RedisSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\SessionHandlerFactory' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/SessionHandlerFactory.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\StrictSessionHandler' => $vendorDir . '/symfony/http-foundation/Session/Storage/Handler/StrictSessionHandler.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MetadataBag' => $vendorDir . '/symfony/http-foundation/Session/Storage/MetadataBag.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockArraySessionStorage' => $vendorDir . '/symfony/http-foundation/Session/Storage/MockArraySessionStorage.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockFileSessionStorage' => $vendorDir . '/symfony/http-foundation/Session/Storage/MockFileSessionStorage.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockFileSessionStorageFactory' => $vendorDir . '/symfony/http-foundation/Session/Storage/MockFileSessionStorageFactory.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\NativeSessionStorage' => $vendorDir . '/symfony/http-foundation/Session/Storage/NativeSessionStorage.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\NativeSessionStorageFactory' => $vendorDir . '/symfony/http-foundation/Session/Storage/NativeSessionStorageFactory.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\PhpBridgeSessionStorage' => $vendorDir . '/symfony/http-foundation/Session/Storage/PhpBridgeSessionStorage.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\PhpBridgeSessionStorageFactory' => $vendorDir . '/symfony/http-foundation/Session/Storage/PhpBridgeSessionStorageFactory.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Proxy\\AbstractProxy' => $vendorDir . '/symfony/http-foundation/Session/Storage/Proxy/AbstractProxy.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Proxy\\SessionHandlerProxy' => $vendorDir . '/symfony/http-foundation/Session/Storage/Proxy/SessionHandlerProxy.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\SessionStorageFactoryInterface' => $vendorDir . '/symfony/http-foundation/Session/Storage/SessionStorageFactoryInterface.php',
    'Symfony\\Component\\HttpFoundation\\Session\\Storage\\SessionStorageInterface' => $vendorDir . '/symfony/http-foundation/Session/Storage/SessionStorageInterface.php',
    'Symfony\\Component\\HttpFoundation\\StreamedJsonResponse' => $vendorDir . '/symfony/http-foundation/StreamedJsonResponse.php',
    'Symfony\\Component\\HttpFoundation\\StreamedResponse' => $vendorDir . '/symfony/http-foundation/StreamedResponse.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\RequestAttributeValueSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/RequestAttributeValueSame.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseCookieValueSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseCookieValueSame.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseFormatSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseFormatSame.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHasCookie' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseHasCookie.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHasHeader' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseHasHeader.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHeaderLocationSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseHeaderLocationSame.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHeaderSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseHeaderSame.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsRedirected' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseIsRedirected.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsSuccessful' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseIsSuccessful.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsUnprocessable' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseIsUnprocessable.php',
    'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseStatusCodeSame' => $vendorDir . '/symfony/http-foundation/Test/Constraint/ResponseStatusCodeSame.php',
    'Symfony\\Component\\HttpFoundation\\UriSigner' => $vendorDir . '/symfony/http-foundation/UriSigner.php',
    'Symfony\\Component\\HttpFoundation\\UrlHelper' => $vendorDir . '/symfony/http-foundation/UrlHelper.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\AsController' => $vendorDir . '/symfony/http-kernel/Attribute/AsController.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\AsTargetedValueResolver' => $vendorDir . '/symfony/http-kernel/Attribute/AsTargetedValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\Cache' => $vendorDir . '/symfony/http-kernel/Attribute/Cache.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\MapDateTime' => $vendorDir . '/symfony/http-kernel/Attribute/MapDateTime.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\MapQueryParameter' => $vendorDir . '/symfony/http-kernel/Attribute/MapQueryParameter.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\MapQueryString' => $vendorDir . '/symfony/http-kernel/Attribute/MapQueryString.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\MapRequestPayload' => $vendorDir . '/symfony/http-kernel/Attribute/MapRequestPayload.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\MapUploadedFile' => $vendorDir . '/symfony/http-kernel/Attribute/MapUploadedFile.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\ValueResolver' => $vendorDir . '/symfony/http-kernel/Attribute/ValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\WithHttpStatus' => $vendorDir . '/symfony/http-kernel/Attribute/WithHttpStatus.php',
    'Symfony\\Component\\HttpKernel\\Attribute\\WithLogLevel' => $vendorDir . '/symfony/http-kernel/Attribute/WithLogLevel.php',
    'Symfony\\Component\\HttpKernel\\Bundle\\AbstractBundle' => $vendorDir . '/symfony/http-kernel/Bundle/AbstractBundle.php',
    'Symfony\\Component\\HttpKernel\\Bundle\\Bundle' => $vendorDir . '/symfony/http-kernel/Bundle/Bundle.php',
    'Symfony\\Component\\HttpKernel\\Bundle\\BundleExtension' => $vendorDir . '/symfony/http-kernel/Bundle/BundleExtension.php',
    'Symfony\\Component\\HttpKernel\\Bundle\\BundleInterface' => $vendorDir . '/symfony/http-kernel/Bundle/BundleInterface.php',
    'Symfony\\Component\\HttpKernel\\CacheClearer\\CacheClearerInterface' => $vendorDir . '/symfony/http-kernel/CacheClearer/CacheClearerInterface.php',
    'Symfony\\Component\\HttpKernel\\CacheClearer\\ChainCacheClearer' => $vendorDir . '/symfony/http-kernel/CacheClearer/ChainCacheClearer.php',
    'Symfony\\Component\\HttpKernel\\CacheClearer\\Psr6CacheClearer' => $vendorDir . '/symfony/http-kernel/CacheClearer/Psr6CacheClearer.php',
    'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmer' => $vendorDir . '/symfony/http-kernel/CacheWarmer/CacheWarmer.php',
    'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmerAggregate' => $vendorDir . '/symfony/http-kernel/CacheWarmer/CacheWarmerAggregate.php',
    'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmerInterface' => $vendorDir . '/symfony/http-kernel/CacheWarmer/CacheWarmerInterface.php',
    'Symfony\\Component\\HttpKernel\\CacheWarmer\\WarmableInterface' => $vendorDir . '/symfony/http-kernel/CacheWarmer/WarmableInterface.php',
    'Symfony\\Component\\HttpKernel\\Config\\FileLocator' => $vendorDir . '/symfony/http-kernel/Config/FileLocator.php',
    'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadata' => $vendorDir . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadata.php',
    'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadataFactory' => $vendorDir . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadataFactory.php',
    'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadataFactoryInterface' => $vendorDir . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadataFactoryInterface.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolverInterface' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolverInterface.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\BackedEnumValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/BackedEnumValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\DateTimeValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/DateTimeValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\DefaultValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/DefaultValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\NotTaggedControllerValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/NotTaggedControllerValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\QueryParameterValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/QueryParameterValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestAttributeValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/RequestAttributeValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestPayloadValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/RequestPayloadValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/RequestValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\ServiceValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/ServiceValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\SessionValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/SessionValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\TraceableValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/TraceableValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\UidValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/UidValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\VariadicValueResolver' => $vendorDir . '/symfony/http-kernel/Controller/ArgumentResolver/VariadicValueResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ContainerControllerResolver' => $vendorDir . '/symfony/http-kernel/Controller/ContainerControllerResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ControllerReference' => $vendorDir . '/symfony/http-kernel/Controller/ControllerReference.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ControllerResolver' => $vendorDir . '/symfony/http-kernel/Controller/ControllerResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ControllerResolverInterface' => $vendorDir . '/symfony/http-kernel/Controller/ControllerResolverInterface.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ErrorController' => $vendorDir . '/symfony/http-kernel/Controller/ErrorController.php',
    'Symfony\\Component\\HttpKernel\\Controller\\TraceableArgumentResolver' => $vendorDir . '/symfony/http-kernel/Controller/TraceableArgumentResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\TraceableControllerResolver' => $vendorDir . '/symfony/http-kernel/Controller/TraceableControllerResolver.php',
    'Symfony\\Component\\HttpKernel\\Controller\\ValueResolverInterface' => $vendorDir . '/symfony/http-kernel/Controller/ValueResolverInterface.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\AjaxDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/AjaxDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\ConfigDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/ConfigDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\DataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/DataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\DataCollectorInterface' => $vendorDir . '/symfony/http-kernel/DataCollector/DataCollectorInterface.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\DumpDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/DumpDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\EventDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/EventDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\ExceptionDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/ExceptionDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\LateDataCollectorInterface' => $vendorDir . '/symfony/http-kernel/DataCollector/LateDataCollectorInterface.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\LoggerDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/LoggerDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\MemoryDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/MemoryDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\RequestDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/RequestDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\RouterDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/RouterDataCollector.php',
    'Symfony\\Component\\HttpKernel\\DataCollector\\TimeDataCollector' => $vendorDir . '/symfony/http-kernel/DataCollector/TimeDataCollector.php',
    'Symfony\\Component\\HttpKernel\\Debug\\ErrorHandlerConfigurator' => $vendorDir . '/symfony/http-kernel/Debug/ErrorHandlerConfigurator.php',
    'Symfony\\Component\\HttpKernel\\Debug\\TraceableEventDispatcher' => $vendorDir . '/symfony/http-kernel/Debug/TraceableEventDispatcher.php',
    'Symfony\\Component\\HttpKernel\\Debug\\VirtualRequestStack' => $vendorDir . '/symfony/http-kernel/Debug/VirtualRequestStack.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\AddAnnotatedClassesToCachePass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/AddAnnotatedClassesToCachePass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\ConfigurableExtension' => $vendorDir . '/symfony/http-kernel/DependencyInjection/ConfigurableExtension.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\ControllerArgumentValueResolverPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/ControllerArgumentValueResolverPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\Extension' => $vendorDir . '/symfony/http-kernel/DependencyInjection/Extension.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\FragmentRendererPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/FragmentRendererPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\LazyLoadingFragmentHandler' => $vendorDir . '/symfony/http-kernel/DependencyInjection/LazyLoadingFragmentHandler.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\LoggerPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/LoggerPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\MergeExtensionConfigurationPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/MergeExtensionConfigurationPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\RegisterControllerArgumentLocatorsPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/RegisterControllerArgumentLocatorsPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\RegisterLocaleAwareServicesPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/RegisterLocaleAwareServicesPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\RemoveEmptyControllerArgumentLocatorsPass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/RemoveEmptyControllerArgumentLocatorsPass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\ResettableServicePass' => $vendorDir . '/symfony/http-kernel/DependencyInjection/ResettableServicePass.php',
    'Symfony\\Component\\HttpKernel\\DependencyInjection\\ServicesResetter' => $vendorDir . '/symfony/http-kernel/DependencyInjection/ServicesResetter.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\AbstractSessionListener' => $vendorDir . '/symfony/http-kernel/EventListener/AbstractSessionListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\AddRequestFormatsListener' => $vendorDir . '/symfony/http-kernel/EventListener/AddRequestFormatsListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\CacheAttributeListener' => $vendorDir . '/symfony/http-kernel/EventListener/CacheAttributeListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\DebugHandlersListener' => $vendorDir . '/symfony/http-kernel/EventListener/DebugHandlersListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\DisallowRobotsIndexingListener' => $vendorDir . '/symfony/http-kernel/EventListener/DisallowRobotsIndexingListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\DumpListener' => $vendorDir . '/symfony/http-kernel/EventListener/DumpListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\ErrorListener' => $vendorDir . '/symfony/http-kernel/EventListener/ErrorListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\FragmentListener' => $vendorDir . '/symfony/http-kernel/EventListener/FragmentListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\LocaleAwareListener' => $vendorDir . '/symfony/http-kernel/EventListener/LocaleAwareListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\LocaleListener' => $vendorDir . '/symfony/http-kernel/EventListener/LocaleListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\ProfilerListener' => $vendorDir . '/symfony/http-kernel/EventListener/ProfilerListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\ResponseListener' => $vendorDir . '/symfony/http-kernel/EventListener/ResponseListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\RouterListener' => $vendorDir . '/symfony/http-kernel/EventListener/RouterListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\SessionListener' => $vendorDir . '/symfony/http-kernel/EventListener/SessionListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\SurrogateListener' => $vendorDir . '/symfony/http-kernel/EventListener/SurrogateListener.php',
    'Symfony\\Component\\HttpKernel\\EventListener\\ValidateRequestListener' => $vendorDir . '/symfony/http-kernel/EventListener/ValidateRequestListener.php',
    'Symfony\\Component\\HttpKernel\\Event\\ControllerArgumentsEvent' => $vendorDir . '/symfony/http-kernel/Event/ControllerArgumentsEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\ControllerEvent' => $vendorDir . '/symfony/http-kernel/Event/ControllerEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\ExceptionEvent' => $vendorDir . '/symfony/http-kernel/Event/ExceptionEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\FinishRequestEvent' => $vendorDir . '/symfony/http-kernel/Event/FinishRequestEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\KernelEvent' => $vendorDir . '/symfony/http-kernel/Event/KernelEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\RequestEvent' => $vendorDir . '/symfony/http-kernel/Event/RequestEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\ResponseEvent' => $vendorDir . '/symfony/http-kernel/Event/ResponseEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\TerminateEvent' => $vendorDir . '/symfony/http-kernel/Event/TerminateEvent.php',
    'Symfony\\Component\\HttpKernel\\Event\\ViewEvent' => $vendorDir . '/symfony/http-kernel/Event/ViewEvent.php',
    'Symfony\\Component\\HttpKernel\\Exception\\AccessDeniedHttpException' => $vendorDir . '/symfony/http-kernel/Exception/AccessDeniedHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\BadRequestHttpException' => $vendorDir . '/symfony/http-kernel/Exception/BadRequestHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\ConflictHttpException' => $vendorDir . '/symfony/http-kernel/Exception/ConflictHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\ControllerDoesNotReturnResponseException' => $vendorDir . '/symfony/http-kernel/Exception/ControllerDoesNotReturnResponseException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\GoneHttpException' => $vendorDir . '/symfony/http-kernel/Exception/GoneHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\HttpException' => $vendorDir . '/symfony/http-kernel/Exception/HttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\HttpExceptionInterface' => $vendorDir . '/symfony/http-kernel/Exception/HttpExceptionInterface.php',
    'Symfony\\Component\\HttpKernel\\Exception\\InvalidMetadataException' => $vendorDir . '/symfony/http-kernel/Exception/InvalidMetadataException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\LengthRequiredHttpException' => $vendorDir . '/symfony/http-kernel/Exception/LengthRequiredHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\LockedHttpException' => $vendorDir . '/symfony/http-kernel/Exception/LockedHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\MethodNotAllowedHttpException' => $vendorDir . '/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\NearMissValueResolverException' => $vendorDir . '/symfony/http-kernel/Exception/NearMissValueResolverException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\NotAcceptableHttpException' => $vendorDir . '/symfony/http-kernel/Exception/NotAcceptableHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\NotFoundHttpException' => $vendorDir . '/symfony/http-kernel/Exception/NotFoundHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\PreconditionFailedHttpException' => $vendorDir . '/symfony/http-kernel/Exception/PreconditionFailedHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\PreconditionRequiredHttpException' => $vendorDir . '/symfony/http-kernel/Exception/PreconditionRequiredHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\ResolverNotFoundException' => $vendorDir . '/symfony/http-kernel/Exception/ResolverNotFoundException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\ServiceUnavailableHttpException' => $vendorDir . '/symfony/http-kernel/Exception/ServiceUnavailableHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\TooManyRequestsHttpException' => $vendorDir . '/symfony/http-kernel/Exception/TooManyRequestsHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\UnauthorizedHttpException' => $vendorDir . '/symfony/http-kernel/Exception/UnauthorizedHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\UnexpectedSessionUsageException' => $vendorDir . '/symfony/http-kernel/Exception/UnexpectedSessionUsageException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\UnprocessableEntityHttpException' => $vendorDir . '/symfony/http-kernel/Exception/UnprocessableEntityHttpException.php',
    'Symfony\\Component\\HttpKernel\\Exception\\UnsupportedMediaTypeHttpException' => $vendorDir . '/symfony/http-kernel/Exception/UnsupportedMediaTypeHttpException.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\AbstractSurrogateFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/AbstractSurrogateFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\EsiFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/EsiFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\FragmentHandler' => $vendorDir . '/symfony/http-kernel/Fragment/FragmentHandler.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\FragmentRendererInterface' => $vendorDir . '/symfony/http-kernel/Fragment/FragmentRendererInterface.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\FragmentUriGenerator' => $vendorDir . '/symfony/http-kernel/Fragment/FragmentUriGenerator.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\FragmentUriGeneratorInterface' => $vendorDir . '/symfony/http-kernel/Fragment/FragmentUriGeneratorInterface.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\HIncludeFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/HIncludeFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\InlineFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/InlineFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\RoutableFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/RoutableFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\Fragment\\SsiFragmentRenderer' => $vendorDir . '/symfony/http-kernel/Fragment/SsiFragmentRenderer.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\AbstractSurrogate' => $vendorDir . '/symfony/http-kernel/HttpCache/AbstractSurrogate.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\Esi' => $vendorDir . '/symfony/http-kernel/HttpCache/Esi.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\HttpCache' => $vendorDir . '/symfony/http-kernel/HttpCache/HttpCache.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\ResponseCacheStrategy' => $vendorDir . '/symfony/http-kernel/HttpCache/ResponseCacheStrategy.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\ResponseCacheStrategyInterface' => $vendorDir . '/symfony/http-kernel/HttpCache/ResponseCacheStrategyInterface.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\Ssi' => $vendorDir . '/symfony/http-kernel/HttpCache/Ssi.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\Store' => $vendorDir . '/symfony/http-kernel/HttpCache/Store.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\StoreInterface' => $vendorDir . '/symfony/http-kernel/HttpCache/StoreInterface.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\SubRequestHandler' => $vendorDir . '/symfony/http-kernel/HttpCache/SubRequestHandler.php',
    'Symfony\\Component\\HttpKernel\\HttpCache\\SurrogateInterface' => $vendorDir . '/symfony/http-kernel/HttpCache/SurrogateInterface.php',
    'Symfony\\Component\\HttpKernel\\HttpClientKernel' => $vendorDir . '/symfony/http-kernel/HttpClientKernel.php',
    'Symfony\\Component\\HttpKernel\\HttpKernel' => $vendorDir . '/symfony/http-kernel/HttpKernel.php',
    'Symfony\\Component\\HttpKernel\\HttpKernelBrowser' => $vendorDir . '/symfony/http-kernel/HttpKernelBrowser.php',
    'Symfony\\Component\\HttpKernel\\HttpKernelInterface' => $vendorDir . '/symfony/http-kernel/HttpKernelInterface.php',
    'Symfony\\Component\\HttpKernel\\Kernel' => $vendorDir . '/symfony/http-kernel/Kernel.php',
    'Symfony\\Component\\HttpKernel\\KernelEvents' => $vendorDir . '/symfony/http-kernel/KernelEvents.php',
    'Symfony\\Component\\HttpKernel\\KernelInterface' => $vendorDir . '/symfony/http-kernel/KernelInterface.php',
    'Symfony\\Component\\HttpKernel\\Log\\DebugLoggerConfigurator' => $vendorDir . '/symfony/http-kernel/Log/DebugLoggerConfigurator.php',
    'Symfony\\Component\\HttpKernel\\Log\\DebugLoggerInterface' => $vendorDir . '/symfony/http-kernel/Log/DebugLoggerInterface.php',
    'Symfony\\Component\\HttpKernel\\Log\\Logger' => $vendorDir . '/symfony/http-kernel/Log/Logger.php',
    'Symfony\\Component\\HttpKernel\\Profiler\\FileProfilerStorage' => $vendorDir . '/symfony/http-kernel/Profiler/FileProfilerStorage.php',
    'Symfony\\Component\\HttpKernel\\Profiler\\Profile' => $vendorDir . '/symfony/http-kernel/Profiler/Profile.php',
    'Symfony\\Component\\HttpKernel\\Profiler\\Profiler' => $vendorDir . '/symfony/http-kernel/Profiler/Profiler.php',
    'Symfony\\Component\\HttpKernel\\Profiler\\ProfilerStorageInterface' => $vendorDir . '/symfony/http-kernel/Profiler/ProfilerStorageInterface.php',
    'Symfony\\Component\\HttpKernel\\RebootableInterface' => $vendorDir . '/symfony/http-kernel/RebootableInterface.php',
    'Symfony\\Component\\HttpKernel\\TerminableInterface' => $vendorDir . '/symfony/http-kernel/TerminableInterface.php',
    'Symfony\\Component\\Mailer\\Command\\MailerTestCommand' => $vendorDir . '/symfony/mailer/Command/MailerTestCommand.php',
    'Symfony\\Component\\Mailer\\DataCollector\\MessageDataCollector' => $vendorDir . '/symfony/mailer/DataCollector/MessageDataCollector.php',
    'Symfony\\Component\\Mailer\\DelayedEnvelope' => $vendorDir . '/symfony/mailer/DelayedEnvelope.php',
    'Symfony\\Component\\Mailer\\Envelope' => $vendorDir . '/symfony/mailer/Envelope.php',
    'Symfony\\Component\\Mailer\\EventListener\\EnvelopeListener' => $vendorDir . '/symfony/mailer/EventListener/EnvelopeListener.php',
    'Symfony\\Component\\Mailer\\EventListener\\MessageListener' => $vendorDir . '/symfony/mailer/EventListener/MessageListener.php',
    'Symfony\\Component\\Mailer\\EventListener\\MessageLoggerListener' => $vendorDir . '/symfony/mailer/EventListener/MessageLoggerListener.php',
    'Symfony\\Component\\Mailer\\EventListener\\MessengerTransportListener' => $vendorDir . '/symfony/mailer/EventListener/MessengerTransportListener.php',
    'Symfony\\Component\\Mailer\\Event\\FailedMessageEvent' => $vendorDir . '/symfony/mailer/Event/FailedMessageEvent.php',
    'Symfony\\Component\\Mailer\\Event\\MessageEvent' => $vendorDir . '/symfony/mailer/Event/MessageEvent.php',
    'Symfony\\Component\\Mailer\\Event\\MessageEvents' => $vendorDir . '/symfony/mailer/Event/MessageEvents.php',
    'Symfony\\Component\\Mailer\\Event\\SentMessageEvent' => $vendorDir . '/symfony/mailer/Event/SentMessageEvent.php',
    'Symfony\\Component\\Mailer\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/mailer/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Mailer\\Exception\\HttpTransportException' => $vendorDir . '/symfony/mailer/Exception/HttpTransportException.php',
    'Symfony\\Component\\Mailer\\Exception\\IncompleteDsnException' => $vendorDir . '/symfony/mailer/Exception/IncompleteDsnException.php',
    'Symfony\\Component\\Mailer\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/mailer/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Mailer\\Exception\\LogicException' => $vendorDir . '/symfony/mailer/Exception/LogicException.php',
    'Symfony\\Component\\Mailer\\Exception\\RuntimeException' => $vendorDir . '/symfony/mailer/Exception/RuntimeException.php',
    'Symfony\\Component\\Mailer\\Exception\\TransportException' => $vendorDir . '/symfony/mailer/Exception/TransportException.php',
    'Symfony\\Component\\Mailer\\Exception\\TransportExceptionInterface' => $vendorDir . '/symfony/mailer/Exception/TransportExceptionInterface.php',
    'Symfony\\Component\\Mailer\\Exception\\UnexpectedResponseException' => $vendorDir . '/symfony/mailer/Exception/UnexpectedResponseException.php',
    'Symfony\\Component\\Mailer\\Exception\\UnsupportedSchemeException' => $vendorDir . '/symfony/mailer/Exception/UnsupportedSchemeException.php',
    'Symfony\\Component\\Mailer\\Header\\MetadataHeader' => $vendorDir . '/symfony/mailer/Header/MetadataHeader.php',
    'Symfony\\Component\\Mailer\\Header\\TagHeader' => $vendorDir . '/symfony/mailer/Header/TagHeader.php',
    'Symfony\\Component\\Mailer\\Mailer' => $vendorDir . '/symfony/mailer/Mailer.php',
    'Symfony\\Component\\Mailer\\MailerInterface' => $vendorDir . '/symfony/mailer/MailerInterface.php',
    'Symfony\\Component\\Mailer\\Messenger\\MessageHandler' => $vendorDir . '/symfony/mailer/Messenger/MessageHandler.php',
    'Symfony\\Component\\Mailer\\Messenger\\SendEmailMessage' => $vendorDir . '/symfony/mailer/Messenger/SendEmailMessage.php',
    'Symfony\\Component\\Mailer\\SentMessage' => $vendorDir . '/symfony/mailer/SentMessage.php',
    'Symfony\\Component\\Mailer\\Test\\Constraint\\EmailCount' => $vendorDir . '/symfony/mailer/Test/Constraint/EmailCount.php',
    'Symfony\\Component\\Mailer\\Test\\Constraint\\EmailIsQueued' => $vendorDir . '/symfony/mailer/Test/Constraint/EmailIsQueued.php',
    'Symfony\\Component\\Mailer\\Test\\TransportFactoryTestCase' => $vendorDir . '/symfony/mailer/Test/TransportFactoryTestCase.php',
    'Symfony\\Component\\Mailer\\Transport' => $vendorDir . '/symfony/mailer/Transport.php',
    'Symfony\\Component\\Mailer\\Transport\\AbstractApiTransport' => $vendorDir . '/symfony/mailer/Transport/AbstractApiTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\AbstractHttpTransport' => $vendorDir . '/symfony/mailer/Transport/AbstractHttpTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\AbstractTransport' => $vendorDir . '/symfony/mailer/Transport/AbstractTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\AbstractTransportFactory' => $vendorDir . '/symfony/mailer/Transport/AbstractTransportFactory.php',
    'Symfony\\Component\\Mailer\\Transport\\Dsn' => $vendorDir . '/symfony/mailer/Transport/Dsn.php',
    'Symfony\\Component\\Mailer\\Transport\\FailoverTransport' => $vendorDir . '/symfony/mailer/Transport/FailoverTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\NativeTransportFactory' => $vendorDir . '/symfony/mailer/Transport/NativeTransportFactory.php',
    'Symfony\\Component\\Mailer\\Transport\\NullTransport' => $vendorDir . '/symfony/mailer/Transport/NullTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\NullTransportFactory' => $vendorDir . '/symfony/mailer/Transport/NullTransportFactory.php',
    'Symfony\\Component\\Mailer\\Transport\\RoundRobinTransport' => $vendorDir . '/symfony/mailer/Transport/RoundRobinTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\SendmailTransport' => $vendorDir . '/symfony/mailer/Transport/SendmailTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\SendmailTransportFactory' => $vendorDir . '/symfony/mailer/Transport/SendmailTransportFactory.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Auth\\AuthenticatorInterface' => $vendorDir . '/symfony/mailer/Transport/Smtp/Auth/AuthenticatorInterface.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Auth\\CramMd5Authenticator' => $vendorDir . '/symfony/mailer/Transport/Smtp/Auth/CramMd5Authenticator.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Auth\\LoginAuthenticator' => $vendorDir . '/symfony/mailer/Transport/Smtp/Auth/LoginAuthenticator.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Auth\\PlainAuthenticator' => $vendorDir . '/symfony/mailer/Transport/Smtp/Auth/PlainAuthenticator.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Auth\\XOAuth2Authenticator' => $vendorDir . '/symfony/mailer/Transport/Smtp/Auth/XOAuth2Authenticator.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\EsmtpTransport' => $vendorDir . '/symfony/mailer/Transport/Smtp/EsmtpTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\EsmtpTransportFactory' => $vendorDir . '/symfony/mailer/Transport/Smtp/EsmtpTransportFactory.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\SmtpTransport' => $vendorDir . '/symfony/mailer/Transport/Smtp/SmtpTransport.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Stream\\AbstractStream' => $vendorDir . '/symfony/mailer/Transport/Smtp/Stream/AbstractStream.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Stream\\ProcessStream' => $vendorDir . '/symfony/mailer/Transport/Smtp/Stream/ProcessStream.php',
    'Symfony\\Component\\Mailer\\Transport\\Smtp\\Stream\\SocketStream' => $vendorDir . '/symfony/mailer/Transport/Smtp/Stream/SocketStream.php',
    'Symfony\\Component\\Mailer\\Transport\\TransportFactoryInterface' => $vendorDir . '/symfony/mailer/Transport/TransportFactoryInterface.php',
    'Symfony\\Component\\Mailer\\Transport\\TransportInterface' => $vendorDir . '/symfony/mailer/Transport/TransportInterface.php',
    'Symfony\\Component\\Mailer\\Transport\\Transports' => $vendorDir . '/symfony/mailer/Transport/Transports.php',
    'Symfony\\Component\\Mime\\Address' => $vendorDir . '/symfony/mime/Address.php',
    'Symfony\\Component\\Mime\\BodyRendererInterface' => $vendorDir . '/symfony/mime/BodyRendererInterface.php',
    'Symfony\\Component\\Mime\\CharacterStream' => $vendorDir . '/symfony/mime/CharacterStream.php',
    'Symfony\\Component\\Mime\\Crypto\\DkimOptions' => $vendorDir . '/symfony/mime/Crypto/DkimOptions.php',
    'Symfony\\Component\\Mime\\Crypto\\DkimSigner' => $vendorDir . '/symfony/mime/Crypto/DkimSigner.php',
    'Symfony\\Component\\Mime\\Crypto\\SMime' => $vendorDir . '/symfony/mime/Crypto/SMime.php',
    'Symfony\\Component\\Mime\\Crypto\\SMimeEncrypter' => $vendorDir . '/symfony/mime/Crypto/SMimeEncrypter.php',
    'Symfony\\Component\\Mime\\Crypto\\SMimeSigner' => $vendorDir . '/symfony/mime/Crypto/SMimeSigner.php',
    'Symfony\\Component\\Mime\\DependencyInjection\\AddMimeTypeGuesserPass' => $vendorDir . '/symfony/mime/DependencyInjection/AddMimeTypeGuesserPass.php',
    'Symfony\\Component\\Mime\\DraftEmail' => $vendorDir . '/symfony/mime/DraftEmail.php',
    'Symfony\\Component\\Mime\\Email' => $vendorDir . '/symfony/mime/Email.php',
    'Symfony\\Component\\Mime\\Encoder\\AddressEncoderInterface' => $vendorDir . '/symfony/mime/Encoder/AddressEncoderInterface.php',
    'Symfony\\Component\\Mime\\Encoder\\Base64ContentEncoder' => $vendorDir . '/symfony/mime/Encoder/Base64ContentEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\Base64Encoder' => $vendorDir . '/symfony/mime/Encoder/Base64Encoder.php',
    'Symfony\\Component\\Mime\\Encoder\\Base64MimeHeaderEncoder' => $vendorDir . '/symfony/mime/Encoder/Base64MimeHeaderEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\ContentEncoderInterface' => $vendorDir . '/symfony/mime/Encoder/ContentEncoderInterface.php',
    'Symfony\\Component\\Mime\\Encoder\\EightBitContentEncoder' => $vendorDir . '/symfony/mime/Encoder/EightBitContentEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\EncoderInterface' => $vendorDir . '/symfony/mime/Encoder/EncoderInterface.php',
    'Symfony\\Component\\Mime\\Encoder\\IdnAddressEncoder' => $vendorDir . '/symfony/mime/Encoder/IdnAddressEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\MimeHeaderEncoderInterface' => $vendorDir . '/symfony/mime/Encoder/MimeHeaderEncoderInterface.php',
    'Symfony\\Component\\Mime\\Encoder\\QpContentEncoder' => $vendorDir . '/symfony/mime/Encoder/QpContentEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\QpEncoder' => $vendorDir . '/symfony/mime/Encoder/QpEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\QpMimeHeaderEncoder' => $vendorDir . '/symfony/mime/Encoder/QpMimeHeaderEncoder.php',
    'Symfony\\Component\\Mime\\Encoder\\Rfc2231Encoder' => $vendorDir . '/symfony/mime/Encoder/Rfc2231Encoder.php',
    'Symfony\\Component\\Mime\\Exception\\AddressEncoderException' => $vendorDir . '/symfony/mime/Exception/AddressEncoderException.php',
    'Symfony\\Component\\Mime\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/mime/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Mime\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/mime/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Mime\\Exception\\LogicException' => $vendorDir . '/symfony/mime/Exception/LogicException.php',
    'Symfony\\Component\\Mime\\Exception\\RfcComplianceException' => $vendorDir . '/symfony/mime/Exception/RfcComplianceException.php',
    'Symfony\\Component\\Mime\\Exception\\RuntimeException' => $vendorDir . '/symfony/mime/Exception/RuntimeException.php',
    'Symfony\\Component\\Mime\\FileBinaryMimeTypeGuesser' => $vendorDir . '/symfony/mime/FileBinaryMimeTypeGuesser.php',
    'Symfony\\Component\\Mime\\FileinfoMimeTypeGuesser' => $vendorDir . '/symfony/mime/FileinfoMimeTypeGuesser.php',
    'Symfony\\Component\\Mime\\Header\\AbstractHeader' => $vendorDir . '/symfony/mime/Header/AbstractHeader.php',
    'Symfony\\Component\\Mime\\Header\\DateHeader' => $vendorDir . '/symfony/mime/Header/DateHeader.php',
    'Symfony\\Component\\Mime\\Header\\HeaderInterface' => $vendorDir . '/symfony/mime/Header/HeaderInterface.php',
    'Symfony\\Component\\Mime\\Header\\Headers' => $vendorDir . '/symfony/mime/Header/Headers.php',
    'Symfony\\Component\\Mime\\Header\\IdentificationHeader' => $vendorDir . '/symfony/mime/Header/IdentificationHeader.php',
    'Symfony\\Component\\Mime\\Header\\MailboxHeader' => $vendorDir . '/symfony/mime/Header/MailboxHeader.php',
    'Symfony\\Component\\Mime\\Header\\MailboxListHeader' => $vendorDir . '/symfony/mime/Header/MailboxListHeader.php',
    'Symfony\\Component\\Mime\\Header\\ParameterizedHeader' => $vendorDir . '/symfony/mime/Header/ParameterizedHeader.php',
    'Symfony\\Component\\Mime\\Header\\PathHeader' => $vendorDir . '/symfony/mime/Header/PathHeader.php',
    'Symfony\\Component\\Mime\\Header\\UnstructuredHeader' => $vendorDir . '/symfony/mime/Header/UnstructuredHeader.php',
    'Symfony\\Component\\Mime\\HtmlToTextConverter\\DefaultHtmlToTextConverter' => $vendorDir . '/symfony/mime/HtmlToTextConverter/DefaultHtmlToTextConverter.php',
    'Symfony\\Component\\Mime\\HtmlToTextConverter\\HtmlToTextConverterInterface' => $vendorDir . '/symfony/mime/HtmlToTextConverter/HtmlToTextConverterInterface.php',
    'Symfony\\Component\\Mime\\HtmlToTextConverter\\LeagueHtmlToMarkdownConverter' => $vendorDir . '/symfony/mime/HtmlToTextConverter/LeagueHtmlToMarkdownConverter.php',
    'Symfony\\Component\\Mime\\Message' => $vendorDir . '/symfony/mime/Message.php',
    'Symfony\\Component\\Mime\\MessageConverter' => $vendorDir . '/symfony/mime/MessageConverter.php',
    'Symfony\\Component\\Mime\\MimeTypeGuesserInterface' => $vendorDir . '/symfony/mime/MimeTypeGuesserInterface.php',
    'Symfony\\Component\\Mime\\MimeTypes' => $vendorDir . '/symfony/mime/MimeTypes.php',
    'Symfony\\Component\\Mime\\MimeTypesInterface' => $vendorDir . '/symfony/mime/MimeTypesInterface.php',
    'Symfony\\Component\\Mime\\Part\\AbstractMultipartPart' => $vendorDir . '/symfony/mime/Part/AbstractMultipartPart.php',
    'Symfony\\Component\\Mime\\Part\\AbstractPart' => $vendorDir . '/symfony/mime/Part/AbstractPart.php',
    'Symfony\\Component\\Mime\\Part\\DataPart' => $vendorDir . '/symfony/mime/Part/DataPart.php',
    'Symfony\\Component\\Mime\\Part\\File' => $vendorDir . '/symfony/mime/Part/File.php',
    'Symfony\\Component\\Mime\\Part\\MessagePart' => $vendorDir . '/symfony/mime/Part/MessagePart.php',
    'Symfony\\Component\\Mime\\Part\\Multipart\\AlternativePart' => $vendorDir . '/symfony/mime/Part/Multipart/AlternativePart.php',
    'Symfony\\Component\\Mime\\Part\\Multipart\\DigestPart' => $vendorDir . '/symfony/mime/Part/Multipart/DigestPart.php',
    'Symfony\\Component\\Mime\\Part\\Multipart\\FormDataPart' => $vendorDir . '/symfony/mime/Part/Multipart/FormDataPart.php',
    'Symfony\\Component\\Mime\\Part\\Multipart\\MixedPart' => $vendorDir . '/symfony/mime/Part/Multipart/MixedPart.php',
    'Symfony\\Component\\Mime\\Part\\Multipart\\RelatedPart' => $vendorDir . '/symfony/mime/Part/Multipart/RelatedPart.php',
    'Symfony\\Component\\Mime\\Part\\SMimePart' => $vendorDir . '/symfony/mime/Part/SMimePart.php',
    'Symfony\\Component\\Mime\\Part\\TextPart' => $vendorDir . '/symfony/mime/Part/TextPart.php',
    'Symfony\\Component\\Mime\\RawMessage' => $vendorDir . '/symfony/mime/RawMessage.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailAddressContains' => $vendorDir . '/symfony/mime/Test/Constraint/EmailAddressContains.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailAttachmentCount' => $vendorDir . '/symfony/mime/Test/Constraint/EmailAttachmentCount.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailHasHeader' => $vendorDir . '/symfony/mime/Test/Constraint/EmailHasHeader.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailHeaderSame' => $vendorDir . '/symfony/mime/Test/Constraint/EmailHeaderSame.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailHtmlBodyContains' => $vendorDir . '/symfony/mime/Test/Constraint/EmailHtmlBodyContains.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailSubjectContains' => $vendorDir . '/symfony/mime/Test/Constraint/EmailSubjectContains.php',
    'Symfony\\Component\\Mime\\Test\\Constraint\\EmailTextBodyContains' => $vendorDir . '/symfony/mime/Test/Constraint/EmailTextBodyContains.php',
    'Symfony\\Component\\Process\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/process/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Process\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/process/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Process\\Exception\\LogicException' => $vendorDir . '/symfony/process/Exception/LogicException.php',
    'Symfony\\Component\\Process\\Exception\\ProcessFailedException' => $vendorDir . '/symfony/process/Exception/ProcessFailedException.php',
    'Symfony\\Component\\Process\\Exception\\ProcessSignaledException' => $vendorDir . '/symfony/process/Exception/ProcessSignaledException.php',
    'Symfony\\Component\\Process\\Exception\\ProcessStartFailedException' => $vendorDir . '/symfony/process/Exception/ProcessStartFailedException.php',
    'Symfony\\Component\\Process\\Exception\\ProcessTimedOutException' => $vendorDir . '/symfony/process/Exception/ProcessTimedOutException.php',
    'Symfony\\Component\\Process\\Exception\\RunProcessFailedException' => $vendorDir . '/symfony/process/Exception/RunProcessFailedException.php',
    'Symfony\\Component\\Process\\Exception\\RuntimeException' => $vendorDir . '/symfony/process/Exception/RuntimeException.php',
    'Symfony\\Component\\Process\\ExecutableFinder' => $vendorDir . '/symfony/process/ExecutableFinder.php',
    'Symfony\\Component\\Process\\InputStream' => $vendorDir . '/symfony/process/InputStream.php',
    'Symfony\\Component\\Process\\Messenger\\RunProcessContext' => $vendorDir . '/symfony/process/Messenger/RunProcessContext.php',
    'Symfony\\Component\\Process\\Messenger\\RunProcessMessage' => $vendorDir . '/symfony/process/Messenger/RunProcessMessage.php',
    'Symfony\\Component\\Process\\Messenger\\RunProcessMessageHandler' => $vendorDir . '/symfony/process/Messenger/RunProcessMessageHandler.php',
    'Symfony\\Component\\Process\\PhpExecutableFinder' => $vendorDir . '/symfony/process/PhpExecutableFinder.php',
    'Symfony\\Component\\Process\\PhpProcess' => $vendorDir . '/symfony/process/PhpProcess.php',
    'Symfony\\Component\\Process\\PhpSubprocess' => $vendorDir . '/symfony/process/PhpSubprocess.php',
    'Symfony\\Component\\Process\\Pipes\\AbstractPipes' => $vendorDir . '/symfony/process/Pipes/AbstractPipes.php',
    'Symfony\\Component\\Process\\Pipes\\PipesInterface' => $vendorDir . '/symfony/process/Pipes/PipesInterface.php',
    'Symfony\\Component\\Process\\Pipes\\UnixPipes' => $vendorDir . '/symfony/process/Pipes/UnixPipes.php',
    'Symfony\\Component\\Process\\Pipes\\WindowsPipes' => $vendorDir . '/symfony/process/Pipes/WindowsPipes.php',
    'Symfony\\Component\\Process\\Process' => $vendorDir . '/symfony/process/Process.php',
    'Symfony\\Component\\Process\\ProcessUtils' => $vendorDir . '/symfony/process/ProcessUtils.php',
    'Symfony\\Component\\Routing\\Alias' => $vendorDir . '/symfony/routing/Alias.php',
    'Symfony\\Component\\Routing\\Annotation\\Route' => $vendorDir . '/symfony/routing/Annotation/Route.php',
    'Symfony\\Component\\Routing\\Attribute\\Route' => $vendorDir . '/symfony/routing/Attribute/Route.php',
    'Symfony\\Component\\Routing\\CompiledRoute' => $vendorDir . '/symfony/routing/CompiledRoute.php',
    'Symfony\\Component\\Routing\\DependencyInjection\\AddExpressionLanguageProvidersPass' => $vendorDir . '/symfony/routing/DependencyInjection/AddExpressionLanguageProvidersPass.php',
    'Symfony\\Component\\Routing\\DependencyInjection\\RoutingResolverPass' => $vendorDir . '/symfony/routing/DependencyInjection/RoutingResolverPass.php',
    'Symfony\\Component\\Routing\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/routing/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Routing\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/routing/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Routing\\Exception\\InvalidParameterException' => $vendorDir . '/symfony/routing/Exception/InvalidParameterException.php',
    'Symfony\\Component\\Routing\\Exception\\LogicException' => $vendorDir . '/symfony/routing/Exception/LogicException.php',
    'Symfony\\Component\\Routing\\Exception\\MethodNotAllowedException' => $vendorDir . '/symfony/routing/Exception/MethodNotAllowedException.php',
    'Symfony\\Component\\Routing\\Exception\\MissingMandatoryParametersException' => $vendorDir . '/symfony/routing/Exception/MissingMandatoryParametersException.php',
    'Symfony\\Component\\Routing\\Exception\\NoConfigurationException' => $vendorDir . '/symfony/routing/Exception/NoConfigurationException.php',
    'Symfony\\Component\\Routing\\Exception\\ResourceNotFoundException' => $vendorDir . '/symfony/routing/Exception/ResourceNotFoundException.php',
    'Symfony\\Component\\Routing\\Exception\\RouteCircularReferenceException' => $vendorDir . '/symfony/routing/Exception/RouteCircularReferenceException.php',
    'Symfony\\Component\\Routing\\Exception\\RouteNotFoundException' => $vendorDir . '/symfony/routing/Exception/RouteNotFoundException.php',
    'Symfony\\Component\\Routing\\Exception\\RuntimeException' => $vendorDir . '/symfony/routing/Exception/RuntimeException.php',
    'Symfony\\Component\\Routing\\Generator\\CompiledUrlGenerator' => $vendorDir . '/symfony/routing/Generator/CompiledUrlGenerator.php',
    'Symfony\\Component\\Routing\\Generator\\ConfigurableRequirementsInterface' => $vendorDir . '/symfony/routing/Generator/ConfigurableRequirementsInterface.php',
    'Symfony\\Component\\Routing\\Generator\\Dumper\\CompiledUrlGeneratorDumper' => $vendorDir . '/symfony/routing/Generator/Dumper/CompiledUrlGeneratorDumper.php',
    'Symfony\\Component\\Routing\\Generator\\Dumper\\GeneratorDumper' => $vendorDir . '/symfony/routing/Generator/Dumper/GeneratorDumper.php',
    'Symfony\\Component\\Routing\\Generator\\Dumper\\GeneratorDumperInterface' => $vendorDir . '/symfony/routing/Generator/Dumper/GeneratorDumperInterface.php',
    'Symfony\\Component\\Routing\\Generator\\UrlGenerator' => $vendorDir . '/symfony/routing/Generator/UrlGenerator.php',
    'Symfony\\Component\\Routing\\Generator\\UrlGeneratorInterface' => $vendorDir . '/symfony/routing/Generator/UrlGeneratorInterface.php',
    'Symfony\\Component\\Routing\\Loader\\AttributeClassLoader' => $vendorDir . '/symfony/routing/Loader/AttributeClassLoader.php',
    'Symfony\\Component\\Routing\\Loader\\AttributeDirectoryLoader' => $vendorDir . '/symfony/routing/Loader/AttributeDirectoryLoader.php',
    'Symfony\\Component\\Routing\\Loader\\AttributeFileLoader' => $vendorDir . '/symfony/routing/Loader/AttributeFileLoader.php',
    'Symfony\\Component\\Routing\\Loader\\ClosureLoader' => $vendorDir . '/symfony/routing/Loader/ClosureLoader.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\AliasConfigurator' => $vendorDir . '/symfony/routing/Loader/Configurator/AliasConfigurator.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\CollectionConfigurator' => $vendorDir . '/symfony/routing/Loader/Configurator/CollectionConfigurator.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\ImportConfigurator' => $vendorDir . '/symfony/routing/Loader/Configurator/ImportConfigurator.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\RouteConfigurator' => $vendorDir . '/symfony/routing/Loader/Configurator/RouteConfigurator.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\RoutingConfigurator' => $vendorDir . '/symfony/routing/Loader/Configurator/RoutingConfigurator.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\AddTrait' => $vendorDir . '/symfony/routing/Loader/Configurator/Traits/AddTrait.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\HostTrait' => $vendorDir . '/symfony/routing/Loader/Configurator/Traits/HostTrait.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\LocalizedRouteTrait' => $vendorDir . '/symfony/routing/Loader/Configurator/Traits/LocalizedRouteTrait.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\PrefixTrait' => $vendorDir . '/symfony/routing/Loader/Configurator/Traits/PrefixTrait.php',
    'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\RouteTrait' => $vendorDir . '/symfony/routing/Loader/Configurator/Traits/RouteTrait.php',
    'Symfony\\Component\\Routing\\Loader\\ContainerLoader' => $vendorDir . '/symfony/routing/Loader/ContainerLoader.php',
    'Symfony\\Component\\Routing\\Loader\\DirectoryLoader' => $vendorDir . '/symfony/routing/Loader/DirectoryLoader.php',
    'Symfony\\Component\\Routing\\Loader\\GlobFileLoader' => $vendorDir . '/symfony/routing/Loader/GlobFileLoader.php',
    'Symfony\\Component\\Routing\\Loader\\ObjectLoader' => $vendorDir . '/symfony/routing/Loader/ObjectLoader.php',
    'Symfony\\Component\\Routing\\Loader\\PhpFileLoader' => $vendorDir . '/symfony/routing/Loader/PhpFileLoader.php',
    'Symfony\\Component\\Routing\\Loader\\Psr4DirectoryLoader' => $vendorDir . '/symfony/routing/Loader/Psr4DirectoryLoader.php',
    'Symfony\\Component\\Routing\\Loader\\XmlFileLoader' => $vendorDir . '/symfony/routing/Loader/XmlFileLoader.php',
    'Symfony\\Component\\Routing\\Loader\\YamlFileLoader' => $vendorDir . '/symfony/routing/Loader/YamlFileLoader.php',
    'Symfony\\Component\\Routing\\Matcher\\CompiledUrlMatcher' => $vendorDir . '/symfony/routing/Matcher/CompiledUrlMatcher.php',
    'Symfony\\Component\\Routing\\Matcher\\Dumper\\CompiledUrlMatcherDumper' => $vendorDir . '/symfony/routing/Matcher/Dumper/CompiledUrlMatcherDumper.php',
    'Symfony\\Component\\Routing\\Matcher\\Dumper\\CompiledUrlMatcherTrait' => $vendorDir . '/symfony/routing/Matcher/Dumper/CompiledUrlMatcherTrait.php',
    'Symfony\\Component\\Routing\\Matcher\\Dumper\\MatcherDumper' => $vendorDir . '/symfony/routing/Matcher/Dumper/MatcherDumper.php',
    'Symfony\\Component\\Routing\\Matcher\\Dumper\\MatcherDumperInterface' => $vendorDir . '/symfony/routing/Matcher/Dumper/MatcherDumperInterface.php',
    'Symfony\\Component\\Routing\\Matcher\\Dumper\\StaticPrefixCollection' => $vendorDir . '/symfony/routing/Matcher/Dumper/StaticPrefixCollection.php',
    'Symfony\\Component\\Routing\\Matcher\\ExpressionLanguageProvider' => $vendorDir . '/symfony/routing/Matcher/ExpressionLanguageProvider.php',
    'Symfony\\Component\\Routing\\Matcher\\RedirectableUrlMatcher' => $vendorDir . '/symfony/routing/Matcher/RedirectableUrlMatcher.php',
    'Symfony\\Component\\Routing\\Matcher\\RedirectableUrlMatcherInterface' => $vendorDir . '/symfony/routing/Matcher/RedirectableUrlMatcherInterface.php',
    'Symfony\\Component\\Routing\\Matcher\\RequestMatcherInterface' => $vendorDir . '/symfony/routing/Matcher/RequestMatcherInterface.php',
    'Symfony\\Component\\Routing\\Matcher\\TraceableUrlMatcher' => $vendorDir . '/symfony/routing/Matcher/TraceableUrlMatcher.php',
    'Symfony\\Component\\Routing\\Matcher\\UrlMatcher' => $vendorDir . '/symfony/routing/Matcher/UrlMatcher.php',
    'Symfony\\Component\\Routing\\Matcher\\UrlMatcherInterface' => $vendorDir . '/symfony/routing/Matcher/UrlMatcherInterface.php',
    'Symfony\\Component\\Routing\\RequestContext' => $vendorDir . '/symfony/routing/RequestContext.php',
    'Symfony\\Component\\Routing\\RequestContextAwareInterface' => $vendorDir . '/symfony/routing/RequestContextAwareInterface.php',
    'Symfony\\Component\\Routing\\Requirement\\EnumRequirement' => $vendorDir . '/symfony/routing/Requirement/EnumRequirement.php',
    'Symfony\\Component\\Routing\\Requirement\\Requirement' => $vendorDir . '/symfony/routing/Requirement/Requirement.php',
    'Symfony\\Component\\Routing\\Route' => $vendorDir . '/symfony/routing/Route.php',
    'Symfony\\Component\\Routing\\RouteCollection' => $vendorDir . '/symfony/routing/RouteCollection.php',
    'Symfony\\Component\\Routing\\RouteCompiler' => $vendorDir . '/symfony/routing/RouteCompiler.php',
    'Symfony\\Component\\Routing\\RouteCompilerInterface' => $vendorDir . '/symfony/routing/RouteCompilerInterface.php',
    'Symfony\\Component\\Routing\\Router' => $vendorDir . '/symfony/routing/Router.php',
    'Symfony\\Component\\Routing\\RouterInterface' => $vendorDir . '/symfony/routing/RouterInterface.php',
    'Symfony\\Component\\String\\AbstractString' => $vendorDir . '/symfony/string/AbstractString.php',
    'Symfony\\Component\\String\\AbstractUnicodeString' => $vendorDir . '/symfony/string/AbstractUnicodeString.php',
    'Symfony\\Component\\String\\ByteString' => $vendorDir . '/symfony/string/ByteString.php',
    'Symfony\\Component\\String\\CodePointString' => $vendorDir . '/symfony/string/CodePointString.php',
    'Symfony\\Component\\String\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/string/Exception/ExceptionInterface.php',
    'Symfony\\Component\\String\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/string/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\String\\Exception\\RuntimeException' => $vendorDir . '/symfony/string/Exception/RuntimeException.php',
    'Symfony\\Component\\String\\Inflector\\EnglishInflector' => $vendorDir . '/symfony/string/Inflector/EnglishInflector.php',
    'Symfony\\Component\\String\\Inflector\\FrenchInflector' => $vendorDir . '/symfony/string/Inflector/FrenchInflector.php',
    'Symfony\\Component\\String\\Inflector\\InflectorInterface' => $vendorDir . '/symfony/string/Inflector/InflectorInterface.php',
    'Symfony\\Component\\String\\LazyString' => $vendorDir . '/symfony/string/LazyString.php',
    'Symfony\\Component\\String\\Slugger\\AsciiSlugger' => $vendorDir . '/symfony/string/Slugger/AsciiSlugger.php',
    'Symfony\\Component\\String\\Slugger\\SluggerInterface' => $vendorDir . '/symfony/string/Slugger/SluggerInterface.php',
    'Symfony\\Component\\String\\UnicodeString' => $vendorDir . '/symfony/string/UnicodeString.php',
    'Symfony\\Component\\Translation\\CatalogueMetadataAwareInterface' => $vendorDir . '/symfony/translation/CatalogueMetadataAwareInterface.php',
    'Symfony\\Component\\Translation\\Catalogue\\AbstractOperation' => $vendorDir . '/symfony/translation/Catalogue/AbstractOperation.php',
    'Symfony\\Component\\Translation\\Catalogue\\MergeOperation' => $vendorDir . '/symfony/translation/Catalogue/MergeOperation.php',
    'Symfony\\Component\\Translation\\Catalogue\\OperationInterface' => $vendorDir . '/symfony/translation/Catalogue/OperationInterface.php',
    'Symfony\\Component\\Translation\\Catalogue\\TargetOperation' => $vendorDir . '/symfony/translation/Catalogue/TargetOperation.php',
    'Symfony\\Component\\Translation\\Command\\TranslationPullCommand' => $vendorDir . '/symfony/translation/Command/TranslationPullCommand.php',
    'Symfony\\Component\\Translation\\Command\\TranslationPushCommand' => $vendorDir . '/symfony/translation/Command/TranslationPushCommand.php',
    'Symfony\\Component\\Translation\\Command\\TranslationTrait' => $vendorDir . '/symfony/translation/Command/TranslationTrait.php',
    'Symfony\\Component\\Translation\\Command\\XliffLintCommand' => $vendorDir . '/symfony/translation/Command/XliffLintCommand.php',
    'Symfony\\Component\\Translation\\DataCollectorTranslator' => $vendorDir . '/symfony/translation/DataCollectorTranslator.php',
    'Symfony\\Component\\Translation\\DataCollector\\TranslationDataCollector' => $vendorDir . '/symfony/translation/DataCollector/TranslationDataCollector.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\DataCollectorTranslatorPass' => $vendorDir . '/symfony/translation/DependencyInjection/DataCollectorTranslatorPass.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\LoggingTranslatorPass' => $vendorDir . '/symfony/translation/DependencyInjection/LoggingTranslatorPass.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\TranslationDumperPass' => $vendorDir . '/symfony/translation/DependencyInjection/TranslationDumperPass.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\TranslationExtractorPass' => $vendorDir . '/symfony/translation/DependencyInjection/TranslationExtractorPass.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\TranslatorPass' => $vendorDir . '/symfony/translation/DependencyInjection/TranslatorPass.php',
    'Symfony\\Component\\Translation\\DependencyInjection\\TranslatorPathsPass' => $vendorDir . '/symfony/translation/DependencyInjection/TranslatorPathsPass.php',
    'Symfony\\Component\\Translation\\Dumper\\CsvFileDumper' => $vendorDir . '/symfony/translation/Dumper/CsvFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\DumperInterface' => $vendorDir . '/symfony/translation/Dumper/DumperInterface.php',
    'Symfony\\Component\\Translation\\Dumper\\FileDumper' => $vendorDir . '/symfony/translation/Dumper/FileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\IcuResFileDumper' => $vendorDir . '/symfony/translation/Dumper/IcuResFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\IniFileDumper' => $vendorDir . '/symfony/translation/Dumper/IniFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\JsonFileDumper' => $vendorDir . '/symfony/translation/Dumper/JsonFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\MoFileDumper' => $vendorDir . '/symfony/translation/Dumper/MoFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\PhpFileDumper' => $vendorDir . '/symfony/translation/Dumper/PhpFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\PoFileDumper' => $vendorDir . '/symfony/translation/Dumper/PoFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\QtFileDumper' => $vendorDir . '/symfony/translation/Dumper/QtFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\XliffFileDumper' => $vendorDir . '/symfony/translation/Dumper/XliffFileDumper.php',
    'Symfony\\Component\\Translation\\Dumper\\YamlFileDumper' => $vendorDir . '/symfony/translation/Dumper/YamlFileDumper.php',
    'Symfony\\Component\\Translation\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/translation/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Translation\\Exception\\IncompleteDsnException' => $vendorDir . '/symfony/translation/Exception/IncompleteDsnException.php',
    'Symfony\\Component\\Translation\\Exception\\InvalidArgumentException' => $vendorDir . '/symfony/translation/Exception/InvalidArgumentException.php',
    'Symfony\\Component\\Translation\\Exception\\InvalidResourceException' => $vendorDir . '/symfony/translation/Exception/InvalidResourceException.php',
    'Symfony\\Component\\Translation\\Exception\\LogicException' => $vendorDir . '/symfony/translation/Exception/LogicException.php',
    'Symfony\\Component\\Translation\\Exception\\MissingRequiredOptionException' => $vendorDir . '/symfony/translation/Exception/MissingRequiredOptionException.php',
    'Symfony\\Component\\Translation\\Exception\\NotFoundResourceException' => $vendorDir . '/symfony/translation/Exception/NotFoundResourceException.php',
    'Symfony\\Component\\Translation\\Exception\\ProviderException' => $vendorDir . '/symfony/translation/Exception/ProviderException.php',
    'Symfony\\Component\\Translation\\Exception\\ProviderExceptionInterface' => $vendorDir . '/symfony/translation/Exception/ProviderExceptionInterface.php',
    'Symfony\\Component\\Translation\\Exception\\RuntimeException' => $vendorDir . '/symfony/translation/Exception/RuntimeException.php',
    'Symfony\\Component\\Translation\\Exception\\UnsupportedSchemeException' => $vendorDir . '/symfony/translation/Exception/UnsupportedSchemeException.php',
    'Symfony\\Component\\Translation\\Extractor\\AbstractFileExtractor' => $vendorDir . '/symfony/translation/Extractor/AbstractFileExtractor.php',
    'Symfony\\Component\\Translation\\Extractor\\ChainExtractor' => $vendorDir . '/symfony/translation/Extractor/ChainExtractor.php',
    'Symfony\\Component\\Translation\\Extractor\\ExtractorInterface' => $vendorDir . '/symfony/translation/Extractor/ExtractorInterface.php',
    'Symfony\\Component\\Translation\\Extractor\\PhpAstExtractor' => $vendorDir . '/symfony/translation/Extractor/PhpAstExtractor.php',
    'Symfony\\Component\\Translation\\Extractor\\Visitor\\AbstractVisitor' => $vendorDir . '/symfony/translation/Extractor/Visitor/AbstractVisitor.php',
    'Symfony\\Component\\Translation\\Extractor\\Visitor\\ConstraintVisitor' => $vendorDir . '/symfony/translation/Extractor/Visitor/ConstraintVisitor.php',
    'Symfony\\Component\\Translation\\Extractor\\Visitor\\TransMethodVisitor' => $vendorDir . '/symfony/translation/Extractor/Visitor/TransMethodVisitor.php',
    'Symfony\\Component\\Translation\\Extractor\\Visitor\\TranslatableMessageVisitor' => $vendorDir . '/symfony/translation/Extractor/Visitor/TranslatableMessageVisitor.php',
    'Symfony\\Component\\Translation\\Formatter\\IntlFormatter' => $vendorDir . '/symfony/translation/Formatter/IntlFormatter.php',
    'Symfony\\Component\\Translation\\Formatter\\IntlFormatterInterface' => $vendorDir . '/symfony/translation/Formatter/IntlFormatterInterface.php',
    'Symfony\\Component\\Translation\\Formatter\\MessageFormatter' => $vendorDir . '/symfony/translation/Formatter/MessageFormatter.php',
    'Symfony\\Component\\Translation\\Formatter\\MessageFormatterInterface' => $vendorDir . '/symfony/translation/Formatter/MessageFormatterInterface.php',
    'Symfony\\Component\\Translation\\IdentityTranslator' => $vendorDir . '/symfony/translation/IdentityTranslator.php',
    'Symfony\\Component\\Translation\\Loader\\ArrayLoader' => $vendorDir . '/symfony/translation/Loader/ArrayLoader.php',
    'Symfony\\Component\\Translation\\Loader\\CsvFileLoader' => $vendorDir . '/symfony/translation/Loader/CsvFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\FileLoader' => $vendorDir . '/symfony/translation/Loader/FileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\IcuDatFileLoader' => $vendorDir . '/symfony/translation/Loader/IcuDatFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\IcuResFileLoader' => $vendorDir . '/symfony/translation/Loader/IcuResFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\IniFileLoader' => $vendorDir . '/symfony/translation/Loader/IniFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\JsonFileLoader' => $vendorDir . '/symfony/translation/Loader/JsonFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\LoaderInterface' => $vendorDir . '/symfony/translation/Loader/LoaderInterface.php',
    'Symfony\\Component\\Translation\\Loader\\MoFileLoader' => $vendorDir . '/symfony/translation/Loader/MoFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\PhpFileLoader' => $vendorDir . '/symfony/translation/Loader/PhpFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\PoFileLoader' => $vendorDir . '/symfony/translation/Loader/PoFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\QtFileLoader' => $vendorDir . '/symfony/translation/Loader/QtFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\XliffFileLoader' => $vendorDir . '/symfony/translation/Loader/XliffFileLoader.php',
    'Symfony\\Component\\Translation\\Loader\\YamlFileLoader' => $vendorDir . '/symfony/translation/Loader/YamlFileLoader.php',
    'Symfony\\Component\\Translation\\LocaleSwitcher' => $vendorDir . '/symfony/translation/LocaleSwitcher.php',
    'Symfony\\Component\\Translation\\LoggingTranslator' => $vendorDir . '/symfony/translation/LoggingTranslator.php',
    'Symfony\\Component\\Translation\\MessageCatalogue' => $vendorDir . '/symfony/translation/MessageCatalogue.php',
    'Symfony\\Component\\Translation\\MessageCatalogueInterface' => $vendorDir . '/symfony/translation/MessageCatalogueInterface.php',
    'Symfony\\Component\\Translation\\MetadataAwareInterface' => $vendorDir . '/symfony/translation/MetadataAwareInterface.php',
    'Symfony\\Component\\Translation\\Provider\\AbstractProviderFactory' => $vendorDir . '/symfony/translation/Provider/AbstractProviderFactory.php',
    'Symfony\\Component\\Translation\\Provider\\Dsn' => $vendorDir . '/symfony/translation/Provider/Dsn.php',
    'Symfony\\Component\\Translation\\Provider\\FilteringProvider' => $vendorDir . '/symfony/translation/Provider/FilteringProvider.php',
    'Symfony\\Component\\Translation\\Provider\\NullProvider' => $vendorDir . '/symfony/translation/Provider/NullProvider.php',
    'Symfony\\Component\\Translation\\Provider\\NullProviderFactory' => $vendorDir . '/symfony/translation/Provider/NullProviderFactory.php',
    'Symfony\\Component\\Translation\\Provider\\ProviderFactoryInterface' => $vendorDir . '/symfony/translation/Provider/ProviderFactoryInterface.php',
    'Symfony\\Component\\Translation\\Provider\\ProviderInterface' => $vendorDir . '/symfony/translation/Provider/ProviderInterface.php',
    'Symfony\\Component\\Translation\\Provider\\TranslationProviderCollection' => $vendorDir . '/symfony/translation/Provider/TranslationProviderCollection.php',
    'Symfony\\Component\\Translation\\Provider\\TranslationProviderCollectionFactory' => $vendorDir . '/symfony/translation/Provider/TranslationProviderCollectionFactory.php',
    'Symfony\\Component\\Translation\\PseudoLocalizationTranslator' => $vendorDir . '/symfony/translation/PseudoLocalizationTranslator.php',
    'Symfony\\Component\\Translation\\Reader\\TranslationReader' => $vendorDir . '/symfony/translation/Reader/TranslationReader.php',
    'Symfony\\Component\\Translation\\Reader\\TranslationReaderInterface' => $vendorDir . '/symfony/translation/Reader/TranslationReaderInterface.php',
    'Symfony\\Component\\Translation\\Test\\ProviderFactoryTestCase' => $vendorDir . '/symfony/translation/Test/ProviderFactoryTestCase.php',
    'Symfony\\Component\\Translation\\Test\\ProviderTestCase' => $vendorDir . '/symfony/translation/Test/ProviderTestCase.php',
    'Symfony\\Component\\Translation\\TranslatableMessage' => $vendorDir . '/symfony/translation/TranslatableMessage.php',
    'Symfony\\Component\\Translation\\Translator' => $vendorDir . '/symfony/translation/Translator.php',
    'Symfony\\Component\\Translation\\TranslatorBag' => $vendorDir . '/symfony/translation/TranslatorBag.php',
    'Symfony\\Component\\Translation\\TranslatorBagInterface' => $vendorDir . '/symfony/translation/TranslatorBagInterface.php',
    'Symfony\\Component\\Translation\\Util\\ArrayConverter' => $vendorDir . '/symfony/translation/Util/ArrayConverter.php',
    'Symfony\\Component\\Translation\\Util\\XliffUtils' => $vendorDir . '/symfony/translation/Util/XliffUtils.php',
    'Symfony\\Component\\Translation\\Writer\\TranslationWriter' => $vendorDir . '/symfony/translation/Writer/TranslationWriter.php',
    'Symfony\\Component\\Translation\\Writer\\TranslationWriterInterface' => $vendorDir . '/symfony/translation/Writer/TranslationWriterInterface.php',
    'Symfony\\Component\\Uid\\AbstractUid' => $vendorDir . '/symfony/uid/AbstractUid.php',
    'Symfony\\Component\\Uid\\BinaryUtil' => $vendorDir . '/symfony/uid/BinaryUtil.php',
    'Symfony\\Component\\Uid\\Command\\GenerateUlidCommand' => $vendorDir . '/symfony/uid/Command/GenerateUlidCommand.php',
    'Symfony\\Component\\Uid\\Command\\GenerateUuidCommand' => $vendorDir . '/symfony/uid/Command/GenerateUuidCommand.php',
    'Symfony\\Component\\Uid\\Command\\InspectUlidCommand' => $vendorDir . '/symfony/uid/Command/InspectUlidCommand.php',
    'Symfony\\Component\\Uid\\Command\\InspectUuidCommand' => $vendorDir . '/symfony/uid/Command/InspectUuidCommand.php',
    'Symfony\\Component\\Uid\\Factory\\NameBasedUuidFactory' => $vendorDir . '/symfony/uid/Factory/NameBasedUuidFactory.php',
    'Symfony\\Component\\Uid\\Factory\\RandomBasedUuidFactory' => $vendorDir . '/symfony/uid/Factory/RandomBasedUuidFactory.php',
    'Symfony\\Component\\Uid\\Factory\\TimeBasedUuidFactory' => $vendorDir . '/symfony/uid/Factory/TimeBasedUuidFactory.php',
    'Symfony\\Component\\Uid\\Factory\\UlidFactory' => $vendorDir . '/symfony/uid/Factory/UlidFactory.php',
    'Symfony\\Component\\Uid\\Factory\\UuidFactory' => $vendorDir . '/symfony/uid/Factory/UuidFactory.php',
    'Symfony\\Component\\Uid\\MaxUlid' => $vendorDir . '/symfony/uid/MaxUlid.php',
    'Symfony\\Component\\Uid\\MaxUuid' => $vendorDir . '/symfony/uid/MaxUuid.php',
    'Symfony\\Component\\Uid\\NilUlid' => $vendorDir . '/symfony/uid/NilUlid.php',
    'Symfony\\Component\\Uid\\NilUuid' => $vendorDir . '/symfony/uid/NilUuid.php',
    'Symfony\\Component\\Uid\\TimeBasedUidInterface' => $vendorDir . '/symfony/uid/TimeBasedUidInterface.php',
    'Symfony\\Component\\Uid\\Ulid' => $vendorDir . '/symfony/uid/Ulid.php',
    'Symfony\\Component\\Uid\\Uuid' => $vendorDir . '/symfony/uid/Uuid.php',
    'Symfony\\Component\\Uid\\UuidV1' => $vendorDir . '/symfony/uid/UuidV1.php',
    'Symfony\\Component\\Uid\\UuidV3' => $vendorDir . '/symfony/uid/UuidV3.php',
    'Symfony\\Component\\Uid\\UuidV4' => $vendorDir . '/symfony/uid/UuidV4.php',
    'Symfony\\Component\\Uid\\UuidV5' => $vendorDir . '/symfony/uid/UuidV5.php',
    'Symfony\\Component\\Uid\\UuidV6' => $vendorDir . '/symfony/uid/UuidV6.php',
    'Symfony\\Component\\Uid\\UuidV7' => $vendorDir . '/symfony/uid/UuidV7.php',
    'Symfony\\Component\\Uid\\UuidV8' => $vendorDir . '/symfony/uid/UuidV8.php',
    'Symfony\\Component\\VarDumper\\Caster\\AmqpCaster' => $vendorDir . '/symfony/var-dumper/Caster/AmqpCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ArgsStub' => $vendorDir . '/symfony/var-dumper/Caster/ArgsStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\Caster' => $vendorDir . '/symfony/var-dumper/Caster/Caster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ClassStub' => $vendorDir . '/symfony/var-dumper/Caster/ClassStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\ConstStub' => $vendorDir . '/symfony/var-dumper/Caster/ConstStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\CutArrayStub' => $vendorDir . '/symfony/var-dumper/Caster/CutArrayStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\CutStub' => $vendorDir . '/symfony/var-dumper/Caster/CutStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\DOMCaster' => $vendorDir . '/symfony/var-dumper/Caster/DOMCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\DateCaster' => $vendorDir . '/symfony/var-dumper/Caster/DateCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\DoctrineCaster' => $vendorDir . '/symfony/var-dumper/Caster/DoctrineCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\DsCaster' => $vendorDir . '/symfony/var-dumper/Caster/DsCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\DsPairStub' => $vendorDir . '/symfony/var-dumper/Caster/DsPairStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\EnumStub' => $vendorDir . '/symfony/var-dumper/Caster/EnumStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\ExceptionCaster' => $vendorDir . '/symfony/var-dumper/Caster/ExceptionCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\FFICaster' => $vendorDir . '/symfony/var-dumper/Caster/FFICaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\FiberCaster' => $vendorDir . '/symfony/var-dumper/Caster/FiberCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\FrameStub' => $vendorDir . '/symfony/var-dumper/Caster/FrameStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\GmpCaster' => $vendorDir . '/symfony/var-dumper/Caster/GmpCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ImagineCaster' => $vendorDir . '/symfony/var-dumper/Caster/ImagineCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ImgStub' => $vendorDir . '/symfony/var-dumper/Caster/ImgStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\IntlCaster' => $vendorDir . '/symfony/var-dumper/Caster/IntlCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\LinkStub' => $vendorDir . '/symfony/var-dumper/Caster/LinkStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\MemcachedCaster' => $vendorDir . '/symfony/var-dumper/Caster/MemcachedCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\MysqliCaster' => $vendorDir . '/symfony/var-dumper/Caster/MysqliCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\PdoCaster' => $vendorDir . '/symfony/var-dumper/Caster/PdoCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\PgSqlCaster' => $vendorDir . '/symfony/var-dumper/Caster/PgSqlCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ProxyManagerCaster' => $vendorDir . '/symfony/var-dumper/Caster/ProxyManagerCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\RdKafkaCaster' => $vendorDir . '/symfony/var-dumper/Caster/RdKafkaCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\RedisCaster' => $vendorDir . '/symfony/var-dumper/Caster/RedisCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ReflectionCaster' => $vendorDir . '/symfony/var-dumper/Caster/ReflectionCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ResourceCaster' => $vendorDir . '/symfony/var-dumper/Caster/ResourceCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\ScalarStub' => $vendorDir . '/symfony/var-dumper/Caster/ScalarStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\SplCaster' => $vendorDir . '/symfony/var-dumper/Caster/SplCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\StubCaster' => $vendorDir . '/symfony/var-dumper/Caster/StubCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\SymfonyCaster' => $vendorDir . '/symfony/var-dumper/Caster/SymfonyCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\TraceStub' => $vendorDir . '/symfony/var-dumper/Caster/TraceStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\UninitializedStub' => $vendorDir . '/symfony/var-dumper/Caster/UninitializedStub.php',
    'Symfony\\Component\\VarDumper\\Caster\\UuidCaster' => $vendorDir . '/symfony/var-dumper/Caster/UuidCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\XmlReaderCaster' => $vendorDir . '/symfony/var-dumper/Caster/XmlReaderCaster.php',
    'Symfony\\Component\\VarDumper\\Caster\\XmlResourceCaster' => $vendorDir . '/symfony/var-dumper/Caster/XmlResourceCaster.php',
    'Symfony\\Component\\VarDumper\\Cloner\\AbstractCloner' => $vendorDir . '/symfony/var-dumper/Cloner/AbstractCloner.php',
    'Symfony\\Component\\VarDumper\\Cloner\\ClonerInterface' => $vendorDir . '/symfony/var-dumper/Cloner/ClonerInterface.php',
    'Symfony\\Component\\VarDumper\\Cloner\\Cursor' => $vendorDir . '/symfony/var-dumper/Cloner/Cursor.php',
    'Symfony\\Component\\VarDumper\\Cloner\\Data' => $vendorDir . '/symfony/var-dumper/Cloner/Data.php',
    'Symfony\\Component\\VarDumper\\Cloner\\DumperInterface' => $vendorDir . '/symfony/var-dumper/Cloner/DumperInterface.php',
    'Symfony\\Component\\VarDumper\\Cloner\\Internal\\NoDefault' => $vendorDir . '/symfony/var-dumper/Cloner/Internal/NoDefault.php',
    'Symfony\\Component\\VarDumper\\Cloner\\Stub' => $vendorDir . '/symfony/var-dumper/Cloner/Stub.php',
    'Symfony\\Component\\VarDumper\\Cloner\\VarCloner' => $vendorDir . '/symfony/var-dumper/Cloner/VarCloner.php',
    'Symfony\\Component\\VarDumper\\Command\\Descriptor\\CliDescriptor' => $vendorDir . '/symfony/var-dumper/Command/Descriptor/CliDescriptor.php',
    'Symfony\\Component\\VarDumper\\Command\\Descriptor\\DumpDescriptorInterface' => $vendorDir . '/symfony/var-dumper/Command/Descriptor/DumpDescriptorInterface.php',
    'Symfony\\Component\\VarDumper\\Command\\Descriptor\\HtmlDescriptor' => $vendorDir . '/symfony/var-dumper/Command/Descriptor/HtmlDescriptor.php',
    'Symfony\\Component\\VarDumper\\Command\\ServerDumpCommand' => $vendorDir . '/symfony/var-dumper/Command/ServerDumpCommand.php',
    'Symfony\\Component\\VarDumper\\Dumper\\AbstractDumper' => $vendorDir . '/symfony/var-dumper/Dumper/AbstractDumper.php',
    'Symfony\\Component\\VarDumper\\Dumper\\CliDumper' => $vendorDir . '/symfony/var-dumper/Dumper/CliDumper.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\CliContextProvider' => $vendorDir . '/symfony/var-dumper/Dumper/ContextProvider/CliContextProvider.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\ContextProviderInterface' => $vendorDir . '/symfony/var-dumper/Dumper/ContextProvider/ContextProviderInterface.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\RequestContextProvider' => $vendorDir . '/symfony/var-dumper/Dumper/ContextProvider/RequestContextProvider.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\SourceContextProvider' => $vendorDir . '/symfony/var-dumper/Dumper/ContextProvider/SourceContextProvider.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ContextualizedDumper' => $vendorDir . '/symfony/var-dumper/Dumper/ContextualizedDumper.php',
    'Symfony\\Component\\VarDumper\\Dumper\\DataDumperInterface' => $vendorDir . '/symfony/var-dumper/Dumper/DataDumperInterface.php',
    'Symfony\\Component\\VarDumper\\Dumper\\HtmlDumper' => $vendorDir . '/symfony/var-dumper/Dumper/HtmlDumper.php',
    'Symfony\\Component\\VarDumper\\Dumper\\ServerDumper' => $vendorDir . '/symfony/var-dumper/Dumper/ServerDumper.php',
    'Symfony\\Component\\VarDumper\\Exception\\ThrowingCasterException' => $vendorDir . '/symfony/var-dumper/Exception/ThrowingCasterException.php',
    'Symfony\\Component\\VarDumper\\Server\\Connection' => $vendorDir . '/symfony/var-dumper/Server/Connection.php',
    'Symfony\\Component\\VarDumper\\Server\\DumpServer' => $vendorDir . '/symfony/var-dumper/Server/DumpServer.php',
    'Symfony\\Component\\VarDumper\\Test\\VarDumperTestTrait' => $vendorDir . '/symfony/var-dumper/Test/VarDumperTestTrait.php',
    'Symfony\\Component\\VarDumper\\VarDumper' => $vendorDir . '/symfony/var-dumper/VarDumper.php',
    'Symfony\\Component\\Yaml\\Command\\LintCommand' => $vendorDir . '/symfony/yaml/Command/LintCommand.php',
    'Symfony\\Component\\Yaml\\Dumper' => $vendorDir . '/symfony/yaml/Dumper.php',
    'Symfony\\Component\\Yaml\\Escaper' => $vendorDir . '/symfony/yaml/Escaper.php',
    'Symfony\\Component\\Yaml\\Exception\\DumpException' => $vendorDir . '/symfony/yaml/Exception/DumpException.php',
    'Symfony\\Component\\Yaml\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/yaml/Exception/ExceptionInterface.php',
    'Symfony\\Component\\Yaml\\Exception\\ParseException' => $vendorDir . '/symfony/yaml/Exception/ParseException.php',
    'Symfony\\Component\\Yaml\\Exception\\RuntimeException' => $vendorDir . '/symfony/yaml/Exception/RuntimeException.php',
    'Symfony\\Component\\Yaml\\Inline' => $vendorDir . '/symfony/yaml/Inline.php',
    'Symfony\\Component\\Yaml\\Parser' => $vendorDir . '/symfony/yaml/Parser.php',
    'Symfony\\Component\\Yaml\\Tag\\TaggedValue' => $vendorDir . '/symfony/yaml/Tag/TaggedValue.php',
    'Symfony\\Component\\Yaml\\Unescaper' => $vendorDir . '/symfony/yaml/Unescaper.php',
    'Symfony\\Component\\Yaml\\Yaml' => $vendorDir . '/symfony/yaml/Yaml.php',
    'Symfony\\Contracts\\EventDispatcher\\Event' => $vendorDir . '/symfony/event-dispatcher-contracts/Event.php',
    'Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface' => $vendorDir . '/symfony/event-dispatcher-contracts/EventDispatcherInterface.php',
    'Symfony\\Contracts\\Service\\Attribute\\Required' => $vendorDir . '/symfony/service-contracts/Attribute/Required.php',
    'Symfony\\Contracts\\Service\\Attribute\\SubscribedService' => $vendorDir . '/symfony/service-contracts/Attribute/SubscribedService.php',
    'Symfony\\Contracts\\Service\\ResetInterface' => $vendorDir . '/symfony/service-contracts/ResetInterface.php',
    'Symfony\\Contracts\\Service\\ServiceCollectionInterface' => $vendorDir . '/symfony/service-contracts/ServiceCollectionInterface.php',
    'Symfony\\Contracts\\Service\\ServiceLocatorTrait' => $vendorDir . '/symfony/service-contracts/ServiceLocatorTrait.php',
    'Symfony\\Contracts\\Service\\ServiceMethodsSubscriberTrait' => $vendorDir . '/symfony/service-contracts/ServiceMethodsSubscriberTrait.php',
    'Symfony\\Contracts\\Service\\ServiceProviderInterface' => $vendorDir . '/symfony/service-contracts/ServiceProviderInterface.php',
    'Symfony\\Contracts\\Service\\ServiceSubscriberInterface' => $vendorDir . '/symfony/service-contracts/ServiceSubscriberInterface.php',
    'Symfony\\Contracts\\Service\\ServiceSubscriberTrait' => $vendorDir . '/symfony/service-contracts/ServiceSubscriberTrait.php',
    'Symfony\\Contracts\\Translation\\LocaleAwareInterface' => $vendorDir . '/symfony/translation-contracts/LocaleAwareInterface.php',
    'Symfony\\Contracts\\Translation\\TranslatableInterface' => $vendorDir . '/symfony/translation-contracts/TranslatableInterface.php',
    'Symfony\\Contracts\\Translation\\TranslatorInterface' => $vendorDir . '/symfony/translation-contracts/TranslatorInterface.php',
    'Symfony\\Contracts\\Translation\\TranslatorTrait' => $vendorDir . '/symfony/translation-contracts/TranslatorTrait.php',
    'Symfony\\Polyfill\\Ctype\\Ctype' => $vendorDir . '/symfony/polyfill-ctype/Ctype.php',
    'Symfony\\Polyfill\\Intl\\Grapheme\\Grapheme' => $vendorDir . '/symfony/polyfill-intl-grapheme/Grapheme.php',
    'Symfony\\Polyfill\\Intl\\Idn\\Idn' => $vendorDir . '/symfony/polyfill-intl-idn/Idn.php',
    'Symfony\\Polyfill\\Intl\\Idn\\Info' => $vendorDir . '/symfony/polyfill-intl-idn/Info.php',
    'Symfony\\Polyfill\\Intl\\Idn\\Resources\\unidata\\DisallowedRanges' => $vendorDir . '/symfony/polyfill-intl-idn/Resources/unidata/DisallowedRanges.php',
    'Symfony\\Polyfill\\Intl\\Idn\\Resources\\unidata\\Regex' => $vendorDir . '/symfony/polyfill-intl-idn/Resources/unidata/Regex.php',
    'Symfony\\Polyfill\\Intl\\Normalizer\\Normalizer' => $vendorDir . '/symfony/polyfill-intl-normalizer/Normalizer.php',
    'Symfony\\Polyfill\\Mbstring\\Mbstring' => $vendorDir . '/symfony/polyfill-mbstring/Mbstring.php',
    'Symfony\\Polyfill\\Php72\\Php72' => $vendorDir . '/symfony/polyfill-php72/Php72.php',
    'Symfony\\Polyfill\\Php80\\Php80' => $vendorDir . '/symfony/polyfill-php80/Php80.php',
    'Symfony\\Polyfill\\Php80\\PhpToken' => $vendorDir . '/symfony/polyfill-php80/PhpToken.php',
    'Symfony\\Polyfill\\Php83\\Php83' => $vendorDir . '/symfony/polyfill-php83/Php83.php',
    'Symfony\\Polyfill\\Uuid\\Uuid' => $vendorDir . '/symfony/polyfill-uuid/Uuid.php',
    'Termwind\\Actions\\StyleToMethod' => $vendorDir . '/nunomaduro/termwind/src/Actions/StyleToMethod.php',
    'Termwind\\Components\\Anchor' => $vendorDir . '/nunomaduro/termwind/src/Components/Anchor.php',
    'Termwind\\Components\\BreakLine' => $vendorDir . '/nunomaduro/termwind/src/Components/BreakLine.php',
    'Termwind\\Components\\Dd' => $vendorDir . '/nunomaduro/termwind/src/Components/Dd.php',
    'Termwind\\Components\\Div' => $vendorDir . '/nunomaduro/termwind/src/Components/Div.php',
    'Termwind\\Components\\Dl' => $vendorDir . '/nunomaduro/termwind/src/Components/Dl.php',
    'Termwind\\Components\\Dt' => $vendorDir . '/nunomaduro/termwind/src/Components/Dt.php',
    'Termwind\\Components\\Element' => $vendorDir . '/nunomaduro/termwind/src/Components/Element.php',
    'Termwind\\Components\\Hr' => $vendorDir . '/nunomaduro/termwind/src/Components/Hr.php',
    'Termwind\\Components\\Li' => $vendorDir . '/nunomaduro/termwind/src/Components/Li.php',
    'Termwind\\Components\\Ol' => $vendorDir . '/nunomaduro/termwind/src/Components/Ol.php',
    'Termwind\\Components\\Paragraph' => $vendorDir . '/nunomaduro/termwind/src/Components/Paragraph.php',
    'Termwind\\Components\\Raw' => $vendorDir . '/nunomaduro/termwind/src/Components/Raw.php',
    'Termwind\\Components\\Span' => $vendorDir . '/nunomaduro/termwind/src/Components/Span.php',
    'Termwind\\Components\\Ul' => $vendorDir . '/nunomaduro/termwind/src/Components/Ul.php',
    'Termwind\\Enums\\Color' => $vendorDir . '/nunomaduro/termwind/src/Enums/Color.php',
    'Termwind\\Exceptions\\ColorNotFound' => $vendorDir . '/nunomaduro/termwind/src/Exceptions/ColorNotFound.php',
    'Termwind\\Exceptions\\InvalidChild' => $vendorDir . '/nunomaduro/termwind/src/Exceptions/InvalidChild.php',
    'Termwind\\Exceptions\\InvalidColor' => $vendorDir . '/nunomaduro/termwind/src/Exceptions/InvalidColor.php',
    'Termwind\\Exceptions\\InvalidStyle' => $vendorDir . '/nunomaduro/termwind/src/Exceptions/InvalidStyle.php',
    'Termwind\\Exceptions\\StyleNotFound' => $vendorDir . '/nunomaduro/termwind/src/Exceptions/StyleNotFound.php',
    'Termwind\\Helpers\\QuestionHelper' => $vendorDir . '/nunomaduro/termwind/src/Helpers/QuestionHelper.php',
    'Termwind\\HtmlRenderer' => $vendorDir . '/nunomaduro/termwind/src/HtmlRenderer.php',
    'Termwind\\Html\\CodeRenderer' => $vendorDir . '/nunomaduro/termwind/src/Html/CodeRenderer.php',
    'Termwind\\Html\\InheritStyles' => $vendorDir . '/nunomaduro/termwind/src/Html/InheritStyles.php',
    'Termwind\\Html\\PreRenderer' => $vendorDir . '/nunomaduro/termwind/src/Html/PreRenderer.php',
    'Termwind\\Html\\TableRenderer' => $vendorDir . '/nunomaduro/termwind/src/Html/TableRenderer.php',
    'Termwind\\Laravel\\TermwindServiceProvider' => $vendorDir . '/nunomaduro/termwind/src/Laravel/TermwindServiceProvider.php',
    'Termwind\\Question' => $vendorDir . '/nunomaduro/termwind/src/Question.php',
    'Termwind\\Repositories\\Styles' => $vendorDir . '/nunomaduro/termwind/src/Repositories/Styles.php',
    'Termwind\\Terminal' => $vendorDir . '/nunomaduro/termwind/src/Terminal.php',
    'Termwind\\Termwind' => $vendorDir . '/nunomaduro/termwind/src/Termwind.php',
    'Termwind\\ValueObjects\\Node' => $vendorDir . '/nunomaduro/termwind/src/ValueObjects/Node.php',
    'Termwind\\ValueObjects\\Style' => $vendorDir . '/nunomaduro/termwind/src/ValueObjects/Style.php',
    'Termwind\\ValueObjects\\Styles' => $vendorDir . '/nunomaduro/termwind/src/ValueObjects/Styles.php',
    'Tests\\CreatesApplication' => $baseDir . '/tests/CreatesApplication.php',
    'Tests\\Feature\\Auth\\AuthenticationTest' => $baseDir . '/tests/Feature/Auth/AuthenticationTest.php',
    'Tests\\Feature\\Auth\\EmailVerificationTest' => $baseDir . '/tests/Feature/Auth/EmailVerificationTest.php',
    'Tests\\Feature\\Auth\\PasswordConfirmationTest' => $baseDir . '/tests/Feature/Auth/PasswordConfirmationTest.php',
    'Tests\\Feature\\Auth\\PasswordResetTest' => $baseDir . '/tests/Feature/Auth/PasswordResetTest.php',
    'Tests\\Feature\\Auth\\RegistrationTest' => $baseDir . '/tests/Feature/Auth/RegistrationTest.php',
    'Tests\\Feature\\ExampleTest' => $baseDir . '/tests/Feature/ExampleTest.php',
    'Tests\\TestCase' => $baseDir . '/tests/TestCase.php',
    'Tests\\Unit\\ExampleTest' => $baseDir . '/tests/Unit/ExampleTest.php',
    'TheSeer\\Tokenizer\\Exception' => $vendorDir . '/theseer/tokenizer/src/Exception.php',
    'TheSeer\\Tokenizer\\NamespaceUri' => $vendorDir . '/theseer/tokenizer/src/NamespaceUri.php',
    'TheSeer\\Tokenizer\\NamespaceUriException' => $vendorDir . '/theseer/tokenizer/src/NamespaceUriException.php',
    'TheSeer\\Tokenizer\\Token' => $vendorDir . '/theseer/tokenizer/src/Token.php',
    'TheSeer\\Tokenizer\\TokenCollection' => $vendorDir . '/theseer/tokenizer/src/TokenCollection.php',
    'TheSeer\\Tokenizer\\TokenCollectionException' => $vendorDir . '/theseer/tokenizer/src/TokenCollectionException.php',
    'TheSeer\\Tokenizer\\Tokenizer' => $vendorDir . '/theseer/tokenizer/src/Tokenizer.php',
    'TheSeer\\Tokenizer\\XMLSerializer' => $vendorDir . '/theseer/tokenizer/src/XMLSerializer.php',
    'TijsVerkoyen\\CssToInlineStyles\\CssToInlineStyles' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/CssToInlineStyles.php',
    'TijsVerkoyen\\CssToInlineStyles\\Css\\Processor' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/Css/Processor.php',
    'TijsVerkoyen\\CssToInlineStyles\\Css\\Property\\Processor' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/Css/Property/Processor.php',
    'TijsVerkoyen\\CssToInlineStyles\\Css\\Property\\Property' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/Css/Property/Property.php',
    'TijsVerkoyen\\CssToInlineStyles\\Css\\Rule\\Processor' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/Css/Rule/Processor.php',
    'TijsVerkoyen\\CssToInlineStyles\\Css\\Rule\\Rule' => $vendorDir . '/tijsverkoyen/css-to-inline-styles/src/Css/Rule/Rule.php',
    'Twilio\\Base\\BaseClient' => $vendorDir . '/twilio/sdk/src/Twilio/Base/BaseClient.php',
    'Twilio\\Base\\PhoneNumberCapabilities' => $vendorDir . '/twilio/sdk/src/Twilio/Base/PhoneNumberCapabilities.php',
    'Twilio\\Deserialize' => $vendorDir . '/twilio/sdk/src/Twilio/Deserialize.php',
    'Twilio\\Domain' => $vendorDir . '/twilio/sdk/src/Twilio/Domain.php',
    'Twilio\\Exceptions\\ConfigurationException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/ConfigurationException.php',
    'Twilio\\Exceptions\\DeserializeException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/DeserializeException.php',
    'Twilio\\Exceptions\\EnvironmentException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/EnvironmentException.php',
    'Twilio\\Exceptions\\HttpException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/HttpException.php',
    'Twilio\\Exceptions\\RestException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/RestException.php',
    'Twilio\\Exceptions\\TwilioException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/TwilioException.php',
    'Twilio\\Exceptions\\TwimlException' => $vendorDir . '/twilio/sdk/src/Twilio/Exceptions/TwimlException.php',
    'Twilio\\Http\\Client' => $vendorDir . '/twilio/sdk/src/Twilio/Http/Client.php',
    'Twilio\\Http\\CurlClient' => $vendorDir . '/twilio/sdk/src/Twilio/Http/CurlClient.php',
    'Twilio\\Http\\File' => $vendorDir . '/twilio/sdk/src/Twilio/Http/File.php',
    'Twilio\\Http\\GuzzleClient' => $vendorDir . '/twilio/sdk/src/Twilio/Http/GuzzleClient.php',
    'Twilio\\Http\\Response' => $vendorDir . '/twilio/sdk/src/Twilio/Http/Response.php',
    'Twilio\\InstanceContext' => $vendorDir . '/twilio/sdk/src/Twilio/InstanceContext.php',
    'Twilio\\InstanceResource' => $vendorDir . '/twilio/sdk/src/Twilio/InstanceResource.php',
    'Twilio\\Jwt\\AccessToken' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/AccessToken.php',
    'Twilio\\Jwt\\ClientToken' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/ClientToken.php',
    'Twilio\\Jwt\\Client\\ScopeURI' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Client/ScopeURI.php',
    'Twilio\\Jwt\\Grants\\ChatGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/ChatGrant.php',
    'Twilio\\Jwt\\Grants\\Grant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/Grant.php',
    'Twilio\\Jwt\\Grants\\PlaybackGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/PlaybackGrant.php',
    'Twilio\\Jwt\\Grants\\SyncGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/SyncGrant.php',
    'Twilio\\Jwt\\Grants\\TaskRouterGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/TaskRouterGrant.php',
    'Twilio\\Jwt\\Grants\\VideoGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/VideoGrant.php',
    'Twilio\\Jwt\\Grants\\VoiceGrant' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/Grants/VoiceGrant.php',
    'Twilio\\Jwt\\JWT' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/JWT.php',
    'Twilio\\Jwt\\TaskRouter\\CapabilityToken' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/TaskRouter/CapabilityToken.php',
    'Twilio\\Jwt\\TaskRouter\\Policy' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/TaskRouter/Policy.php',
    'Twilio\\Jwt\\TaskRouter\\TaskQueueCapability' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/TaskRouter/TaskQueueCapability.php',
    'Twilio\\Jwt\\TaskRouter\\WorkerCapability' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/TaskRouter/WorkerCapability.php',
    'Twilio\\Jwt\\TaskRouter\\WorkspaceCapability' => $vendorDir . '/twilio/sdk/src/Twilio/Jwt/TaskRouter/WorkspaceCapability.php',
    'Twilio\\ListResource' => $vendorDir . '/twilio/sdk/src/Twilio/ListResource.php',
    'Twilio\\Options' => $vendorDir . '/twilio/sdk/src/Twilio/Options.php',
    'Twilio\\Page' => $vendorDir . '/twilio/sdk/src/Twilio/Page.php',
    'Twilio\\Rest\\Accounts' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts.php',
    'Twilio\\Rest\\AccountsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/AccountsBase.php',
    'Twilio\\Rest\\Accounts\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1.php',
    'Twilio\\Rest\\Accounts\\V1\\AuthTokenPromotionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/AuthTokenPromotionContext.php',
    'Twilio\\Rest\\Accounts\\V1\\AuthTokenPromotionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/AuthTokenPromotionInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\AuthTokenPromotionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/AuthTokenPromotionList.php',
    'Twilio\\Rest\\Accounts\\V1\\AuthTokenPromotionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/AuthTokenPromotionPage.php',
    'Twilio\\Rest\\Accounts\\V1\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/CredentialInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/CredentialList.php',
    'Twilio\\Rest\\Accounts\\V1\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/CredentialPage.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\AwsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/AwsContext.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\AwsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/AwsInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\AwsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/AwsList.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\AwsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/AwsOptions.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\AwsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/AwsPage.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\PublicKeyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/PublicKeyContext.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\PublicKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/PublicKeyInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\PublicKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/PublicKeyList.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\PublicKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/PublicKeyOptions.php',
    'Twilio\\Rest\\Accounts\\V1\\Credential\\PublicKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/Credential/PublicKeyPage.php',
    'Twilio\\Rest\\Accounts\\V1\\SafelistInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SafelistInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\SafelistList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SafelistList.php',
    'Twilio\\Rest\\Accounts\\V1\\SafelistOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SafelistOptions.php',
    'Twilio\\Rest\\Accounts\\V1\\SafelistPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SafelistPage.php',
    'Twilio\\Rest\\Accounts\\V1\\SecondaryAuthTokenContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SecondaryAuthTokenContext.php',
    'Twilio\\Rest\\Accounts\\V1\\SecondaryAuthTokenInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SecondaryAuthTokenInstance.php',
    'Twilio\\Rest\\Accounts\\V1\\SecondaryAuthTokenList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SecondaryAuthTokenList.php',
    'Twilio\\Rest\\Accounts\\V1\\SecondaryAuthTokenPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Accounts/V1/SecondaryAuthTokenPage.php',
    'Twilio\\Rest\\Api' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api.php',
    'Twilio\\Rest\\ApiBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ApiBase.php',
    'Twilio\\Rest\\Api\\V2010' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010.php',
    'Twilio\\Rest\\Api\\V2010\\AccountContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/AccountContext.php',
    'Twilio\\Rest\\Api\\V2010\\AccountInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/AccountInstance.php',
    'Twilio\\Rest\\Api\\V2010\\AccountList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/AccountList.php',
    'Twilio\\Rest\\Api\\V2010\\AccountOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/AccountOptions.php',
    'Twilio\\Rest\\Api\\V2010\\AccountPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/AccountPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AddressContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AddressContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AddressInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AddressInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AddressList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AddressList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AddressOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AddressOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AddressPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AddressPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Address\\DependentPhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Address/DependentPhoneNumberInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Address\\DependentPhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Address/DependentPhoneNumberList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Address\\DependentPhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Address/DependentPhoneNumberPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ApplicationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ApplicationContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ApplicationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ApplicationInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ApplicationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ApplicationList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ApplicationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ApplicationOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ApplicationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ApplicationPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AuthorizedConnectAppContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AuthorizedConnectAppContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AuthorizedConnectAppInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AuthorizedConnectAppInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AuthorizedConnectAppList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AuthorizedConnectAppList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AuthorizedConnectAppPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AuthorizedConnectAppPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountryContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountryInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountryList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountryPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\LocalInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/LocalInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\LocalList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/LocalList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\LocalOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/LocalOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\LocalPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/LocalPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MachineToMachineInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MachineToMachineInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MachineToMachineList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MachineToMachineList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MachineToMachineOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MachineToMachineOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MachineToMachinePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MachineToMachinePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MobileInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MobileInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MobileList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MobileList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MobileOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MobileOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\MobilePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/MobilePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\NationalInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/NationalInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\NationalList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/NationalList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\NationalOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/NationalOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\NationalPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/NationalPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\SharedCostInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/SharedCostInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\SharedCostList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/SharedCostList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\SharedCostOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/SharedCostOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\SharedCostPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/SharedCostPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\TollFreeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/TollFreeInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\TollFreeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/TollFreeList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\TollFreeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/TollFreeOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\TollFreePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/TollFreePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\VoipInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/VoipInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\VoipList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/VoipList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\VoipOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/VoipOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\AvailablePhoneNumberCountry\\VoipPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/AvailablePhoneNumberCountry/VoipPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\BalanceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/BalanceInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\BalanceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/BalanceList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\BalancePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/BalancePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\CallContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/CallContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\CallInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/CallInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\CallList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/CallList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\CallOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/CallOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\CallPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/CallPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\EventInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/EventInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\EventList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/EventList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\EventPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/EventPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\NotificationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/NotificationContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\NotificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/NotificationInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\NotificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/NotificationList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\NotificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/NotificationOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\NotificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/NotificationPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\PaymentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/PaymentContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\PaymentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/PaymentInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\PaymentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/PaymentList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\PaymentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/PaymentOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\PaymentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/PaymentPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\RecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/RecordingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\RecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/RecordingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\RecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/RecordingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\RecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/RecordingOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\RecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/RecordingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\SiprecContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/SiprecContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\SiprecInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/SiprecInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\SiprecList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/SiprecList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\SiprecOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/SiprecOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\SiprecPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/SiprecPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\StreamContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/StreamContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\StreamInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/StreamInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\StreamList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/StreamList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\StreamOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/StreamOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\StreamPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/StreamPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\TranscriptionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/TranscriptionContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\TranscriptionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/TranscriptionInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\TranscriptionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/TranscriptionList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\TranscriptionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/TranscriptionOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\TranscriptionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/TranscriptionPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessagePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageSubscriptionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageSubscriptionContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageSubscriptionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageSubscriptionInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageSubscriptionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageSubscriptionList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageSubscriptionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageSubscriptionOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Call\\UserDefinedMessageSubscriptionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Call/UserDefinedMessageSubscriptionPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConferenceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConferenceContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConferenceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConferenceInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConferenceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConferenceList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConferenceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConferenceOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConferencePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConferencePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/ParticipantContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/ParticipantInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/ParticipantList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\ParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/ParticipantOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/ParticipantPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\RecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/RecordingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\RecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/RecordingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\RecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/RecordingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\RecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/RecordingOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Conference\\RecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Conference/RecordingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConnectAppContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConnectAppContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConnectAppInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConnectAppInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConnectAppList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConnectAppList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConnectAppOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConnectAppOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ConnectAppPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ConnectAppPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumberContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumberInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumberList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumberOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumberPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOnContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOnContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOnInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOnInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOnList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOnList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOnPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOnPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOn\\AssignedAddOnExtensionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOn/AssignedAddOnExtensionContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOn\\AssignedAddOnExtensionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOn/AssignedAddOnExtensionInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOn\\AssignedAddOnExtensionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOn/AssignedAddOnExtensionList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\AssignedAddOn\\AssignedAddOnExtensionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/AssignedAddOn/AssignedAddOnExtensionPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\LocalInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/LocalInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\LocalList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/LocalList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\LocalOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/LocalOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\LocalPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/LocalPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\MobileInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/MobileInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\MobileList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/MobileList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\MobileOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/MobileOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\MobilePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/MobilePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\TollFreeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/TollFreeInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\TollFreeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/TollFreeList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\TollFreeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/TollFreeOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\IncomingPhoneNumber\\TollFreePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/IncomingPhoneNumber/TollFreePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\KeyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/KeyContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\KeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/KeyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\KeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/KeyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\KeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/KeyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\KeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/KeyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/MessageContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/MessageInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/MessageList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/MessageOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/MessagePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\FeedbackInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/FeedbackInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\FeedbackList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/FeedbackList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\FeedbackOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/FeedbackOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\FeedbackPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/FeedbackPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\MediaContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/MediaContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\MediaInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/MediaInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\MediaList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/MediaList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\MediaOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/MediaOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Message\\MediaPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Message/MediaPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewKeyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewKeyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewKeyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewKeyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewSigningKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewSigningKeyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewSigningKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewSigningKeyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewSigningKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewSigningKeyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NewSigningKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NewSigningKeyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NotificationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NotificationContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NotificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NotificationInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NotificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NotificationList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NotificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NotificationOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\NotificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/NotificationPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\OutgoingCallerIdContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/OutgoingCallerIdContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\OutgoingCallerIdInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/OutgoingCallerIdInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\OutgoingCallerIdList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/OutgoingCallerIdList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\OutgoingCallerIdOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/OutgoingCallerIdOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\OutgoingCallerIdPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/OutgoingCallerIdPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\QueueContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/QueueContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\QueueInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/QueueInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\QueueList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/QueueList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\QueueOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/QueueOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\QueuePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/QueuePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Queue\\MemberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Queue/MemberContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Queue\\MemberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Queue/MemberInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Queue\\MemberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Queue/MemberList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Queue\\MemberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Queue/MemberOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Queue\\MemberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Queue/MemberPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\RecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/RecordingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\RecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/RecordingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\RecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/RecordingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\RecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/RecordingOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\RecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/RecordingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResultContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResultContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResultInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResultInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResultList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResultList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResultPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResultPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\PayloadContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/PayloadContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\PayloadInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/PayloadInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\PayloadList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/PayloadList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\PayloadPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/PayloadPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\Payload\\DataContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/Payload/DataContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\Payload\\DataInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/Payload/DataInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\Payload\\DataList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/Payload/DataList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\AddOnResult\\Payload\\DataPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/AddOnResult/Payload/DataPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\TranscriptionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/TranscriptionContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\TranscriptionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/TranscriptionInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\TranscriptionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/TranscriptionList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Recording\\TranscriptionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Recording/TranscriptionPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ShortCodeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ShortCodeContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ShortCodeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ShortCodeInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ShortCodeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ShortCodeList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ShortCodeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ShortCodeOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ShortCodePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ShortCodePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SigningKeyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SigningKeyContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SigningKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SigningKeyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SigningKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SigningKeyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SigningKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SigningKeyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SigningKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SigningKeyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SipInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SipInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SipList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SipList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\SipPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/SipPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialListContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialListInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialListList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialListPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialList\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialList/CredentialContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialList\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialList/CredentialInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialList\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialList/CredentialList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialList\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialList/CredentialOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\CredentialList\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/CredentialList/CredentialPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\DomainContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/DomainContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\DomainInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/DomainInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\DomainList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/DomainList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\DomainOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/DomainOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\DomainPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/DomainPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypesInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypesList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypesPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCallsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCallsInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCallsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCallsList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCallsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCallsPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsCredentialListMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsCredentialListMappingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsCredentialListMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsCredentialListMappingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsCredentialListMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsCredentialListMappingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsCredentialListMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsCredentialListMappingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsIpAccessControlListMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsIpAccessControlListMappingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsIpAccessControlListMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsIpAccessControlListMappingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsIpAccessControlListMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsIpAccessControlListMappingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeCalls\\AuthCallsIpAccessControlListMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeCalls/AuthCallsIpAccessControlListMappingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrationsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrationsInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrationsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrationsList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrationsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrationsPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrations\\AuthRegistrationsCredentialListMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrations/AuthRegistrationsCredentialListMappingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrations\\AuthRegistrationsCredentialListMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrations/AuthRegistrationsCredentialListMappingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrations\\AuthRegistrationsCredentialListMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrations/AuthRegistrationsCredentialListMappingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\AuthTypes\\AuthTypeRegistrations\\AuthRegistrationsCredentialListMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/AuthTypes/AuthTypeRegistrations/AuthRegistrationsCredentialListMappingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\CredentialListMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/CredentialListMappingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\CredentialListMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/CredentialListMappingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\CredentialListMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/CredentialListMappingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\CredentialListMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/CredentialListMappingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\IpAccessControlListMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/IpAccessControlListMappingContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\IpAccessControlListMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/IpAccessControlListMappingInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\IpAccessControlListMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/IpAccessControlListMappingList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\Domain\\IpAccessControlListMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/Domain/IpAccessControlListMappingPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlListContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlListInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlListList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlListPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlList\\IpAddressContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlList/IpAddressContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlList\\IpAddressInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlList/IpAddressInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlList\\IpAddressList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlList/IpAddressList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlList\\IpAddressOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlList/IpAddressOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Sip\\IpAccessControlList\\IpAddressPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Sip/IpAccessControlList/IpAddressPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TokenInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TokenInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TokenList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TokenList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TokenOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TokenOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TokenPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TokenPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TranscriptionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TranscriptionContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TranscriptionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TranscriptionInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TranscriptionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TranscriptionList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\TranscriptionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/TranscriptionPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\UsageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/UsageInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\UsageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/UsageList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\UsagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/UsagePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\RecordInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/RecordInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\RecordList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/RecordList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\RecordOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/RecordOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\RecordPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/RecordPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\AllTimeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/AllTimeInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\AllTimeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/AllTimeList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\AllTimeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/AllTimeOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\AllTimePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/AllTimePage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\DailyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/DailyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\DailyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/DailyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\DailyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/DailyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\DailyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/DailyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\LastMonthInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/LastMonthInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\LastMonthList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/LastMonthList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\LastMonthOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/LastMonthOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\LastMonthPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/LastMonthPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\MonthlyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/MonthlyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\MonthlyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/MonthlyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\MonthlyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/MonthlyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\MonthlyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/MonthlyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\ThisMonthInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/ThisMonthInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\ThisMonthList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/ThisMonthList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\ThisMonthOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/ThisMonthOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\ThisMonthPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/ThisMonthPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\TodayInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/TodayInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\TodayList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/TodayList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\TodayOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/TodayOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\TodayPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/TodayPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YearlyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YearlyInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YearlyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YearlyList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YearlyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YearlyOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YearlyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YearlyPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YesterdayInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YesterdayInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YesterdayList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YesterdayList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YesterdayOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YesterdayOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\Record\\YesterdayPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/Record/YesterdayPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\TriggerContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/TriggerContext.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\TriggerInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/TriggerInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\TriggerList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/TriggerList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\TriggerOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/TriggerOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\Usage\\TriggerPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/Usage/TriggerPage.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ValidationRequestInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ValidationRequestInstance.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ValidationRequestList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ValidationRequestList.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ValidationRequestOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ValidationRequestOptions.php',
    'Twilio\\Rest\\Api\\V2010\\Account\\ValidationRequestPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Api/V2010/Account/ValidationRequestPage.php',
    'Twilio\\Rest\\Autopilot' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Autopilot.php',
    'Twilio\\Rest\\Bulkexports' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports.php',
    'Twilio\\Rest\\BulkexportsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/BulkexportsBase.php',
    'Twilio\\Rest\\Bulkexports\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportConfigurationContext.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportConfigurationInstance.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportConfigurationList.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportConfigurationOptions.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportConfigurationPage.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportContext.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportInstance.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportList.php',
    'Twilio\\Rest\\Bulkexports\\V1\\ExportPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/ExportPage.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\DayContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/DayContext.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\DayInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/DayInstance.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\DayList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/DayList.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\DayPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/DayPage.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\ExportCustomJobInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/ExportCustomJobInstance.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\ExportCustomJobList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/ExportCustomJobList.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\ExportCustomJobOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/ExportCustomJobOptions.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\ExportCustomJobPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/ExportCustomJobPage.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\JobContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/JobContext.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\JobInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/JobInstance.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\JobList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/JobList.php',
    'Twilio\\Rest\\Bulkexports\\V1\\Export\\JobPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Bulkexports/V1/Export/JobPage.php',
    'Twilio\\Rest\\Chat' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat.php',
    'Twilio\\Rest\\ChatBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ChatBase.php',
    'Twilio\\Rest\\Chat\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1.php',
    'Twilio\\Rest\\Chat\\V1\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/CredentialContext.php',
    'Twilio\\Rest\\Chat\\V1\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/CredentialInstance.php',
    'Twilio\\Rest\\Chat\\V1\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/CredentialList.php',
    'Twilio\\Rest\\Chat\\V1\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/CredentialOptions.php',
    'Twilio\\Rest\\Chat\\V1\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/CredentialPage.php',
    'Twilio\\Rest\\Chat\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/ServiceContext.php',
    'Twilio\\Rest\\Chat\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/ServiceInstance.php',
    'Twilio\\Rest\\Chat\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/ServiceList.php',
    'Twilio\\Rest\\Chat\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/ServiceOptions.php',
    'Twilio\\Rest\\Chat\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/ServicePage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/ChannelContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/ChannelInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/ChannelList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/ChannelOptions.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/ChannelPage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\InviteContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/InviteContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\InviteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/InviteInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\InviteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/InviteList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\InviteOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/InviteOptions.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\InvitePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/InvitePage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MemberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MemberContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MemberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MemberInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MemberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MemberList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MemberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MemberOptions.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MemberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MemberPage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MessageContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MessageInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MessageList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MessageOptions.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\Channel\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/Channel/MessagePage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/RoleContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/RoleInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/RoleList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/RolePage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/UserContext.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/UserInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/UserList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/UserOptions.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/UserPage.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\User\\UserChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/User/UserChannelInstance.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\User\\UserChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/User/UserChannelList.php',
    'Twilio\\Rest\\Chat\\V1\\Service\\User\\UserChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V1/Service/User/UserChannelPage.php',
    'Twilio\\Rest\\Chat\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2.php',
    'Twilio\\Rest\\Chat\\V2\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/CredentialContext.php',
    'Twilio\\Rest\\Chat\\V2\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/CredentialInstance.php',
    'Twilio\\Rest\\Chat\\V2\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/CredentialList.php',
    'Twilio\\Rest\\Chat\\V2\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/CredentialOptions.php',
    'Twilio\\Rest\\Chat\\V2\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/CredentialPage.php',
    'Twilio\\Rest\\Chat\\V2\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/ServiceContext.php',
    'Twilio\\Rest\\Chat\\V2\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/ServiceInstance.php',
    'Twilio\\Rest\\Chat\\V2\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/ServiceList.php',
    'Twilio\\Rest\\Chat\\V2\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/ServiceOptions.php',
    'Twilio\\Rest\\Chat\\V2\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/ServicePage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\BindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/BindingContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\BindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/BindingInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\BindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/BindingList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\BindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/BindingOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\BindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/BindingPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/ChannelContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/ChannelInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/ChannelList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/ChannelOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/ChannelPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\InviteContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/InviteContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\InviteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/InviteInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\InviteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/InviteList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\InviteOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/InviteOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\InvitePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/InvitePage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MemberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MemberContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MemberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MemberInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MemberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MemberList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MemberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MemberOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MemberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MemberPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MessageContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MessageInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MessageList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MessageOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/MessagePage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/WebhookContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/WebhookInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/WebhookList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/WebhookOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\Channel\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/Channel/WebhookPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/RoleContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/RoleInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/RoleList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/RolePage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/UserContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/UserInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/UserList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/UserOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/UserPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserBindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserBindingContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserBindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserBindingInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserBindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserBindingList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserBindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserBindingOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserBindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserBindingPage.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserChannelContext.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserChannelInstance.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserChannelList.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserChannelOptions.php',
    'Twilio\\Rest\\Chat\\V2\\Service\\User\\UserChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V2/Service/User/UserChannelPage.php',
    'Twilio\\Rest\\Chat\\V3' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3.php',
    'Twilio\\Rest\\Chat\\V3\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3/ChannelContext.php',
    'Twilio\\Rest\\Chat\\V3\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3/ChannelInstance.php',
    'Twilio\\Rest\\Chat\\V3\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3/ChannelList.php',
    'Twilio\\Rest\\Chat\\V3\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3/ChannelOptions.php',
    'Twilio\\Rest\\Chat\\V3\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Chat/V3/ChannelPage.php',
    'Twilio\\Rest\\Client' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Client.php',
    'Twilio\\Rest\\Content' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content.php',
    'Twilio\\Rest\\ContentBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ContentBase.php',
    'Twilio\\Rest\\Content\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1.php',
    'Twilio\\Rest\\Content\\V1\\ContentAndApprovalsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentAndApprovalsInstance.php',
    'Twilio\\Rest\\Content\\V1\\ContentAndApprovalsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentAndApprovalsList.php',
    'Twilio\\Rest\\Content\\V1\\ContentAndApprovalsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentAndApprovalsPage.php',
    'Twilio\\Rest\\Content\\V1\\ContentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentContext.php',
    'Twilio\\Rest\\Content\\V1\\ContentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentInstance.php',
    'Twilio\\Rest\\Content\\V1\\ContentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentList.php',
    'Twilio\\Rest\\Content\\V1\\ContentModels' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentModels.php',
    'Twilio\\Rest\\Content\\V1\\ContentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/ContentPage.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalCreateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalCreateInstance.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalCreateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalCreateList.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalCreateModels' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalCreateModels.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalCreatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalCreatePage.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalFetchContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalFetchContext.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalFetchInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalFetchInstance.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalFetchList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalFetchList.php',
    'Twilio\\Rest\\Content\\V1\\Content\\ApprovalFetchPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/Content/ApprovalFetchPage.php',
    'Twilio\\Rest\\Content\\V1\\LegacyContentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/LegacyContentInstance.php',
    'Twilio\\Rest\\Content\\V1\\LegacyContentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/LegacyContentList.php',
    'Twilio\\Rest\\Content\\V1\\LegacyContentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V1/LegacyContentPage.php',
    'Twilio\\Rest\\Content\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2.php',
    'Twilio\\Rest\\Content\\V2\\ContentAndApprovalsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentAndApprovalsInstance.php',
    'Twilio\\Rest\\Content\\V2\\ContentAndApprovalsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentAndApprovalsList.php',
    'Twilio\\Rest\\Content\\V2\\ContentAndApprovalsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentAndApprovalsOptions.php',
    'Twilio\\Rest\\Content\\V2\\ContentAndApprovalsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentAndApprovalsPage.php',
    'Twilio\\Rest\\Content\\V2\\ContentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentInstance.php',
    'Twilio\\Rest\\Content\\V2\\ContentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentList.php',
    'Twilio\\Rest\\Content\\V2\\ContentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentOptions.php',
    'Twilio\\Rest\\Content\\V2\\ContentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Content/V2/ContentPage.php',
    'Twilio\\Rest\\Conversations' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations.php',
    'Twilio\\Rest\\ConversationsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ConversationsBase.php',
    'Twilio\\Rest\\Conversations\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1.php',
    'Twilio\\Rest\\Conversations\\V1\\AddressConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/AddressConfigurationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\AddressConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/AddressConfigurationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\AddressConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/AddressConfigurationList.php',
    'Twilio\\Rest\\Conversations\\V1\\AddressConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/AddressConfigurationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\AddressConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/AddressConfigurationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\ConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConfigurationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\ConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConfigurationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\ConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConfigurationList.php',
    'Twilio\\Rest\\Conversations\\V1\\ConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConfigurationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\ConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConfigurationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Configuration\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Configuration/WebhookContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Configuration\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Configuration/WebhookInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Configuration\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Configuration/WebhookList.php',
    'Twilio\\Rest\\Conversations\\V1\\Configuration\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Configuration/WebhookOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Configuration\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Configuration/WebhookPage.php',
    'Twilio\\Rest\\Conversations\\V1\\ConversationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConversationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\ConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\ConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\ConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\ConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ConversationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/MessageContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/MessageInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/MessageList.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/MessageOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/MessagePage.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\Message\\DeliveryReceiptContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/Message/DeliveryReceiptContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\Message\\DeliveryReceiptInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/Message/DeliveryReceiptInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\Message\\DeliveryReceiptList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/Message/DeliveryReceiptList.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\Message\\DeliveryReceiptPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/Message/DeliveryReceiptPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/ParticipantContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/ParticipantInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/ParticipantList.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\ParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/ParticipantOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/ParticipantPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/WebhookContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/WebhookInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/WebhookList.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/WebhookOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Conversation\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Conversation/WebhookPage.php',
    'Twilio\\Rest\\Conversations\\V1\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/CredentialContext.php',
    'Twilio\\Rest\\Conversations\\V1\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/CredentialInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/CredentialList.php',
    'Twilio\\Rest\\Conversations\\V1\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/CredentialOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/CredentialPage.php',
    'Twilio\\Rest\\Conversations\\V1\\ParticipantConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ParticipantConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\ParticipantConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ParticipantConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\ParticipantConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ParticipantConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\ParticipantConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ParticipantConversationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/RoleContext.php',
    'Twilio\\Rest\\Conversations\\V1\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/RoleInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/RoleList.php',
    'Twilio\\Rest\\Conversations\\V1\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/RolePage.php',
    'Twilio\\Rest\\Conversations\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ServiceContext.php',
    'Twilio\\Rest\\Conversations\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ServiceInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ServiceList.php',
    'Twilio\\Rest\\Conversations\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/ServicePage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\BindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/BindingContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\BindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/BindingInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\BindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/BindingList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\BindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/BindingOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\BindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/BindingPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConfigurationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConfigurationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConfigurationList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConfigurationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConfigurationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\NotificationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/NotificationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\NotificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/NotificationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\NotificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/NotificationList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\NotificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/NotificationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\NotificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/NotificationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/WebhookContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/WebhookInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/WebhookList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/WebhookOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Configuration\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Configuration/WebhookPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConversationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConversationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ConversationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/MessageContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/MessageInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/MessageList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/MessageOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/MessagePage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\Message\\DeliveryReceiptContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/Message/DeliveryReceiptContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\Message\\DeliveryReceiptInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/Message/DeliveryReceiptInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\Message\\DeliveryReceiptList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/Message/DeliveryReceiptList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\Message\\DeliveryReceiptPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/Message/DeliveryReceiptPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/ParticipantContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/ParticipantInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/ParticipantList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\ParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/ParticipantOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/ParticipantPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/WebhookContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/WebhookInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/WebhookList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/WebhookOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\Conversation\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/Conversation/WebhookPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ParticipantConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ParticipantConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ParticipantConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ParticipantConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ParticipantConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ParticipantConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\ParticipantConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/ParticipantConversationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/RoleContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/RoleInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/RoleList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/RolePage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/UserContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/UserInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/UserList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/UserOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/UserPage.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\User\\UserConversationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/User/UserConversationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\User\\UserConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/User/UserConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\User\\UserConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/User/UserConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\User\\UserConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/User/UserConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\Service\\User\\UserConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/Service/User/UserConversationPage.php',
    'Twilio\\Rest\\Conversations\\V1\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/UserContext.php',
    'Twilio\\Rest\\Conversations\\V1\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/UserInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/UserList.php',
    'Twilio\\Rest\\Conversations\\V1\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/UserOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/UserPage.php',
    'Twilio\\Rest\\Conversations\\V1\\User\\UserConversationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/User/UserConversationContext.php',
    'Twilio\\Rest\\Conversations\\V1\\User\\UserConversationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/User/UserConversationInstance.php',
    'Twilio\\Rest\\Conversations\\V1\\User\\UserConversationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/User/UserConversationList.php',
    'Twilio\\Rest\\Conversations\\V1\\User\\UserConversationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/User/UserConversationOptions.php',
    'Twilio\\Rest\\Conversations\\V1\\User\\UserConversationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Conversations/V1/User/UserConversationPage.php',
    'Twilio\\Rest\\Events' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events.php',
    'Twilio\\Rest\\EventsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/EventsBase.php',
    'Twilio\\Rest\\Events\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1.php',
    'Twilio\\Rest\\Events\\V1\\EventTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/EventTypeContext.php',
    'Twilio\\Rest\\Events\\V1\\EventTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/EventTypeInstance.php',
    'Twilio\\Rest\\Events\\V1\\EventTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/EventTypeList.php',
    'Twilio\\Rest\\Events\\V1\\EventTypeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/EventTypeOptions.php',
    'Twilio\\Rest\\Events\\V1\\EventTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/EventTypePage.php',
    'Twilio\\Rest\\Events\\V1\\SchemaContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SchemaContext.php',
    'Twilio\\Rest\\Events\\V1\\SchemaInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SchemaInstance.php',
    'Twilio\\Rest\\Events\\V1\\SchemaList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SchemaList.php',
    'Twilio\\Rest\\Events\\V1\\SchemaPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SchemaPage.php',
    'Twilio\\Rest\\Events\\V1\\Schema\\SchemaVersionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Schema/SchemaVersionContext.php',
    'Twilio\\Rest\\Events\\V1\\Schema\\SchemaVersionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Schema/SchemaVersionInstance.php',
    'Twilio\\Rest\\Events\\V1\\Schema\\SchemaVersionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Schema/SchemaVersionList.php',
    'Twilio\\Rest\\Events\\V1\\Schema\\SchemaVersionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Schema/SchemaVersionPage.php',
    'Twilio\\Rest\\Events\\V1\\SinkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SinkContext.php',
    'Twilio\\Rest\\Events\\V1\\SinkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SinkInstance.php',
    'Twilio\\Rest\\Events\\V1\\SinkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SinkList.php',
    'Twilio\\Rest\\Events\\V1\\SinkOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SinkOptions.php',
    'Twilio\\Rest\\Events\\V1\\SinkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SinkPage.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkTestInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkTestInstance.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkTestList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkTestList.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkTestPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkTestPage.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkValidateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkValidateInstance.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkValidateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkValidateList.php',
    'Twilio\\Rest\\Events\\V1\\Sink\\SinkValidatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Sink/SinkValidatePage.php',
    'Twilio\\Rest\\Events\\V1\\SubscriptionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SubscriptionContext.php',
    'Twilio\\Rest\\Events\\V1\\SubscriptionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SubscriptionInstance.php',
    'Twilio\\Rest\\Events\\V1\\SubscriptionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SubscriptionList.php',
    'Twilio\\Rest\\Events\\V1\\SubscriptionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SubscriptionOptions.php',
    'Twilio\\Rest\\Events\\V1\\SubscriptionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/SubscriptionPage.php',
    'Twilio\\Rest\\Events\\V1\\Subscription\\SubscribedEventContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Subscription/SubscribedEventContext.php',
    'Twilio\\Rest\\Events\\V1\\Subscription\\SubscribedEventInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Subscription/SubscribedEventInstance.php',
    'Twilio\\Rest\\Events\\V1\\Subscription\\SubscribedEventList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Subscription/SubscribedEventList.php',
    'Twilio\\Rest\\Events\\V1\\Subscription\\SubscribedEventOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Subscription/SubscribedEventOptions.php',
    'Twilio\\Rest\\Events\\V1\\Subscription\\SubscribedEventPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Events/V1/Subscription/SubscribedEventPage.php',
    'Twilio\\Rest\\FlexApi' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi.php',
    'Twilio\\Rest\\FlexApiBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApiBase.php',
    'Twilio\\Rest\\FlexApi\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1.php',
    'Twilio\\Rest\\FlexApi\\V1\\AssessmentsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/AssessmentsContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\AssessmentsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/AssessmentsInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\AssessmentsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/AssessmentsList.php',
    'Twilio\\Rest\\FlexApi\\V1\\AssessmentsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/AssessmentsOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\AssessmentsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/AssessmentsPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ChannelContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ChannelInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ChannelList.php',
    'Twilio\\Rest\\FlexApi\\V1\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ChannelOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ChannelPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\ConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ConfigurationContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\ConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ConfigurationInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\ConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ConfigurationList.php',
    'Twilio\\Rest\\FlexApi\\V1\\ConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ConfigurationOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\ConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ConfigurationPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\FlexFlowContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/FlexFlowContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\FlexFlowInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/FlexFlowInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\FlexFlowList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/FlexFlowList.php',
    'Twilio\\Rest\\FlexApi\\V1\\FlexFlowOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/FlexFlowOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\FlexFlowPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/FlexFlowPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsAssessmentsCommentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsAssessmentsCommentInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsAssessmentsCommentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsAssessmentsCommentList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsAssessmentsCommentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsAssessmentsCommentOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsAssessmentsCommentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsAssessmentsCommentPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsConversationsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsConversationsInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsConversationsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsConversationsList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsConversationsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsConversationsOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsConversationsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsConversationsPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesCategoryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesCategoryContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesCategoryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesCategoryInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesCategoryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesCategoryList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesCategoryOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesCategoryOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesCategoryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesCategoryPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesQuestionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesQuestionContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesQuestionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesQuestionInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesQuestionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesQuestionList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesQuestionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesQuestionOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsQuestionnairesQuestionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsQuestionnairesQuestionPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSegmentsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSegmentsInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSegmentsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSegmentsList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSegmentsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSegmentsOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSegmentsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSegmentsPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSessionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSessionContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSessionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSessionInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSessionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSessionList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSessionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSessionOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSessionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSessionPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsAnswerSetsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsAnswerSetsInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsAnswerSetsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsAnswerSetsList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsAnswerSetsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsAnswerSetsOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsAnswerSetsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsAnswerSetsPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsCommentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsCommentInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsCommentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsCommentList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsCommentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsCommentOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsSettingsCommentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsSettingsCommentPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsUserRolesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsUserRolesContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsUserRolesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsUserRolesInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsUserRolesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsUserRolesList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsUserRolesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsUserRolesOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InsightsUserRolesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InsightsUserRolesPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\InteractionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InteractionContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\InteractionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InteractionInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\InteractionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InteractionList.php',
    'Twilio\\Rest\\FlexApi\\V1\\InteractionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InteractionOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\InteractionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/InteractionPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannelContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannelInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannelList.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannelOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannelPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelInviteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelInviteInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelInviteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelInviteList.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelInvitePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelInvitePage.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelParticipantContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelParticipantInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelParticipantList.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelParticipantOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\Interaction\\InteractionChannel\\InteractionChannelParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Interaction/InteractionChannel/InteractionChannelParticipantPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginArchiveContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginArchiveContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginArchiveInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginArchiveInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginArchiveList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginArchiveList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginArchiveOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginArchiveOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginArchivePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginArchivePage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationArchiveContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationArchiveContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationArchiveInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationArchiveInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationArchiveList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationArchiveList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationArchiveOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationArchiveOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationArchivePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationArchivePage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfigurationPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfiguration\\ConfiguredPluginContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfiguration/ConfiguredPluginContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfiguration\\ConfiguredPluginInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfiguration/ConfiguredPluginInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfiguration\\ConfiguredPluginList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfiguration/ConfiguredPluginList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfiguration\\ConfiguredPluginOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfiguration/ConfiguredPluginOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginConfiguration\\ConfiguredPluginPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginConfiguration/ConfiguredPluginPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginReleaseContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginReleaseContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginReleaseInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginReleaseInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginReleaseList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginReleaseList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginReleaseOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginReleaseOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginReleasePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginReleasePage.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginVersionArchiveContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginVersionArchiveContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginVersionArchiveInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginVersionArchiveInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginVersionArchiveList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginVersionArchiveList.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginVersionArchiveOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginVersionArchiveOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\PluginVersionArchivePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/PluginVersionArchivePage.php',
    'Twilio\\Rest\\FlexApi\\V1\\Plugin\\PluginVersionsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Plugin/PluginVersionsContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\Plugin\\PluginVersionsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Plugin/PluginVersionsInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\Plugin\\PluginVersionsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Plugin/PluginVersionsList.php',
    'Twilio\\Rest\\FlexApi\\V1\\Plugin\\PluginVersionsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Plugin/PluginVersionsOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\Plugin\\PluginVersionsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/Plugin/PluginVersionsPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\ProvisioningStatusContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ProvisioningStatusContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\ProvisioningStatusInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ProvisioningStatusInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\ProvisioningStatusList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ProvisioningStatusList.php',
    'Twilio\\Rest\\FlexApi\\V1\\ProvisioningStatusPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/ProvisioningStatusPage.php',
    'Twilio\\Rest\\FlexApi\\V1\\WebChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/WebChannelContext.php',
    'Twilio\\Rest\\FlexApi\\V1\\WebChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/WebChannelInstance.php',
    'Twilio\\Rest\\FlexApi\\V1\\WebChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/WebChannelList.php',
    'Twilio\\Rest\\FlexApi\\V1\\WebChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/WebChannelOptions.php',
    'Twilio\\Rest\\FlexApi\\V1\\WebChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V1/WebChannelPage.php',
    'Twilio\\Rest\\FlexApi\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2.php',
    'Twilio\\Rest\\FlexApi\\V2\\FlexUserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/FlexUserContext.php',
    'Twilio\\Rest\\FlexApi\\V2\\FlexUserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/FlexUserInstance.php',
    'Twilio\\Rest\\FlexApi\\V2\\FlexUserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/FlexUserList.php',
    'Twilio\\Rest\\FlexApi\\V2\\FlexUserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/FlexUserOptions.php',
    'Twilio\\Rest\\FlexApi\\V2\\FlexUserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/FlexUserPage.php',
    'Twilio\\Rest\\FlexApi\\V2\\WebChannelsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/WebChannelsInstance.php',
    'Twilio\\Rest\\FlexApi\\V2\\WebChannelsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/WebChannelsList.php',
    'Twilio\\Rest\\FlexApi\\V2\\WebChannelsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/WebChannelsOptions.php',
    'Twilio\\Rest\\FlexApi\\V2\\WebChannelsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FlexApi/V2/WebChannelsPage.php',
    'Twilio\\Rest\\FrontlineApi' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi.php',
    'Twilio\\Rest\\FrontlineApiBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApiBase.php',
    'Twilio\\Rest\\FrontlineApi\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1.php',
    'Twilio\\Rest\\FrontlineApi\\V1\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1/UserContext.php',
    'Twilio\\Rest\\FrontlineApi\\V1\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1/UserInstance.php',
    'Twilio\\Rest\\FrontlineApi\\V1\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1/UserList.php',
    'Twilio\\Rest\\FrontlineApi\\V1\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1/UserOptions.php',
    'Twilio\\Rest\\FrontlineApi\\V1\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/FrontlineApi/V1/UserPage.php',
    'Twilio\\Rest\\Iam' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam.php',
    'Twilio\\Rest\\IamBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IamBase.php',
    'Twilio\\Rest\\Iam\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1.php',
    'Twilio\\Rest\\Iam\\V1\\ApiKeyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/ApiKeyContext.php',
    'Twilio\\Rest\\Iam\\V1\\ApiKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/ApiKeyInstance.php',
    'Twilio\\Rest\\Iam\\V1\\ApiKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/ApiKeyList.php',
    'Twilio\\Rest\\Iam\\V1\\ApiKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/ApiKeyOptions.php',
    'Twilio\\Rest\\Iam\\V1\\ApiKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/ApiKeyPage.php',
    'Twilio\\Rest\\Iam\\V1\\GetApiKeysInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/GetApiKeysInstance.php',
    'Twilio\\Rest\\Iam\\V1\\GetApiKeysList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/GetApiKeysList.php',
    'Twilio\\Rest\\Iam\\V1\\GetApiKeysPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/GetApiKeysPage.php',
    'Twilio\\Rest\\Iam\\V1\\NewApiKeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/NewApiKeyInstance.php',
    'Twilio\\Rest\\Iam\\V1\\NewApiKeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/NewApiKeyList.php',
    'Twilio\\Rest\\Iam\\V1\\NewApiKeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/NewApiKeyOptions.php',
    'Twilio\\Rest\\Iam\\V1\\NewApiKeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Iam/V1/NewApiKeyPage.php',
    'Twilio\\Rest\\Insights' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights.php',
    'Twilio\\Rest\\InsightsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/InsightsBase.php',
    'Twilio\\Rest\\Insights\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1.php',
    'Twilio\\Rest\\Insights\\V1\\CallContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallContext.php',
    'Twilio\\Rest\\Insights\\V1\\CallInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallInstance.php',
    'Twilio\\Rest\\Insights\\V1\\CallList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallList.php',
    'Twilio\\Rest\\Insights\\V1\\CallPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallPage.php',
    'Twilio\\Rest\\Insights\\V1\\CallSummariesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallSummariesInstance.php',
    'Twilio\\Rest\\Insights\\V1\\CallSummariesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallSummariesList.php',
    'Twilio\\Rest\\Insights\\V1\\CallSummariesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallSummariesOptions.php',
    'Twilio\\Rest\\Insights\\V1\\CallSummariesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/CallSummariesPage.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\AnnotationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/AnnotationContext.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\AnnotationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/AnnotationInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\AnnotationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/AnnotationList.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\AnnotationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/AnnotationOptions.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\AnnotationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/AnnotationPage.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\CallSummaryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/CallSummaryContext.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\CallSummaryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/CallSummaryInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\CallSummaryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/CallSummaryList.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\CallSummaryOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/CallSummaryOptions.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\CallSummaryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/CallSummaryPage.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\EventInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/EventInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\EventList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/EventList.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\EventOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/EventOptions.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\EventPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/EventPage.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\MetricInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/MetricInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\MetricList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/MetricList.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\MetricOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/MetricOptions.php',
    'Twilio\\Rest\\Insights\\V1\\Call\\MetricPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Call/MetricPage.php',
    'Twilio\\Rest\\Insights\\V1\\ConferenceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/ConferenceContext.php',
    'Twilio\\Rest\\Insights\\V1\\ConferenceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/ConferenceInstance.php',
    'Twilio\\Rest\\Insights\\V1\\ConferenceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/ConferenceList.php',
    'Twilio\\Rest\\Insights\\V1\\ConferenceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/ConferenceOptions.php',
    'Twilio\\Rest\\Insights\\V1\\ConferencePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/ConferencePage.php',
    'Twilio\\Rest\\Insights\\V1\\Conference\\ConferenceParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Conference/ConferenceParticipantContext.php',
    'Twilio\\Rest\\Insights\\V1\\Conference\\ConferenceParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Conference/ConferenceParticipantInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Conference\\ConferenceParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Conference/ConferenceParticipantList.php',
    'Twilio\\Rest\\Insights\\V1\\Conference\\ConferenceParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Conference/ConferenceParticipantOptions.php',
    'Twilio\\Rest\\Insights\\V1\\Conference\\ConferenceParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Conference/ConferenceParticipantPage.php',
    'Twilio\\Rest\\Insights\\V1\\RoomContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/RoomContext.php',
    'Twilio\\Rest\\Insights\\V1\\RoomInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/RoomInstance.php',
    'Twilio\\Rest\\Insights\\V1\\RoomList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/RoomList.php',
    'Twilio\\Rest\\Insights\\V1\\RoomOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/RoomOptions.php',
    'Twilio\\Rest\\Insights\\V1\\RoomPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/RoomPage.php',
    'Twilio\\Rest\\Insights\\V1\\Room\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Room/ParticipantContext.php',
    'Twilio\\Rest\\Insights\\V1\\Room\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Room/ParticipantInstance.php',
    'Twilio\\Rest\\Insights\\V1\\Room\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Room/ParticipantList.php',
    'Twilio\\Rest\\Insights\\V1\\Room\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/Room/ParticipantPage.php',
    'Twilio\\Rest\\Insights\\V1\\SettingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/SettingContext.php',
    'Twilio\\Rest\\Insights\\V1\\SettingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/SettingInstance.php',
    'Twilio\\Rest\\Insights\\V1\\SettingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/SettingList.php',
    'Twilio\\Rest\\Insights\\V1\\SettingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/SettingOptions.php',
    'Twilio\\Rest\\Insights\\V1\\SettingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Insights/V1/SettingPage.php',
    'Twilio\\Rest\\Intelligence' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence.php',
    'Twilio\\Rest\\IntelligenceBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IntelligenceBase.php',
    'Twilio\\Rest\\Intelligence\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2.php',
    'Twilio\\Rest\\Intelligence\\V2\\CustomOperatorContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/CustomOperatorContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\CustomOperatorInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/CustomOperatorInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\CustomOperatorList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/CustomOperatorList.php',
    'Twilio\\Rest\\Intelligence\\V2\\CustomOperatorOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/CustomOperatorOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\CustomOperatorPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/CustomOperatorPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentList.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentsContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentsInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentsList.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorAttachmentsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorAttachmentsPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorList.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorTypeContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorTypeInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorTypeList.php',
    'Twilio\\Rest\\Intelligence\\V2\\OperatorTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/OperatorTypePage.php',
    'Twilio\\Rest\\Intelligence\\V2\\PrebuiltOperatorContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/PrebuiltOperatorContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\PrebuiltOperatorInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/PrebuiltOperatorInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\PrebuiltOperatorList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/PrebuiltOperatorList.php',
    'Twilio\\Rest\\Intelligence\\V2\\PrebuiltOperatorOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/PrebuiltOperatorOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\PrebuiltOperatorPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/PrebuiltOperatorPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/ServiceContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/ServiceInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/ServiceList.php',
    'Twilio\\Rest\\Intelligence\\V2\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/ServiceOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/ServicePage.php',
    'Twilio\\Rest\\Intelligence\\V2\\TranscriptContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/TranscriptContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\TranscriptInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/TranscriptInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\TranscriptList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/TranscriptList.php',
    'Twilio\\Rest\\Intelligence\\V2\\TranscriptOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/TranscriptOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\TranscriptPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/TranscriptPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\MediaContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/MediaContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\MediaInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/MediaInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\MediaList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/MediaList.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\MediaOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/MediaOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\MediaPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/MediaPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\OperatorResultContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/OperatorResultContext.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\OperatorResultInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/OperatorResultInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\OperatorResultList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/OperatorResultList.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\OperatorResultOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/OperatorResultOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\OperatorResultPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/OperatorResultPage.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\SentenceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/SentenceInstance.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\SentenceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/SentenceList.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\SentenceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/SentenceOptions.php',
    'Twilio\\Rest\\Intelligence\\V2\\Transcript\\SentencePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Intelligence/V2/Transcript/SentencePage.php',
    'Twilio\\Rest\\IpMessaging' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging.php',
    'Twilio\\Rest\\IpMessagingBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessagingBase.php',
    'Twilio\\Rest\\IpMessaging\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1.php',
    'Twilio\\Rest\\IpMessaging\\V1\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/CredentialContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/CredentialInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/CredentialList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/CredentialOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/CredentialPage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/ServiceContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/ServiceInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/ServiceList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/ServiceOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/ServicePage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/ChannelContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/ChannelInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/ChannelList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/ChannelOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/ChannelPage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\InviteContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/InviteContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\InviteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/InviteInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\InviteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/InviteList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\InviteOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/InviteOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\InvitePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/InvitePage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MemberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MemberContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MemberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MemberInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MemberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MemberList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MemberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MemberOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MemberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MemberPage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MessageContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MessageInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MessageList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MessageOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\Channel\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/Channel/MessagePage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/RoleContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/RoleInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/RoleList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/RolePage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/UserContext.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/UserInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/UserList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/UserOptions.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/UserPage.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\User\\UserChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/User/UserChannelInstance.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\User\\UserChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/User/UserChannelList.php',
    'Twilio\\Rest\\IpMessaging\\V1\\Service\\User\\UserChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V1/Service/User/UserChannelPage.php',
    'Twilio\\Rest\\IpMessaging\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2.php',
    'Twilio\\Rest\\IpMessaging\\V2\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/CredentialContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/CredentialInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/CredentialList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/CredentialOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/CredentialPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/ServiceContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/ServiceInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/ServiceList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/ServiceOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/ServicePage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\BindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/BindingContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\BindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/BindingInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\BindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/BindingList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\BindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/BindingOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\BindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/BindingPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\ChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/ChannelContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\ChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/ChannelInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\ChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/ChannelList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\ChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/ChannelOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\ChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/ChannelPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\InviteContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/InviteContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\InviteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/InviteInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\InviteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/InviteList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\InviteOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/InviteOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\InvitePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/InvitePage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MemberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MemberContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MemberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MemberInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MemberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MemberList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MemberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MemberOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MemberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MemberPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MessageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MessageContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MessageInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MessageList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MessageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MessageOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\MessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/MessagePage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/WebhookContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/WebhookInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/WebhookList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/WebhookOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\Channel\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/Channel/WebhookPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\RoleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/RoleContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\RoleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/RoleInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\RoleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/RoleList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\RolePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/RolePage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\UserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/UserContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\UserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/UserInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\UserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/UserList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\UserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/UserOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\UserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/UserPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserBindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserBindingContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserBindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserBindingInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserBindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserBindingList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserBindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserBindingOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserBindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserBindingPage.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserChannelContext.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserChannelInstance.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserChannelList.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserChannelOptions.php',
    'Twilio\\Rest\\IpMessaging\\V2\\Service\\User\\UserChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/IpMessaging/V2/Service/User/UserChannelPage.php',
    'Twilio\\Rest\\Lookups' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups.php',
    'Twilio\\Rest\\LookupsBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/LookupsBase.php',
    'Twilio\\Rest\\Lookups\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1.php',
    'Twilio\\Rest\\Lookups\\V1\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1/PhoneNumberContext.php',
    'Twilio\\Rest\\Lookups\\V1\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1/PhoneNumberInstance.php',
    'Twilio\\Rest\\Lookups\\V1\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1/PhoneNumberList.php',
    'Twilio\\Rest\\Lookups\\V1\\PhoneNumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1/PhoneNumberOptions.php',
    'Twilio\\Rest\\Lookups\\V1\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V1/PhoneNumberPage.php',
    'Twilio\\Rest\\Lookups\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2.php',
    'Twilio\\Rest\\Lookups\\V2\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2/PhoneNumberContext.php',
    'Twilio\\Rest\\Lookups\\V2\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2/PhoneNumberInstance.php',
    'Twilio\\Rest\\Lookups\\V2\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2/PhoneNumberList.php',
    'Twilio\\Rest\\Lookups\\V2\\PhoneNumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2/PhoneNumberOptions.php',
    'Twilio\\Rest\\Lookups\\V2\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Lookups/V2/PhoneNumberPage.php',
    'Twilio\\Rest\\Marketplace' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace.php',
    'Twilio\\Rest\\MarketplaceBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/MarketplaceBase.php',
    'Twilio\\Rest\\Marketplace\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOnContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOnContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOnInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOnInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOnList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOnList.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOnPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOnPage.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOn\\AvailableAddOnExtensionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOn/AvailableAddOnExtensionContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOn\\AvailableAddOnExtensionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOn/AvailableAddOnExtensionInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOn\\AvailableAddOnExtensionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOn/AvailableAddOnExtensionList.php',
    'Twilio\\Rest\\Marketplace\\V1\\AvailableAddOn\\AvailableAddOnExtensionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/AvailableAddOn/AvailableAddOnExtensionPage.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOnContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOnContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOnInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOnInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOnList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOnList.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOnOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOnOptions.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOnPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOnPage.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnExtensionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnExtensionContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnExtensionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnExtensionInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnExtensionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnExtensionList.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnExtensionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnExtensionPage.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnUsageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnUsageInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnUsageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnUsageList.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnUsageModels' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnUsageModels.php',
    'Twilio\\Rest\\Marketplace\\V1\\InstalledAddOn\\InstalledAddOnUsagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/InstalledAddOn/InstalledAddOnUsagePage.php',
    'Twilio\\Rest\\Marketplace\\V1\\ModuleDataManagementContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ModuleDataManagementContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\ModuleDataManagementInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ModuleDataManagementInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\ModuleDataManagementList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ModuleDataManagementList.php',
    'Twilio\\Rest\\Marketplace\\V1\\ModuleDataManagementOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ModuleDataManagementOptions.php',
    'Twilio\\Rest\\Marketplace\\V1\\ModuleDataManagementPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ModuleDataManagementPage.php',
    'Twilio\\Rest\\Marketplace\\V1\\ReferralConversionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ReferralConversionContext.php',
    'Twilio\\Rest\\Marketplace\\V1\\ReferralConversionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ReferralConversionInstance.php',
    'Twilio\\Rest\\Marketplace\\V1\\ReferralConversionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ReferralConversionList.php',
    'Twilio\\Rest\\Marketplace\\V1\\ReferralConversionModels' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ReferralConversionModels.php',
    'Twilio\\Rest\\Marketplace\\V1\\ReferralConversionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Marketplace/V1/ReferralConversionPage.php',
    'Twilio\\Rest\\Media' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Media.php',
    'Twilio\\Rest\\Messaging' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging.php',
    'Twilio\\Rest\\MessagingBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/MessagingBase.php',
    'Twilio\\Rest\\Messaging\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistrationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistrationContext.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistrationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistrationInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistrationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistrationList.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistrationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistrationOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistrationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistrationPage.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandRegistrationOtpInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandRegistrationOtpInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandRegistrationOtpList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandRegistrationOtpList.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandRegistrationOtpPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandRegistrationOtpPage.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandVettingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandVettingContext.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandVettingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandVettingInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandVettingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandVettingList.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandVettingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandVettingOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\BrandRegistration\\BrandVettingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/BrandRegistration/BrandVettingPage.php',
    'Twilio\\Rest\\Messaging\\V1\\DeactivationsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DeactivationsContext.php',
    'Twilio\\Rest\\Messaging\\V1\\DeactivationsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DeactivationsInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\DeactivationsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DeactivationsList.php',
    'Twilio\\Rest\\Messaging\\V1\\DeactivationsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DeactivationsOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\DeactivationsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DeactivationsPage.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainCertsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainCertsContext.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainCertsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainCertsInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainCertsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainCertsList.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainCertsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainCertsPage.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigContext.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigList.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigMessagingServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigMessagingServiceContext.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigMessagingServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigMessagingServiceInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigMessagingServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigMessagingServiceList.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigMessagingServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigMessagingServicePage.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\DomainConfigPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/DomainConfigPage.php',
    'Twilio\\Rest\\Messaging\\V1\\ExternalCampaignInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ExternalCampaignInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\ExternalCampaignList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ExternalCampaignList.php',
    'Twilio\\Rest\\Messaging\\V1\\ExternalCampaignOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ExternalCampaignOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\ExternalCampaignPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ExternalCampaignPage.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceContext.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceDomainAssociationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceDomainAssociationContext.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceDomainAssociationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceDomainAssociationInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceDomainAssociationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceDomainAssociationList.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceDomainAssociationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceDomainAssociationPage.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServiceList.php',
    'Twilio\\Rest\\Messaging\\V1\\LinkshorteningMessagingServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/LinkshorteningMessagingServicePage.php',
    'Twilio\\Rest\\Messaging\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ServiceContext.php',
    'Twilio\\Rest\\Messaging\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ServiceInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ServiceList.php',
    'Twilio\\Rest\\Messaging\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ServiceOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/ServicePage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\AlphaSenderContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/AlphaSenderContext.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\AlphaSenderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/AlphaSenderInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\AlphaSenderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/AlphaSenderList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\AlphaSenderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/AlphaSenderPage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ChannelSenderContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ChannelSenderContext.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ChannelSenderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ChannelSenderInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ChannelSenderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ChannelSenderList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ChannelSenderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ChannelSenderPage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/PhoneNumberContext.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/PhoneNumberInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/PhoneNumberList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/PhoneNumberPage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ShortCodeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ShortCodeContext.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ShortCodeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ShortCodeInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ShortCodeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ShortCodeList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\ShortCodePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/ShortCodePage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonContext.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonPage.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonUsecaseInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonUsecaseInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonUsecaseList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonUsecaseList.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonUsecaseOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonUsecaseOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\Service\\UsAppToPersonUsecasePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/Service/UsAppToPersonUsecasePage.php',
    'Twilio\\Rest\\Messaging\\V1\\TollfreeVerificationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/TollfreeVerificationContext.php',
    'Twilio\\Rest\\Messaging\\V1\\TollfreeVerificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/TollfreeVerificationInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\TollfreeVerificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/TollfreeVerificationList.php',
    'Twilio\\Rest\\Messaging\\V1\\TollfreeVerificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/TollfreeVerificationOptions.php',
    'Twilio\\Rest\\Messaging\\V1\\TollfreeVerificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/TollfreeVerificationPage.php',
    'Twilio\\Rest\\Messaging\\V1\\UsecaseInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/UsecaseInstance.php',
    'Twilio\\Rest\\Messaging\\V1\\UsecaseList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/UsecaseList.php',
    'Twilio\\Rest\\Messaging\\V1\\UsecasePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Messaging/V1/UsecasePage.php',
    'Twilio\\Rest\\Microvisor' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor.php',
    'Twilio\\Rest\\MicrovisorBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/MicrovisorBase.php',
    'Twilio\\Rest\\Microvisor\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountConfigContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountConfigContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountConfigInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountConfigInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountConfigList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountConfigList.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountConfigPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountConfigPage.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountSecretContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountSecretContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountSecretInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountSecretInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountSecretList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountSecretList.php',
    'Twilio\\Rest\\Microvisor\\V1\\AccountSecretPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AccountSecretPage.php',
    'Twilio\\Rest\\Microvisor\\V1\\AppContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AppContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\AppInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AppInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\AppList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AppList.php',
    'Twilio\\Rest\\Microvisor\\V1\\AppPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/AppPage.php',
    'Twilio\\Rest\\Microvisor\\V1\\App\\AppManifestContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/App/AppManifestContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\App\\AppManifestInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/App/AppManifestInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\App\\AppManifestList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/App/AppManifestList.php',
    'Twilio\\Rest\\Microvisor\\V1\\App\\AppManifestPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/App/AppManifestPage.php',
    'Twilio\\Rest\\Microvisor\\V1\\DeviceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/DeviceContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\DeviceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/DeviceInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\DeviceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/DeviceList.php',
    'Twilio\\Rest\\Microvisor\\V1\\DeviceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/DeviceOptions.php',
    'Twilio\\Rest\\Microvisor\\V1\\DevicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/DevicePage.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceConfigContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceConfigContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceConfigInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceConfigInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceConfigList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceConfigList.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceConfigPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceConfigPage.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceSecretContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceSecretContext.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceSecretInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceSecretInstance.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceSecretList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceSecretList.php',
    'Twilio\\Rest\\Microvisor\\V1\\Device\\DeviceSecretPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Microvisor/V1/Device/DeviceSecretPage.php',
    'Twilio\\Rest\\Monitor' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor.php',
    'Twilio\\Rest\\MonitorBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/MonitorBase.php',
    'Twilio\\Rest\\Monitor\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1.php',
    'Twilio\\Rest\\Monitor\\V1\\AlertContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/AlertContext.php',
    'Twilio\\Rest\\Monitor\\V1\\AlertInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/AlertInstance.php',
    'Twilio\\Rest\\Monitor\\V1\\AlertList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/AlertList.php',
    'Twilio\\Rest\\Monitor\\V1\\AlertOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/AlertOptions.php',
    'Twilio\\Rest\\Monitor\\V1\\AlertPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/AlertPage.php',
    'Twilio\\Rest\\Monitor\\V1\\EventContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/EventContext.php',
    'Twilio\\Rest\\Monitor\\V1\\EventInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/EventInstance.php',
    'Twilio\\Rest\\Monitor\\V1\\EventList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/EventList.php',
    'Twilio\\Rest\\Monitor\\V1\\EventOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/EventOptions.php',
    'Twilio\\Rest\\Monitor\\V1\\EventPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Monitor/V1/EventPage.php',
    'Twilio\\Rest\\Notify' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify.php',
    'Twilio\\Rest\\NotifyBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/NotifyBase.php',
    'Twilio\\Rest\\Notify\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1.php',
    'Twilio\\Rest\\Notify\\V1\\CredentialContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/CredentialContext.php',
    'Twilio\\Rest\\Notify\\V1\\CredentialInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/CredentialInstance.php',
    'Twilio\\Rest\\Notify\\V1\\CredentialList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/CredentialList.php',
    'Twilio\\Rest\\Notify\\V1\\CredentialOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/CredentialOptions.php',
    'Twilio\\Rest\\Notify\\V1\\CredentialPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/CredentialPage.php',
    'Twilio\\Rest\\Notify\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/ServiceContext.php',
    'Twilio\\Rest\\Notify\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/ServiceInstance.php',
    'Twilio\\Rest\\Notify\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/ServiceList.php',
    'Twilio\\Rest\\Notify\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/ServiceOptions.php',
    'Twilio\\Rest\\Notify\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/ServicePage.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\BindingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/BindingContext.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\BindingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/BindingInstance.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\BindingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/BindingList.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\BindingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/BindingOptions.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\BindingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/BindingPage.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\NotificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/NotificationInstance.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\NotificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/NotificationList.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\NotificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/NotificationOptions.php',
    'Twilio\\Rest\\Notify\\V1\\Service\\NotificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Notify/V1/Service/NotificationPage.php',
    'Twilio\\Rest\\Numbers' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers.php',
    'Twilio\\Rest\\NumbersBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/NumbersBase.php',
    'Twilio\\Rest\\Numbers\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1.php',
    'Twilio\\Rest\\Numbers\\V1\\BulkEligibilityContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/BulkEligibilityContext.php',
    'Twilio\\Rest\\Numbers\\V1\\BulkEligibilityInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/BulkEligibilityInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\BulkEligibilityList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/BulkEligibilityList.php',
    'Twilio\\Rest\\Numbers\\V1\\BulkEligibilityPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/BulkEligibilityPage.php',
    'Twilio\\Rest\\Numbers\\V1\\EligibilityInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/EligibilityInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\EligibilityList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/EligibilityList.php',
    'Twilio\\Rest\\Numbers\\V1\\EligibilityPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/EligibilityPage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInContext.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInPage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInPhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInPhoneNumberContext.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInPhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInPhoneNumberInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInPhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInPhoneNumberList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortInPhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortInPhoneNumberPage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortabilityContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortabilityContext.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortabilityInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortabilityInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortabilityList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortabilityList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortabilityOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortabilityOptions.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingPortabilityPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingPortabilityPage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationDeleteContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationDeleteContext.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationDeleteInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationDeleteInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationDeleteList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationDeleteList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationDeletePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationDeletePage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationFetchInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationFetchInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationFetchList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationFetchList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationFetchPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationFetchPage.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationList.php',
    'Twilio\\Rest\\Numbers\\V1\\PortingWebhookConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/PortingWebhookConfigurationPage.php',
    'Twilio\\Rest\\Numbers\\V1\\SigningRequestConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/SigningRequestConfigurationInstance.php',
    'Twilio\\Rest\\Numbers\\V1\\SigningRequestConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/SigningRequestConfigurationList.php',
    'Twilio\\Rest\\Numbers\\V1\\SigningRequestConfigurationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/SigningRequestConfigurationOptions.php',
    'Twilio\\Rest\\Numbers\\V1\\SigningRequestConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V1/SigningRequestConfigurationPage.php',
    'Twilio\\Rest\\Numbers\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocumentContext.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocumentInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocumentList.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocumentOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocumentPage.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocument\\DependentHostedNumberOrderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocument/DependentHostedNumberOrderInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocument\\DependentHostedNumberOrderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocument/DependentHostedNumberOrderList.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocument\\DependentHostedNumberOrderOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocument/DependentHostedNumberOrderOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\AuthorizationDocument\\DependentHostedNumberOrderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/AuthorizationDocument/DependentHostedNumberOrderPage.php',
    'Twilio\\Rest\\Numbers\\V2\\BulkHostedNumberOrderContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BulkHostedNumberOrderContext.php',
    'Twilio\\Rest\\Numbers\\V2\\BulkHostedNumberOrderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BulkHostedNumberOrderInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\BulkHostedNumberOrderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BulkHostedNumberOrderList.php',
    'Twilio\\Rest\\Numbers\\V2\\BulkHostedNumberOrderOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BulkHostedNumberOrderOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\BulkHostedNumberOrderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BulkHostedNumberOrderPage.php',
    'Twilio\\Rest\\Numbers\\V2\\BundleCloneContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BundleCloneContext.php',
    'Twilio\\Rest\\Numbers\\V2\\BundleCloneInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BundleCloneInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\BundleCloneList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BundleCloneList.php',
    'Twilio\\Rest\\Numbers\\V2\\BundleCloneOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BundleCloneOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\BundleClonePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/BundleClonePage.php',
    'Twilio\\Rest\\Numbers\\V2\\HostedNumberOrderContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/HostedNumberOrderContext.php',
    'Twilio\\Rest\\Numbers\\V2\\HostedNumberOrderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/HostedNumberOrderInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\HostedNumberOrderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/HostedNumberOrderList.php',
    'Twilio\\Rest\\Numbers\\V2\\HostedNumberOrderOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/HostedNumberOrderOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\HostedNumberOrderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/HostedNumberOrderPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryComplianceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryComplianceInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryComplianceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryComplianceList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliancePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliancePage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\BundleContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/BundleContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\BundleInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/BundleInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\BundleList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/BundleList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\BundleOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/BundleOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\BundlePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/BundlePage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\BundleCopyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/BundleCopyInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\BundleCopyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/BundleCopyList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\BundleCopyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/BundleCopyOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\BundleCopyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/BundleCopyPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\EvaluationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/EvaluationContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\EvaluationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/EvaluationInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\EvaluationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/EvaluationList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\EvaluationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/EvaluationPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ItemAssignmentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ItemAssignmentContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ItemAssignmentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ItemAssignmentInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ItemAssignmentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ItemAssignmentList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ItemAssignmentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ItemAssignmentPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ReplaceItemsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ReplaceItemsInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ReplaceItemsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ReplaceItemsList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\Bundle\\ReplaceItemsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/Bundle/ReplaceItemsPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserTypeContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserTypeInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserTypeList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\EndUserTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/EndUserTypePage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\RegulationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/RegulationContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\RegulationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/RegulationInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\RegulationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/RegulationList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\RegulationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/RegulationOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\RegulationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/RegulationPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentOptions.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentPage.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentTypeContext.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentTypeInstance.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentTypeList.php',
    'Twilio\\Rest\\Numbers\\V2\\RegulatoryCompliance\\SupportingDocumentTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Numbers/V2/RegulatoryCompliance/SupportingDocumentTypePage.php',
    'Twilio\\Rest\\Oauth' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth.php',
    'Twilio\\Rest\\OauthBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/OauthBase.php',
    'Twilio\\Rest\\Oauth\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1.php',
    'Twilio\\Rest\\Oauth\\V1\\AuthorizeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/AuthorizeInstance.php',
    'Twilio\\Rest\\Oauth\\V1\\AuthorizeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/AuthorizeList.php',
    'Twilio\\Rest\\Oauth\\V1\\AuthorizeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/AuthorizeOptions.php',
    'Twilio\\Rest\\Oauth\\V1\\AuthorizePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/AuthorizePage.php',
    'Twilio\\Rest\\Oauth\\V1\\TokenInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/TokenInstance.php',
    'Twilio\\Rest\\Oauth\\V1\\TokenList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/TokenList.php',
    'Twilio\\Rest\\Oauth\\V1\\TokenOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/TokenOptions.php',
    'Twilio\\Rest\\Oauth\\V1\\TokenPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Oauth/V1/TokenPage.php',
    'Twilio\\Rest\\Preview' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview.php',
    'Twilio\\Rest\\PreviewBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/PreviewBase.php',
    'Twilio\\Rest\\PreviewMessaging' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/PreviewMessaging.php',
    'Twilio\\Rest\\Preview\\DeployedDevices' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\FleetContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/FleetContext.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\FleetInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/FleetInstance.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\FleetList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/FleetList.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\FleetOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/FleetOptions.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\FleetPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/FleetPage.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\CertificateContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/CertificateContext.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\CertificateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/CertificateInstance.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\CertificateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/CertificateList.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\CertificateOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/CertificateOptions.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\CertificatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/CertificatePage.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeploymentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeploymentContext.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeploymentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeploymentInstance.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeploymentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeploymentList.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeploymentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeploymentOptions.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeploymentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeploymentPage.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeviceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeviceContext.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeviceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeviceInstance.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeviceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeviceList.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DeviceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DeviceOptions.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\DevicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/DevicePage.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\KeyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/KeyContext.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\KeyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/KeyInstance.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\KeyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/KeyList.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\KeyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/KeyOptions.php',
    'Twilio\\Rest\\Preview\\DeployedDevices\\Fleet\\KeyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/DeployedDevices/Fleet/KeyPage.php',
    'Twilio\\Rest\\Preview\\HostedNumbers' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocumentContext.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocumentInstance.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocumentList.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocumentOptions.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocumentPage.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocument\\DependentHostedNumberOrderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocument/DependentHostedNumberOrderInstance.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocument\\DependentHostedNumberOrderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocument/DependentHostedNumberOrderList.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocument\\DependentHostedNumberOrderOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocument/DependentHostedNumberOrderOptions.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\AuthorizationDocument\\DependentHostedNumberOrderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/AuthorizationDocument/DependentHostedNumberOrderPage.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\HostedNumberOrderContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/HostedNumberOrderContext.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\HostedNumberOrderInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/HostedNumberOrderInstance.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\HostedNumberOrderList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/HostedNumberOrderList.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\HostedNumberOrderOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/HostedNumberOrderOptions.php',
    'Twilio\\Rest\\Preview\\HostedNumbers\\HostedNumberOrderPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/HostedNumbers/HostedNumberOrderPage.php',
    'Twilio\\Rest\\Preview\\Marketplace' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOnContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOnContext.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOnInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOnInstance.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOnList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOnList.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOnPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOnPage.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOn\\AvailableAddOnExtensionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOn/AvailableAddOnExtensionContext.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOn\\AvailableAddOnExtensionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOn/AvailableAddOnExtensionInstance.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOn\\AvailableAddOnExtensionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOn/AvailableAddOnExtensionList.php',
    'Twilio\\Rest\\Preview\\Marketplace\\AvailableAddOn\\AvailableAddOnExtensionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/AvailableAddOn/AvailableAddOnExtensionPage.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOnContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOnContext.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOnInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOnInstance.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOnList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOnList.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOnOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOnOptions.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOnPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOnPage.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOn\\InstalledAddOnExtensionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOn/InstalledAddOnExtensionContext.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOn\\InstalledAddOnExtensionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOn/InstalledAddOnExtensionInstance.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOn\\InstalledAddOnExtensionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOn/InstalledAddOnExtensionList.php',
    'Twilio\\Rest\\Preview\\Marketplace\\InstalledAddOn\\InstalledAddOnExtensionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Marketplace/InstalledAddOn/InstalledAddOnExtensionPage.php',
    'Twilio\\Rest\\Preview\\Sync' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync.php',
    'Twilio\\Rest\\Preview\\Sync\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/ServiceContext.php',
    'Twilio\\Rest\\Preview\\Sync\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/ServiceInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/ServiceList.php',
    'Twilio\\Rest\\Preview\\Sync\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/ServiceOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/ServicePage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\DocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/DocumentContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\DocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/DocumentInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\DocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/DocumentList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\DocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/DocumentOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\DocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/DocumentPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\Document\\DocumentPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/Document/DocumentPermissionContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\Document\\DocumentPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/Document/DocumentPermissionInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\Document\\DocumentPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/Document/DocumentPermissionList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\Document\\DocumentPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/Document/DocumentPermissionPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncListContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncListInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncListList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncListOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncListOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncListPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListItemContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListItemContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListItemInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListItemInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListItemList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListItemList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListItemOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListItemOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListItemPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListItemPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListPermissionContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListPermissionInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListPermissionList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncList\\SyncListPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncList/SyncListPermissionPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMapContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMapContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMapInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMapInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMapList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMapList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMapOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMapOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMapPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMapPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapItemContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapItemContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapItemInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapItemInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapItemList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapItemList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapItemOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapItemOptions.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapItemPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapItemPage.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapPermissionContext.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapPermissionInstance.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapPermissionList.php',
    'Twilio\\Rest\\Preview\\Sync\\Service\\SyncMap\\SyncMapPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Sync/Service/SyncMap/SyncMapPermissionPage.php',
    'Twilio\\Rest\\Preview\\Wireless' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless.php',
    'Twilio\\Rest\\Preview\\Wireless\\CommandContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/CommandContext.php',
    'Twilio\\Rest\\Preview\\Wireless\\CommandInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/CommandInstance.php',
    'Twilio\\Rest\\Preview\\Wireless\\CommandList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/CommandList.php',
    'Twilio\\Rest\\Preview\\Wireless\\CommandOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/CommandOptions.php',
    'Twilio\\Rest\\Preview\\Wireless\\CommandPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/CommandPage.php',
    'Twilio\\Rest\\Preview\\Wireless\\RatePlanContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/RatePlanContext.php',
    'Twilio\\Rest\\Preview\\Wireless\\RatePlanInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/RatePlanInstance.php',
    'Twilio\\Rest\\Preview\\Wireless\\RatePlanList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/RatePlanList.php',
    'Twilio\\Rest\\Preview\\Wireless\\RatePlanOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/RatePlanOptions.php',
    'Twilio\\Rest\\Preview\\Wireless\\RatePlanPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/RatePlanPage.php',
    'Twilio\\Rest\\Preview\\Wireless\\SimContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/SimContext.php',
    'Twilio\\Rest\\Preview\\Wireless\\SimInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/SimInstance.php',
    'Twilio\\Rest\\Preview\\Wireless\\SimList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/SimList.php',
    'Twilio\\Rest\\Preview\\Wireless\\SimOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/SimOptions.php',
    'Twilio\\Rest\\Preview\\Wireless\\SimPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/SimPage.php',
    'Twilio\\Rest\\Preview\\Wireless\\Sim\\UsageContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/Sim/UsageContext.php',
    'Twilio\\Rest\\Preview\\Wireless\\Sim\\UsageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/Sim/UsageInstance.php',
    'Twilio\\Rest\\Preview\\Wireless\\Sim\\UsageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/Sim/UsageList.php',
    'Twilio\\Rest\\Preview\\Wireless\\Sim\\UsageOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/Sim/UsageOptions.php',
    'Twilio\\Rest\\Preview\\Wireless\\Sim\\UsagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Preview/Wireless/Sim/UsagePage.php',
    'Twilio\\Rest\\Pricing' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing.php',
    'Twilio\\Rest\\PricingBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/PricingBase.php',
    'Twilio\\Rest\\Pricing\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1.php',
    'Twilio\\Rest\\Pricing\\V1\\MessagingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/MessagingInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\MessagingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/MessagingList.php',
    'Twilio\\Rest\\Pricing\\V1\\MessagingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/MessagingPage.php',
    'Twilio\\Rest\\Pricing\\V1\\Messaging\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Messaging/CountryContext.php',
    'Twilio\\Rest\\Pricing\\V1\\Messaging\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Messaging/CountryInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\Messaging\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Messaging/CountryList.php',
    'Twilio\\Rest\\Pricing\\V1\\Messaging\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Messaging/CountryPage.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumberInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumberList.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumberPage.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumber\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumber/CountryContext.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumber\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumber/CountryInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumber\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumber/CountryList.php',
    'Twilio\\Rest\\Pricing\\V1\\PhoneNumber\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/PhoneNumber/CountryPage.php',
    'Twilio\\Rest\\Pricing\\V1\\VoiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/VoiceInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\VoiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/VoiceList.php',
    'Twilio\\Rest\\Pricing\\V1\\VoicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/VoicePage.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/CountryContext.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/CountryInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/CountryList.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/CountryPage.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\NumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/NumberContext.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\NumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/NumberInstance.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\NumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/NumberList.php',
    'Twilio\\Rest\\Pricing\\V1\\Voice\\NumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V1/Voice/NumberPage.php',
    'Twilio\\Rest\\Pricing\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2.php',
    'Twilio\\Rest\\Pricing\\V2\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/CountryContext.php',
    'Twilio\\Rest\\Pricing\\V2\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/CountryInstance.php',
    'Twilio\\Rest\\Pricing\\V2\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/CountryList.php',
    'Twilio\\Rest\\Pricing\\V2\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/CountryPage.php',
    'Twilio\\Rest\\Pricing\\V2\\NumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/NumberContext.php',
    'Twilio\\Rest\\Pricing\\V2\\NumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/NumberInstance.php',
    'Twilio\\Rest\\Pricing\\V2\\NumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/NumberList.php',
    'Twilio\\Rest\\Pricing\\V2\\NumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/NumberOptions.php',
    'Twilio\\Rest\\Pricing\\V2\\NumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/NumberPage.php',
    'Twilio\\Rest\\Pricing\\V2\\VoiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/VoiceInstance.php',
    'Twilio\\Rest\\Pricing\\V2\\VoiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/VoiceList.php',
    'Twilio\\Rest\\Pricing\\V2\\VoicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/VoicePage.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/CountryContext.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/CountryInstance.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/CountryList.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/CountryPage.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\NumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/NumberContext.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\NumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/NumberInstance.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\NumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/NumberList.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\NumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/NumberOptions.php',
    'Twilio\\Rest\\Pricing\\V2\\Voice\\NumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Pricing/V2/Voice/NumberPage.php',
    'Twilio\\Rest\\Proxy' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy.php',
    'Twilio\\Rest\\ProxyBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ProxyBase.php',
    'Twilio\\Rest\\Proxy\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1.php',
    'Twilio\\Rest\\Proxy\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/ServiceContext.php',
    'Twilio\\Rest\\Proxy\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/ServiceInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/ServiceList.php',
    'Twilio\\Rest\\Proxy\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/ServiceOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/ServicePage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/PhoneNumberContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/PhoneNumberInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/PhoneNumberList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\PhoneNumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/PhoneNumberOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/PhoneNumberPage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\SessionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/SessionContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\SessionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/SessionInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\SessionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/SessionList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\SessionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/SessionOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\SessionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/SessionPage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\InteractionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/InteractionContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\InteractionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/InteractionInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\InteractionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/InteractionList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\InteractionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/InteractionPage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/ParticipantContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/ParticipantInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/ParticipantList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\ParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/ParticipantOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/ParticipantPage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\Participant\\MessageInteractionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/Participant/MessageInteractionContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\Participant\\MessageInteractionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/Participant/MessageInteractionInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\Participant\\MessageInteractionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/Participant/MessageInteractionList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\Participant\\MessageInteractionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/Participant/MessageInteractionOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\Session\\Participant\\MessageInteractionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/Session/Participant/MessageInteractionPage.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\ShortCodeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/ShortCodeContext.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\ShortCodeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/ShortCodeInstance.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\ShortCodeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/ShortCodeList.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\ShortCodeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/ShortCodeOptions.php',
    'Twilio\\Rest\\Proxy\\V1\\Service\\ShortCodePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Proxy/V1/Service/ShortCodePage.php',
    'Twilio\\Rest\\Routes' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes.php',
    'Twilio\\Rest\\RoutesBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/RoutesBase.php',
    'Twilio\\Rest\\Routes\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2.php',
    'Twilio\\Rest\\Routes\\V2\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/PhoneNumberContext.php',
    'Twilio\\Rest\\Routes\\V2\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/PhoneNumberInstance.php',
    'Twilio\\Rest\\Routes\\V2\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/PhoneNumberList.php',
    'Twilio\\Rest\\Routes\\V2\\PhoneNumberOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/PhoneNumberOptions.php',
    'Twilio\\Rest\\Routes\\V2\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/PhoneNumberPage.php',
    'Twilio\\Rest\\Routes\\V2\\SipDomainContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/SipDomainContext.php',
    'Twilio\\Rest\\Routes\\V2\\SipDomainInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/SipDomainInstance.php',
    'Twilio\\Rest\\Routes\\V2\\SipDomainList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/SipDomainList.php',
    'Twilio\\Rest\\Routes\\V2\\SipDomainOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/SipDomainOptions.php',
    'Twilio\\Rest\\Routes\\V2\\SipDomainPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/SipDomainPage.php',
    'Twilio\\Rest\\Routes\\V2\\TrunkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/TrunkContext.php',
    'Twilio\\Rest\\Routes\\V2\\TrunkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/TrunkInstance.php',
    'Twilio\\Rest\\Routes\\V2\\TrunkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/TrunkList.php',
    'Twilio\\Rest\\Routes\\V2\\TrunkOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/TrunkOptions.php',
    'Twilio\\Rest\\Routes\\V2\\TrunkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Routes/V2/TrunkPage.php',
    'Twilio\\Rest\\Serverless' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless.php',
    'Twilio\\Rest\\ServerlessBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/ServerlessBase.php',
    'Twilio\\Rest\\Serverless\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1.php',
    'Twilio\\Rest\\Serverless\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/ServiceContext.php',
    'Twilio\\Rest\\Serverless\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/ServiceInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/ServiceList.php',
    'Twilio\\Rest\\Serverless\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/ServiceOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/ServicePage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\AssetContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/AssetContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\AssetInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/AssetInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\AssetList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/AssetList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\AssetPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/AssetPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Asset\\AssetVersionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Asset/AssetVersionContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Asset\\AssetVersionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Asset/AssetVersionInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Asset\\AssetVersionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Asset/AssetVersionList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Asset\\AssetVersionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Asset/AssetVersionPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\BuildContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/BuildContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\BuildInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/BuildInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\BuildList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/BuildList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\BuildOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/BuildOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\BuildPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/BuildPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Build\\BuildStatusContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Build/BuildStatusContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Build\\BuildStatusInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Build/BuildStatusInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Build\\BuildStatusList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Build/BuildStatusList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Build\\BuildStatusPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Build/BuildStatusPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\EnvironmentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/EnvironmentContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\EnvironmentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/EnvironmentInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\EnvironmentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/EnvironmentList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\EnvironmentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/EnvironmentOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\EnvironmentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/EnvironmentPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\DeploymentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/DeploymentContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\DeploymentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/DeploymentInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\DeploymentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/DeploymentList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\DeploymentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/DeploymentOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\DeploymentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/DeploymentPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\LogContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/LogContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\LogInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/LogInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\LogList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/LogList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\LogOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/LogOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\LogPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/LogPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\VariableContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/VariableContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\VariableInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/VariableInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\VariableList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/VariableList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\VariableOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/VariableOptions.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\Environment\\VariablePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/Environment/VariablePage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\FunctionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/FunctionContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\FunctionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/FunctionInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\FunctionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/FunctionList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\FunctionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/FunctionPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersionContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersionInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersionList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersionPage.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersion\\FunctionVersionContentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersion/FunctionVersionContentContext.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersion\\FunctionVersionContentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersion/FunctionVersionContentInstance.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersion\\FunctionVersionContentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersion/FunctionVersionContentList.php',
    'Twilio\\Rest\\Serverless\\V1\\Service\\TwilioFunction\\FunctionVersion\\FunctionVersionContentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Serverless/V1/Service/TwilioFunction/FunctionVersion/FunctionVersionContentPage.php',
    'Twilio\\Rest\\Studio' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio.php',
    'Twilio\\Rest\\StudioBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/StudioBase.php',
    'Twilio\\Rest\\Studio\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1.php',
    'Twilio\\Rest\\Studio\\V1\\FlowContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/FlowContext.php',
    'Twilio\\Rest\\Studio\\V1\\FlowInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/FlowInstance.php',
    'Twilio\\Rest\\Studio\\V1\\FlowList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/FlowList.php',
    'Twilio\\Rest\\Studio\\V1\\FlowPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/FlowPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\EngagementContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/EngagementContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\EngagementInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/EngagementInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\EngagementList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/EngagementList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\EngagementOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/EngagementOptions.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\EngagementPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/EngagementPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\EngagementContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/EngagementContextContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\EngagementContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/EngagementContextInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\EngagementContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/EngagementContextList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\EngagementContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/EngagementContextPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\StepContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/StepContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\StepInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/StepInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\StepList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/StepList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\StepPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/StepPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\Step\\StepContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/Step/StepContextContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\Step\\StepContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/Step/StepContextInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\Step\\StepContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/Step/StepContextList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Engagement\\Step\\StepContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Engagement/Step/StepContextPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\ExecutionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/ExecutionContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\ExecutionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/ExecutionInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\ExecutionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/ExecutionList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\ExecutionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/ExecutionOptions.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\ExecutionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/ExecutionPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionContextContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionContextInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionContextList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionContextPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStepContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStepContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStepInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStepInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStepList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStepList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStepPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStepPage.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStep/ExecutionStepContextContext.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStep/ExecutionStepContextInstance.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStep/ExecutionStepContextList.php',
    'Twilio\\Rest\\Studio\\V1\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V1/Flow/Execution/ExecutionStep/ExecutionStepContextPage.php',
    'Twilio\\Rest\\Studio\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2.php',
    'Twilio\\Rest\\Studio\\V2\\FlowContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowContext.php',
    'Twilio\\Rest\\Studio\\V2\\FlowInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowInstance.php',
    'Twilio\\Rest\\Studio\\V2\\FlowList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowList.php',
    'Twilio\\Rest\\Studio\\V2\\FlowOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowOptions.php',
    'Twilio\\Rest\\Studio\\V2\\FlowPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowPage.php',
    'Twilio\\Rest\\Studio\\V2\\FlowValidateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowValidateInstance.php',
    'Twilio\\Rest\\Studio\\V2\\FlowValidateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowValidateList.php',
    'Twilio\\Rest\\Studio\\V2\\FlowValidateOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowValidateOptions.php',
    'Twilio\\Rest\\Studio\\V2\\FlowValidatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/FlowValidatePage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\ExecutionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/ExecutionContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\ExecutionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/ExecutionInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\ExecutionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/ExecutionList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\ExecutionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/ExecutionOptions.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\ExecutionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/ExecutionPage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionContextContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionContextInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionContextList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionContextPage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStepContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStepContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStepInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStepInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStepList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStepList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStepPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStepPage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStep/ExecutionStepContextContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStep/ExecutionStepContextInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStep/ExecutionStepContextList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\Execution\\ExecutionStep\\ExecutionStepContextPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/Execution/ExecutionStep/ExecutionStepContextPage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowRevisionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowRevisionContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowRevisionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowRevisionInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowRevisionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowRevisionList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowRevisionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowRevisionPage.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowTestUserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowTestUserContext.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowTestUserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowTestUserInstance.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowTestUserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowTestUserList.php',
    'Twilio\\Rest\\Studio\\V2\\Flow\\FlowTestUserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Studio/V2/Flow/FlowTestUserPage.php',
    'Twilio\\Rest\\Supersim' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim.php',
    'Twilio\\Rest\\SupersimBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/SupersimBase.php',
    'Twilio\\Rest\\Supersim\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1.php',
    'Twilio\\Rest\\Supersim\\V1\\EsimProfileContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/EsimProfileContext.php',
    'Twilio\\Rest\\Supersim\\V1\\EsimProfileInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/EsimProfileInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\EsimProfileList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/EsimProfileList.php',
    'Twilio\\Rest\\Supersim\\V1\\EsimProfileOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/EsimProfileOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\EsimProfilePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/EsimProfilePage.php',
    'Twilio\\Rest\\Supersim\\V1\\FleetContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/FleetContext.php',
    'Twilio\\Rest\\Supersim\\V1\\FleetInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/FleetInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\FleetList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/FleetList.php',
    'Twilio\\Rest\\Supersim\\V1\\FleetOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/FleetOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\FleetPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/FleetPage.php',
    'Twilio\\Rest\\Supersim\\V1\\IpCommandContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/IpCommandContext.php',
    'Twilio\\Rest\\Supersim\\V1\\IpCommandInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/IpCommandInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\IpCommandList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/IpCommandList.php',
    'Twilio\\Rest\\Supersim\\V1\\IpCommandOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/IpCommandOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\IpCommandPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/IpCommandPage.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfileContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfileContext.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfileInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfileInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfileList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfileList.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfileOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfileOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfilePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfilePage.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfile\\NetworkAccessProfileNetworkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfile/NetworkAccessProfileNetworkContext.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfile\\NetworkAccessProfileNetworkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfile/NetworkAccessProfileNetworkInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfile\\NetworkAccessProfileNetworkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfile/NetworkAccessProfileNetworkList.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkAccessProfile\\NetworkAccessProfileNetworkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkAccessProfile/NetworkAccessProfileNetworkPage.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkContext.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkList.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\NetworkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/NetworkPage.php',
    'Twilio\\Rest\\Supersim\\V1\\SettingsUpdateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SettingsUpdateInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\SettingsUpdateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SettingsUpdateList.php',
    'Twilio\\Rest\\Supersim\\V1\\SettingsUpdateOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SettingsUpdateOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\SettingsUpdatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SettingsUpdatePage.php',
    'Twilio\\Rest\\Supersim\\V1\\SimContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SimContext.php',
    'Twilio\\Rest\\Supersim\\V1\\SimInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SimInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\SimList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SimList.php',
    'Twilio\\Rest\\Supersim\\V1\\SimOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SimOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\SimPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SimPage.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\BillingPeriodInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/BillingPeriodInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\BillingPeriodList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/BillingPeriodList.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\BillingPeriodPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/BillingPeriodPage.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\SimIpAddressInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/SimIpAddressInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\SimIpAddressList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/SimIpAddressList.php',
    'Twilio\\Rest\\Supersim\\V1\\Sim\\SimIpAddressPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/Sim/SimIpAddressPage.php',
    'Twilio\\Rest\\Supersim\\V1\\SmsCommandContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SmsCommandContext.php',
    'Twilio\\Rest\\Supersim\\V1\\SmsCommandInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SmsCommandInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\SmsCommandList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SmsCommandList.php',
    'Twilio\\Rest\\Supersim\\V1\\SmsCommandOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SmsCommandOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\SmsCommandPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/SmsCommandPage.php',
    'Twilio\\Rest\\Supersim\\V1\\UsageRecordInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/UsageRecordInstance.php',
    'Twilio\\Rest\\Supersim\\V1\\UsageRecordList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/UsageRecordList.php',
    'Twilio\\Rest\\Supersim\\V1\\UsageRecordOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/UsageRecordOptions.php',
    'Twilio\\Rest\\Supersim\\V1\\UsageRecordPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Supersim/V1/UsageRecordPage.php',
    'Twilio\\Rest\\Sync' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync.php',
    'Twilio\\Rest\\SyncBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/SyncBase.php',
    'Twilio\\Rest\\Sync\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1.php',
    'Twilio\\Rest\\Sync\\V1\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/ServiceContext.php',
    'Twilio\\Rest\\Sync\\V1\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/ServiceInstance.php',
    'Twilio\\Rest\\Sync\\V1\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/ServiceList.php',
    'Twilio\\Rest\\Sync\\V1\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/ServiceOptions.php',
    'Twilio\\Rest\\Sync\\V1\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/ServicePage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\DocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/DocumentContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\DocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/DocumentInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\DocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/DocumentList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\DocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/DocumentOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\DocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/DocumentPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\Document\\DocumentPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/Document/DocumentPermissionContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\Document\\DocumentPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/Document/DocumentPermissionInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\Document\\DocumentPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/Document/DocumentPermissionList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\Document\\DocumentPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/Document/DocumentPermissionPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncListContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncListInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncListList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncListOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncListOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncListPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListItemContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListItemContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListItemInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListItemInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListItemList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListItemList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListItemOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListItemOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListItemPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListItemPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListPermissionContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListPermissionInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListPermissionList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncList\\SyncListPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncList/SyncListPermissionPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMapContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMapContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMapInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMapInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMapList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMapList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMapOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMapOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMapPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMapPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapItemContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapItemContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapItemInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapItemInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapItemList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapItemList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapItemOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapItemOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapItemPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapItemPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapPermissionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapPermissionContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapPermissionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapPermissionInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapPermissionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapPermissionList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncMap\\SyncMapPermissionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncMap/SyncMapPermissionPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStreamContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStreamContext.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStreamInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStreamInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStreamList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStreamList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStreamOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStreamOptions.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStreamPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStreamPage.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStream\\StreamMessageInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStream/StreamMessageInstance.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStream\\StreamMessageList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStream/StreamMessageList.php',
    'Twilio\\Rest\\Sync\\V1\\Service\\SyncStream\\StreamMessagePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Sync/V1/Service/SyncStream/StreamMessagePage.php',
    'Twilio\\Rest\\Taskrouter' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter.php',
    'Twilio\\Rest\\TaskrouterBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/TaskrouterBase.php',
    'Twilio\\Rest\\Taskrouter\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1.php',
    'Twilio\\Rest\\Taskrouter\\V1\\WorkspaceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/WorkspaceContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\WorkspaceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/WorkspaceInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\WorkspaceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/WorkspaceList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\WorkspaceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/WorkspaceOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\WorkspacePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/WorkspacePage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\ActivityContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/ActivityContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\ActivityInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/ActivityInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\ActivityList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/ActivityList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\ActivityOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/ActivityOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\ActivityPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/ActivityPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\EventContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/EventContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\EventInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/EventInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\EventList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/EventList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\EventOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/EventOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\EventPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/EventPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskChannelContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskChannelInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskChannelList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskChannelOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskChannelPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueueContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueueContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueueInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueueInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueueList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueueList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueueOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueueOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueuePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueuePage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueBulkRealTimeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueBulkRealTimeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueBulkRealTimeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueBulkRealTimeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueBulkRealTimeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueBulkRealTimeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueCumulativeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueCumulativeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueCumulativeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueCumulativeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueCumulativeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueCumulativeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueCumulativeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueCumulativeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueCumulativeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueCumulativeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueRealTimeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueRealTimeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueRealTimeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueRealTimeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueRealTimeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueRealTimeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueRealTimeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueRealTimeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueRealTimeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueRealTimeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueueStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueueStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueuesStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueuesStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueuesStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueuesStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueuesStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueuesStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\TaskQueue\\TaskQueuesStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/TaskQueue/TaskQueuesStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Task\\ReservationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Task/ReservationContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Task\\ReservationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Task/ReservationInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Task\\ReservationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Task/ReservationList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Task\\ReservationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Task/ReservationOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Task\\ReservationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Task/ReservationPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkerContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkerContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkerInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkerInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkerList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkerList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkerOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkerOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkerPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkerPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\ReservationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/ReservationContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\ReservationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/ReservationInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\ReservationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/ReservationList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\ReservationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/ReservationOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\ReservationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/ReservationPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerChannelContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerChannelContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerChannelInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerChannelInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerChannelList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerChannelList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerChannelOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerChannelOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerChannelPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerChannelPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkerStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkerStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersCumulativeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersCumulativeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersCumulativeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersCumulativeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersCumulativeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersCumulativeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersCumulativeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersCumulativeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersCumulativeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersCumulativeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersRealTimeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersRealTimeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersRealTimeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersRealTimeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersRealTimeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersRealTimeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersRealTimeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersRealTimeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersRealTimeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersRealTimeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Worker\\WorkersStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Worker/WorkersStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkflowContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkflowContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkflowInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkflowInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkflowList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkflowList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkflowOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkflowOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkflowPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkflowPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowCumulativeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowCumulativeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowCumulativeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowCumulativeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowCumulativeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowCumulativeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowCumulativeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowCumulativeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowCumulativeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowCumulativeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowRealTimeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowRealTimeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowRealTimeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowRealTimeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowRealTimeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowRealTimeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowRealTimeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowRealTimeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowRealTimeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowRealTimeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\Workflow\\WorkflowStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/Workflow/WorkflowStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceCumulativeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceCumulativeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceCumulativeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceCumulativeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceCumulativeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceCumulativeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceCumulativeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceCumulativeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceCumulativeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceCumulativeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceRealTimeStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceRealTimeStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceRealTimeStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceRealTimeStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceRealTimeStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceRealTimeStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceRealTimeStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceRealTimeStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceRealTimeStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceRealTimeStatisticsPage.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceStatisticsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceStatisticsContext.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceStatisticsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceStatisticsInstance.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceStatisticsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceStatisticsList.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceStatisticsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceStatisticsOptions.php',
    'Twilio\\Rest\\Taskrouter\\V1\\Workspace\\WorkspaceStatisticsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Taskrouter/V1/Workspace/WorkspaceStatisticsPage.php',
    'Twilio\\Rest\\Trunking' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking.php',
    'Twilio\\Rest\\TrunkingBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/TrunkingBase.php',
    'Twilio\\Rest\\Trunking\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1.php',
    'Twilio\\Rest\\Trunking\\V1\\TrunkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/TrunkContext.php',
    'Twilio\\Rest\\Trunking\\V1\\TrunkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/TrunkInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\TrunkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/TrunkList.php',
    'Twilio\\Rest\\Trunking\\V1\\TrunkOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/TrunkOptions.php',
    'Twilio\\Rest\\Trunking\\V1\\TrunkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/TrunkPage.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\CredentialListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/CredentialListContext.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\CredentialListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/CredentialListInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\CredentialListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/CredentialListList.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\CredentialListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/CredentialListPage.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\IpAccessControlListContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/IpAccessControlListContext.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\IpAccessControlListInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/IpAccessControlListInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\IpAccessControlListList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/IpAccessControlListList.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\IpAccessControlListPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/IpAccessControlListPage.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\OriginationUrlContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/OriginationUrlContext.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\OriginationUrlInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/OriginationUrlInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\OriginationUrlList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/OriginationUrlList.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\OriginationUrlOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/OriginationUrlOptions.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\OriginationUrlPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/OriginationUrlPage.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\PhoneNumberContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/PhoneNumberContext.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\PhoneNumberInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/PhoneNumberInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\PhoneNumberList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/PhoneNumberList.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\PhoneNumberPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/PhoneNumberPage.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\RecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/RecordingContext.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\RecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/RecordingInstance.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\RecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/RecordingList.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\RecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/RecordingOptions.php',
    'Twilio\\Rest\\Trunking\\V1\\Trunk\\RecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trunking/V1/Trunk/RecordingPage.php',
    'Twilio\\Rest\\Trusthub' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub.php',
    'Twilio\\Rest\\TrusthubBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/TrusthubBase.php',
    'Twilio\\Rest\\Trusthub\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceInquiriesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceInquiriesContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceInquiriesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceInquiriesInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceInquiriesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceInquiriesList.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceInquiriesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceInquiriesOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceInquiriesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceInquiriesPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceRegistrationInquiriesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceRegistrationInquiriesContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceRegistrationInquiriesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceRegistrationInquiriesInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceRegistrationInquiriesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceRegistrationInquiriesList.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceRegistrationInquiriesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceRegistrationInquiriesOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceRegistrationInquiriesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceRegistrationInquiriesPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceTollfreeInquiriesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceTollfreeInquiriesInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceTollfreeInquiriesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceTollfreeInquiriesList.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceTollfreeInquiriesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceTollfreeInquiriesOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\ComplianceTollfreeInquiriesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/ComplianceTollfreeInquiriesPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfilesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfilesContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfilesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfilesInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfilesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfilesList.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfilesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfilesOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfilesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfilesPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesChannelEndpointAssignmentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesChannelEndpointAssignmentContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesChannelEndpointAssignmentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesChannelEndpointAssignmentInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesChannelEndpointAssignmentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesChannelEndpointAssignmentList.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesChannelEndpointAssignmentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesChannelEndpointAssignmentOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesChannelEndpointAssignmentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesChannelEndpointAssignmentPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEntityAssignmentsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEntityAssignmentsContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEntityAssignmentsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEntityAssignmentsInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEntityAssignmentsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEntityAssignmentsList.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEntityAssignmentsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEntityAssignmentsOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEntityAssignmentsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEntityAssignmentsPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEvaluationsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEvaluationsContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEvaluationsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEvaluationsInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEvaluationsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEvaluationsList.php',
    'Twilio\\Rest\\Trusthub\\V1\\CustomerProfiles\\CustomerProfilesEvaluationsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/CustomerProfiles/CustomerProfilesEvaluationsPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserList.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserTypeContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserTypeInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserTypeList.php',
    'Twilio\\Rest\\Trusthub\\V1\\EndUserTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/EndUserTypePage.php',
    'Twilio\\Rest\\Trusthub\\V1\\PoliciesContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/PoliciesContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\PoliciesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/PoliciesInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\PoliciesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/PoliciesList.php',
    'Twilio\\Rest\\Trusthub\\V1\\PoliciesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/PoliciesPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentList.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentTypeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentTypeContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentTypeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentTypeInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentTypeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentTypeList.php',
    'Twilio\\Rest\\Trusthub\\V1\\SupportingDocumentTypePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/SupportingDocumentTypePage.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProductsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProductsContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProductsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProductsInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProductsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProductsList.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProductsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProductsOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProductsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProductsPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsChannelEndpointAssignmentContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsChannelEndpointAssignmentContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsChannelEndpointAssignmentInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsChannelEndpointAssignmentInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsChannelEndpointAssignmentList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsChannelEndpointAssignmentList.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsChannelEndpointAssignmentOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsChannelEndpointAssignmentOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsChannelEndpointAssignmentPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsChannelEndpointAssignmentPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEntityAssignmentsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEntityAssignmentsContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEntityAssignmentsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEntityAssignmentsInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEntityAssignmentsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEntityAssignmentsList.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEntityAssignmentsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEntityAssignmentsOptions.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEntityAssignmentsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEntityAssignmentsPage.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEvaluationsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEvaluationsContext.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEvaluationsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEvaluationsInstance.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEvaluationsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEvaluationsList.php',
    'Twilio\\Rest\\Trusthub\\V1\\TrustProducts\\TrustProductsEvaluationsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Trusthub/V1/TrustProducts/TrustProductsEvaluationsPage.php',
    'Twilio\\Rest\\Verify' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify.php',
    'Twilio\\Rest\\VerifyBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/VerifyBase.php',
    'Twilio\\Rest\\Verify\\V2' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2.php',
    'Twilio\\Rest\\Verify\\V2\\FormContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/FormContext.php',
    'Twilio\\Rest\\Verify\\V2\\FormInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/FormInstance.php',
    'Twilio\\Rest\\Verify\\V2\\FormList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/FormList.php',
    'Twilio\\Rest\\Verify\\V2\\FormPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/FormPage.php',
    'Twilio\\Rest\\Verify\\V2\\SafelistContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/SafelistContext.php',
    'Twilio\\Rest\\Verify\\V2\\SafelistInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/SafelistInstance.php',
    'Twilio\\Rest\\Verify\\V2\\SafelistList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/SafelistList.php',
    'Twilio\\Rest\\Verify\\V2\\SafelistPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/SafelistPage.php',
    'Twilio\\Rest\\Verify\\V2\\ServiceContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/ServiceContext.php',
    'Twilio\\Rest\\Verify\\V2\\ServiceInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/ServiceInstance.php',
    'Twilio\\Rest\\Verify\\V2\\ServiceList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/ServiceList.php',
    'Twilio\\Rest\\Verify\\V2\\ServiceOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/ServiceOptions.php',
    'Twilio\\Rest\\Verify\\V2\\ServicePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/ServicePage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\AccessTokenContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/AccessTokenContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\AccessTokenInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/AccessTokenInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\AccessTokenList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/AccessTokenList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\AccessTokenOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/AccessTokenOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\AccessTokenPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/AccessTokenPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\EntityContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/EntityContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\EntityInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/EntityInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\EntityList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/EntityList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\EntityPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/EntityPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\ChallengeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/ChallengeContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\ChallengeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/ChallengeInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\ChallengeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/ChallengeList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\ChallengeOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/ChallengeOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\ChallengePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/ChallengePage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\Challenge\\NotificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/Challenge/NotificationInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\Challenge\\NotificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/Challenge/NotificationList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\Challenge\\NotificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/Challenge/NotificationOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\Challenge\\NotificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/Challenge/NotificationPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\FactorContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/FactorContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\FactorInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/FactorInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\FactorList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/FactorList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\FactorOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/FactorOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\FactorPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/FactorPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\NewFactorInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/NewFactorInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\NewFactorList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/NewFactorList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\NewFactorOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/NewFactorOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\Entity\\NewFactorPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/Entity/NewFactorPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\MessagingConfigurationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/MessagingConfigurationContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\MessagingConfigurationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/MessagingConfigurationInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\MessagingConfigurationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/MessagingConfigurationList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\MessagingConfigurationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/MessagingConfigurationPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimitContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimitContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimitInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimitInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimitList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimitList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimitOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimitOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimitPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimitPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimit\\BucketContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimit/BucketContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimit\\BucketInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimit/BucketInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimit\\BucketList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimit/BucketList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimit\\BucketOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimit/BucketOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\RateLimit\\BucketPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/RateLimit/BucketPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationCheckInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationCheckInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationCheckList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationCheckList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationCheckOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationCheckOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationCheckPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationCheckPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\VerificationPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/VerificationPage.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\WebhookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/WebhookContext.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\WebhookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/WebhookInstance.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\WebhookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/WebhookList.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\WebhookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/WebhookOptions.php',
    'Twilio\\Rest\\Verify\\V2\\Service\\WebhookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/Service/WebhookPage.php',
    'Twilio\\Rest\\Verify\\V2\\TemplateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/TemplateInstance.php',
    'Twilio\\Rest\\Verify\\V2\\TemplateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/TemplateList.php',
    'Twilio\\Rest\\Verify\\V2\\TemplateOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/TemplateOptions.php',
    'Twilio\\Rest\\Verify\\V2\\TemplatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/TemplatePage.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptContext.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptInstance.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptList.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptOptions.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptPage.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptsSummaryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptsSummaryContext.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptsSummaryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptsSummaryInstance.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptsSummaryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptsSummaryList.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptsSummaryOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptsSummaryOptions.php',
    'Twilio\\Rest\\Verify\\V2\\VerificationAttemptsSummaryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Verify/V2/VerificationAttemptsSummaryPage.php',
    'Twilio\\Rest\\Video' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video.php',
    'Twilio\\Rest\\VideoBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/VideoBase.php',
    'Twilio\\Rest\\Video\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1.php',
    'Twilio\\Rest\\Video\\V1\\CompositionContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionContext.php',
    'Twilio\\Rest\\Video\\V1\\CompositionHookContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionHookContext.php',
    'Twilio\\Rest\\Video\\V1\\CompositionHookInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionHookInstance.php',
    'Twilio\\Rest\\Video\\V1\\CompositionHookList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionHookList.php',
    'Twilio\\Rest\\Video\\V1\\CompositionHookOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionHookOptions.php',
    'Twilio\\Rest\\Video\\V1\\CompositionHookPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionHookPage.php',
    'Twilio\\Rest\\Video\\V1\\CompositionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionInstance.php',
    'Twilio\\Rest\\Video\\V1\\CompositionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionList.php',
    'Twilio\\Rest\\Video\\V1\\CompositionOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionOptions.php',
    'Twilio\\Rest\\Video\\V1\\CompositionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionPage.php',
    'Twilio\\Rest\\Video\\V1\\CompositionSettingsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionSettingsContext.php',
    'Twilio\\Rest\\Video\\V1\\CompositionSettingsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionSettingsInstance.php',
    'Twilio\\Rest\\Video\\V1\\CompositionSettingsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionSettingsList.php',
    'Twilio\\Rest\\Video\\V1\\CompositionSettingsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionSettingsOptions.php',
    'Twilio\\Rest\\Video\\V1\\CompositionSettingsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/CompositionSettingsPage.php',
    'Twilio\\Rest\\Video\\V1\\RecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingContext.php',
    'Twilio\\Rest\\Video\\V1\\RecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingInstance.php',
    'Twilio\\Rest\\Video\\V1\\RecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingList.php',
    'Twilio\\Rest\\Video\\V1\\RecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingOptions.php',
    'Twilio\\Rest\\Video\\V1\\RecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingPage.php',
    'Twilio\\Rest\\Video\\V1\\RecordingSettingsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingSettingsContext.php',
    'Twilio\\Rest\\Video\\V1\\RecordingSettingsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingSettingsInstance.php',
    'Twilio\\Rest\\Video\\V1\\RecordingSettingsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingSettingsList.php',
    'Twilio\\Rest\\Video\\V1\\RecordingSettingsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingSettingsOptions.php',
    'Twilio\\Rest\\Video\\V1\\RecordingSettingsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RecordingSettingsPage.php',
    'Twilio\\Rest\\Video\\V1\\RoomContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RoomContext.php',
    'Twilio\\Rest\\Video\\V1\\RoomInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RoomInstance.php',
    'Twilio\\Rest\\Video\\V1\\RoomList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RoomList.php',
    'Twilio\\Rest\\Video\\V1\\RoomOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RoomOptions.php',
    'Twilio\\Rest\\Video\\V1\\RoomPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/RoomPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\ParticipantContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/ParticipantContext.php',
    'Twilio\\Rest\\Video\\V1\\Room\\ParticipantInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/ParticipantInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\ParticipantList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/ParticipantList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\ParticipantOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/ParticipantOptions.php',
    'Twilio\\Rest\\Video\\V1\\Room\\ParticipantPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/ParticipantPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\AnonymizeContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/AnonymizeContext.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\AnonymizeInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/AnonymizeInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\AnonymizeList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/AnonymizeList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\AnonymizePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/AnonymizePage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\PublishedTrackContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/PublishedTrackContext.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\PublishedTrackInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/PublishedTrackInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\PublishedTrackList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/PublishedTrackList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\PublishedTrackPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/PublishedTrackPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribeRulesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribeRulesInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribeRulesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribeRulesList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribeRulesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribeRulesOptions.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribeRulesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribeRulesPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribedTrackContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribedTrackContext.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribedTrackInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribedTrackInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribedTrackList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribedTrackList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\Participant\\SubscribedTrackPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/Participant/SubscribedTrackPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RecordingRulesInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RecordingRulesInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RecordingRulesList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RecordingRulesList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RecordingRulesOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RecordingRulesOptions.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RecordingRulesPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RecordingRulesPage.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RoomRecordingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RoomRecordingContext.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RoomRecordingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RoomRecordingInstance.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RoomRecordingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RoomRecordingList.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RoomRecordingOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RoomRecordingOptions.php',
    'Twilio\\Rest\\Video\\V1\\Room\\RoomRecordingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Video/V1/Room/RoomRecordingPage.php',
    'Twilio\\Rest\\Voice' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice.php',
    'Twilio\\Rest\\VoiceBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/VoiceBase.php',
    'Twilio\\Rest\\Voice\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1.php',
    'Twilio\\Rest\\Voice\\V1\\ArchivedCallContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ArchivedCallContext.php',
    'Twilio\\Rest\\Voice\\V1\\ArchivedCallInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ArchivedCallInstance.php',
    'Twilio\\Rest\\Voice\\V1\\ArchivedCallList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ArchivedCallList.php',
    'Twilio\\Rest\\Voice\\V1\\ArchivedCallPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ArchivedCallPage.php',
    'Twilio\\Rest\\Voice\\V1\\ByocTrunkContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ByocTrunkContext.php',
    'Twilio\\Rest\\Voice\\V1\\ByocTrunkInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ByocTrunkInstance.php',
    'Twilio\\Rest\\Voice\\V1\\ByocTrunkList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ByocTrunkList.php',
    'Twilio\\Rest\\Voice\\V1\\ByocTrunkOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ByocTrunkOptions.php',
    'Twilio\\Rest\\Voice\\V1\\ByocTrunkPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ByocTrunkPage.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicyContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicyContext.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicyInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicyInstance.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicyList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicyList.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicyOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicyOptions.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicyPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicyPage.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicy\\ConnectionPolicyTargetContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicy/ConnectionPolicyTargetContext.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicy\\ConnectionPolicyTargetInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicy/ConnectionPolicyTargetInstance.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicy\\ConnectionPolicyTargetList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicy/ConnectionPolicyTargetList.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicy\\ConnectionPolicyTargetOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicy/ConnectionPolicyTargetOptions.php',
    'Twilio\\Rest\\Voice\\V1\\ConnectionPolicy\\ConnectionPolicyTargetPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/ConnectionPolicy/ConnectionPolicyTargetPage.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissionsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissionsInstance.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissionsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissionsList.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissionsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissionsPage.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\BulkCountryUpdateInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/BulkCountryUpdateInstance.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\BulkCountryUpdateList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/BulkCountryUpdateList.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\BulkCountryUpdatePage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/BulkCountryUpdatePage.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\CountryContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/CountryContext.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\CountryInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/CountryInstance.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\CountryList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/CountryList.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\CountryOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/CountryOptions.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\CountryPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/CountryPage.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\Country\\HighriskSpecialPrefixInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/Country/HighriskSpecialPrefixInstance.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\Country\\HighriskSpecialPrefixList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/Country/HighriskSpecialPrefixList.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\Country\\HighriskSpecialPrefixPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/Country/HighriskSpecialPrefixPage.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\SettingsContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/SettingsContext.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\SettingsInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/SettingsInstance.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\SettingsList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/SettingsList.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\SettingsOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/SettingsOptions.php',
    'Twilio\\Rest\\Voice\\V1\\DialingPermissions\\SettingsPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/DialingPermissions/SettingsPage.php',
    'Twilio\\Rest\\Voice\\V1\\IpRecordContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/IpRecordContext.php',
    'Twilio\\Rest\\Voice\\V1\\IpRecordInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/IpRecordInstance.php',
    'Twilio\\Rest\\Voice\\V1\\IpRecordList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/IpRecordList.php',
    'Twilio\\Rest\\Voice\\V1\\IpRecordOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/IpRecordOptions.php',
    'Twilio\\Rest\\Voice\\V1\\IpRecordPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/IpRecordPage.php',
    'Twilio\\Rest\\Voice\\V1\\SourceIpMappingContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/SourceIpMappingContext.php',
    'Twilio\\Rest\\Voice\\V1\\SourceIpMappingInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/SourceIpMappingInstance.php',
    'Twilio\\Rest\\Voice\\V1\\SourceIpMappingList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/SourceIpMappingList.php',
    'Twilio\\Rest\\Voice\\V1\\SourceIpMappingPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Voice/V1/SourceIpMappingPage.php',
    'Twilio\\Rest\\Wireless' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless.php',
    'Twilio\\Rest\\WirelessBase' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/WirelessBase.php',
    'Twilio\\Rest\\Wireless\\V1' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1.php',
    'Twilio\\Rest\\Wireless\\V1\\CommandContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/CommandContext.php',
    'Twilio\\Rest\\Wireless\\V1\\CommandInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/CommandInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\CommandList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/CommandList.php',
    'Twilio\\Rest\\Wireless\\V1\\CommandOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/CommandOptions.php',
    'Twilio\\Rest\\Wireless\\V1\\CommandPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/CommandPage.php',
    'Twilio\\Rest\\Wireless\\V1\\RatePlanContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/RatePlanContext.php',
    'Twilio\\Rest\\Wireless\\V1\\RatePlanInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/RatePlanInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\RatePlanList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/RatePlanList.php',
    'Twilio\\Rest\\Wireless\\V1\\RatePlanOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/RatePlanOptions.php',
    'Twilio\\Rest\\Wireless\\V1\\RatePlanPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/RatePlanPage.php',
    'Twilio\\Rest\\Wireless\\V1\\SimContext' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/SimContext.php',
    'Twilio\\Rest\\Wireless\\V1\\SimInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/SimInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\SimList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/SimList.php',
    'Twilio\\Rest\\Wireless\\V1\\SimOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/SimOptions.php',
    'Twilio\\Rest\\Wireless\\V1\\SimPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/SimPage.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\DataSessionInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/DataSessionInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\DataSessionList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/DataSessionList.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\DataSessionPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/DataSessionPage.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\UsageRecordInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/UsageRecordInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\UsageRecordList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/UsageRecordList.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\UsageRecordOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/UsageRecordOptions.php',
    'Twilio\\Rest\\Wireless\\V1\\Sim\\UsageRecordPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/Sim/UsageRecordPage.php',
    'Twilio\\Rest\\Wireless\\V1\\UsageRecordInstance' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/UsageRecordInstance.php',
    'Twilio\\Rest\\Wireless\\V1\\UsageRecordList' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/UsageRecordList.php',
    'Twilio\\Rest\\Wireless\\V1\\UsageRecordOptions' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/UsageRecordOptions.php',
    'Twilio\\Rest\\Wireless\\V1\\UsageRecordPage' => $vendorDir . '/twilio/sdk/src/Twilio/Rest/Wireless/V1/UsageRecordPage.php',
    'Twilio\\Security\\RequestValidator' => $vendorDir . '/twilio/sdk/src/Twilio/Security/RequestValidator.php',
    'Twilio\\Serialize' => $vendorDir . '/twilio/sdk/src/Twilio/Serialize.php',
    'Twilio\\Stream' => $vendorDir . '/twilio/sdk/src/Twilio/Stream.php',
    'Twilio\\TaskRouter\\WorkflowConfiguration' => $vendorDir . '/twilio/sdk/src/Twilio/TaskRouter/WorkflowConfiguration.php',
    'Twilio\\TaskRouter\\WorkflowRule' => $vendorDir . '/twilio/sdk/src/Twilio/TaskRouter/WorkflowRule.php',
    'Twilio\\TaskRouter\\WorkflowRuleTarget' => $vendorDir . '/twilio/sdk/src/Twilio/TaskRouter/WorkflowRuleTarget.php',
    'Twilio\\TwiML\\FaxResponse' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/FaxResponse.php',
    'Twilio\\TwiML\\Fax\\Receive' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Fax/Receive.php',
    'Twilio\\TwiML\\GenericNode' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/GenericNode.php',
    'Twilio\\TwiML\\MessagingResponse' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/MessagingResponse.php',
    'Twilio\\TwiML\\Messaging\\Body' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Messaging/Body.php',
    'Twilio\\TwiML\\Messaging\\Media' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Messaging/Media.php',
    'Twilio\\TwiML\\Messaging\\Message' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Messaging/Message.php',
    'Twilio\\TwiML\\Messaging\\Redirect' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Messaging/Redirect.php',
    'Twilio\\TwiML\\TwiML' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/TwiML.php',
    'Twilio\\TwiML\\Video\\Room' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Video/Room.php',
    'Twilio\\TwiML\\VoiceResponse' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/VoiceResponse.php',
    'Twilio\\TwiML\\Voice\\Application' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Application.php',
    'Twilio\\TwiML\\Voice\\ApplicationSid' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/ApplicationSid.php',
    'Twilio\\TwiML\\Voice\\Autopilot' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Autopilot.php',
    'Twilio\\TwiML\\Voice\\Client' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Client.php',
    'Twilio\\TwiML\\Voice\\Conference' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Conference.php',
    'Twilio\\TwiML\\Voice\\Config' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Config.php',
    'Twilio\\TwiML\\Voice\\Connect' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Connect.php',
    'Twilio\\TwiML\\Voice\\Conversation' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Conversation.php',
    'Twilio\\TwiML\\Voice\\Dial' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Dial.php',
    'Twilio\\TwiML\\Voice\\Echo_' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Echo_.php',
    'Twilio\\TwiML\\Voice\\Enqueue' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Enqueue.php',
    'Twilio\\TwiML\\Voice\\Gather' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Gather.php',
    'Twilio\\TwiML\\Voice\\Hangup' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Hangup.php',
    'Twilio\\TwiML\\Voice\\Identity' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Identity.php',
    'Twilio\\TwiML\\Voice\\Leave' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Leave.php',
    'Twilio\\TwiML\\Voice\\Number' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Number.php',
    'Twilio\\TwiML\\Voice\\Parameter' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Parameter.php',
    'Twilio\\TwiML\\Voice\\Pause' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Pause.php',
    'Twilio\\TwiML\\Voice\\Pay' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Pay.php',
    'Twilio\\TwiML\\Voice\\Play' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Play.php',
    'Twilio\\TwiML\\Voice\\Prompt' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Prompt.php',
    'Twilio\\TwiML\\Voice\\Queue' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Queue.php',
    'Twilio\\TwiML\\Voice\\Record' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Record.php',
    'Twilio\\TwiML\\Voice\\Redirect' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Redirect.php',
    'Twilio\\TwiML\\Voice\\Refer' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Refer.php',
    'Twilio\\TwiML\\Voice\\ReferSip' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/ReferSip.php',
    'Twilio\\TwiML\\Voice\\Reject' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Reject.php',
    'Twilio\\TwiML\\Voice\\Room' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Room.php',
    'Twilio\\TwiML\\Voice\\Say' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Say.php',
    'Twilio\\TwiML\\Voice\\Sim' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Sim.php',
    'Twilio\\TwiML\\Voice\\Sip' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Sip.php',
    'Twilio\\TwiML\\Voice\\Siprec' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Siprec.php',
    'Twilio\\TwiML\\Voice\\Sms' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Sms.php',
    'Twilio\\TwiML\\Voice\\SsmlBreak' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlBreak.php',
    'Twilio\\TwiML\\Voice\\SsmlEmphasis' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlEmphasis.php',
    'Twilio\\TwiML\\Voice\\SsmlLang' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlLang.php',
    'Twilio\\TwiML\\Voice\\SsmlP' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlP.php',
    'Twilio\\TwiML\\Voice\\SsmlPhoneme' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlPhoneme.php',
    'Twilio\\TwiML\\Voice\\SsmlProsody' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlProsody.php',
    'Twilio\\TwiML\\Voice\\SsmlS' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlS.php',
    'Twilio\\TwiML\\Voice\\SsmlSayAs' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlSayAs.php',
    'Twilio\\TwiML\\Voice\\SsmlSub' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlSub.php',
    'Twilio\\TwiML\\Voice\\SsmlW' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/SsmlW.php',
    'Twilio\\TwiML\\Voice\\Start' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Start.php',
    'Twilio\\TwiML\\Voice\\Stop' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Stop.php',
    'Twilio\\TwiML\\Voice\\Stream' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Stream.php',
    'Twilio\\TwiML\\Voice\\Task' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Task.php',
    'Twilio\\TwiML\\Voice\\Transcription' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/Transcription.php',
    'Twilio\\TwiML\\Voice\\VirtualAgent' => $vendorDir . '/twilio/sdk/src/Twilio/TwiML/Voice/VirtualAgent.php',
    'Twilio\\Values' => $vendorDir . '/twilio/sdk/src/Twilio/Values.php',
    'Twilio\\Version' => $vendorDir . '/twilio/sdk/src/Twilio/Version.php',
    'Twilio\\VersionInfo' => $vendorDir . '/twilio/sdk/src/Twilio/VersionInfo.php',
    'UnhandledMatchError' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
    'Unirest\\Exception' => $vendorDir . '/mashape/unirest-php/src/Unirest/Exception.php',
    'Unirest\\Method' => $vendorDir . '/mashape/unirest-php/src/Unirest/Method.php',
    'Unirest\\Request' => $vendorDir . '/mashape/unirest-php/src/Unirest/Request.php',
    'Unirest\\Request\\Body' => $vendorDir . '/mashape/unirest-php/src/Unirest/Request/Body.php',
    'Unirest\\Response' => $vendorDir . '/mashape/unirest-php/src/Unirest/Response.php',
    'ValueError' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/ValueError.php',
    'Webmozart\\Assert\\Assert' => $vendorDir . '/webmozart/assert/src/Assert.php',
    'Webmozart\\Assert\\InvalidArgumentException' => $vendorDir . '/webmozart/assert/src/InvalidArgumentException.php',
    'Webmozart\\Assert\\Mixin' => $vendorDir . '/webmozart/assert/src/Mixin.php',
    'WhichBrowser\\Analyser' => $vendorDir . '/whichbrowser/parser/src/Analyser.php',
    'WhichBrowser\\Analyser\\Camouflage' => $vendorDir . '/whichbrowser/parser/src/Analyser/Camouflage.php',
    'WhichBrowser\\Analyser\\Corrections' => $vendorDir . '/whichbrowser/parser/src/Analyser/Corrections.php',
    'WhichBrowser\\Analyser\\Derive' => $vendorDir . '/whichbrowser/parser/src/Analyser/Derive.php',
    'WhichBrowser\\Analyser\\Header' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header.php',
    'WhichBrowser\\Analyser\\Header\\Baidu' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Baidu.php',
    'WhichBrowser\\Analyser\\Header\\BrowserId' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/BrowserId.php',
    'WhichBrowser\\Analyser\\Header\\OperaMini' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/OperaMini.php',
    'WhichBrowser\\Analyser\\Header\\Puffin' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Puffin.php',
    'WhichBrowser\\Analyser\\Header\\UCBrowserNew' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/UCBrowserNew.php',
    'WhichBrowser\\Analyser\\Header\\UCBrowserOld' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/UCBrowserOld.php',
    'WhichBrowser\\Analyser\\Header\\Useragent' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Application' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Application.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Bot' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Bot.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Browser' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Browser.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Appliance' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Appliance.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Cars' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Cars.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Ereader' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Ereader.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Gaming' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Gaming.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Gps' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Gps.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Media' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Media.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Mobile' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Mobile.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Pda' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Pda.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Phone' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Phone.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Printer' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Printer.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Signage' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Signage.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Tablet' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Tablet.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Device\\Television' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Device/Television.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Engine' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Engine.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Os' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Os.php',
    'WhichBrowser\\Analyser\\Header\\Useragent\\Using' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Useragent/Using.php',
    'WhichBrowser\\Analyser\\Header\\Wap' => $vendorDir . '/whichbrowser/parser/src/Analyser/Header/Wap.php',
    'WhichBrowser\\Cache' => $vendorDir . '/whichbrowser/parser/src/Cache.php',
    'WhichBrowser\\Constants\\BrowserType' => $vendorDir . '/whichbrowser/parser/src/Constants/BrowserType.php',
    'WhichBrowser\\Constants\\DeviceSubType' => $vendorDir . '/whichbrowser/parser/src/Constants/DeviceSubType.php',
    'WhichBrowser\\Constants\\DeviceType' => $vendorDir . '/whichbrowser/parser/src/Constants/DeviceType.php',
    'WhichBrowser\\Constants\\EngineType' => $vendorDir . '/whichbrowser/parser/src/Constants/EngineType.php',
    'WhichBrowser\\Constants\\Feature' => $vendorDir . '/whichbrowser/parser/src/Constants/Feature.php',
    'WhichBrowser\\Constants\\Flag' => $vendorDir . '/whichbrowser/parser/src/Constants/Flag.php',
    'WhichBrowser\\Constants\\Id' => $vendorDir . '/whichbrowser/parser/src/Constants/Id.php',
    'WhichBrowser\\Data\\Applications' => $vendorDir . '/whichbrowser/parser/src/Data/Applications.php',
    'WhichBrowser\\Data\\BrowserIds' => $vendorDir . '/whichbrowser/parser/src/Data/BrowserIds.php',
    'WhichBrowser\\Data\\BuildIds' => $vendorDir . '/whichbrowser/parser/src/Data/BuildIds.php',
    'WhichBrowser\\Data\\CFNetwork' => $vendorDir . '/whichbrowser/parser/src/Data/CFNetwork.php',
    'WhichBrowser\\Data\\Chrome' => $vendorDir . '/whichbrowser/parser/src/Data/Chrome.php',
    'WhichBrowser\\Data\\Darwin' => $vendorDir . '/whichbrowser/parser/src/Data/Darwin.php',
    'WhichBrowser\\Data\\DeviceModels' => $vendorDir . '/whichbrowser/parser/src/Data/DeviceModels.php',
    'WhichBrowser\\Data\\DeviceProfiles' => $vendorDir . '/whichbrowser/parser/src/Data/DeviceProfiles.php',
    'WhichBrowser\\Data\\Manufacturers' => $vendorDir . '/whichbrowser/parser/src/Data/Manufacturers.php',
    'WhichBrowser\\Model\\Browser' => $vendorDir . '/whichbrowser/parser/src/Model/Browser.php',
    'WhichBrowser\\Model\\Device' => $vendorDir . '/whichbrowser/parser/src/Model/Device.php',
    'WhichBrowser\\Model\\Engine' => $vendorDir . '/whichbrowser/parser/src/Model/Engine.php',
    'WhichBrowser\\Model\\Family' => $vendorDir . '/whichbrowser/parser/src/Model/Family.php',
    'WhichBrowser\\Model\\Main' => $vendorDir . '/whichbrowser/parser/src/Model/Main.php',
    'WhichBrowser\\Model\\Os' => $vendorDir . '/whichbrowser/parser/src/Model/Os.php',
    'WhichBrowser\\Model\\Primitive\\Base' => $vendorDir . '/whichbrowser/parser/src/Model/Primitive/Base.php',
    'WhichBrowser\\Model\\Primitive\\NameVersion' => $vendorDir . '/whichbrowser/parser/src/Model/Primitive/NameVersion.php',
    'WhichBrowser\\Model\\Using' => $vendorDir . '/whichbrowser/parser/src/Model/Using.php',
    'WhichBrowser\\Model\\Version' => $vendorDir . '/whichbrowser/parser/src/Model/Version.php',
    'WhichBrowser\\Parser' => $vendorDir . '/whichbrowser/parser/src/Parser.php',
    'Whoops\\Exception\\ErrorException' => $vendorDir . '/filp/whoops/src/Whoops/Exception/ErrorException.php',
    'Whoops\\Exception\\Formatter' => $vendorDir . '/filp/whoops/src/Whoops/Exception/Formatter.php',
    'Whoops\\Exception\\Frame' => $vendorDir . '/filp/whoops/src/Whoops/Exception/Frame.php',
    'Whoops\\Exception\\FrameCollection' => $vendorDir . '/filp/whoops/src/Whoops/Exception/FrameCollection.php',
    'Whoops\\Exception\\Inspector' => $vendorDir . '/filp/whoops/src/Whoops/Exception/Inspector.php',
    'Whoops\\Handler\\CallbackHandler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/CallbackHandler.php',
    'Whoops\\Handler\\Handler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/Handler.php',
    'Whoops\\Handler\\HandlerInterface' => $vendorDir . '/filp/whoops/src/Whoops/Handler/HandlerInterface.php',
    'Whoops\\Handler\\JsonResponseHandler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/JsonResponseHandler.php',
    'Whoops\\Handler\\PlainTextHandler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/PlainTextHandler.php',
    'Whoops\\Handler\\PrettyPageHandler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/PrettyPageHandler.php',
    'Whoops\\Handler\\XmlResponseHandler' => $vendorDir . '/filp/whoops/src/Whoops/Handler/XmlResponseHandler.php',
    'Whoops\\Inspector\\InspectorFactory' => $vendorDir . '/filp/whoops/src/Whoops/Inspector/InspectorFactory.php',
    'Whoops\\Inspector\\InspectorFactoryInterface' => $vendorDir . '/filp/whoops/src/Whoops/Inspector/InspectorFactoryInterface.php',
    'Whoops\\Inspector\\InspectorInterface' => $vendorDir . '/filp/whoops/src/Whoops/Inspector/InspectorInterface.php',
    'Whoops\\Run' => $vendorDir . '/filp/whoops/src/Whoops/Run.php',
    'Whoops\\RunInterface' => $vendorDir . '/filp/whoops/src/Whoops/RunInterface.php',
    'Whoops\\Util\\HtmlDumperOutput' => $vendorDir . '/filp/whoops/src/Whoops/Util/HtmlDumperOutput.php',
    'Whoops\\Util\\Misc' => $vendorDir . '/filp/whoops/src/Whoops/Util/Misc.php',
    'Whoops\\Util\\SystemFacade' => $vendorDir . '/filp/whoops/src/Whoops/Util/SystemFacade.php',
    'Whoops\\Util\\TemplateHelper' => $vendorDir . '/filp/whoops/src/Whoops/Util/TemplateHelper.php',
    'Wikimedia\\Composer\\Merge\\V2\\ExtraPackage' => $vendorDir . '/wikimedia/composer-merge-plugin/src/ExtraPackage.php',
    'Wikimedia\\Composer\\Merge\\V2\\Logger' => $vendorDir . '/wikimedia/composer-merge-plugin/src/Logger.php',
    'Wikimedia\\Composer\\Merge\\V2\\MergePlugin' => $vendorDir . '/wikimedia/composer-merge-plugin/src/MergePlugin.php',
    'Wikimedia\\Composer\\Merge\\V2\\MissingFileException' => $vendorDir . '/wikimedia/composer-merge-plugin/src/MissingFileException.php',
    'Wikimedia\\Composer\\Merge\\V2\\MultiConstraint' => $vendorDir . '/wikimedia/composer-merge-plugin/src/MultiConstraint.php',
    'Wikimedia\\Composer\\Merge\\V2\\NestedArray' => $vendorDir . '/wikimedia/composer-merge-plugin/src/NestedArray.php',
    'Wikimedia\\Composer\\Merge\\V2\\PluginState' => $vendorDir . '/wikimedia/composer-merge-plugin/src/PluginState.php',
    'Wikimedia\\Composer\\Merge\\V2\\StabilityFlags' => $vendorDir . '/wikimedia/composer-merge-plugin/src/StabilityFlags.php',
    'YooKassa\\Client' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Client.php',
    'YooKassa\\Client\\ApiClientInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Client/ApiClientInterface.php',
    'YooKassa\\Client\\BaseClient' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Client/BaseClient.php',
    'YooKassa\\Client\\CurlClient' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Client/CurlClient.php',
    'YooKassa\\Client\\UserAgent' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Client/UserAgent.php',
    'YooKassa\\Common\\AbstractEnum' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/AbstractEnum.php',
    'YooKassa\\Common\\AbstractObject' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/AbstractObject.php',
    'YooKassa\\Common\\AbstractRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/AbstractRequest.php',
    'YooKassa\\Common\\AbstractRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/AbstractRequestBuilder.php',
    'YooKassa\\Common\\AbstractRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/AbstractRequestInterface.php',
    'YooKassa\\Common\\Exceptions\\ApiConnectionException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/ApiConnectionException.php',
    'YooKassa\\Common\\Exceptions\\ApiException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/ApiException.php',
    'YooKassa\\Common\\Exceptions\\AuthorizeException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/AuthorizeException.php',
    'YooKassa\\Common\\Exceptions\\BadApiRequestException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/BadApiRequestException.php',
    'YooKassa\\Common\\Exceptions\\EmptyPropertyValueException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/EmptyPropertyValueException.php',
    'YooKassa\\Common\\Exceptions\\ExtensionNotFoundException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/ExtensionNotFoundException.php',
    'YooKassa\\Common\\Exceptions\\ForbiddenException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/ForbiddenException.php',
    'YooKassa\\Common\\Exceptions\\InternalServerError' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/InternalServerError.php',
    'YooKassa\\Common\\Exceptions\\InvalidPropertyException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/InvalidPropertyException.php',
    'YooKassa\\Common\\Exceptions\\InvalidPropertyValueException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/InvalidPropertyValueException.php',
    'YooKassa\\Common\\Exceptions\\InvalidPropertyValueTypeException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/InvalidPropertyValueTypeException.php',
    'YooKassa\\Common\\Exceptions\\InvalidRequestException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/InvalidRequestException.php',
    'YooKassa\\Common\\Exceptions\\JsonException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/JsonException.php',
    'YooKassa\\Common\\Exceptions\\NotFoundException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/NotFoundException.php',
    'YooKassa\\Common\\Exceptions\\ResponseProcessingException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/ResponseProcessingException.php',
    'YooKassa\\Common\\Exceptions\\TooManyRequestsException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/TooManyRequestsException.php',
    'YooKassa\\Common\\Exceptions\\UnauthorizedException' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/Exceptions/UnauthorizedException.php',
    'YooKassa\\Common\\HttpVerb' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/HttpVerb.php',
    'YooKassa\\Common\\ListObject' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/ListObject.php',
    'YooKassa\\Common\\ListObjectInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/ListObjectInterface.php',
    'YooKassa\\Common\\LoggerWrapper' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/LoggerWrapper.php',
    'YooKassa\\Common\\ResponseObject' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Common/ResponseObject.php',
    'YooKassa\\Helpers\\Config\\ConfigurationLoader' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/Config/ConfigurationLoader.php',
    'YooKassa\\Helpers\\Config\\ConfigurationLoaderInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/Config/ConfigurationLoaderInterface.php',
    'YooKassa\\Helpers\\ProductCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/ProductCode.php',
    'YooKassa\\Helpers\\Random' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/Random.php',
    'YooKassa\\Helpers\\RawHeadersParser' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/RawHeadersParser.php',
    'YooKassa\\Helpers\\SecurityHelper' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/SecurityHelper.php',
    'YooKassa\\Helpers\\StringObject' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/StringObject.php',
    'YooKassa\\Helpers\\TypeCast' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/TypeCast.php',
    'YooKassa\\Helpers\\UUID' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Helpers/UUID.php',
    'YooKassa\\Model\\AmountInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/AmountInterface.php',
    'YooKassa\\Model\\CancellationDetailsInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/CancellationDetailsInterface.php',
    'YooKassa\\Model\\CurrencyCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/CurrencyCode.php',
    'YooKassa\\Model\\Deal\\AbstractBaseDeal' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/AbstractBaseDeal.php',
    'YooKassa\\Model\\Deal\\CaptureDealData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/CaptureDealData.php',
    'YooKassa\\Model\\Deal\\DealBalanceAmount' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/DealBalanceAmount.php',
    'YooKassa\\Model\\Deal\\DealInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/DealInterface.php',
    'YooKassa\\Model\\Deal\\DealStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/DealStatus.php',
    'YooKassa\\Model\\Deal\\DealType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/DealType.php',
    'YooKassa\\Model\\Deal\\FeeMoment' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/FeeMoment.php',
    'YooKassa\\Model\\Deal\\PaymentDealInfo' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/PaymentDealInfo.php',
    'YooKassa\\Model\\Deal\\PayoutDealInfo' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/PayoutDealInfo.php',
    'YooKassa\\Model\\Deal\\RefundDealData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/RefundDealData.php',
    'YooKassa\\Model\\Deal\\RefundDealInfo' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/RefundDealInfo.php',
    'YooKassa\\Model\\Deal\\SafeDeal' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/SafeDeal.php',
    'YooKassa\\Model\\Deal\\SettlementPayoutPayment' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/SettlementPayoutPayment.php',
    'YooKassa\\Model\\Deal\\SettlementPayoutPaymentType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/SettlementPayoutPaymentType.php',
    'YooKassa\\Model\\Deal\\SettlementPayoutRefund' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Deal/SettlementPayoutRefund.php',
    'YooKassa\\Model\\Metadata' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Metadata.php',
    'YooKassa\\Model\\MonetaryAmount' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/MonetaryAmount.php',
    'YooKassa\\Model\\Notification\\AbstractNotification' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/AbstractNotification.php',
    'YooKassa\\Model\\Notification\\NotificationCanceled' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationCanceled.php',
    'YooKassa\\Model\\Notification\\NotificationDealClosed' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationDealClosed.php',
    'YooKassa\\Model\\Notification\\NotificationEventType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationEventType.php',
    'YooKassa\\Model\\Notification\\NotificationFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationFactory.php',
    'YooKassa\\Model\\Notification\\NotificationInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationInterface.php',
    'YooKassa\\Model\\Notification\\NotificationPayoutCanceled' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationPayoutCanceled.php',
    'YooKassa\\Model\\Notification\\NotificationPayoutSucceeded' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationPayoutSucceeded.php',
    'YooKassa\\Model\\Notification\\NotificationRefundSucceeded' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationRefundSucceeded.php',
    'YooKassa\\Model\\Notification\\NotificationSucceeded' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationSucceeded.php',
    'YooKassa\\Model\\Notification\\NotificationType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationType.php',
    'YooKassa\\Model\\Notification\\NotificationWaitingForCapture' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Notification/NotificationWaitingForCapture.php',
    'YooKassa\\Model\\Payment\\AuthorizationDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/AuthorizationDetails.php',
    'YooKassa\\Model\\Payment\\AuthorizationDetailsInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/AuthorizationDetailsInterface.php',
    'YooKassa\\Model\\Payment\\CancellationDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/CancellationDetails.php',
    'YooKassa\\Model\\Payment\\CancellationDetailsPartyCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/CancellationDetailsPartyCode.php',
    'YooKassa\\Model\\Payment\\CancellationDetailsReasonCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/CancellationDetailsReasonCode.php',
    'YooKassa\\Model\\Payment\\ConfirmationType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/ConfirmationType.php',
    'YooKassa\\Model\\Payment\\Confirmation\\AbstractConfirmation' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/AbstractConfirmation.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationCodeVerification' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationCodeVerification.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationEmbedded' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationEmbedded.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationExternal' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationExternal.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationFactory.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationMobileApplication' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationMobileApplication.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationQr' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationQr.php',
    'YooKassa\\Model\\Payment\\Confirmation\\ConfirmationRedirect' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Confirmation/ConfirmationRedirect.php',
    'YooKassa\\Model\\Payment\\Payment' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Payment.php',
    'YooKassa\\Model\\Payment\\PaymentInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentInterface.php',
    'YooKassa\\Model\\Payment\\PaymentMethodType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethodType.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\AbstractPaymentMethod' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/AbstractPaymentMethod.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\AbstractVatData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/AbstractVatData.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\CalculatedVatData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/CalculatedVatData.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\MixedVatData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/MixedVatData.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\PayerBankDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/PayerBankDetails.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\PayerBankDetailsInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/PayerBankDetailsInterface.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\UntaxedVatData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/UntaxedVatData.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\VatDataFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/VatDataFactory.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\VatDataInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/VatDataInterface.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\VatDataRate' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/VatDataRate.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\B2b\\Sberbank\\VatDataType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/B2b/Sberbank/VatDataType.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\BankCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/BankCard.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\BankCardProduct' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/BankCardProduct.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\BankCardSource' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/BankCardSource.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\BankCardType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/BankCardType.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodAlfaBank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodAlfaBank.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodApplePay' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodApplePay.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodB2bSberbank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodB2bSberbank.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodBankCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodBankCard.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodCash' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodCash.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodFactory.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodGooglePay' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodGooglePay.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodInstallments' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodInstallments.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodMobileBalance' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodMobileBalance.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodPsb' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodPsb.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodQiwi' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodQiwi.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodSberLoan' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodSberLoan.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodSberbank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodSberbank.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodSbp' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodSbp.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodTinkoffBank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodTinkoffBank.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodUnknown' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodUnknown.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodWebmoney' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodWebmoney.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodWechat' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodWechat.php',
    'YooKassa\\Model\\Payment\\PaymentMethod\\PaymentMethodYooMoney' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentMethod/PaymentMethodYooMoney.php',
    'YooKassa\\Model\\Payment\\PaymentStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/PaymentStatus.php',
    'YooKassa\\Model\\Payment\\ReceiptRegistrationStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/ReceiptRegistrationStatus.php',
    'YooKassa\\Model\\Payment\\Recipient' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Recipient.php',
    'YooKassa\\Model\\Payment\\RecipientInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/RecipientInterface.php',
    'YooKassa\\Model\\Payment\\ThreeDSecure' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/ThreeDSecure.php',
    'YooKassa\\Model\\Payment\\Transfer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/Transfer.php',
    'YooKassa\\Model\\Payment\\TransferInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/TransferInterface.php',
    'YooKassa\\Model\\Payment\\TransferStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payment/TransferStatus.php',
    'YooKassa\\Model\\Payout\\AbstractPayoutDestination' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/AbstractPayoutDestination.php',
    'YooKassa\\Model\\Payout\\IncomeReceipt' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/IncomeReceipt.php',
    'YooKassa\\Model\\Payout\\Payout' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/Payout.php',
    'YooKassa\\Model\\Payout\\PayoutCancellationDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutCancellationDetails.php',
    'YooKassa\\Model\\Payout\\PayoutCancellationDetailsPartyCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutCancellationDetailsPartyCode.php',
    'YooKassa\\Model\\Payout\\PayoutCancellationDetailsReasonCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutCancellationDetailsReasonCode.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationBankCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationBankCard.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationBankCardCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationBankCardCard.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationFactory.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationSbp' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationSbp.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationType.php',
    'YooKassa\\Model\\Payout\\PayoutDestinationYooMoney' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutDestinationYooMoney.php',
    'YooKassa\\Model\\Payout\\PayoutInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutInterface.php',
    'YooKassa\\Model\\Payout\\PayoutSelfEmployed' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutSelfEmployed.php',
    'YooKassa\\Model\\Payout\\PayoutStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/PayoutStatus.php',
    'YooKassa\\Model\\Payout\\SbpParticipantBank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Payout/SbpParticipantBank.php',
    'YooKassa\\Model\\PersonalData\\PersonalData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalData.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataCancellationDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataCancellationDetails.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataCancellationDetailsPartyCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataCancellationDetailsPartyCode.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataCancellationDetailsReasonCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataCancellationDetailsReasonCode.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataInterface.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataStatus.php',
    'YooKassa\\Model\\PersonalData\\PersonalDataType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/PersonalData/PersonalDataType.php',
    'YooKassa\\Model\\Receipt\\AdditionalUserProps' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/AdditionalUserProps.php',
    'YooKassa\\Model\\Receipt\\AgentType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/AgentType.php',
    'YooKassa\\Model\\Receipt\\IndustryDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/IndustryDetails.php',
    'YooKassa\\Model\\Receipt\\MarkCodeInfo' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/MarkCodeInfo.php',
    'YooKassa\\Model\\Receipt\\MarkQuantity' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/MarkQuantity.php',
    'YooKassa\\Model\\Receipt\\OperationalDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/OperationalDetails.php',
    'YooKassa\\Model\\Receipt\\PaymentMode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/PaymentMode.php',
    'YooKassa\\Model\\Receipt\\PaymentSubject' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/PaymentSubject.php',
    'YooKassa\\Model\\Receipt\\Receipt' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/Receipt.php',
    'YooKassa\\Model\\Receipt\\ReceiptCustomer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptCustomer.php',
    'YooKassa\\Model\\Receipt\\ReceiptCustomerInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptCustomerInterface.php',
    'YooKassa\\Model\\Receipt\\ReceiptInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptInterface.php',
    'YooKassa\\Model\\Receipt\\ReceiptItem' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptItem.php',
    'YooKassa\\Model\\Receipt\\ReceiptItemAmount' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptItemAmount.php',
    'YooKassa\\Model\\Receipt\\ReceiptItemInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptItemInterface.php',
    'YooKassa\\Model\\Receipt\\ReceiptItemMeasure' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptItemMeasure.php',
    'YooKassa\\Model\\Receipt\\ReceiptType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/ReceiptType.php',
    'YooKassa\\Model\\Receipt\\Settlement' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/Settlement.php',
    'YooKassa\\Model\\Receipt\\SettlementInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/SettlementInterface.php',
    'YooKassa\\Model\\Receipt\\SettlementType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/SettlementType.php',
    'YooKassa\\Model\\Receipt\\Supplier' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/Supplier.php',
    'YooKassa\\Model\\Receipt\\SupplierInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Receipt/SupplierInterface.php',
    'YooKassa\\Model\\Refund\\Refund' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/Refund.php',
    'YooKassa\\Model\\Refund\\RefundCancellationDetails' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundCancellationDetails.php',
    'YooKassa\\Model\\Refund\\RefundCancellationDetailsPartyCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundCancellationDetailsPartyCode.php',
    'YooKassa\\Model\\Refund\\RefundCancellationDetailsReasonCode' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundCancellationDetailsReasonCode.php',
    'YooKassa\\Model\\Refund\\RefundInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundInterface.php',
    'YooKassa\\Model\\Refund\\RefundMethodType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundMethodType.php',
    'YooKassa\\Model\\Refund\\RefundMethod\\AbstractRefundMethod' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundMethod/AbstractRefundMethod.php',
    'YooKassa\\Model\\Refund\\RefundMethod\\RefundMethodFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundMethod/RefundMethodFactory.php',
    'YooKassa\\Model\\Refund\\RefundMethod\\RefundMethodSbp' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundMethod/RefundMethodSbp.php',
    'YooKassa\\Model\\Refund\\RefundMethod\\RefundMethodUnknown' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundMethod/RefundMethodUnknown.php',
    'YooKassa\\Model\\Refund\\RefundStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/RefundStatus.php',
    'YooKassa\\Model\\Refund\\Source' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/Source.php',
    'YooKassa\\Model\\Refund\\SourceInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Refund/SourceInterface.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployed' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployed.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedConfirmation' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedConfirmation.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedConfirmationFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedConfirmationFactory.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedConfirmationRedirect' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedConfirmationRedirect.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedConfirmationType' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedConfirmationType.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedInterface.php',
    'YooKassa\\Model\\SelfEmployed\\SelfEmployedStatus' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/SelfEmployed/SelfEmployedStatus.php',
    'YooKassa\\Model\\Settings\\FiscalizationData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Settings/FiscalizationData.php',
    'YooKassa\\Model\\Settings\\FiscalizationProvider' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Settings/FiscalizationProvider.php',
    'YooKassa\\Model\\Settings\\Me' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Settings/Me.php',
    'YooKassa\\Model\\Webhook\\Webhook' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Webhook/Webhook.php',
    'YooKassa\\Model\\Webhook\\WebhookInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Model/Webhook/WebhookInterface.php',
    'YooKassa\\Request\\AbstractListResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/AbstractListResponse.php',
    'YooKassa\\Request\\Deals\\AbstractDealResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/AbstractDealResponse.php',
    'YooKassa\\Request\\Deals\\CreateDealRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/CreateDealRequest.php',
    'YooKassa\\Request\\Deals\\CreateDealRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/CreateDealRequestBuilder.php',
    'YooKassa\\Request\\Deals\\CreateDealRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/CreateDealRequestInterface.php',
    'YooKassa\\Request\\Deals\\CreateDealRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/CreateDealRequestSerializer.php',
    'YooKassa\\Request\\Deals\\CreateDealResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/CreateDealResponse.php',
    'YooKassa\\Request\\Deals\\DealResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealResponse.php',
    'YooKassa\\Request\\Deals\\DealsRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealsRequest.php',
    'YooKassa\\Request\\Deals\\DealsRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealsRequestBuilder.php',
    'YooKassa\\Request\\Deals\\DealsRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealsRequestInterface.php',
    'YooKassa\\Request\\Deals\\DealsRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealsRequestSerializer.php',
    'YooKassa\\Request\\Deals\\DealsResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Deals/DealsResponse.php',
    'YooKassa\\Request\\Payments\\AbstractPaymentRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/AbstractPaymentRequest.php',
    'YooKassa\\Request\\Payments\\AbstractPaymentRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/AbstractPaymentRequestBuilder.php',
    'YooKassa\\Request\\Payments\\AbstractPaymentResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/AbstractPaymentResponse.php',
    'YooKassa\\Request\\Payments\\Airline' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/Airline.php',
    'YooKassa\\Request\\Payments\\AirlineInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/AirlineInterface.php',
    'YooKassa\\Request\\Payments\\CancelResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CancelResponse.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\AbstractConfirmationAttributes' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/AbstractConfirmationAttributes.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesEmbedded' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesEmbedded.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesExternal' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesExternal.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesFactory.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesMobileApplication' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesMobileApplication.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesQr' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesQr.php',
    'YooKassa\\Request\\Payments\\ConfirmationAttributes\\ConfirmationAttributesRedirect' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/ConfirmationAttributes/ConfirmationAttributesRedirect.php',
    'YooKassa\\Request\\Payments\\CreateCaptureRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreateCaptureRequest.php',
    'YooKassa\\Request\\Payments\\CreateCaptureRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreateCaptureRequestBuilder.php',
    'YooKassa\\Request\\Payments\\CreateCaptureRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreateCaptureRequestInterface.php',
    'YooKassa\\Request\\Payments\\CreateCaptureRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreateCaptureRequestSerializer.php',
    'YooKassa\\Request\\Payments\\CreateCaptureResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreateCaptureResponse.php',
    'YooKassa\\Request\\Payments\\CreatePaymentRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreatePaymentRequest.php',
    'YooKassa\\Request\\Payments\\CreatePaymentRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreatePaymentRequestBuilder.php',
    'YooKassa\\Request\\Payments\\CreatePaymentRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreatePaymentRequestInterface.php',
    'YooKassa\\Request\\Payments\\CreatePaymentRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreatePaymentRequestSerializer.php',
    'YooKassa\\Request\\Payments\\CreatePaymentResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/CreatePaymentResponse.php',
    'YooKassa\\Request\\Payments\\FraudData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/FraudData.php',
    'YooKassa\\Request\\Payments\\Leg' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/Leg.php',
    'YooKassa\\Request\\Payments\\LegInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/LegInterface.php',
    'YooKassa\\Request\\Payments\\Locale' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/Locale.php',
    'YooKassa\\Request\\Payments\\MerchantCustomerBankAccount' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/MerchantCustomerBankAccount.php',
    'YooKassa\\Request\\Payments\\Passenger' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/Passenger.php',
    'YooKassa\\Request\\Payments\\PassengerInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PassengerInterface.php',
    'YooKassa\\Request\\Payments\\PaymentData\\AbstractPaymentData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/AbstractPaymentData.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataAlfabank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataAlfabank.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataApplePay' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataApplePay.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataB2bSberbank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataB2bSberbank.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataBankCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataBankCard.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataBankCardCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataBankCardCard.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataCash' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataCash.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataFactory.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataGooglePay' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataGooglePay.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataInstallments' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataInstallments.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataMobileBalance' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataMobileBalance.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataQiwi' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataQiwi.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataSberLoan' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataSberLoan.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataSberbank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataSberbank.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataSbp' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataSbp.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataTinkoffBank' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataTinkoffBank.php',
    'YooKassa\\Request\\Payments\\PaymentData\\PaymentDataYooMoney' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentData/PaymentDataYooMoney.php',
    'YooKassa\\Request\\Payments\\PaymentResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentResponse.php',
    'YooKassa\\Request\\Payments\\PaymentsRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentsRequest.php',
    'YooKassa\\Request\\Payments\\PaymentsRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentsRequestBuilder.php',
    'YooKassa\\Request\\Payments\\PaymentsRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentsRequestInterface.php',
    'YooKassa\\Request\\Payments\\PaymentsRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentsRequestSerializer.php',
    'YooKassa\\Request\\Payments\\PaymentsResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/PaymentsResponse.php',
    'YooKassa\\Request\\Payments\\TransferData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/TransferData.php',
    'YooKassa\\Request\\Payments\\TransferDataInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payments/TransferDataInterface.php',
    'YooKassa\\Request\\Payouts\\AbstractPayoutResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/AbstractPayoutResponse.php',
    'YooKassa\\Request\\Payouts\\CreatePayoutRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/CreatePayoutRequest.php',
    'YooKassa\\Request\\Payouts\\CreatePayoutRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/CreatePayoutRequestBuilder.php',
    'YooKassa\\Request\\Payouts\\CreatePayoutRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/CreatePayoutRequestInterface.php',
    'YooKassa\\Request\\Payouts\\CreatePayoutRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/CreatePayoutRequestSerializer.php',
    'YooKassa\\Request\\Payouts\\CreatePayoutResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/CreatePayoutResponse.php',
    'YooKassa\\Request\\Payouts\\IncomeReceiptData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/IncomeReceiptData.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\AbstractPayoutDestinationData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/AbstractPayoutDestinationData.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\PayoutDestinationDataBankCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/PayoutDestinationDataBankCard.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\PayoutDestinationDataBankCardCard' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/PayoutDestinationDataBankCardCard.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\PayoutDestinationDataFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/PayoutDestinationDataFactory.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\PayoutDestinationDataSbp' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/PayoutDestinationDataSbp.php',
    'YooKassa\\Request\\Payouts\\PayoutDestinationData\\PayoutDestinationDataYooMoney' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutDestinationData/PayoutDestinationDataYooMoney.php',
    'YooKassa\\Request\\Payouts\\PayoutPersonalData' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutPersonalData.php',
    'YooKassa\\Request\\Payouts\\PayoutResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutResponse.php',
    'YooKassa\\Request\\Payouts\\PayoutSelfEmployedInfo' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/PayoutSelfEmployedInfo.php',
    'YooKassa\\Request\\Payouts\\SbpBanksResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Payouts/SbpBanksResponse.php',
    'YooKassa\\Request\\PersonalData\\CreatePayoutStatementRecipientPersonalDataRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/CreatePayoutStatementRecipientPersonalDataRequestBuilder.php',
    'YooKassa\\Request\\PersonalData\\CreatePersonalDataRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/CreatePersonalDataRequestInterface.php',
    'YooKassa\\Request\\PersonalData\\CreateSbpPayoutRecipientPersonalDataRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/CreateSbpPayoutRecipientPersonalDataRequestBuilder.php',
    'YooKassa\\Request\\PersonalData\\PersonalDataResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/PersonalDataResponse.php',
    'YooKassa\\Request\\PersonalData\\PersonalDataType\\AbstractPersonalDataRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/PersonalDataType/AbstractPersonalDataRequest.php',
    'YooKassa\\Request\\PersonalData\\PersonalDataType\\PayoutStatementRecipientPersonalDataRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/PersonalDataType/PayoutStatementRecipientPersonalDataRequest.php',
    'YooKassa\\Request\\PersonalData\\PersonalDataType\\RecipientPersonalDataRequestFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/PersonalDataType/RecipientPersonalDataRequestFactory.php',
    'YooKassa\\Request\\PersonalData\\PersonalDataType\\SbpPayoutRecipientPersonalDataRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/PersonalData/PersonalDataType/SbpPayoutRecipientPersonalDataRequest.php',
    'YooKassa\\Request\\Receipts\\AbstractReceiptResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/AbstractReceiptResponse.php',
    'YooKassa\\Request\\Receipts\\CreatePostReceiptRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/CreatePostReceiptRequest.php',
    'YooKassa\\Request\\Receipts\\CreatePostReceiptRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/CreatePostReceiptRequestBuilder.php',
    'YooKassa\\Request\\Receipts\\CreatePostReceiptRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/CreatePostReceiptRequestInterface.php',
    'YooKassa\\Request\\Receipts\\CreatePostReceiptRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/CreatePostReceiptRequestSerializer.php',
    'YooKassa\\Request\\Receipts\\PaymentReceiptResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/PaymentReceiptResponse.php',
    'YooKassa\\Request\\Receipts\\ReceiptResponseFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptResponseFactory.php',
    'YooKassa\\Request\\Receipts\\ReceiptResponseInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptResponseInterface.php',
    'YooKassa\\Request\\Receipts\\ReceiptResponseItem' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptResponseItem.php',
    'YooKassa\\Request\\Receipts\\ReceiptResponseItemInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptResponseItemInterface.php',
    'YooKassa\\Request\\Receipts\\ReceiptsRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptsRequest.php',
    'YooKassa\\Request\\Receipts\\ReceiptsRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptsRequestBuilder.php',
    'YooKassa\\Request\\Receipts\\ReceiptsRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptsRequestInterface.php',
    'YooKassa\\Request\\Receipts\\ReceiptsRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptsRequestSerializer.php',
    'YooKassa\\Request\\Receipts\\ReceiptsResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/ReceiptsResponse.php',
    'YooKassa\\Request\\Receipts\\RefundReceiptResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/RefundReceiptResponse.php',
    'YooKassa\\Request\\Receipts\\SimpleReceiptResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Receipts/SimpleReceiptResponse.php',
    'YooKassa\\Request\\Refunds\\AbstractRefundResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/AbstractRefundResponse.php',
    'YooKassa\\Request\\Refunds\\CreateRefundRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/CreateRefundRequest.php',
    'YooKassa\\Request\\Refunds\\CreateRefundRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/CreateRefundRequestBuilder.php',
    'YooKassa\\Request\\Refunds\\CreateRefundRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/CreateRefundRequestInterface.php',
    'YooKassa\\Request\\Refunds\\CreateRefundRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/CreateRefundRequestSerializer.php',
    'YooKassa\\Request\\Refunds\\CreateRefundResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/CreateRefundResponse.php',
    'YooKassa\\Request\\Refunds\\RefundResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundResponse.php',
    'YooKassa\\Request\\Refunds\\RefundsRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundsRequest.php',
    'YooKassa\\Request\\Refunds\\RefundsRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundsRequestBuilder.php',
    'YooKassa\\Request\\Refunds\\RefundsRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundsRequestInterface.php',
    'YooKassa\\Request\\Refunds\\RefundsRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundsRequestSerializer.php',
    'YooKassa\\Request\\Refunds\\RefundsResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Refunds/RefundsResponse.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequest' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequest.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestBuilder' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestBuilder.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestConfirmation' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestConfirmation.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestConfirmationFactory' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestConfirmationFactory.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestConfirmationRedirect' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestConfirmationRedirect.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestInterface' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestInterface.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedRequestSerializer' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedRequestSerializer.php',
    'YooKassa\\Request\\SelfEmployed\\SelfEmployedResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/SelfEmployed/SelfEmployedResponse.php',
    'YooKassa\\Request\\Webhook\\WebhookListResponse' => $vendorDir . '/yoomoney/yookassa-sdk-php/lib/Request/Webhook/WebhookListResponse.php',
    'YooKassa\\Validator\\Constraints\\AbstractComparison' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/AbstractComparison.php',
    'YooKassa\\Validator\\Constraints\\AbstractComparisonValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/AbstractComparisonValidator.php',
    'YooKassa\\Validator\\Constraints\\AbstractConstraint' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/AbstractConstraint.php',
    'YooKassa\\Validator\\Constraints\\AllType' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/AllType.php',
    'YooKassa\\Validator\\Constraints\\AllTypeValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/AllTypeValidator.php',
    'YooKassa\\Validator\\Constraints\\Choice' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Choice.php',
    'YooKassa\\Validator\\Constraints\\ChoiceValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/ChoiceValidator.php',
    'YooKassa\\Validator\\Constraints\\ConstraintValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/ConstraintValidator.php',
    'YooKassa\\Validator\\Constraints\\Count' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Count.php',
    'YooKassa\\Validator\\Constraints\\CountValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/CountValidator.php',
    'YooKassa\\Validator\\Constraints\\Date' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Date.php',
    'YooKassa\\Validator\\Constraints\\DateTime' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/DateTime.php',
    'YooKassa\\Validator\\Constraints\\DateTimeValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/DateTimeValidator.php',
    'YooKassa\\Validator\\Constraints\\DateValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/DateValidator.php',
    'YooKassa\\Validator\\Constraints\\Email' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Email.php',
    'YooKassa\\Validator\\Constraints\\EmailValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/EmailValidator.php',
    'YooKassa\\Validator\\Constraints\\GreaterThan' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/GreaterThan.php',
    'YooKassa\\Validator\\Constraints\\GreaterThanOrEqual' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/GreaterThanOrEqual.php',
    'YooKassa\\Validator\\Constraints\\GreaterThanOrEqualValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/GreaterThanOrEqualValidator.php',
    'YooKassa\\Validator\\Constraints\\GreaterThanValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/GreaterThanValidator.php',
    'YooKassa\\Validator\\Constraints\\Ip' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Ip.php',
    'YooKassa\\Validator\\Constraints\\IpValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/IpValidator.php',
    'YooKassa\\Validator\\Constraints\\Json' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Json.php',
    'YooKassa\\Validator\\Constraints\\JsonValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/JsonValidator.php',
    'YooKassa\\Validator\\Constraints\\Length' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Length.php',
    'YooKassa\\Validator\\Constraints\\LengthValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/LengthValidator.php',
    'YooKassa\\Validator\\Constraints\\LessThan' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/LessThan.php',
    'YooKassa\\Validator\\Constraints\\LessThanOrEqual' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/LessThanOrEqual.php',
    'YooKassa\\Validator\\Constraints\\LessThanOrEqualValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/LessThanOrEqualValidator.php',
    'YooKassa\\Validator\\Constraints\\LessThanValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/LessThanValidator.php',
    'YooKassa\\Validator\\Constraints\\NotBlank' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/NotBlank.php',
    'YooKassa\\Validator\\Constraints\\NotBlankValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/NotBlankValidator.php',
    'YooKassa\\Validator\\Constraints\\NotNull' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/NotNull.php',
    'YooKassa\\Validator\\Constraints\\NotNullValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/NotNullValidator.php',
    'YooKassa\\Validator\\Constraints\\Regex' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Regex.php',
    'YooKassa\\Validator\\Constraints\\RegexValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/RegexValidator.php',
    'YooKassa\\Validator\\Constraints\\Time' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Time.php',
    'YooKassa\\Validator\\Constraints\\TimeValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/TimeValidator.php',
    'YooKassa\\Validator\\Constraints\\Type' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Type.php',
    'YooKassa\\Validator\\Constraints\\TypeValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/TypeValidator.php',
    'YooKassa\\Validator\\Constraints\\Url' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Url.php',
    'YooKassa\\Validator\\Constraints\\UrlValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/UrlValidator.php',
    'YooKassa\\Validator\\Constraints\\Valid' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/Valid.php',
    'YooKassa\\Validator\\Constraints\\ValidValidator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Constraints/ValidValidator.php',
    'YooKassa\\Validator\\Exceptions\\EmptyPropertyValueException' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Exceptions/EmptyPropertyValueException.php',
    'YooKassa\\Validator\\Exceptions\\InvalidPropertyException' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Exceptions/InvalidPropertyException.php',
    'YooKassa\\Validator\\Exceptions\\InvalidPropertyValueException' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Exceptions/InvalidPropertyValueException.php',
    'YooKassa\\Validator\\Exceptions\\InvalidPropertyValueTypeException' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Exceptions/InvalidPropertyValueTypeException.php',
    'YooKassa\\Validator\\Exceptions\\ValidatorParameterException' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Exceptions/ValidatorParameterException.php',
    'YooKassa\\Validator\\Validator' => $vendorDir . '/yoomoney/yookassa-sdk-validator/src/Validator.php',
    'ZipStream\\CentralDirectoryFileHeader' => $vendorDir . '/maennchen/zipstream-php/src/CentralDirectoryFileHeader.php',
    'ZipStream\\CompressionMethod' => $vendorDir . '/maennchen/zipstream-php/src/CompressionMethod.php',
    'ZipStream\\DataDescriptor' => $vendorDir . '/maennchen/zipstream-php/src/DataDescriptor.php',
    'ZipStream\\EndOfCentralDirectory' => $vendorDir . '/maennchen/zipstream-php/src/EndOfCentralDirectory.php',
    'ZipStream\\Exception' => $vendorDir . '/maennchen/zipstream-php/src/Exception.php',
    'ZipStream\\Exception\\DosTimeOverflowException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/DosTimeOverflowException.php',
    'ZipStream\\Exception\\FileNotFoundException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/FileNotFoundException.php',
    'ZipStream\\Exception\\FileNotReadableException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/FileNotReadableException.php',
    'ZipStream\\Exception\\FileSizeIncorrectException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/FileSizeIncorrectException.php',
    'ZipStream\\Exception\\OverflowException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/OverflowException.php',
    'ZipStream\\Exception\\ResourceActionException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/ResourceActionException.php',
    'ZipStream\\Exception\\SimulationFileUnknownException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/SimulationFileUnknownException.php',
    'ZipStream\\Exception\\StreamNotReadableException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/StreamNotReadableException.php',
    'ZipStream\\Exception\\StreamNotSeekableException' => $vendorDir . '/maennchen/zipstream-php/src/Exception/StreamNotSeekableException.php',
    'ZipStream\\File' => $vendorDir . '/maennchen/zipstream-php/src/File.php',
    'ZipStream\\GeneralPurposeBitFlag' => $vendorDir . '/maennchen/zipstream-php/src/GeneralPurposeBitFlag.php',
    'ZipStream\\LocalFileHeader' => $vendorDir . '/maennchen/zipstream-php/src/LocalFileHeader.php',
    'ZipStream\\OperationMode' => $vendorDir . '/maennchen/zipstream-php/src/OperationMode.php',
    'ZipStream\\PackField' => $vendorDir . '/maennchen/zipstream-php/src/PackField.php',
    'ZipStream\\Time' => $vendorDir . '/maennchen/zipstream-php/src/Time.php',
    'ZipStream\\Version' => $vendorDir . '/maennchen/zipstream-php/src/Version.php',
    'ZipStream\\Zip64\\DataDescriptor' => $vendorDir . '/maennchen/zipstream-php/src/Zip64/DataDescriptor.php',
    'ZipStream\\Zip64\\EndOfCentralDirectory' => $vendorDir . '/maennchen/zipstream-php/src/Zip64/EndOfCentralDirectory.php',
    'ZipStream\\Zip64\\EndOfCentralDirectoryLocator' => $vendorDir . '/maennchen/zipstream-php/src/Zip64/EndOfCentralDirectoryLocator.php',
    'ZipStream\\Zip64\\ExtendedInformationExtraField' => $vendorDir . '/maennchen/zipstream-php/src/Zip64/ExtendedInformationExtraField.php',
    'ZipStream\\ZipStream' => $vendorDir . '/maennchen/zipstream-php/src/ZipStream.php',
    'ZipStream\\Zs\\ExtendedInformationExtraField' => $vendorDir . '/maennchen/zipstream-php/src/Zs/ExtendedInformationExtraField.php',
    'net\\authorize\\api\\constants\\ANetEnvironment' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/constants/ANetEnvironment.php',
    'net\\authorize\\api\\contract\\v1\\ANetApiRequestType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ANetApiRequestType.php',
    'net\\authorize\\api\\contract\\v1\\ANetApiResponseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ANetApiResponseType.php',
    'net\\authorize\\api\\contract\\v1\\ARBCancelSubscriptionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBCancelSubscriptionRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBCancelSubscriptionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBCancelSubscriptionResponse.php',
    'net\\authorize\\api\\contract\\v1\\ARBCreateSubscriptionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBCreateSubscriptionRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBCreateSubscriptionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBCreateSubscriptionResponse.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionListRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionListRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionListResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionListResponse.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionListSortingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionListSortingType.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionResponse.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionStatusRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionStatusRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBGetSubscriptionStatusResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBGetSubscriptionStatusResponse.php',
    'net\\authorize\\api\\contract\\v1\\ARBSubscriptionMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBSubscriptionMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\ARBSubscriptionType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBSubscriptionType.php',
    'net\\authorize\\api\\contract\\v1\\ARBUpdateSubscriptionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBUpdateSubscriptionRequest.php',
    'net\\authorize\\api\\contract\\v1\\ARBUpdateSubscriptionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ARBUpdateSubscriptionResponse.php',
    'net\\authorize\\api\\contract\\v1\\ArbTransactionType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ArbTransactionType.php',
    'net\\authorize\\api\\contract\\v1\\ArrayOfSettingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ArrayOfSettingType.php',
    'net\\authorize\\api\\contract\\v1\\AuDeleteType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuDeleteType.php',
    'net\\authorize\\api\\contract\\v1\\AuDetailsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuDetailsType.php',
    'net\\authorize\\api\\contract\\v1\\AuResponseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuResponseType.php',
    'net\\authorize\\api\\contract\\v1\\AuUpdateType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuUpdateType.php',
    'net\\authorize\\api\\contract\\v1\\AuthenticateTestRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuthenticateTestRequest.php',
    'net\\authorize\\api\\contract\\v1\\AuthenticateTestResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuthenticateTestResponse.php',
    'net\\authorize\\api\\contract\\v1\\AuthorizationIndicatorType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/AuthorizationIndicatorType.php',
    'net\\authorize\\api\\contract\\v1\\BankAccountMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/BankAccountMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\BankAccountType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/BankAccountType.php',
    'net\\authorize\\api\\contract\\v1\\BatchDetailsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/BatchDetailsType.php',
    'net\\authorize\\api\\contract\\v1\\BatchStatisticType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/BatchStatisticType.php',
    'net\\authorize\\api\\contract\\v1\\CardArtType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CardArtType.php',
    'net\\authorize\\api\\contract\\v1\\CcAuthenticationType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CcAuthenticationType.php',
    'net\\authorize\\api\\contract\\v1\\ContactDetailType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ContactDetailType.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerPaymentProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerPaymentProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerPaymentProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerPaymentProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerProfileFromTransactionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerProfileFromTransactionRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerProfileTransactionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerProfileTransactionRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerProfileTransactionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerProfileTransactionResponse.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerShippingAddressRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerShippingAddressRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateCustomerShippingAddressResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateCustomerShippingAddressResponse.php',
    'net\\authorize\\api\\contract\\v1\\CreateProfileResponseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateProfileResponseType.php',
    'net\\authorize\\api\\contract\\v1\\CreateTransactionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateTransactionRequest.php',
    'net\\authorize\\api\\contract\\v1\\CreateTransactionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreateTransactionResponse.php',
    'net\\authorize\\api\\contract\\v1\\CreditCardMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreditCardMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\CreditCardSimpleType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreditCardSimpleType.php',
    'net\\authorize\\api\\contract\\v1\\CreditCardTrackType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreditCardTrackType.php',
    'net\\authorize\\api\\contract\\v1\\CreditCardType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CreditCardType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerAddressExType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerAddressExType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerAddressType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerAddressType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerDataType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerDataType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileBaseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileBaseType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileExType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileExType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileListItemType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileListItemType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileSortingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileSortingType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerPaymentProfileType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerPaymentProfileType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileBaseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileBaseType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileExType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileExType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileIdType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileIdType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileInfoExType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileInfoExType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfilePaymentType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfilePaymentType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileSummaryType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileSummaryType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerProfileType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerProfileType.php',
    'net\\authorize\\api\\contract\\v1\\CustomerType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/CustomerType.php',
    'net\\authorize\\api\\contract\\v1\\DecryptPaymentDataRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DecryptPaymentDataRequest.php',
    'net\\authorize\\api\\contract\\v1\\DecryptPaymentDataResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DecryptPaymentDataResponse.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerPaymentProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerPaymentProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerPaymentProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerPaymentProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerShippingAddressRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerShippingAddressRequest.php',
    'net\\authorize\\api\\contract\\v1\\DeleteCustomerShippingAddressResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DeleteCustomerShippingAddressResponse.php',
    'net\\authorize\\api\\contract\\v1\\DriversLicenseMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DriversLicenseMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\DriversLicenseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/DriversLicenseType.php',
    'net\\authorize\\api\\contract\\v1\\EmailSettingsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/EmailSettingsType.php',
    'net\\authorize\\api\\contract\\v1\\EmvTagType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/EmvTagType.php',
    'net\\authorize\\api\\contract\\v1\\EncryptedTrackDataType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/EncryptedTrackDataType.php',
    'net\\authorize\\api\\contract\\v1\\EnumCollection' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/EnumCollection.php',
    'net\\authorize\\api\\contract\\v1\\ErrorResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ErrorResponse.php',
    'net\\authorize\\api\\contract\\v1\\ExtendedAmountType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ExtendedAmountType.php',
    'net\\authorize\\api\\contract\\v1\\FDSFilterType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/FDSFilterType.php',
    'net\\authorize\\api\\contract\\v1\\FingerPrintType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/FingerPrintType.php',
    'net\\authorize\\api\\contract\\v1\\FraudInformationType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/FraudInformationType.php',
    'net\\authorize\\api\\contract\\v1\\GetAUJobDetailsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetAUJobDetailsRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetAUJobDetailsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetAUJobDetailsResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetAUJobSummaryRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetAUJobSummaryRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetAUJobSummaryResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetAUJobSummaryResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetBatchStatisticsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetBatchStatisticsRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetBatchStatisticsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetBatchStatisticsResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerPaymentProfileListRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerPaymentProfileListRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerPaymentProfileListResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerPaymentProfileListResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerPaymentProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerPaymentProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerPaymentProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerPaymentProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerProfileIdsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerProfileIdsRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerProfileIdsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerProfileIdsResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerShippingAddressRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerShippingAddressRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetCustomerShippingAddressResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetCustomerShippingAddressResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetHostedPaymentPageRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetHostedPaymentPageRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetHostedPaymentPageResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetHostedPaymentPageResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetHostedProfilePageRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetHostedProfilePageRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetHostedProfilePageResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetHostedProfilePageResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetMerchantDetailsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetMerchantDetailsRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetMerchantDetailsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetMerchantDetailsResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetSettledBatchListRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetSettledBatchListRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetSettledBatchListResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetSettledBatchListResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetTransactionDetailsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetTransactionDetailsRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetTransactionDetailsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetTransactionDetailsResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetTransactionListForCustomerRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetTransactionListForCustomerRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetTransactionListRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetTransactionListRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetTransactionListResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetTransactionListResponse.php',
    'net\\authorize\\api\\contract\\v1\\GetUnsettledTransactionListRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetUnsettledTransactionListRequest.php',
    'net\\authorize\\api\\contract\\v1\\GetUnsettledTransactionListResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/GetUnsettledTransactionListResponse.php',
    'net\\authorize\\api\\contract\\v1\\HeldTransactionRequestType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/HeldTransactionRequestType.php',
    'net\\authorize\\api\\contract\\v1\\ImpersonationAuthenticationType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ImpersonationAuthenticationType.php',
    'net\\authorize\\api\\contract\\v1\\IsAliveRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/IsAliveRequest.php',
    'net\\authorize\\api\\contract\\v1\\IsAliveResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/IsAliveResponse.php',
    'net\\authorize\\api\\contract\\v1\\KeyBlockType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyBlockType.php',
    'net\\authorize\\api\\contract\\v1\\KeyManagementSchemeType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyManagementSchemeType.php',
    'net\\authorize\\api\\contract\\v1\\KeyManagementSchemeType\\DUKPTAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyManagementSchemeType/DUKPTAType.php',
    'net\\authorize\\api\\contract\\v1\\KeyManagementSchemeType\\DUKPTAType\\DeviceInfoAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyManagementSchemeType/DUKPTAType/DeviceInfoAType.php',
    'net\\authorize\\api\\contract\\v1\\KeyManagementSchemeType\\DUKPTAType\\EncryptedDataAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyManagementSchemeType/DUKPTAType/EncryptedDataAType.php',
    'net\\authorize\\api\\contract\\v1\\KeyManagementSchemeType\\DUKPTAType\\ModeAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyManagementSchemeType/DUKPTAType/ModeAType.php',
    'net\\authorize\\api\\contract\\v1\\KeyValueType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/KeyValueType.php',
    'net\\authorize\\api\\contract\\v1\\LineItemType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/LineItemType.php',
    'net\\authorize\\api\\contract\\v1\\ListOfAUDetailsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ListOfAUDetailsType.php',
    'net\\authorize\\api\\contract\\v1\\LogoutRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/LogoutRequest.php',
    'net\\authorize\\api\\contract\\v1\\LogoutResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/LogoutResponse.php',
    'net\\authorize\\api\\contract\\v1\\MerchantAuthenticationType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MerchantAuthenticationType.php',
    'net\\authorize\\api\\contract\\v1\\MerchantContactType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MerchantContactType.php',
    'net\\authorize\\api\\contract\\v1\\MessagesType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MessagesType.php',
    'net\\authorize\\api\\contract\\v1\\MessagesType\\MessageAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MessagesType/MessageAType.php',
    'net\\authorize\\api\\contract\\v1\\MobileDeviceLoginRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MobileDeviceLoginRequest.php',
    'net\\authorize\\api\\contract\\v1\\MobileDeviceLoginResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MobileDeviceLoginResponse.php',
    'net\\authorize\\api\\contract\\v1\\MobileDeviceRegistrationRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MobileDeviceRegistrationRequest.php',
    'net\\authorize\\api\\contract\\v1\\MobileDeviceRegistrationResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MobileDeviceRegistrationResponse.php',
    'net\\authorize\\api\\contract\\v1\\MobileDeviceType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/MobileDeviceType.php',
    'net\\authorize\\api\\contract\\v1\\NameAndAddressType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/NameAndAddressType.php',
    'net\\authorize\\api\\contract\\v1\\OpaqueDataType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/OpaqueDataType.php',
    'net\\authorize\\api\\contract\\v1\\OrderExType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/OrderExType.php',
    'net\\authorize\\api\\contract\\v1\\OrderType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/OrderType.php',
    'net\\authorize\\api\\contract\\v1\\OtherTaxType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/OtherTaxType.php',
    'net\\authorize\\api\\contract\\v1\\PagingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PagingType.php',
    'net\\authorize\\api\\contract\\v1\\PayPalType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PayPalType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentDetailsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentDetailsType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentEmvType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentEmvType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentProfileType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentProfileType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentScheduleType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentScheduleType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentScheduleType\\IntervalAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentScheduleType/IntervalAType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentSimpleType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentSimpleType.php',
    'net\\authorize\\api\\contract\\v1\\PaymentType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PaymentType.php',
    'net\\authorize\\api\\contract\\v1\\PermissionType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/PermissionType.php',
    'net\\authorize\\api\\contract\\v1\\ProcessingOptionsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProcessingOptionsType.php',
    'net\\authorize\\api\\contract\\v1\\ProcessorType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProcessorType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransAmountType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransAmountType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransAuthCaptureType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransAuthCaptureType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransAuthOnlyType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransAuthOnlyType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransCaptureOnlyType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransCaptureOnlyType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransOrderType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransOrderType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransPriorAuthCaptureType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransPriorAuthCaptureType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransRefundType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransRefundType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransVoidType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransVoidType.php',
    'net\\authorize\\api\\contract\\v1\\ProfileTransactionType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ProfileTransactionType.php',
    'net\\authorize\\api\\contract\\v1\\ReturnedItemType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ReturnedItemType.php',
    'net\\authorize\\api\\contract\\v1\\SecurePaymentContainerErrorType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SecurePaymentContainerErrorType.php',
    'net\\authorize\\api\\contract\\v1\\SecurePaymentContainerRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SecurePaymentContainerRequest.php',
    'net\\authorize\\api\\contract\\v1\\SecurePaymentContainerResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SecurePaymentContainerResponse.php',
    'net\\authorize\\api\\contract\\v1\\SendCustomerTransactionReceiptRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SendCustomerTransactionReceiptRequest.php',
    'net\\authorize\\api\\contract\\v1\\SendCustomerTransactionReceiptResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SendCustomerTransactionReceiptResponse.php',
    'net\\authorize\\api\\contract\\v1\\SettingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SettingType.php',
    'net\\authorize\\api\\contract\\v1\\SolutionType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SolutionType.php',
    'net\\authorize\\api\\contract\\v1\\SubMerchantType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SubMerchantType.php',
    'net\\authorize\\api\\contract\\v1\\SubscriptionCustomerProfileType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SubscriptionCustomerProfileType.php',
    'net\\authorize\\api\\contract\\v1\\SubscriptionDetailType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SubscriptionDetailType.php',
    'net\\authorize\\api\\contract\\v1\\SubscriptionPaymentType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SubscriptionPaymentType.php',
    'net\\authorize\\api\\contract\\v1\\SubsequentAuthInformationType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/SubsequentAuthInformationType.php',
    'net\\authorize\\api\\contract\\v1\\TokenMaskedType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TokenMaskedType.php',
    'net\\authorize\\api\\contract\\v1\\TransRetailInfoType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransRetailInfoType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionDetailsType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionDetailsType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionDetailsType\\EmvDetailsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionDetailsType/EmvDetailsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionDetailsType\\EmvDetailsAType\\TagAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionDetailsType/EmvDetailsAType/TagAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionListSortingType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionListSortingType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionRequestType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionRequestType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionRequestType\\UserFieldsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionRequestType/UserFieldsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\EmvResponseAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/EmvResponseAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\EmvResponseAType\\TagsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/EmvResponseAType/TagsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\ErrorsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/ErrorsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\ErrorsAType\\ErrorAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/ErrorsAType/ErrorAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\MessagesAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/MessagesAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\MessagesAType\\MessageAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/MessagesAType/MessageAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\PrePaidCardAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/PrePaidCardAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\SecureAcceptanceAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/SecureAcceptanceAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\SplitTenderPaymentsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/SplitTenderPaymentsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\SplitTenderPaymentsAType\\SplitTenderPaymentAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/SplitTenderPaymentsAType/SplitTenderPaymentAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionResponseType\\UserFieldsAType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionResponseType/UserFieldsAType.php',
    'net\\authorize\\api\\contract\\v1\\TransactionSummaryType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/TransactionSummaryType.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerPaymentProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerPaymentProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerPaymentProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerPaymentProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerShippingAddressRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerShippingAddressRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateCustomerShippingAddressResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateCustomerShippingAddressResponse.php',
    'net\\authorize\\api\\contract\\v1\\UpdateHeldTransactionRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateHeldTransactionRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateHeldTransactionResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateHeldTransactionResponse.php',
    'net\\authorize\\api\\contract\\v1\\UpdateMerchantDetailsRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateMerchantDetailsRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateMerchantDetailsResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateMerchantDetailsResponse.php',
    'net\\authorize\\api\\contract\\v1\\UpdateSplitTenderGroupRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateSplitTenderGroupRequest.php',
    'net\\authorize\\api\\contract\\v1\\UpdateSplitTenderGroupResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UpdateSplitTenderGroupResponse.php',
    'net\\authorize\\api\\contract\\v1\\UserFieldType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/UserFieldType.php',
    'net\\authorize\\api\\contract\\v1\\ValidateCustomerPaymentProfileRequest' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ValidateCustomerPaymentProfileRequest.php',
    'net\\authorize\\api\\contract\\v1\\ValidateCustomerPaymentProfileResponse' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/ValidateCustomerPaymentProfileResponse.php',
    'net\\authorize\\api\\contract\\v1\\WebCheckOutDataType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/WebCheckOutDataType.php',
    'net\\authorize\\api\\contract\\v1\\WebCheckOutDataTypeTokenType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/contract/v1/WebCheckOutDataTypeTokenType.php',
    'net\\authorize\\api\\controller\\ARBCancelSubscriptionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBCancelSubscriptionController.php',
    'net\\authorize\\api\\controller\\ARBCreateSubscriptionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBCreateSubscriptionController.php',
    'net\\authorize\\api\\controller\\ARBGetSubscriptionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBGetSubscriptionController.php',
    'net\\authorize\\api\\controller\\ARBGetSubscriptionListController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBGetSubscriptionListController.php',
    'net\\authorize\\api\\controller\\ARBGetSubscriptionStatusController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBGetSubscriptionStatusController.php',
    'net\\authorize\\api\\controller\\ARBUpdateSubscriptionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ARBUpdateSubscriptionController.php',
    'net\\authorize\\api\\controller\\AuthenticateTestController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/AuthenticateTestController.php',
    'net\\authorize\\api\\controller\\CreateCustomerPaymentProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateCustomerPaymentProfileController.php',
    'net\\authorize\\api\\controller\\CreateCustomerProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateCustomerProfileController.php',
    'net\\authorize\\api\\controller\\CreateCustomerProfileFromTransactionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateCustomerProfileFromTransactionController.php',
    'net\\authorize\\api\\controller\\CreateCustomerProfileTransactionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateCustomerProfileTransactionController.php',
    'net\\authorize\\api\\controller\\CreateCustomerShippingAddressController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateCustomerShippingAddressController.php',
    'net\\authorize\\api\\controller\\CreateTransactionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/CreateTransactionController.php',
    'net\\authorize\\api\\controller\\DecryptPaymentDataController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/DecryptPaymentDataController.php',
    'net\\authorize\\api\\controller\\DeleteCustomerPaymentProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/DeleteCustomerPaymentProfileController.php',
    'net\\authorize\\api\\controller\\DeleteCustomerProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/DeleteCustomerProfileController.php',
    'net\\authorize\\api\\controller\\DeleteCustomerShippingAddressController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/DeleteCustomerShippingAddressController.php',
    'net\\authorize\\api\\controller\\GetAUJobDetailsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetAUJobDetailsController.php',
    'net\\authorize\\api\\controller\\GetAUJobSummaryController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetAUJobSummaryController.php',
    'net\\authorize\\api\\controller\\GetBatchStatisticsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetBatchStatisticsController.php',
    'net\\authorize\\api\\controller\\GetCustomerPaymentProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetCustomerPaymentProfileController.php',
    'net\\authorize\\api\\controller\\GetCustomerPaymentProfileListController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetCustomerPaymentProfileListController.php',
    'net\\authorize\\api\\controller\\GetCustomerProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetCustomerProfileController.php',
    'net\\authorize\\api\\controller\\GetCustomerProfileIdsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetCustomerProfileIdsController.php',
    'net\\authorize\\api\\controller\\GetCustomerShippingAddressController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetCustomerShippingAddressController.php',
    'net\\authorize\\api\\controller\\GetHostedPaymentPageController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetHostedPaymentPageController.php',
    'net\\authorize\\api\\controller\\GetHostedProfilePageController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetHostedProfilePageController.php',
    'net\\authorize\\api\\controller\\GetMerchantDetailsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetMerchantDetailsController.php',
    'net\\authorize\\api\\controller\\GetSettledBatchListController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetSettledBatchListController.php',
    'net\\authorize\\api\\controller\\GetTransactionDetailsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetTransactionDetailsController.php',
    'net\\authorize\\api\\controller\\GetTransactionListController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetTransactionListController.php',
    'net\\authorize\\api\\controller\\GetTransactionListForCustomerController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetTransactionListForCustomerController.php',
    'net\\authorize\\api\\controller\\GetUnsettledTransactionListController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/GetUnsettledTransactionListController.php',
    'net\\authorize\\api\\controller\\IsAliveController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/IsAliveController.php',
    'net\\authorize\\api\\controller\\LogoutController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/LogoutController.php',
    'net\\authorize\\api\\controller\\MobileDeviceLoginController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/MobileDeviceLoginController.php',
    'net\\authorize\\api\\controller\\MobileDeviceRegistrationController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/MobileDeviceRegistrationController.php',
    'net\\authorize\\api\\controller\\SecurePaymentContainerController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/SecurePaymentContainerController.php',
    'net\\authorize\\api\\controller\\SendCustomerTransactionReceiptController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/SendCustomerTransactionReceiptController.php',
    'net\\authorize\\api\\controller\\UpdateCustomerPaymentProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateCustomerPaymentProfileController.php',
    'net\\authorize\\api\\controller\\UpdateCustomerProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateCustomerProfileController.php',
    'net\\authorize\\api\\controller\\UpdateCustomerShippingAddressController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateCustomerShippingAddressController.php',
    'net\\authorize\\api\\controller\\UpdateHeldTransactionController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateHeldTransactionController.php',
    'net\\authorize\\api\\controller\\UpdateMerchantDetailsController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateMerchantDetailsController.php',
    'net\\authorize\\api\\controller\\UpdateSplitTenderGroupController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/UpdateSplitTenderGroupController.php',
    'net\\authorize\\api\\controller\\ValidateCustomerPaymentProfileController' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/ValidateCustomerPaymentProfileController.php',
    'net\\authorize\\api\\controller\\base\\ApiOperationBase' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/base/ApiOperationBase.php',
    'net\\authorize\\api\\controller\\base\\IApiOperation' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/api/controller/base/IApiOperation.php',
    'net\\authorize\\util\\ANetSensitiveFields' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/ANetSensitiveFields.php',
    'net\\authorize\\util\\Helpers' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/Helpers.php',
    'net\\authorize\\util\\HttpClient' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/HttpClient.php',
    'net\\authorize\\util\\Log' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/Log.php',
    'net\\authorize\\util\\LogFactory' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/LogFactory.php',
    'net\\authorize\\util\\Mapper' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/Mapper.php',
    'net\\authorize\\util\\MapperObj' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/MapperObj.php',
    'net\\authorize\\util\\SensitiveDataConfigType' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/SensitiveDataConfigType.php',
    'net\\authorize\\util\\SensitiveTag' => $vendorDir . '/authorizenet/authorizenet/lib/net/authorize/util/SensitiveTag.php',
    'phpseclib3\\Common\\Functions\\Strings' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Common/Functions/Strings.php',
    'phpseclib3\\Crypt\\AES' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/AES.php',
    'phpseclib3\\Crypt\\Blowfish' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Blowfish.php',
    'phpseclib3\\Crypt\\ChaCha20' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/ChaCha20.php',
    'phpseclib3\\Crypt\\Common\\AsymmetricKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/AsymmetricKey.php',
    'phpseclib3\\Crypt\\Common\\BlockCipher' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/BlockCipher.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\JWK' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/JWK.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\OpenSSH' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/OpenSSH.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS1.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS8' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS8.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Keys\\PuTTY' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PuTTY.php',
    'phpseclib3\\Crypt\\Common\\Formats\\Signature\\Raw' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Signature/Raw.php',
    'phpseclib3\\Crypt\\Common\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/PrivateKey.php',
    'phpseclib3\\Crypt\\Common\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/PublicKey.php',
    'phpseclib3\\Crypt\\Common\\StreamCipher' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/StreamCipher.php',
    'phpseclib3\\Crypt\\Common\\SymmetricKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/SymmetricKey.php',
    'phpseclib3\\Crypt\\Common\\Traits\\Fingerprint' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/Fingerprint.php',
    'phpseclib3\\Crypt\\Common\\Traits\\PasswordProtected' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/PasswordProtected.php',
    'phpseclib3\\Crypt\\DES' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DES.php',
    'phpseclib3\\Crypt\\DH' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH.php',
    'phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS1.php',
    'phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS8' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS8.php',
    'phpseclib3\\Crypt\\DH\\Parameters' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Parameters.php',
    'phpseclib3\\Crypt\\DH\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/PrivateKey.php',
    'phpseclib3\\Crypt\\DH\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/PublicKey.php',
    'phpseclib3\\Crypt\\DSA' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\OpenSSH' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/OpenSSH.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS1.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS8' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS8.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PuTTY' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PuTTY.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\Raw' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/Raw.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Keys\\XML' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/XML.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Signature\\ASN1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/ASN1.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Signature\\Raw' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/Raw.php',
    'phpseclib3\\Crypt\\DSA\\Formats\\Signature\\SSH2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/SSH2.php',
    'phpseclib3\\Crypt\\DSA\\Parameters' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Parameters.php',
    'phpseclib3\\Crypt\\DSA\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/PrivateKey.php',
    'phpseclib3\\Crypt\\DSA\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/PublicKey.php',
    'phpseclib3\\Crypt\\EC' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\Base' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Base.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\Binary' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Binary.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\KoblitzPrime' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/KoblitzPrime.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\Montgomery' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Montgomery.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\Prime' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Prime.php',
    'phpseclib3\\Crypt\\EC\\BaseCurves\\TwistedEdwards' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/TwistedEdwards.php',
    'phpseclib3\\Crypt\\EC\\Curves\\Curve25519' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve25519.php',
    'phpseclib3\\Crypt\\EC\\Curves\\Curve448' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve448.php',
    'phpseclib3\\Crypt\\EC\\Curves\\Ed25519' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed25519.php',
    'phpseclib3\\Crypt\\EC\\Curves\\Ed448' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed448.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512t1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512t1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistb233' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb233.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistb409' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb409.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistk163' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk163.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistk233' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk233.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistk283' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk283.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistk409' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk409.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistp192' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp192.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistp224' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp224.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistp256' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp256.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistp384' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp384.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistp521' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp521.php',
    'phpseclib3\\Crypt\\EC\\Curves\\nistt571' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistt571.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime192v1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime192v2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime192v3' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v3.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime239v1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime239v2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime239v3' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v3.php',
    'phpseclib3\\Crypt\\EC\\Curves\\prime256v1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime256v1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp112r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp112r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp128r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp128r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp160k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp160r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp160r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp192k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp192r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp224k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp224r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp256k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp256r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp384r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp384r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\secp521r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp521r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect113r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect113r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect131r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect131r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect163k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect163r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect163r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect193r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect193r2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r2.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect233k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect233r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect239k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect239k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect283k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect283r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect409k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect409r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409r1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect571k1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571k1.php',
    'phpseclib3\\Crypt\\EC\\Curves\\sect571r1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571r1.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\Common' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/Common.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\JWK' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/JWK.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPrivate' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPrivate.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPublic' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPublic.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\OpenSSH' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/OpenSSH.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS1.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS8' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS8.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\PuTTY' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PuTTY.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\XML' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/XML.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Keys\\libsodium' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/libsodium.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Signature\\ASN1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/ASN1.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Signature\\IEEE' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/IEEE.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Signature\\Raw' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/Raw.php',
    'phpseclib3\\Crypt\\EC\\Formats\\Signature\\SSH2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/SSH2.php',
    'phpseclib3\\Crypt\\EC\\Parameters' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Parameters.php',
    'phpseclib3\\Crypt\\EC\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/PrivateKey.php',
    'phpseclib3\\Crypt\\EC\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/PublicKey.php',
    'phpseclib3\\Crypt\\Hash' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Hash.php',
    'phpseclib3\\Crypt\\PublicKeyLoader' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/PublicKeyLoader.php',
    'phpseclib3\\Crypt\\RC2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RC2.php',
    'phpseclib3\\Crypt\\RC4' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RC4.php',
    'phpseclib3\\Crypt\\RSA' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\JWK' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/JWK.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\MSBLOB' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/MSBLOB.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\OpenSSH' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/OpenSSH.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS1.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS8' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS8.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PSS' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PSS.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PuTTY' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PuTTY.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\Raw' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/Raw.php',
    'phpseclib3\\Crypt\\RSA\\Formats\\Keys\\XML' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/XML.php',
    'phpseclib3\\Crypt\\RSA\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/PrivateKey.php',
    'phpseclib3\\Crypt\\RSA\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/PublicKey.php',
    'phpseclib3\\Crypt\\Random' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Random.php',
    'phpseclib3\\Crypt\\Rijndael' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Rijndael.php',
    'phpseclib3\\Crypt\\Salsa20' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Salsa20.php',
    'phpseclib3\\Crypt\\TripleDES' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/TripleDES.php',
    'phpseclib3\\Crypt\\Twofish' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Crypt/Twofish.php',
    'phpseclib3\\Exception\\BadConfigurationException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/BadConfigurationException.php',
    'phpseclib3\\Exception\\BadDecryptionException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/BadDecryptionException.php',
    'phpseclib3\\Exception\\BadModeException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/BadModeException.php',
    'phpseclib3\\Exception\\ConnectionClosedException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/ConnectionClosedException.php',
    'phpseclib3\\Exception\\FileNotFoundException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/FileNotFoundException.php',
    'phpseclib3\\Exception\\InconsistentSetupException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/InconsistentSetupException.php',
    'phpseclib3\\Exception\\InsufficientSetupException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/InsufficientSetupException.php',
    'phpseclib3\\Exception\\InvalidPacketLengthException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/InvalidPacketLengthException.php',
    'phpseclib3\\Exception\\NoKeyLoadedException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/NoKeyLoadedException.php',
    'phpseclib3\\Exception\\NoSupportedAlgorithmsException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/NoSupportedAlgorithmsException.php',
    'phpseclib3\\Exception\\TimeoutException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/TimeoutException.php',
    'phpseclib3\\Exception\\UnableToConnectException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/UnableToConnectException.php',
    'phpseclib3\\Exception\\UnsupportedAlgorithmException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedAlgorithmException.php',
    'phpseclib3\\Exception\\UnsupportedCurveException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedCurveException.php',
    'phpseclib3\\Exception\\UnsupportedFormatException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedFormatException.php',
    'phpseclib3\\Exception\\UnsupportedOperationException' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedOperationException.php',
    'phpseclib3\\File\\ANSI' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ANSI.php',
    'phpseclib3\\File\\ASN1' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1.php',
    'phpseclib3\\File\\ASN1\\Element' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Element.php',
    'phpseclib3\\File\\ASN1\\Maps\\AccessDescription' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AccessDescription.php',
    'phpseclib3\\File\\ASN1\\Maps\\AdministrationDomainName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AdministrationDomainName.php',
    'phpseclib3\\File\\ASN1\\Maps\\AlgorithmIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AlgorithmIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\AnotherName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AnotherName.php',
    'phpseclib3\\File\\ASN1\\Maps\\Attribute' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attribute.php',
    'phpseclib3\\File\\ASN1\\Maps\\AttributeType' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeType.php',
    'phpseclib3\\File\\ASN1\\Maps\\AttributeTypeAndValue' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeTypeAndValue.php',
    'phpseclib3\\File\\ASN1\\Maps\\AttributeValue' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeValue.php',
    'phpseclib3\\File\\ASN1\\Maps\\Attributes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attributes.php',
    'phpseclib3\\File\\ASN1\\Maps\\AuthorityInfoAccessSyntax' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityInfoAccessSyntax.php',
    'phpseclib3\\File\\ASN1\\Maps\\AuthorityKeyIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityKeyIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\BaseDistance' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BaseDistance.php',
    'phpseclib3\\File\\ASN1\\Maps\\BasicConstraints' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BasicConstraints.php',
    'phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttribute' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttribute.php',
    'phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttributes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttributes.php',
    'phpseclib3\\File\\ASN1\\Maps\\BuiltInStandardAttributes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInStandardAttributes.php',
    'phpseclib3\\File\\ASN1\\Maps\\CPSuri' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CPSuri.php',
    'phpseclib3\\File\\ASN1\\Maps\\CRLDistributionPoints' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLDistributionPoints.php',
    'phpseclib3\\File\\ASN1\\Maps\\CRLNumber' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLNumber.php',
    'phpseclib3\\File\\ASN1\\Maps\\CRLReason' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLReason.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertPolicyId' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertPolicyId.php',
    'phpseclib3\\File\\ASN1\\Maps\\Certificate' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Certificate.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificateIssuer' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateIssuer.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificateList' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateList.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificatePolicies' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificatePolicies.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificateSerialNumber' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateSerialNumber.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificationRequest' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequest.php',
    'phpseclib3\\File\\ASN1\\Maps\\CertificationRequestInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequestInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\Characteristic_two' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Characteristic_two.php',
    'phpseclib3\\File\\ASN1\\Maps\\CountryName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CountryName.php',
    'phpseclib3\\File\\ASN1\\Maps\\Curve' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Curve.php',
    'phpseclib3\\File\\ASN1\\Maps\\DHParameter' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DHParameter.php',
    'phpseclib3\\File\\ASN1\\Maps\\DSAParams' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAParams.php',
    'phpseclib3\\File\\ASN1\\Maps\\DSAPrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPrivateKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\DSAPublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPublicKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\DigestInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DigestInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\DirectoryString' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DirectoryString.php',
    'phpseclib3\\File\\ASN1\\Maps\\DisplayText' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DisplayText.php',
    'phpseclib3\\File\\ASN1\\Maps\\DistributionPoint' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPoint.php',
    'phpseclib3\\File\\ASN1\\Maps\\DistributionPointName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPointName.php',
    'phpseclib3\\File\\ASN1\\Maps\\DssSigValue' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DssSigValue.php',
    'phpseclib3\\File\\ASN1\\Maps\\ECParameters' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECParameters.php',
    'phpseclib3\\File\\ASN1\\Maps\\ECPoint' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPoint.php',
    'phpseclib3\\File\\ASN1\\Maps\\ECPrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPrivateKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\EDIPartyName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EDIPartyName.php',
    'phpseclib3\\File\\ASN1\\Maps\\EcdsaSigValue' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EcdsaSigValue.php',
    'phpseclib3\\File\\ASN1\\Maps\\EncryptedData' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedData.php',
    'phpseclib3\\File\\ASN1\\Maps\\EncryptedPrivateKeyInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedPrivateKeyInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\ExtKeyUsageSyntax' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtKeyUsageSyntax.php',
    'phpseclib3\\File\\ASN1\\Maps\\Extension' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extension.php',
    'phpseclib3\\File\\ASN1\\Maps\\ExtensionAttribute' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttribute.php',
    'phpseclib3\\File\\ASN1\\Maps\\ExtensionAttributes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttributes.php',
    'phpseclib3\\File\\ASN1\\Maps\\Extensions' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extensions.php',
    'phpseclib3\\File\\ASN1\\Maps\\FieldElement' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldElement.php',
    'phpseclib3\\File\\ASN1\\Maps\\FieldID' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldID.php',
    'phpseclib3\\File\\ASN1\\Maps\\GeneralName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralName.php',
    'phpseclib3\\File\\ASN1\\Maps\\GeneralNames' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralNames.php',
    'phpseclib3\\File\\ASN1\\Maps\\GeneralSubtree' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtree.php',
    'phpseclib3\\File\\ASN1\\Maps\\GeneralSubtrees' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtrees.php',
    'phpseclib3\\File\\ASN1\\Maps\\HashAlgorithm' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HashAlgorithm.php',
    'phpseclib3\\File\\ASN1\\Maps\\HoldInstructionCode' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HoldInstructionCode.php',
    'phpseclib3\\File\\ASN1\\Maps\\InvalidityDate' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/InvalidityDate.php',
    'phpseclib3\\File\\ASN1\\Maps\\IssuerAltName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuerAltName.php',
    'phpseclib3\\File\\ASN1\\Maps\\IssuingDistributionPoint' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuingDistributionPoint.php',
    'phpseclib3\\File\\ASN1\\Maps\\KeyIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\KeyPurposeId' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyPurposeId.php',
    'phpseclib3\\File\\ASN1\\Maps\\KeyUsage' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyUsage.php',
    'phpseclib3\\File\\ASN1\\Maps\\MaskGenAlgorithm' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/MaskGenAlgorithm.php',
    'phpseclib3\\File\\ASN1\\Maps\\Name' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Name.php',
    'phpseclib3\\File\\ASN1\\Maps\\NameConstraints' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NameConstraints.php',
    'phpseclib3\\File\\ASN1\\Maps\\NetworkAddress' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NetworkAddress.php',
    'phpseclib3\\File\\ASN1\\Maps\\NoticeReference' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NoticeReference.php',
    'phpseclib3\\File\\ASN1\\Maps\\NumericUserIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NumericUserIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\ORAddress' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ORAddress.php',
    'phpseclib3\\File\\ASN1\\Maps\\OneAsymmetricKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OneAsymmetricKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\OrganizationName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationName.php',
    'phpseclib3\\File\\ASN1\\Maps\\OrganizationalUnitNames' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationalUnitNames.php',
    'phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfos' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfos.php',
    'phpseclib3\\File\\ASN1\\Maps\\PBEParameter' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBEParameter.php',
    'phpseclib3\\File\\ASN1\\Maps\\PBES2params' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBES2params.php',
    'phpseclib3\\File\\ASN1\\Maps\\PBKDF2params' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBKDF2params.php',
    'phpseclib3\\File\\ASN1\\Maps\\PBMAC1params' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBMAC1params.php',
    'phpseclib3\\File\\ASN1\\Maps\\PKCS9String' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PKCS9String.php',
    'phpseclib3\\File\\ASN1\\Maps\\Pentanomial' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Pentanomial.php',
    'phpseclib3\\File\\ASN1\\Maps\\PersonalName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PersonalName.php',
    'phpseclib3\\File\\ASN1\\Maps\\PolicyInformation' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyInformation.php',
    'phpseclib3\\File\\ASN1\\Maps\\PolicyMappings' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyMappings.php',
    'phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierId' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierId.php',
    'phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\PostalAddress' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PostalAddress.php',
    'phpseclib3\\File\\ASN1\\Maps\\Prime_p' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Prime_p.php',
    'phpseclib3\\File\\ASN1\\Maps\\PrivateDomainName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateDomainName.php',
    'phpseclib3\\File\\ASN1\\Maps\\PrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\PrivateKeyInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\PrivateKeyUsagePeriod' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyUsagePeriod.php',
    'phpseclib3\\File\\ASN1\\Maps\\PublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\PublicKeyAndChallenge' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyAndChallenge.php',
    'phpseclib3\\File\\ASN1\\Maps\\PublicKeyInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\RC2CBCParameter' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RC2CBCParameter.php',
    'phpseclib3\\File\\ASN1\\Maps\\RDNSequence' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RDNSequence.php',
    'phpseclib3\\File\\ASN1\\Maps\\RSAPrivateKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPrivateKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\RSAPublicKey' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPublicKey.php',
    'phpseclib3\\File\\ASN1\\Maps\\RSASSA_PSS_params' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSASSA_PSS_params.php',
    'phpseclib3\\File\\ASN1\\Maps\\ReasonFlags' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ReasonFlags.php',
    'phpseclib3\\File\\ASN1\\Maps\\RelativeDistinguishedName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RelativeDistinguishedName.php',
    'phpseclib3\\File\\ASN1\\Maps\\RevokedCertificate' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RevokedCertificate.php',
    'phpseclib3\\File\\ASN1\\Maps\\SignedPublicKeyAndChallenge' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SignedPublicKeyAndChallenge.php',
    'phpseclib3\\File\\ASN1\\Maps\\SpecifiedECDomain' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SpecifiedECDomain.php',
    'phpseclib3\\File\\ASN1\\Maps\\SubjectAltName' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectAltName.php',
    'phpseclib3\\File\\ASN1\\Maps\\SubjectDirectoryAttributes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectDirectoryAttributes.php',
    'phpseclib3\\File\\ASN1\\Maps\\SubjectInfoAccessSyntax' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectInfoAccessSyntax.php',
    'phpseclib3\\File\\ASN1\\Maps\\SubjectPublicKeyInfo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectPublicKeyInfo.php',
    'phpseclib3\\File\\ASN1\\Maps\\TBSCertList' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertList.php',
    'phpseclib3\\File\\ASN1\\Maps\\TBSCertificate' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertificate.php',
    'phpseclib3\\File\\ASN1\\Maps\\TerminalIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TerminalIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\Time' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Time.php',
    'phpseclib3\\File\\ASN1\\Maps\\Trinomial' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Trinomial.php',
    'phpseclib3\\File\\ASN1\\Maps\\UniqueIdentifier' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UniqueIdentifier.php',
    'phpseclib3\\File\\ASN1\\Maps\\UserNotice' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UserNotice.php',
    'phpseclib3\\File\\ASN1\\Maps\\Validity' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Validity.php',
    'phpseclib3\\File\\ASN1\\Maps\\netscape_ca_policy_url' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_ca_policy_url.php',
    'phpseclib3\\File\\ASN1\\Maps\\netscape_cert_type' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_cert_type.php',
    'phpseclib3\\File\\ASN1\\Maps\\netscape_comment' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_comment.php',
    'phpseclib3\\File\\X509' => $vendorDir . '/phpseclib/phpseclib/phpseclib/File/X509.php',
    'phpseclib3\\Math\\BigInteger' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Base' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Base.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\BuiltIn' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/BuiltIn.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\DefaultEngine' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/DefaultEngine.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\OpenSSL' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/OpenSSL.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\Barrett' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/Barrett.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\EvalBarrett' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/EvalBarrett.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\Engine' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/Engine.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\GMP' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\GMP\\DefaultEngine' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP/DefaultEngine.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\OpenSSL' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/OpenSSL.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP32' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP32.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP64' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP64.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Base' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Base.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\DefaultEngine' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/DefaultEngine.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Montgomery' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Montgomery.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\OpenSSL' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/OpenSSL.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Barrett' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Barrett.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Classic' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Classic.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\EvalBarrett' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/EvalBarrett.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Montgomery' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Montgomery.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\MontgomeryMult' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/MontgomeryMult.php',
    'phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\PowerOfTwo' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/PowerOfTwo.php',
    'phpseclib3\\Math\\BinaryField' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BinaryField.php',
    'phpseclib3\\Math\\BinaryField\\Integer' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/BinaryField/Integer.php',
    'phpseclib3\\Math\\Common\\FiniteField' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField.php',
    'phpseclib3\\Math\\Common\\FiniteField\\Integer' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField/Integer.php',
    'phpseclib3\\Math\\PrimeField' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/PrimeField.php',
    'phpseclib3\\Math\\PrimeField\\Integer' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Math/PrimeField/Integer.php',
    'phpseclib3\\Net\\SFTP' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Net/SFTP.php',
    'phpseclib3\\Net\\SFTP\\Stream' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Net/SFTP/Stream.php',
    'phpseclib3\\Net\\SSH2' => $vendorDir . '/phpseclib/phpseclib/phpseclib/Net/SSH2.php',
    'phpseclib3\\System\\SSH\\Agent' => $vendorDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Agent.php',
    'phpseclib3\\System\\SSH\\Agent\\Identity' => $vendorDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Agent/Identity.php',
    'phpseclib3\\System\\SSH\\Common\\Traits\\ReadBytes' => $vendorDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Common/Traits/ReadBytes.php',
    'voku\\helper\\ASCII' => $vendorDir . '/voku/portable-ascii/src/voku/helper/ASCII.php',
);
